package androidx.appcompat.widget;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.drawable.Drawable;
import android.util.AttributeSet;
import android.view.View;
import android.view.ViewGroup;
import android.view.accessibility.AccessibilityEvent;
import android.view.accessibility.AccessibilityNodeInfo;
import android.view.inspector.InspectionCompanion;
import android.view.inspector.PropertyMapper;
import android.view.inspector.PropertyReader;
import android.widget.LinearLayout;
import androidx.annotation.GravityInt;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.annotation.RequiresApi;
import androidx.annotation.RestrictTo;
import androidx.appcompat.R;
import androidx.core.view.GravityCompat;
import androidx.core.view.ViewCompat;
import com.google.android.material.badge.BadgeDrawable;
import com.graphisoft.bimxlab.MainActivity;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.util.HashSet;
import java.util.Set;
import java.util.function.IntFunction;

public class LinearLayoutCompat extends ViewGroup {
    private static final String ACCESSIBILITY_CLASS_NAME = "androidx.appcompat.widget.LinearLayoutCompat";
    public static final int HORIZONTAL = 0;
    private static final int INDEX_BOTTOM = 2;
    private static final int INDEX_CENTER_VERTICAL = 0;
    private static final int INDEX_FILL = 3;
    private static final int INDEX_TOP = 1;
    public static final int SHOW_DIVIDER_BEGINNING = 1;
    public static final int SHOW_DIVIDER_END = 4;
    public static final int SHOW_DIVIDER_MIDDLE = 2;
    public static final int SHOW_DIVIDER_NONE = 0;
    public static final int VERTICAL = 1;
    private static final int VERTICAL_GRAVITY_COUNT = 4;
    private boolean mBaselineAligned;
    private int mBaselineAlignedChildIndex;
    private int mBaselineChildTop;
    private Drawable mDivider;
    private int mDividerHeight;
    private int mDividerPadding;
    private int mDividerWidth;
    private int mGravity;
    private int[] mMaxAscent;
    private int[] mMaxDescent;
    private int mOrientation;
    private int mShowDividers;
    private int mTotalLength;
    private boolean mUseLargestChild;
    private float mWeightSum;

    @Retention(RetentionPolicy.SOURCE)
    @RestrictTo({RestrictTo.Scope.LIBRARY_GROUP_PREFIX})
    public @interface DividerMode {
    }

    @RequiresApi(29)
    @RestrictTo({RestrictTo.Scope.LIBRARY})
    public final class InspectionCompanion implements android.view.inspector.InspectionCompanion<LinearLayoutCompat> {
        private int mBaselineAlignedChildIndexId;
        private int mBaselineAlignedId;
        private int mDividerId;
        private int mDividerPaddingId;
        private int mGravityId;
        private int mMeasureWithLargestChildId;
        private int mOrientationId;
        private boolean mPropertiesMapped = false;
        private int mShowDividersId;
        private int mWeightSumId;

        public void mapProperties(@NonNull PropertyMapper propertyMapper) {
            this.mBaselineAlignedId = propertyMapper.mapBoolean("baselineAligned", 16843046);
            this.mBaselineAlignedChildIndexId = propertyMapper.mapInt("baselineAlignedChildIndex", 16843047);
            this.mGravityId = propertyMapper.mapGravity("gravity", 16842927);
            this.mOrientationId = propertyMapper.mapIntEnum("orientation", 16842948, new IntFunction<String>() {
                /* class androidx.appcompat.widget.LinearLayoutCompat.InspectionCompanion.AnonymousClass1 */

                @Override // java.util.function.IntFunction
                public String apply(int i7) {
                    if (i7 != 0) {
                        return i7 != 1 ? String.valueOf(i7) : "vertical";
                    }
                    return "horizontal";
                }
            });
            this.mWeightSumId = propertyMapper.mapFloat("weightSum", 16843048);
            this.mDividerId = propertyMapper.mapObject("divider", R.attr.divider);
            this.mDividerPaddingId = propertyMapper.mapInt("dividerPadding", R.attr.dividerPadding);
            this.mMeasureWithLargestChildId = propertyMapper.mapBoolean("measureWithLargestChild", R.attr.measureWithLargestChild);
            this.mShowDividersId = propertyMapper.mapIntFlag("showDividers", R.attr.showDividers, new IntFunction<Set<String>>() {
                /* class androidx.appcompat.widget.LinearLayoutCompat.InspectionCompanion.AnonymousClass2 */

                @Override // java.util.function.IntFunction
                public Set<String> apply(int i7) {
                    HashSet hashSet = new HashSet();
                    if (i7 == 0) {
                        hashSet.add("none");
                    }
                    if (i7 == 1) {
                        hashSet.add("beginning");
                    }
                    if (i7 == 2) {
                        hashSet.add("middle");
                    }
                    if (i7 == 4) {
                        hashSet.add("end");
                    }
                    return hashSet;
                }
            });
            this.mPropertiesMapped = true;
        }

        public void readProperties(@NonNull LinearLayoutCompat linearLayoutCompat, @NonNull PropertyReader propertyReader) {
            if (this.mPropertiesMapped) {
                propertyReader.readBoolean(this.mBaselineAlignedId, linearLayoutCompat.isBaselineAligned());
                propertyReader.readInt(this.mBaselineAlignedChildIndexId, linearLayoutCompat.getBaselineAlignedChildIndex());
                propertyReader.readGravity(this.mGravityId, linearLayoutCompat.getGravity());
                propertyReader.readIntEnum(this.mOrientationId, linearLayoutCompat.getOrientation());
                propertyReader.readFloat(this.mWeightSumId, linearLayoutCompat.getWeightSum());
                propertyReader.readObject(this.mDividerId, linearLayoutCompat.getDividerDrawable());
                propertyReader.readInt(this.mDividerPaddingId, linearLayoutCompat.getDividerPadding());
                propertyReader.readBoolean(this.mMeasureWithLargestChildId, linearLayoutCompat.isMeasureWithLargestChildEnabled());
                propertyReader.readIntFlag(this.mShowDividersId, linearLayoutCompat.getShowDividers());
                return;
            }
            throw new InspectionCompanion.UninitializedPropertyMapException();
        }
    }

    public static class LayoutParams extends LinearLayout.LayoutParams {
        public LayoutParams(int i7, int i8) {
            super(i7, i8);
        }

        public LayoutParams(int i7, int i8, float f7) {
            super(i7, i8, f7);
        }

        public LayoutParams(Context context, AttributeSet attributeSet) {
            super(context, attributeSet);
        }

        public LayoutParams(ViewGroup.LayoutParams layoutParams) {
            super(layoutParams);
        }

        public LayoutParams(ViewGroup.MarginLayoutParams marginLayoutParams) {
            super(marginLayoutParams);
        }
    }

    @Retention(RetentionPolicy.SOURCE)
    @RestrictTo({RestrictTo.Scope.LIBRARY_GROUP_PREFIX})
    public @interface OrientationMode {
    }

    public LinearLayoutCompat(@NonNull Context context) {
        this(context, null);
    }

    private void forceUniformHeight(int i7, int i8) {
        int makeMeasureSpec = View.MeasureSpec.makeMeasureSpec(getMeasuredHeight(), 1073741824);
        for (int i9 = 0; i9 < i7; i9++) {
            View virtualChildAt = getVirtualChildAt(i9);
            if (virtualChildAt.getVisibility() != 8) {
                LayoutParams layoutParams = (LayoutParams) virtualChildAt.getLayoutParams();
                if (((LinearLayout.LayoutParams) layoutParams).height == -1) {
                    int i10 = ((LinearLayout.LayoutParams) layoutParams).width;
                    ((LinearLayout.LayoutParams) layoutParams).width = virtualChildAt.getMeasuredWidth();
                    measureChildWithMargins(virtualChildAt, i8, 0, makeMeasureSpec, 0);
                    ((LinearLayout.LayoutParams) layoutParams).width = i10;
                }
            }
        }
    }

    private void forceUniformWidth(int i7, int i8) {
        int makeMeasureSpec = View.MeasureSpec.makeMeasureSpec(getMeasuredWidth(), 1073741824);
        for (int i9 = 0; i9 < i7; i9++) {
            View virtualChildAt = getVirtualChildAt(i9);
            if (virtualChildAt.getVisibility() != 8) {
                LayoutParams layoutParams = (LayoutParams) virtualChildAt.getLayoutParams();
                if (((LinearLayout.LayoutParams) layoutParams).width == -1) {
                    int i10 = ((LinearLayout.LayoutParams) layoutParams).height;
                    ((LinearLayout.LayoutParams) layoutParams).height = virtualChildAt.getMeasuredHeight();
                    measureChildWithMargins(virtualChildAt, makeMeasureSpec, 0, i8, 0);
                    ((LinearLayout.LayoutParams) layoutParams).height = i10;
                }
            }
        }
    }

    private void setChildFrame(View view, int i7, int i8, int i9, int i10) {
        view.layout(i7, i8, i9 + i7, i10 + i8);
    }

    /* access modifiers changed from: protected */
    public boolean checkLayoutParams(ViewGroup.LayoutParams layoutParams) {
        return layoutParams instanceof LayoutParams;
    }

    /* access modifiers changed from: package-private */
    public void drawDividersHorizontal(Canvas canvas) {
        int i7;
        int i8;
        int i9;
        int virtualChildCount = getVirtualChildCount();
        boolean isLayoutRtl = ViewUtils.isLayoutRtl(this);
        for (int i10 = 0; i10 < virtualChildCount; i10++) {
            View virtualChildAt = getVirtualChildAt(i10);
            if (!(virtualChildAt == null || virtualChildAt.getVisibility() == 8 || !hasDividerBeforeChildAt(i10))) {
                LayoutParams layoutParams = (LayoutParams) virtualChildAt.getLayoutParams();
                drawVerticalDivider(canvas, isLayoutRtl ? virtualChildAt.getRight() + ((LinearLayout.LayoutParams) layoutParams).rightMargin : (virtualChildAt.getLeft() - ((LinearLayout.LayoutParams) layoutParams).leftMargin) - this.mDividerWidth);
            }
        }
        if (hasDividerBeforeChildAt(virtualChildCount)) {
            View virtualChildAt2 = getVirtualChildAt(virtualChildCount - 1);
            if (virtualChildAt2 != null) {
                LayoutParams layoutParams2 = (LayoutParams) virtualChildAt2.getLayoutParams();
                if (isLayoutRtl) {
                    i9 = virtualChildAt2.getLeft();
                    i8 = ((LinearLayout.LayoutParams) layoutParams2).leftMargin;
                } else {
                    i7 = virtualChildAt2.getRight() + ((LinearLayout.LayoutParams) layoutParams2).rightMargin;
                    drawVerticalDivider(canvas, i7);
                }
            } else if (isLayoutRtl) {
                i7 = getPaddingLeft();
                drawVerticalDivider(canvas, i7);
            } else {
                i9 = getWidth();
                i8 = getPaddingRight();
            }
            i7 = (i9 - i8) - this.mDividerWidth;
            drawVerticalDivider(canvas, i7);
        }
    }

    /* access modifiers changed from: package-private */
    public void drawDividersVertical(Canvas canvas) {
        int virtualChildCount = getVirtualChildCount();
        for (int i7 = 0; i7 < virtualChildCount; i7++) {
            View virtualChildAt = getVirtualChildAt(i7);
            if (!(virtualChildAt == null || virtualChildAt.getVisibility() == 8 || !hasDividerBeforeChildAt(i7))) {
                drawHorizontalDivider(canvas, (virtualChildAt.getTop() - ((LinearLayout.LayoutParams) ((LayoutParams) virtualChildAt.getLayoutParams())).topMargin) - this.mDividerHeight);
            }
        }
        if (hasDividerBeforeChildAt(virtualChildCount)) {
            View virtualChildAt2 = getVirtualChildAt(virtualChildCount - 1);
            drawHorizontalDivider(canvas, virtualChildAt2 == null ? (getHeight() - getPaddingBottom()) - this.mDividerHeight : virtualChildAt2.getBottom() + ((LinearLayout.LayoutParams) ((LayoutParams) virtualChildAt2.getLayoutParams())).bottomMargin);
        }
    }

    /* access modifiers changed from: package-private */
    public void drawHorizontalDivider(Canvas canvas, int i7) {
        this.mDivider.setBounds(getPaddingLeft() + this.mDividerPadding, i7, (getWidth() - getPaddingRight()) - this.mDividerPadding, this.mDividerHeight + i7);
        this.mDivider.draw(canvas);
    }

    /* access modifiers changed from: package-private */
    public void drawVerticalDivider(Canvas canvas, int i7) {
        this.mDivider.setBounds(i7, getPaddingTop() + this.mDividerPadding, this.mDividerWidth + i7, (getHeight() - getPaddingBottom()) - this.mDividerPadding);
        this.mDivider.draw(canvas);
    }

    public int getBaseline() {
        int i7;
        if (this.mBaselineAlignedChildIndex < 0) {
            return super.getBaseline();
        }
        int childCount = getChildCount();
        int i8 = this.mBaselineAlignedChildIndex;
        if (childCount > i8) {
            View childAt = getChildAt(i8);
            int baseline = childAt.getBaseline();
            if (baseline != -1) {
                int i9 = this.mBaselineChildTop;
                if (this.mOrientation == 1 && (i7 = this.mGravity & MainActivity.f15646h) != 48) {
                    if (i7 == 16) {
                        i9 += ((((getBottom() - getTop()) - getPaddingTop()) - getPaddingBottom()) - this.mTotalLength) / 2;
                    } else if (i7 == 80) {
                        i9 = ((getBottom() - getTop()) - getPaddingBottom()) - this.mTotalLength;
                    }
                }
                return i9 + ((LinearLayout.LayoutParams) ((LayoutParams) childAt.getLayoutParams())).topMargin + baseline;
            } else if (this.mBaselineAlignedChildIndex == 0) {
                return -1;
            } else {
                throw new RuntimeException("mBaselineAlignedChildIndex of LinearLayout points to a View that doesn't know how to get its baseline.");
            }
        } else {
            throw new RuntimeException("mBaselineAlignedChildIndex of LinearLayout set to an index that is out of bounds.");
        }
    }

    public int getBaselineAlignedChildIndex() {
        return this.mBaselineAlignedChildIndex;
    }

    /* access modifiers changed from: package-private */
    public int getChildrenSkipCount(View view, int i7) {
        return 0;
    }

    public Drawable getDividerDrawable() {
        return this.mDivider;
    }

    public int getDividerPadding() {
        return this.mDividerPadding;
    }

    @RestrictTo({RestrictTo.Scope.LIBRARY_GROUP_PREFIX})
    public int getDividerWidth() {
        return this.mDividerWidth;
    }

    @GravityInt
    public int getGravity() {
        return this.mGravity;
    }

    /* access modifiers changed from: package-private */
    public int getLocationOffset(View view) {
        return 0;
    }

    /* access modifiers changed from: package-private */
    public int getNextLocationOffset(View view) {
        return 0;
    }

    public int getOrientation() {
        return this.mOrientation;
    }

    public int getShowDividers() {
        return this.mShowDividers;
    }

    /* access modifiers changed from: package-private */
    public View getVirtualChildAt(int i7) {
        return getChildAt(i7);
    }

    /* access modifiers changed from: package-private */
    public int getVirtualChildCount() {
        return getChildCount();
    }

    public float getWeightSum() {
        return this.mWeightSum;
    }

    /* access modifiers changed from: protected */
    @RestrictTo({RestrictTo.Scope.LIBRARY})
    public boolean hasDividerBeforeChildAt(int i7) {
        if (i7 == 0) {
            return (this.mShowDividers & 1) != 0;
        }
        if (i7 == getChildCount()) {
            return (this.mShowDividers & 4) != 0;
        }
        if ((this.mShowDividers & 2) == 0) {
            return false;
        }
        for (int i8 = i7 - 1; i8 >= 0; i8--) {
            if (getChildAt(i8).getVisibility() != 8) {
                return true;
            }
        }
        return false;
    }

    public boolean isBaselineAligned() {
        return this.mBaselineAligned;
    }

    public boolean isMeasureWithLargestChildEnabled() {
        return this.mUseLargestChild;
    }

    /* access modifiers changed from: package-private */
    /* JADX WARNING: Removed duplicated region for block: B:27:0x00af  */
    /* JADX WARNING: Removed duplicated region for block: B:30:0x00b8  */
    /* JADX WARNING: Removed duplicated region for block: B:42:0x00eb  */
    /* JADX WARNING: Removed duplicated region for block: B:45:0x00ff  */
    public void layoutHorizontal(int i7, int i8, int i9, int i10) {
        int i11;
        int i12;
        int i13;
        boolean z7;
        int i14;
        int i15;
        int i16;
        int i17;
        int i18;
        int i19;
        boolean isLayoutRtl = ViewUtils.isLayoutRtl(this);
        int paddingTop = getPaddingTop();
        int i20 = i10 - i8;
        int paddingBottom = i20 - getPaddingBottom();
        int paddingBottom2 = (i20 - paddingTop) - getPaddingBottom();
        int virtualChildCount = getVirtualChildCount();
        int i21 = this.mGravity;
        int i22 = i21 & MainActivity.f15646h;
        boolean z8 = this.mBaselineAligned;
        int[] iArr = this.mMaxAscent;
        int[] iArr2 = this.mMaxDescent;
        int absoluteGravity = GravityCompat.getAbsoluteGravity(8388615 & i21, ViewCompat.getLayoutDirection(this));
        boolean z9 = true;
        int paddingLeft = absoluteGravity != 1 ? absoluteGravity != 5 ? getPaddingLeft() : ((getPaddingLeft() + i9) - i7) - this.mTotalLength : getPaddingLeft() + (((i9 - i7) - this.mTotalLength) / 2);
        if (isLayoutRtl) {
            i12 = virtualChildCount - 1;
            i11 = -1;
        } else {
            i12 = 0;
            i11 = 1;
        }
        int i23 = 0;
        while (i23 < virtualChildCount) {
            int i24 = i12 + (i11 * i23);
            View virtualChildAt = getVirtualChildAt(i24);
            if (virtualChildAt == null) {
                paddingLeft += measureNullChild(i24);
                z7 = z9;
                i13 = paddingTop;
                i15 = virtualChildCount;
                i14 = i22;
            } else if (virtualChildAt.getVisibility() != 8) {
                int measuredWidth = virtualChildAt.getMeasuredWidth();
                int measuredHeight = virtualChildAt.getMeasuredHeight();
                LayoutParams layoutParams = (LayoutParams) virtualChildAt.getLayoutParams();
                if (z8) {
                    i15 = virtualChildCount;
                    if (((LinearLayout.LayoutParams) layoutParams).height != -1) {
                        i16 = virtualChildAt.getBaseline();
                        i17 = ((LinearLayout.LayoutParams) layoutParams).gravity;
                        if (i17 < 0) {
                            i17 = i22;
                        }
                        i18 = i17 & MainActivity.f15646h;
                        i14 = i22;
                        if (i18 == 16) {
                            if (i18 == 48) {
                                i19 = ((LinearLayout.LayoutParams) layoutParams).topMargin + paddingTop;
                                if (i16 != -1) {
                                    z7 = true;
                                    i19 += iArr[1] - i16;
                                }
                            } else if (i18 != 80) {
                                i19 = paddingTop;
                            } else {
                                i19 = (paddingBottom - measuredHeight) - ((LinearLayout.LayoutParams) layoutParams).bottomMargin;
                                if (i16 != -1) {
                                    i19 -= iArr2[2] - (virtualChildAt.getMeasuredHeight() - i16);
                                }
                            }
                            z7 = true;
                        } else {
                            z7 = true;
                            i19 = ((((paddingBottom2 - measuredHeight) / 2) + paddingTop) + ((LinearLayout.LayoutParams) layoutParams).topMargin) - ((LinearLayout.LayoutParams) layoutParams).bottomMargin;
                        }
                        if (hasDividerBeforeChildAt(i24)) {
                            paddingLeft += this.mDividerWidth;
                        }
                        int i25 = ((LinearLayout.LayoutParams) layoutParams).leftMargin + paddingLeft;
                        i13 = paddingTop;
                        setChildFrame(virtualChildAt, i25 + getLocationOffset(virtualChildAt), i19, measuredWidth, measuredHeight);
                        i23 += getChildrenSkipCount(virtualChildAt, i24);
                        paddingLeft = i25 + measuredWidth + ((LinearLayout.LayoutParams) layoutParams).rightMargin + getNextLocationOffset(virtualChildAt);
                        i23++;
                        virtualChildCount = i15;
                        i22 = i14;
                        z9 = z7;
                        paddingTop = i13;
                    }
                } else {
                    i15 = virtualChildCount;
                }
                i16 = -1;
                i17 = ((LinearLayout.LayoutParams) layoutParams).gravity;
                if (i17 < 0) {
                }
                i18 = i17 & MainActivity.f15646h;
                i14 = i22;
                if (i18 == 16) {
                }
                if (hasDividerBeforeChildAt(i24)) {
                }
                int i252 = ((LinearLayout.LayoutParams) layoutParams).leftMargin + paddingLeft;
                i13 = paddingTop;
                setChildFrame(virtualChildAt, i252 + getLocationOffset(virtualChildAt), i19, measuredWidth, measuredHeight);
                i23 += getChildrenSkipCount(virtualChildAt, i24);
                paddingLeft = i252 + measuredWidth + ((LinearLayout.LayoutParams) layoutParams).rightMargin + getNextLocationOffset(virtualChildAt);
                i23++;
                virtualChildCount = i15;
                i22 = i14;
                z9 = z7;
                paddingTop = i13;
            } else {
                i13 = paddingTop;
                i15 = virtualChildCount;
                i14 = i22;
                z7 = true;
            }
            i23++;
            virtualChildCount = i15;
            i22 = i14;
            z9 = z7;
            paddingTop = i13;
        }
    }

    /* access modifiers changed from: package-private */
    /* JADX WARNING: Removed duplicated region for block: B:27:0x009d  */
    public void layoutVertical(int i7, int i8, int i9, int i10) {
        int i11;
        int i12;
        int i13;
        int paddingLeft = getPaddingLeft();
        int i14 = i9 - i7;
        int paddingRight = i14 - getPaddingRight();
        int paddingRight2 = (i14 - paddingLeft) - getPaddingRight();
        int virtualChildCount = getVirtualChildCount();
        int i15 = this.mGravity;
        int i16 = i15 & MainActivity.f15646h;
        int i17 = i15 & GravityCompat.RELATIVE_HORIZONTAL_GRAVITY_MASK;
        int paddingTop = i16 != 16 ? i16 != 80 ? getPaddingTop() : ((getPaddingTop() + i10) - i8) - this.mTotalLength : getPaddingTop() + (((i10 - i8) - this.mTotalLength) / 2);
        int i18 = 0;
        while (i18 < virtualChildCount) {
            View virtualChildAt = getVirtualChildAt(i18);
            if (virtualChildAt == null) {
                paddingTop += measureNullChild(i18);
            } else if (virtualChildAt.getVisibility() != 8) {
                int measuredWidth = virtualChildAt.getMeasuredWidth();
                int measuredHeight = virtualChildAt.getMeasuredHeight();
                LayoutParams layoutParams = (LayoutParams) virtualChildAt.getLayoutParams();
                int i19 = ((LinearLayout.LayoutParams) layoutParams).gravity;
                if (i19 < 0) {
                    i19 = i17;
                }
                int absoluteGravity = GravityCompat.getAbsoluteGravity(i19, ViewCompat.getLayoutDirection(this)) & 7;
                if (absoluteGravity == 1) {
                    i13 = ((paddingRight2 - measuredWidth) / 2) + paddingLeft + ((LinearLayout.LayoutParams) layoutParams).leftMargin;
                } else if (absoluteGravity != 5) {
                    i12 = ((LinearLayout.LayoutParams) layoutParams).leftMargin + paddingLeft;
                    if (hasDividerBeforeChildAt(i18)) {
                        paddingTop += this.mDividerHeight;
                    }
                    int i20 = paddingTop + ((LinearLayout.LayoutParams) layoutParams).topMargin;
                    setChildFrame(virtualChildAt, i12, i20 + getLocationOffset(virtualChildAt), measuredWidth, measuredHeight);
                    i18 += getChildrenSkipCount(virtualChildAt, i18);
                    paddingTop = i20 + measuredHeight + ((LinearLayout.LayoutParams) layoutParams).bottomMargin + getNextLocationOffset(virtualChildAt);
                    i11 = 1;
                    i18 += i11;
                } else {
                    i13 = paddingRight - measuredWidth;
                }
                i12 = i13 - ((LinearLayout.LayoutParams) layoutParams).rightMargin;
                if (hasDividerBeforeChildAt(i18)) {
                }
                int i202 = paddingTop + ((LinearLayout.LayoutParams) layoutParams).topMargin;
                setChildFrame(virtualChildAt, i12, i202 + getLocationOffset(virtualChildAt), measuredWidth, measuredHeight);
                i18 += getChildrenSkipCount(virtualChildAt, i18);
                paddingTop = i202 + measuredHeight + ((LinearLayout.LayoutParams) layoutParams).bottomMargin + getNextLocationOffset(virtualChildAt);
                i11 = 1;
                i18 += i11;
            }
            i11 = 1;
            i18 += i11;
        }
    }

    /* access modifiers changed from: package-private */
    public void measureChildBeforeLayout(View view, int i7, int i8, int i9, int i10, int i11) {
        measureChildWithMargins(view, i8, i9, i10, i11);
    }

    /* access modifiers changed from: package-private */
    /* JADX WARNING: Code restructure failed: missing block: B:155:0x03a4, code lost:
        if (r8 > 0) goto L_0x03b2;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:158:0x03af, code lost:
        if (r8 < 0) goto L_0x03b1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:159:0x03b1, code lost:
        r8 = 0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:160:0x03b2, code lost:
        r14.measure(android.view.View.MeasureSpec.makeMeasureSpec(r8, r3), r0);
        r9 = android.view.View.combineMeasuredStates(r9, r14.getMeasuredState() & -16777216);
        r0 = r0;
        r3 = r2;
     */
    /* JADX WARNING: Removed duplicated region for block: B:187:0x043f  */
    /* JADX WARNING: Removed duplicated region for block: B:68:0x0193  */
    /* JADX WARNING: Removed duplicated region for block: B:78:0x01c7  */
    /* JADX WARNING: Removed duplicated region for block: B:81:0x01d2  */
    public void measureHorizontal(int i7, int i8) {
        int i9;
        int i10;
        int i11;
        int i12;
        int i13;
        int i14;
        int i15;
        int i16;
        float f7;
        int i17;
        boolean z7;
        int baseline;
        int i18;
        int i19;
        int i20;
        boolean z8;
        boolean z9;
        int i21;
        int i22;
        int i23;
        View view;
        boolean z10;
        int measuredHeight;
        int baseline2;
        int i24;
        char c7;
        int i25;
        int i26;
        this.mTotalLength = 0;
        int virtualChildCount = getVirtualChildCount();
        int mode = View.MeasureSpec.getMode(i7);
        int mode2 = View.MeasureSpec.getMode(i8);
        if (this.mMaxAscent == null || this.mMaxDescent == null) {
            this.mMaxAscent = new int[4];
            this.mMaxDescent = new int[4];
        }
        int[] iArr = this.mMaxAscent;
        int[] iArr2 = this.mMaxDescent;
        iArr[3] = -1;
        iArr[2] = -1;
        iArr[1] = -1;
        iArr[0] = -1;
        iArr2[3] = -1;
        iArr2[2] = -1;
        iArr2[1] = -1;
        iArr2[0] = -1;
        boolean z11 = this.mBaselineAligned;
        boolean z12 = this.mUseLargestChild;
        int i27 = 1073741824;
        boolean z13 = mode == 1073741824;
        int i28 = 0;
        int i29 = 0;
        int i30 = 0;
        int i31 = 0;
        int i32 = 0;
        boolean z14 = false;
        int i33 = 0;
        boolean z15 = false;
        boolean z16 = true;
        float f8 = 0.0f;
        while (i28 < virtualChildCount) {
            View virtualChildAt = getVirtualChildAt(i28);
            if (virtualChildAt == null) {
                this.mTotalLength += measureNullChild(i28);
            } else if (virtualChildAt.getVisibility() == 8) {
                i28 += getChildrenSkipCount(virtualChildAt, i28);
            } else {
                if (hasDividerBeforeChildAt(i28)) {
                    this.mTotalLength += this.mDividerWidth;
                }
                LayoutParams layoutParams = (LayoutParams) virtualChildAt.getLayoutParams();
                float f9 = ((LinearLayout.LayoutParams) layoutParams).weight;
                float f10 = f8 + f9;
                if (mode == i27 && ((LinearLayout.LayoutParams) layoutParams).width == 0 && f9 > 0.0f) {
                    int i34 = this.mTotalLength;
                    this.mTotalLength = z13 ? i34 + ((LinearLayout.LayoutParams) layoutParams).leftMargin + ((LinearLayout.LayoutParams) layoutParams).rightMargin : Math.max(i34, ((LinearLayout.LayoutParams) layoutParams).leftMargin + i34 + ((LinearLayout.LayoutParams) layoutParams).rightMargin);
                    if (z11) {
                        int makeMeasureSpec = View.MeasureSpec.makeMeasureSpec(0, 0);
                        virtualChildAt.measure(makeMeasureSpec, makeMeasureSpec);
                        i23 = i28;
                        z9 = z12;
                        z8 = z11;
                        view = virtualChildAt;
                    } else {
                        i23 = i28;
                        z9 = z12;
                        z8 = z11;
                        view = virtualChildAt;
                        z14 = true;
                        i22 = 1073741824;
                        if (mode2 == i22 && ((LinearLayout.LayoutParams) layoutParams).height == -1) {
                            z10 = true;
                            z15 = true;
                        } else {
                            z10 = false;
                        }
                        int i35 = ((LinearLayout.LayoutParams) layoutParams).topMargin + ((LinearLayout.LayoutParams) layoutParams).bottomMargin;
                        measuredHeight = view.getMeasuredHeight() + i35;
                        i33 = View.combineMeasuredStates(i33, view.getMeasuredState());
                        if (z8 && (baseline2 = view.getBaseline()) != -1) {
                            i24 = ((LinearLayout.LayoutParams) layoutParams).gravity;
                            if (i24 < 0) {
                                i24 = this.mGravity;
                            }
                            int i36 = (((i24 & MainActivity.f15646h) >> 4) & -2) >> 1;
                            iArr[i36] = Math.max(iArr[i36], baseline2);
                            iArr2[i36] = Math.max(iArr2[i36], measuredHeight - baseline2);
                        }
                        i30 = Math.max(i30, measuredHeight);
                        z16 = !z16 && ((LinearLayout.LayoutParams) layoutParams).height == -1;
                        if (((LinearLayout.LayoutParams) layoutParams).weight <= 0.0f) {
                            if (!z10) {
                                i35 = measuredHeight;
                            }
                            i32 = Math.max(i32, i35);
                        } else {
                            if (!z10) {
                                i35 = measuredHeight;
                            }
                            i31 = Math.max(i31, i35);
                            i32 = i32;
                        }
                        i21 = getChildrenSkipCount(view, i23) + i23;
                        f8 = f10;
                        int i37 = i21 + 1;
                        iArr2 = iArr2;
                        z12 = z9;
                        z11 = z8;
                        i27 = i22;
                        i28 = i37;
                    }
                } else {
                    if (((LinearLayout.LayoutParams) layoutParams).width != 0 || f9 <= 0.0f) {
                        c7 = 65534;
                        i25 = Integer.MIN_VALUE;
                    } else {
                        c7 = 65534;
                        ((LinearLayout.LayoutParams) layoutParams).width = -2;
                        i25 = 0;
                    }
                    i23 = i28;
                    z9 = z12;
                    z8 = z11;
                    measureChildBeforeLayout(virtualChildAt, i23, i7, f10 == 0.0f ? this.mTotalLength : 0, i8, 0);
                    if (i25 != Integer.MIN_VALUE) {
                        ((LinearLayout.LayoutParams) layoutParams).width = i25;
                    }
                    int measuredWidth = virtualChildAt.getMeasuredWidth();
                    if (z13) {
                        view = virtualChildAt;
                        i26 = this.mTotalLength + ((LinearLayout.LayoutParams) layoutParams).leftMargin + measuredWidth + ((LinearLayout.LayoutParams) layoutParams).rightMargin + getNextLocationOffset(view);
                    } else {
                        view = virtualChildAt;
                        int i38 = this.mTotalLength;
                        i26 = Math.max(i38, i38 + measuredWidth + ((LinearLayout.LayoutParams) layoutParams).leftMargin + ((LinearLayout.LayoutParams) layoutParams).rightMargin + getNextLocationOffset(view));
                    }
                    this.mTotalLength = i26;
                    if (z9) {
                        i29 = Math.max(measuredWidth, i29);
                    }
                }
                i22 = 1073741824;
                if (mode2 == i22) {
                }
                z10 = false;
                int i352 = ((LinearLayout.LayoutParams) layoutParams).topMargin + ((LinearLayout.LayoutParams) layoutParams).bottomMargin;
                measuredHeight = view.getMeasuredHeight() + i352;
                i33 = View.combineMeasuredStates(i33, view.getMeasuredState());
                i24 = ((LinearLayout.LayoutParams) layoutParams).gravity;
                if (i24 < 0) {
                }
                int i362 = (((i24 & MainActivity.f15646h) >> 4) & -2) >> 1;
                iArr[i362] = Math.max(iArr[i362], baseline2);
                iArr2[i362] = Math.max(iArr2[i362], measuredHeight - baseline2);
                i30 = Math.max(i30, measuredHeight);
                if (!z16) {
                }
                if (((LinearLayout.LayoutParams) layoutParams).weight <= 0.0f) {
                }
                i21 = getChildrenSkipCount(view, i23) + i23;
                f8 = f10;
                int i372 = i21 + 1;
                iArr2 = iArr2;
                z12 = z9;
                z11 = z8;
                i27 = i22;
                i28 = i372;
            }
            z9 = z12;
            z8 = z11;
            i21 = i28;
            i22 = i27;
            int i3722 = i21 + 1;
            iArr2 = iArr2;
            z12 = z9;
            z11 = z8;
            i27 = i22;
            i28 = i3722;
        }
        if (this.mTotalLength > 0 && hasDividerBeforeChildAt(virtualChildCount)) {
            this.mTotalLength += this.mDividerWidth;
        }
        int i39 = iArr[1];
        if (i39 == -1 && iArr[0] == -1 && iArr[2] == -1 && iArr[3] == -1) {
            i10 = i30;
            i9 = i33;
        } else {
            i9 = i33;
            i10 = Math.max(i30, Math.max(iArr[3], Math.max(iArr[0], Math.max(i39, iArr[2]))) + Math.max(iArr2[3], Math.max(iArr2[0], Math.max(iArr2[1], iArr2[2]))));
        }
        if (z12 && (mode == Integer.MIN_VALUE || mode == 0)) {
            this.mTotalLength = 0;
            int i40 = 0;
            while (i40 < virtualChildCount) {
                View virtualChildAt2 = getVirtualChildAt(i40);
                if (virtualChildAt2 == null) {
                    this.mTotalLength += measureNullChild(i40);
                } else if (virtualChildAt2.getVisibility() == 8) {
                    i40 += getChildrenSkipCount(virtualChildAt2, i40);
                } else {
                    LayoutParams layoutParams2 = (LayoutParams) virtualChildAt2.getLayoutParams();
                    int i41 = this.mTotalLength;
                    if (z13) {
                        this.mTotalLength = i41 + ((LinearLayout.LayoutParams) layoutParams2).leftMargin + i29 + ((LinearLayout.LayoutParams) layoutParams2).rightMargin + getNextLocationOffset(virtualChildAt2);
                    } else {
                        i20 = i10;
                        this.mTotalLength = Math.max(i41, i41 + i29 + ((LinearLayout.LayoutParams) layoutParams2).leftMargin + ((LinearLayout.LayoutParams) layoutParams2).rightMargin + getNextLocationOffset(virtualChildAt2));
                        i40++;
                        i10 = i20;
                    }
                }
                i20 = i10;
                i40++;
                i10 = i20;
            }
        }
        int paddingLeft = this.mTotalLength + getPaddingLeft() + getPaddingRight();
        this.mTotalLength = paddingLeft;
        int resolveSizeAndState = View.resolveSizeAndState(Math.max(paddingLeft, getSuggestedMinimumWidth()), i7, 0);
        int i42 = (16777215 & resolveSizeAndState) - this.mTotalLength;
        if (z14 || (i42 != 0 && f8 > 0.0f)) {
            float f11 = this.mWeightSum;
            if (f11 > 0.0f) {
                f8 = f11;
            }
            iArr[3] = -1;
            iArr[2] = -1;
            iArr[1] = -1;
            iArr[0] = -1;
            iArr2[3] = -1;
            iArr2[2] = -1;
            iArr2[1] = -1;
            iArr2[0] = -1;
            this.mTotalLength = 0;
            int i43 = i31;
            int i44 = -1;
            int i45 = i9;
            int i46 = 0;
            while (i46 < virtualChildCount) {
                View virtualChildAt3 = getVirtualChildAt(i46);
                if (virtualChildAt3 == null || virtualChildAt3.getVisibility() == 8) {
                    i16 = i42;
                    i15 = virtualChildCount;
                } else {
                    LayoutParams layoutParams3 = (LayoutParams) virtualChildAt3.getLayoutParams();
                    float f12 = ((LinearLayout.LayoutParams) layoutParams3).weight;
                    if (f12 > 0.0f) {
                        int i47 = (int) ((((float) i42) * f12) / f8);
                        float f13 = f8 - f12;
                        int i48 = i42 - i47;
                        i15 = virtualChildCount;
                        int childMeasureSpec = ViewGroup.getChildMeasureSpec(i8, getPaddingTop() + getPaddingBottom() + ((LinearLayout.LayoutParams) layoutParams3).topMargin + ((LinearLayout.LayoutParams) layoutParams3).bottomMargin, ((LinearLayout.LayoutParams) layoutParams3).height);
                        if (((LinearLayout.LayoutParams) layoutParams3).width == 0) {
                            i19 = 1073741824;
                            if (mode == 1073741824) {
                            }
                        } else {
                            i19 = 1073741824;
                        }
                        i47 = virtualChildAt3.getMeasuredWidth() + i47;
                    } else {
                        i16 = i42;
                        i15 = virtualChildCount;
                    }
                    int i49 = this.mTotalLength;
                    if (z13) {
                        this.mTotalLength = i49 + virtualChildAt3.getMeasuredWidth() + ((LinearLayout.LayoutParams) layoutParams3).leftMargin + ((LinearLayout.LayoutParams) layoutParams3).rightMargin + getNextLocationOffset(virtualChildAt3);
                        f7 = f8;
                    } else {
                        f7 = f8;
                        this.mTotalLength = Math.max(i49, virtualChildAt3.getMeasuredWidth() + i49 + ((LinearLayout.LayoutParams) layoutParams3).leftMargin + ((LinearLayout.LayoutParams) layoutParams3).rightMargin + getNextLocationOffset(virtualChildAt3));
                    }
                    boolean z17 = mode2 != 1073741824 && ((LinearLayout.LayoutParams) layoutParams3).height == -1;
                    int i50 = ((LinearLayout.LayoutParams) layoutParams3).topMargin + ((LinearLayout.LayoutParams) layoutParams3).bottomMargin;
                    int measuredHeight2 = virtualChildAt3.getMeasuredHeight() + i50;
                    i44 = Math.max(i44, measuredHeight2);
                    if (!z17) {
                        i50 = measuredHeight2;
                    }
                    int max = Math.max(i43, i50);
                    if (z16) {
                        i17 = -1;
                        if (((LinearLayout.LayoutParams) layoutParams3).height == -1) {
                            z7 = true;
                            if (z11 && (baseline = virtualChildAt3.getBaseline()) != i17) {
                                i18 = ((LinearLayout.LayoutParams) layoutParams3).gravity;
                                if (i18 < 0) {
                                    i18 = this.mGravity;
                                }
                                int i51 = (((i18 & MainActivity.f15646h) >> 4) & -2) >> 1;
                                iArr[i51] = Math.max(iArr[i51], baseline);
                                iArr2[i51] = Math.max(iArr2[i51], measuredHeight2 - baseline);
                            }
                            z16 = z7;
                            i43 = max;
                            f8 = f7;
                        }
                    } else {
                        i17 = -1;
                    }
                    z7 = false;
                    i18 = ((LinearLayout.LayoutParams) layoutParams3).gravity;
                    if (i18 < 0) {
                    }
                    int i512 = (((i18 & MainActivity.f15646h) >> 4) & -2) >> 1;
                    iArr[i512] = Math.max(iArr[i512], baseline);
                    iArr2[i512] = Math.max(iArr2[i512], measuredHeight2 - baseline);
                    z16 = z7;
                    i43 = max;
                    f8 = f7;
                }
                i46++;
                i42 = i16;
                virtualChildCount = i15;
            }
            i13 = i8;
            i11 = virtualChildCount;
            this.mTotalLength += getPaddingLeft() + getPaddingRight();
            int i52 = iArr[1];
            i12 = (i52 == -1 && iArr[0] == -1 && iArr[2] == -1 && iArr[3] == -1) ? i44 : Math.max(i44, Math.max(iArr[3], Math.max(iArr[0], Math.max(i52, iArr[2]))) + Math.max(iArr2[3], Math.max(iArr2[0], Math.max(iArr2[1], iArr2[2]))));
            i14 = i43;
            i9 = i45;
        } else {
            i14 = Math.max(i31, i32);
            if (z12 && mode != 1073741824) {
                for (int i53 = 0; i53 < virtualChildCount; i53++) {
                    View virtualChildAt4 = getVirtualChildAt(i53);
                    if (!(virtualChildAt4 == null || virtualChildAt4.getVisibility() == 8 || ((LinearLayout.LayoutParams) ((LayoutParams) virtualChildAt4.getLayoutParams())).weight <= 0.0f)) {
                        virtualChildAt4.measure(View.MeasureSpec.makeMeasureSpec(i29, 1073741824), View.MeasureSpec.makeMeasureSpec(virtualChildAt4.getMeasuredHeight(), 1073741824));
                    }
                }
            }
            i13 = i8;
            i11 = virtualChildCount;
            i12 = i10;
        }
        if (z16 || mode2 == 1073741824) {
            i14 = i12;
        }
        setMeasuredDimension(resolveSizeAndState | (i9 & -16777216), View.resolveSizeAndState(Math.max(i14 + getPaddingTop() + getPaddingBottom(), getSuggestedMinimumHeight()), i13, i9 << 16));
        if (z15) {
            forceUniformHeight(i11, i7);
        }
    }

    /* access modifiers changed from: package-private */
    public int measureNullChild(int i7) {
        return 0;
    }

    /* access modifiers changed from: package-private */
    /* JADX WARNING: Code restructure failed: missing block: B:123:0x02cf, code lost:
        if (r15 > 0) goto L_0x02dd;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:126:0x02da, code lost:
        if (r15 < 0) goto L_0x02dc;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:127:0x02dc, code lost:
        r15 = 0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:128:0x02dd, code lost:
        r13.measure(r0, android.view.View.MeasureSpec.makeMeasureSpec(r15, r10));
        r1 = android.view.View.combineMeasuredStates(r1, r13.getMeasuredState() & androidx.core.view.InputDeviceCompat.SOURCE_ANY);
        r0 = r0;
     */
    /* JADX WARNING: Removed duplicated region for block: B:138:0x031b  */
    public void measureVertical(int i7, int i8) {
        int i9;
        int i10;
        int i11;
        int i12;
        int i13;
        int i14;
        int i15;
        boolean z7;
        int i16;
        int max;
        int i17;
        int i18;
        int i19;
        int i20;
        int i21;
        int i22;
        int i23;
        View view;
        int i24;
        boolean z8;
        int i25;
        int i26;
        this.mTotalLength = 0;
        int virtualChildCount = getVirtualChildCount();
        int mode = View.MeasureSpec.getMode(i7);
        int mode2 = View.MeasureSpec.getMode(i8);
        int i27 = this.mBaselineAlignedChildIndex;
        boolean z9 = this.mUseLargestChild;
        int i28 = 0;
        int i29 = 0;
        int i30 = 0;
        int i31 = 0;
        int i32 = 0;
        int i33 = 0;
        boolean z10 = false;
        boolean z11 = false;
        boolean z12 = true;
        float f7 = 0.0f;
        while (true) {
            int i34 = 8;
            if (i33 < virtualChildCount) {
                View virtualChildAt = getVirtualChildAt(i33);
                if (virtualChildAt == null) {
                    this.mTotalLength += measureNullChild(i33);
                    i17 = virtualChildCount;
                    i18 = mode2;
                    i31 = i31;
                } else if (virtualChildAt.getVisibility() == 8) {
                    i33 += getChildrenSkipCount(virtualChildAt, i33);
                    i17 = virtualChildCount;
                    i31 = i31;
                    i28 = i28;
                    i18 = mode2;
                } else {
                    if (hasDividerBeforeChildAt(i33)) {
                        this.mTotalLength += this.mDividerHeight;
                    }
                    LayoutParams layoutParams = (LayoutParams) virtualChildAt.getLayoutParams();
                    float f8 = ((LinearLayout.LayoutParams) layoutParams).weight;
                    float f9 = f7 + f8;
                    if (mode2 == 1073741824 && ((LinearLayout.LayoutParams) layoutParams).height == 0 && f8 > 0.0f) {
                        int i35 = this.mTotalLength;
                        this.mTotalLength = Math.max(i35, ((LinearLayout.LayoutParams) layoutParams).topMargin + i35 + ((LinearLayout.LayoutParams) layoutParams).bottomMargin);
                        i24 = i30;
                        view = virtualChildAt;
                        i19 = i32;
                        z10 = true;
                        i23 = i28;
                        i20 = i29;
                        i17 = virtualChildCount;
                        i18 = mode2;
                        i21 = i31;
                        i22 = i33;
                    } else {
                        if (((LinearLayout.LayoutParams) layoutParams).height != 0 || f8 <= 0.0f) {
                            i26 = Integer.MIN_VALUE;
                        } else {
                            ((LinearLayout.LayoutParams) layoutParams).height = -2;
                            i26 = 0;
                        }
                        i23 = i28;
                        i20 = i29;
                        i17 = virtualChildCount;
                        i18 = mode2;
                        i21 = i31;
                        i19 = i32;
                        i22 = i33;
                        measureChildBeforeLayout(virtualChildAt, i33, i7, 0, i8, f9 == 0.0f ? this.mTotalLength : 0);
                        if (i26 != Integer.MIN_VALUE) {
                            ((LinearLayout.LayoutParams) layoutParams).height = i26;
                        }
                        int measuredHeight = virtualChildAt.getMeasuredHeight();
                        int i36 = this.mTotalLength;
                        view = virtualChildAt;
                        this.mTotalLength = Math.max(i36, i36 + measuredHeight + ((LinearLayout.LayoutParams) layoutParams).topMargin + ((LinearLayout.LayoutParams) layoutParams).bottomMargin + getNextLocationOffset(view));
                        i24 = z9 ? Math.max(measuredHeight, i30) : i30;
                    }
                    if (i27 >= 0 && i27 == i22 + 1) {
                        this.mBaselineChildTop = this.mTotalLength;
                    }
                    if (i22 >= i27 || ((LinearLayout.LayoutParams) layoutParams).weight <= 0.0f) {
                        if (mode == 1073741824 || ((LinearLayout.LayoutParams) layoutParams).width != -1) {
                            z8 = false;
                        } else {
                            z8 = true;
                            z11 = true;
                        }
                        int i37 = ((LinearLayout.LayoutParams) layoutParams).leftMargin + ((LinearLayout.LayoutParams) layoutParams).rightMargin;
                        int measuredWidth = view.getMeasuredWidth() + i37;
                        int max2 = Math.max(i20, measuredWidth);
                        int combineMeasuredStates = View.combineMeasuredStates(i23, view.getMeasuredState());
                        z12 = z12 && ((LinearLayout.LayoutParams) layoutParams).width == -1;
                        if (((LinearLayout.LayoutParams) layoutParams).weight > 0.0f) {
                            if (!z8) {
                                i37 = measuredWidth;
                            }
                            i31 = Math.max(i21, i37);
                            i25 = i19;
                        } else {
                            if (!z8) {
                                i37 = measuredWidth;
                            }
                            i25 = Math.max(i19, i37);
                            i31 = i21;
                        }
                        i30 = i24;
                        f7 = f9;
                        i32 = i25;
                        i28 = combineMeasuredStates;
                        i33 = getChildrenSkipCount(view, i22) + i22;
                        i29 = max2;
                    } else {
                        throw new RuntimeException("A child of LinearLayout with index less than mBaselineAlignedChildIndex has weight > 0, which won't work.  Either remove the weight, or don't set mBaselineAlignedChildIndex.");
                    }
                }
                i33++;
                mode2 = i18;
                virtualChildCount = i17;
            } else {
                int i38 = i29;
                if (this.mTotalLength > 0) {
                    i9 = virtualChildCount;
                    if (hasDividerBeforeChildAt(i9)) {
                        this.mTotalLength += this.mDividerHeight;
                    }
                } else {
                    i9 = virtualChildCount;
                }
                if (z9 && (mode2 == Integer.MIN_VALUE || mode2 == 0)) {
                    this.mTotalLength = 0;
                    int i39 = 0;
                    while (i39 < i9) {
                        View virtualChildAt2 = getVirtualChildAt(i39);
                        if (virtualChildAt2 == null) {
                            max = this.mTotalLength + measureNullChild(i39);
                        } else if (virtualChildAt2.getVisibility() == i34) {
                            i39 += getChildrenSkipCount(virtualChildAt2, i39);
                            i39++;
                            i34 = 8;
                        } else {
                            LayoutParams layoutParams2 = (LayoutParams) virtualChildAt2.getLayoutParams();
                            int i40 = this.mTotalLength;
                            max = Math.max(i40, i40 + i30 + ((LinearLayout.LayoutParams) layoutParams2).topMargin + ((LinearLayout.LayoutParams) layoutParams2).bottomMargin + getNextLocationOffset(virtualChildAt2));
                        }
                        this.mTotalLength = max;
                        i39++;
                        i34 = 8;
                    }
                }
                int paddingTop = this.mTotalLength + getPaddingTop() + getPaddingBottom();
                this.mTotalLength = paddingTop;
                int resolveSizeAndState = View.resolveSizeAndState(Math.max(paddingTop, getSuggestedMinimumHeight()), i8, 0);
                int i41 = (16777215 & resolveSizeAndState) - this.mTotalLength;
                if (z10 || (i41 != 0 && f7 > 0.0f)) {
                    float f10 = this.mWeightSum;
                    if (f10 > 0.0f) {
                        f7 = f10;
                    }
                    this.mTotalLength = 0;
                    int i42 = i41;
                    int i43 = i32;
                    i11 = i28;
                    int i44 = 0;
                    while (i44 < i9) {
                        View virtualChildAt3 = getVirtualChildAt(i44);
                        if (virtualChildAt3.getVisibility() == 8) {
                            i13 = i42;
                        } else {
                            LayoutParams layoutParams3 = (LayoutParams) virtualChildAt3.getLayoutParams();
                            float f11 = ((LinearLayout.LayoutParams) layoutParams3).weight;
                            if (f11 > 0.0f) {
                                int i45 = (int) ((((float) i42) * f11) / f7);
                                float f12 = f7 - f11;
                                i13 = i42 - i45;
                                int childMeasureSpec = ViewGroup.getChildMeasureSpec(i7, getPaddingLeft() + getPaddingRight() + ((LinearLayout.LayoutParams) layoutParams3).leftMargin + ((LinearLayout.LayoutParams) layoutParams3).rightMargin, ((LinearLayout.LayoutParams) layoutParams3).width);
                                if (((LinearLayout.LayoutParams) layoutParams3).height == 0) {
                                    i16 = 1073741824;
                                    if (mode2 == 1073741824) {
                                    }
                                } else {
                                    i16 = 1073741824;
                                }
                                i45 = virtualChildAt3.getMeasuredHeight() + i45;
                            } else {
                                i13 = i42;
                            }
                            int i46 = ((LinearLayout.LayoutParams) layoutParams3).leftMargin + ((LinearLayout.LayoutParams) layoutParams3).rightMargin;
                            int measuredWidth2 = virtualChildAt3.getMeasuredWidth() + i46;
                            i38 = Math.max(i38, measuredWidth2);
                            if (mode != 1073741824) {
                                i14 = i11;
                                i15 = -1;
                                if (((LinearLayout.LayoutParams) layoutParams3).width == -1) {
                                    z7 = true;
                                    if (!z7) {
                                        i46 = measuredWidth2;
                                    }
                                    int max3 = Math.max(i43, i46);
                                    boolean z13 = !z12 && ((LinearLayout.LayoutParams) layoutParams3).width == i15;
                                    int i47 = this.mTotalLength;
                                    this.mTotalLength = Math.max(i47, virtualChildAt3.getMeasuredHeight() + i47 + ((LinearLayout.LayoutParams) layoutParams3).topMargin + ((LinearLayout.LayoutParams) layoutParams3).bottomMargin + getNextLocationOffset(virtualChildAt3));
                                    z12 = z13;
                                    i11 = i14;
                                    i43 = max3;
                                    f7 = f7;
                                }
                            } else {
                                i14 = i11;
                                i15 = -1;
                            }
                            z7 = false;
                            if (!z7) {
                            }
                            int max32 = Math.max(i43, i46);
                            if (!z12) {
                            }
                            int i472 = this.mTotalLength;
                            this.mTotalLength = Math.max(i472, virtualChildAt3.getMeasuredHeight() + i472 + ((LinearLayout.LayoutParams) layoutParams3).topMargin + ((LinearLayout.LayoutParams) layoutParams3).bottomMargin + getNextLocationOffset(virtualChildAt3));
                            z12 = z13;
                            i11 = i14;
                            i43 = max32;
                            f7 = f7;
                        }
                        i44++;
                        i42 = i13;
                    }
                    i10 = i7;
                    this.mTotalLength += getPaddingTop() + getPaddingBottom();
                    i12 = i43;
                } else {
                    i12 = Math.max(i32, i31);
                    if (z9 && mode2 != 1073741824) {
                        for (int i48 = 0; i48 < i9; i48++) {
                            View virtualChildAt4 = getVirtualChildAt(i48);
                            if (!(virtualChildAt4 == null || virtualChildAt4.getVisibility() == 8 || ((LinearLayout.LayoutParams) ((LayoutParams) virtualChildAt4.getLayoutParams())).weight <= 0.0f)) {
                                virtualChildAt4.measure(View.MeasureSpec.makeMeasureSpec(virtualChildAt4.getMeasuredWidth(), 1073741824), View.MeasureSpec.makeMeasureSpec(i30, 1073741824));
                            }
                        }
                    }
                    i10 = i7;
                    i11 = i28;
                }
                if (z12 || mode == 1073741824) {
                    i12 = i38;
                }
                setMeasuredDimension(View.resolveSizeAndState(Math.max(i12 + getPaddingLeft() + getPaddingRight(), getSuggestedMinimumWidth()), i10, i11), resolveSizeAndState);
                if (z11) {
                    forceUniformWidth(i9, i8);
                    return;
                }
                return;
            }
        }
    }

    /* access modifiers changed from: protected */
    public void onDraw(Canvas canvas) {
        if (this.mDivider != null) {
            if (this.mOrientation == 1) {
                drawDividersVertical(canvas);
            } else {
                drawDividersHorizontal(canvas);
            }
        }
    }

    public void onInitializeAccessibilityEvent(AccessibilityEvent accessibilityEvent) {
        super.onInitializeAccessibilityEvent(accessibilityEvent);
        accessibilityEvent.setClassName(ACCESSIBILITY_CLASS_NAME);
    }

    public void onInitializeAccessibilityNodeInfo(AccessibilityNodeInfo accessibilityNodeInfo) {
        super.onInitializeAccessibilityNodeInfo(accessibilityNodeInfo);
        accessibilityNodeInfo.setClassName(ACCESSIBILITY_CLASS_NAME);
    }

    /* access modifiers changed from: protected */
    public void onLayout(boolean z7, int i7, int i8, int i9, int i10) {
        if (this.mOrientation == 1) {
            layoutVertical(i7, i8, i9, i10);
        } else {
            layoutHorizontal(i7, i8, i9, i10);
        }
    }

    /* access modifiers changed from: protected */
    public void onMeasure(int i7, int i8) {
        if (this.mOrientation == 1) {
            measureVertical(i7, i8);
        } else {
            measureHorizontal(i7, i8);
        }
    }

    public void setBaselineAligned(boolean z7) {
        this.mBaselineAligned = z7;
    }

    public void setBaselineAlignedChildIndex(int i7) {
        if (i7 < 0 || i7 >= getChildCount()) {
            throw new IllegalArgumentException("base aligned child index out of range (0, " + getChildCount() + ")");
        }
        this.mBaselineAlignedChildIndex = i7;
    }

    public void setDividerDrawable(Drawable drawable) {
        if (drawable != this.mDivider) {
            this.mDivider = drawable;
            boolean z7 = false;
            if (drawable != null) {
                this.mDividerWidth = drawable.getIntrinsicWidth();
                this.mDividerHeight = drawable.getIntrinsicHeight();
            } else {
                this.mDividerWidth = 0;
                this.mDividerHeight = 0;
            }
            if (drawable == null) {
                z7 = true;
            }
            setWillNotDraw(z7);
            requestLayout();
        }
    }

    public void setDividerPadding(int i7) {
        this.mDividerPadding = i7;
    }

    public void setGravity(@GravityInt int i7) {
        if (this.mGravity != i7) {
            if ((8388615 & i7) == 0) {
                i7 |= GravityCompat.START;
            }
            if ((i7 & MainActivity.f15646h) == 0) {
                i7 |= 48;
            }
            this.mGravity = i7;
            requestLayout();
        }
    }

    public void setHorizontalGravity(int i7) {
        int i8 = i7 & GravityCompat.RELATIVE_HORIZONTAL_GRAVITY_MASK;
        int i9 = this.mGravity;
        if ((8388615 & i9) != i8) {
            this.mGravity = i8 | (-8388616 & i9);
            requestLayout();
        }
    }

    public void setMeasureWithLargestChildEnabled(boolean z7) {
        this.mUseLargestChild = z7;
    }

    public void setOrientation(int i7) {
        if (this.mOrientation != i7) {
            this.mOrientation = i7;
            requestLayout();
        }
    }

    public void setShowDividers(int i7) {
        if (i7 != this.mShowDividers) {
            requestLayout();
        }
        this.mShowDividers = i7;
    }

    public void setVerticalGravity(int i7) {
        int i8 = i7 & MainActivity.f15646h;
        int i9 = this.mGravity;
        if ((i9 & MainActivity.f15646h) != i8) {
            this.mGravity = i8 | (i9 & -113);
            requestLayout();
        }
    }

    public void setWeightSum(float f7) {
        this.mWeightSum = Math.max(0.0f, f7);
    }

    public boolean shouldDelayChildPressedState() {
        return false;
    }

    public LinearLayoutCompat(@NonNull Context context, @Nullable AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    /* access modifiers changed from: protected */
    public LayoutParams generateDefaultLayoutParams() {
        int i7 = this.mOrientation;
        if (i7 == 0) {
            return new LayoutParams(-2, -2);
        }
        if (i7 == 1) {
            return new LayoutParams(-1, -2);
        }
        return null;
    }

    public LinearLayoutCompat(@NonNull Context context, @Nullable AttributeSet attributeSet, int i7) {
        super(context, attributeSet, i7);
        this.mBaselineAligned = true;
        this.mBaselineAlignedChildIndex = -1;
        this.mBaselineChildTop = 0;
        this.mGravity = BadgeDrawable.f7107r;
        TintTypedArray obtainStyledAttributes = TintTypedArray.obtainStyledAttributes(context, attributeSet, R.styleable.LinearLayoutCompat, i7, 0);
        ViewCompat.saveAttributeDataForStyleable(this, context, R.styleable.LinearLayoutCompat, attributeSet, obtainStyledAttributes.getWrappedTypeArray(), i7, 0);
        int i8 = obtainStyledAttributes.getInt(R.styleable.LinearLayoutCompat_android_orientation, -1);
        if (i8 >= 0) {
            setOrientation(i8);
        }
        int i9 = obtainStyledAttributes.getInt(R.styleable.LinearLayoutCompat_android_gravity, -1);
        if (i9 >= 0) {
            setGravity(i9);
        }
        boolean z7 = obtainStyledAttributes.getBoolean(R.styleable.LinearLayoutCompat_android_baselineAligned, true);
        if (!z7) {
            setBaselineAligned(z7);
        }
        this.mWeightSum = obtainStyledAttributes.getFloat(R.styleable.LinearLayoutCompat_android_weightSum, -1.0f);
        this.mBaselineAlignedChildIndex = obtainStyledAttributes.getInt(R.styleable.LinearLayoutCompat_android_baselineAlignedChildIndex, -1);
        this.mUseLargestChild = obtainStyledAttributes.getBoolean(R.styleable.LinearLayoutCompat_measureWithLargestChild, false);
        setDividerDrawable(obtainStyledAttributes.getDrawable(R.styleable.LinearLayoutCompat_divider));
        this.mShowDividers = obtainStyledAttributes.getInt(R.styleable.LinearLayoutCompat_showDividers, 0);
        this.mDividerPadding = obtainStyledAttributes.getDimensionPixelSize(R.styleable.LinearLayoutCompat_dividerPadding, 0);
        obtainStyledAttributes.recycle();
    }

    @Override // android.view.ViewGroup
    public LayoutParams generateLayoutParams(AttributeSet attributeSet) {
        return new LayoutParams(getContext(), attributeSet);
    }

    /* access modifiers changed from: protected */
    @Override // android.view.ViewGroup
    public LayoutParams generateLayoutParams(ViewGroup.LayoutParams layoutParams) {
        return new LayoutParams(layoutParams);
    }
}
