package androidx.arch.core.internal;

import androidx.annotation.NonNull;
import androidx.annotation.RestrictTo;
import androidx.arch.core.internal.SafeIterableMap;
import java.util.HashMap;
import java.util.Map;

@RestrictTo({RestrictTo.Scope.LIBRARY_GROUP_PREFIX})
public class FastSafeIterableMap<K, V> extends SafeIterableMap<K, V> {
    private HashMap<K, SafeIterableMap.Entry<K, V>> mHashMap = new HashMap<>();

    public Map.Entry<K, V> ceil(K k7) {
        if (contains(k7)) {
            return this.mHashMap.get(k7).mPrevious;
        }
        return null;
    }

    public boolean contains(K k7) {
        return this.mHashMap.containsKey(k7);
    }

    /* access modifiers changed from: protected */
    @Override // androidx.arch.core.internal.SafeIterableMap
    public SafeIterableMap.Entry<K, V> get(K k7) {
        return this.mHashMap.get(k7);
    }

    @Override // androidx.arch.core.internal.SafeIterableMap
    public V putIfAbsent(@NonNull K k7, @NonNull V v7) {
        SafeIterableMap.Entry<K, V> entry = get(k7);
        if (entry != null) {
            return entry.mValue;
        }
        this.mHashMap.put(k7, put(k7, v7));
        return null;
    }

    @Override // androidx.arch.core.internal.SafeIterableMap
    public V remove(@NonNull K k7) {
        V v7 = (V) super.remove(k7);
        this.mHashMap.remove(k7);
        return v7;
    }
}
