package androidx.cardview.widget;

import android.content.res.ColorStateList;
import android.content.res.Resources;
import android.graphics.Canvas;
import android.graphics.ColorFilter;
import android.graphics.LinearGradient;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.RadialGradient;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.Shader;
import android.graphics.drawable.Drawable;
import androidx.annotation.Nullable;
import androidx.cardview.R;

/* access modifiers changed from: package-private */
public class RoundRectDrawableWithShadow extends Drawable {
    private static final double COS_45 = Math.cos(Math.toRadians(45.0d));
    private static final float SHADOW_MULTIPLIER = 1.5f;
    static RoundRectHelper sRoundRectHelper;
    private boolean mAddPaddingForCorners = true;
    private ColorStateList mBackground;
    private final RectF mCardBounds;
    private float mCornerRadius;
    private Paint mCornerShadowPaint;
    private Path mCornerShadowPath;
    private boolean mDirty = true;
    private Paint mEdgeShadowPaint;
    private final int mInsetShadow;
    private Paint mPaint;
    private boolean mPrintedShadowClipWarning = false;
    private float mRawMaxShadowSize;
    private float mRawShadowSize;
    private final int mShadowEndColor;
    private float mShadowSize;
    private final int mShadowStartColor;

    interface RoundRectHelper {
        void drawRoundRect(Canvas canvas, RectF rectF, float f7, Paint paint);
    }

    RoundRectDrawableWithShadow(Resources resources, ColorStateList colorStateList, float f7, float f8, float f9) {
        this.mShadowStartColor = resources.getColor(R.color.cardview_shadow_start_color);
        this.mShadowEndColor = resources.getColor(R.color.cardview_shadow_end_color);
        this.mInsetShadow = resources.getDimensionPixelSize(R.dimen.cardview_compat_inset_shadow);
        this.mPaint = new Paint(5);
        setBackground(colorStateList);
        Paint paint = new Paint(5);
        this.mCornerShadowPaint = paint;
        paint.setStyle(Paint.Style.FILL);
        this.mCornerRadius = (float) ((int) (f7 + 0.5f));
        this.mCardBounds = new RectF();
        Paint paint2 = new Paint(this.mCornerShadowPaint);
        this.mEdgeShadowPaint = paint2;
        paint2.setAntiAlias(false);
        setShadowSize(f8, f9);
    }

    private void buildComponents(Rect rect) {
        float f7 = this.mRawMaxShadowSize;
        float f8 = SHADOW_MULTIPLIER * f7;
        this.mCardBounds.set(((float) rect.left) + f7, ((float) rect.top) + f8, ((float) rect.right) - f7, ((float) rect.bottom) - f8);
        buildShadowCorners();
    }

    private void buildShadowCorners() {
        float f7 = this.mCornerRadius;
        RectF rectF = new RectF(-f7, -f7, f7, f7);
        RectF rectF2 = new RectF(rectF);
        float f8 = this.mShadowSize;
        rectF2.inset(-f8, -f8);
        Path path = this.mCornerShadowPath;
        if (path == null) {
            this.mCornerShadowPath = new Path();
        } else {
            path.reset();
        }
        this.mCornerShadowPath.setFillType(Path.FillType.EVEN_ODD);
        this.mCornerShadowPath.moveTo(-this.mCornerRadius, 0.0f);
        this.mCornerShadowPath.rLineTo(-this.mShadowSize, 0.0f);
        this.mCornerShadowPath.arcTo(rectF2, 180.0f, 90.0f, false);
        this.mCornerShadowPath.arcTo(rectF, 270.0f, -90.0f, false);
        this.mCornerShadowPath.close();
        float f9 = this.mCornerRadius;
        float f10 = f9 / (this.mShadowSize + f9);
        Paint paint = this.mCornerShadowPaint;
        float f11 = this.mCornerRadius + this.mShadowSize;
        int i7 = this.mShadowStartColor;
        paint.setShader(new RadialGradient(0.0f, 0.0f, f11, new int[]{i7, i7, this.mShadowEndColor}, new float[]{0.0f, f10, 1.0f}, Shader.TileMode.CLAMP));
        Paint paint2 = this.mEdgeShadowPaint;
        float f12 = this.mCornerRadius;
        float f13 = this.mShadowSize;
        int i8 = this.mShadowStartColor;
        paint2.setShader(new LinearGradient(0.0f, (-f12) + f13, 0.0f, (-f12) - f13, new int[]{i8, i8, this.mShadowEndColor}, new float[]{0.0f, 0.5f, 1.0f}, Shader.TileMode.CLAMP));
        this.mEdgeShadowPaint.setAntiAlias(false);
    }

    static float calculateHorizontalPadding(float f7, float f8, boolean z7) {
        return z7 ? (float) (((double) f7) + ((1.0d - COS_45) * ((double) f8))) : f7;
    }

    static float calculateVerticalPadding(float f7, float f8, boolean z7) {
        float f9 = f7 * SHADOW_MULTIPLIER;
        return z7 ? (float) (((double) f9) + ((1.0d - COS_45) * ((double) f8))) : f9;
    }

    private void drawShadow(Canvas canvas) {
        float f7 = this.mCornerRadius;
        float f8 = (-f7) - this.mShadowSize;
        float f9 = f7 + ((float) this.mInsetShadow) + (this.mRawShadowSize / 2.0f);
        float f10 = f9 * 2.0f;
        boolean z7 = this.mCardBounds.width() - f10 > 0.0f;
        boolean z8 = this.mCardBounds.height() - f10 > 0.0f;
        int save = canvas.save();
        RectF rectF = this.mCardBounds;
        canvas.translate(rectF.left + f9, rectF.top + f9);
        canvas.drawPath(this.mCornerShadowPath, this.mCornerShadowPaint);
        if (z7) {
            canvas.drawRect(0.0f, f8, this.mCardBounds.width() - f10, -this.mCornerRadius, this.mEdgeShadowPaint);
        }
        canvas.restoreToCount(save);
        int save2 = canvas.save();
        RectF rectF2 = this.mCardBounds;
        canvas.translate(rectF2.right - f9, rectF2.bottom - f9);
        canvas.rotate(180.0f);
        canvas.drawPath(this.mCornerShadowPath, this.mCornerShadowPaint);
        if (z7) {
            canvas.drawRect(0.0f, f8, this.mCardBounds.width() - f10, (-this.mCornerRadius) + this.mShadowSize, this.mEdgeShadowPaint);
        }
        canvas.restoreToCount(save2);
        int save3 = canvas.save();
        RectF rectF3 = this.mCardBounds;
        canvas.translate(rectF3.left + f9, rectF3.bottom - f9);
        canvas.rotate(270.0f);
        canvas.drawPath(this.mCornerShadowPath, this.mCornerShadowPaint);
        if (z8) {
            canvas.drawRect(0.0f, f8, this.mCardBounds.height() - f10, -this.mCornerRadius, this.mEdgeShadowPaint);
        }
        canvas.restoreToCount(save3);
        int save4 = canvas.save();
        RectF rectF4 = this.mCardBounds;
        canvas.translate(rectF4.right - f9, rectF4.top + f9);
        canvas.rotate(90.0f);
        canvas.drawPath(this.mCornerShadowPath, this.mCornerShadowPaint);
        if (z8) {
            canvas.drawRect(0.0f, f8, this.mCardBounds.height() - f10, -this.mCornerRadius, this.mEdgeShadowPaint);
        }
        canvas.restoreToCount(save4);
    }

    private void setBackground(ColorStateList colorStateList) {
        if (colorStateList == null) {
            colorStateList = ColorStateList.valueOf(0);
        }
        this.mBackground = colorStateList;
        this.mPaint.setColor(colorStateList.getColorForState(getState(), this.mBackground.getDefaultColor()));
    }

    private int toEven(float f7) {
        int i7 = (int) (f7 + 0.5f);
        return i7 % 2 == 1 ? i7 - 1 : i7;
    }

    public void draw(Canvas canvas) {
        if (this.mDirty) {
            buildComponents(getBounds());
            this.mDirty = false;
        }
        canvas.translate(0.0f, this.mRawShadowSize / 2.0f);
        drawShadow(canvas);
        canvas.translate(0.0f, (-this.mRawShadowSize) / 2.0f);
        sRoundRectHelper.drawRoundRect(canvas, this.mCardBounds, this.mCornerRadius, this.mPaint);
    }

    /* access modifiers changed from: package-private */
    public ColorStateList getColor() {
        return this.mBackground;
    }

    /* access modifiers changed from: package-private */
    public float getCornerRadius() {
        return this.mCornerRadius;
    }

    /* access modifiers changed from: package-private */
    public void getMaxShadowAndCornerPadding(Rect rect) {
        getPadding(rect);
    }

    /* access modifiers changed from: package-private */
    public float getMaxShadowSize() {
        return this.mRawMaxShadowSize;
    }

    /* access modifiers changed from: package-private */
    public float getMinHeight() {
        float f7 = this.mRawMaxShadowSize;
        return (Math.max(f7, this.mCornerRadius + ((float) this.mInsetShadow) + ((f7 * SHADOW_MULTIPLIER) / 2.0f)) * 2.0f) + (((this.mRawMaxShadowSize * SHADOW_MULTIPLIER) + ((float) this.mInsetShadow)) * 2.0f);
    }

    /* access modifiers changed from: package-private */
    public float getMinWidth() {
        float f7 = this.mRawMaxShadowSize;
        return (Math.max(f7, this.mCornerRadius + ((float) this.mInsetShadow) + (f7 / 2.0f)) * 2.0f) + ((this.mRawMaxShadowSize + ((float) this.mInsetShadow)) * 2.0f);
    }

    public int getOpacity() {
        return -3;
    }

    public boolean getPadding(Rect rect) {
        int ceil = (int) Math.ceil((double) calculateVerticalPadding(this.mRawMaxShadowSize, this.mCornerRadius, this.mAddPaddingForCorners));
        int ceil2 = (int) Math.ceil((double) calculateHorizontalPadding(this.mRawMaxShadowSize, this.mCornerRadius, this.mAddPaddingForCorners));
        rect.set(ceil2, ceil, ceil2, ceil);
        return true;
    }

    /* access modifiers changed from: package-private */
    public float getShadowSize() {
        return this.mRawShadowSize;
    }

    public boolean isStateful() {
        ColorStateList colorStateList = this.mBackground;
        return (colorStateList != null && colorStateList.isStateful()) || super.isStateful();
    }

    /* access modifiers changed from: protected */
    public void onBoundsChange(Rect rect) {
        super.onBoundsChange(rect);
        this.mDirty = true;
    }

    /* access modifiers changed from: protected */
    public boolean onStateChange(int[] iArr) {
        ColorStateList colorStateList = this.mBackground;
        int colorForState = colorStateList.getColorForState(iArr, colorStateList.getDefaultColor());
        if (this.mPaint.getColor() == colorForState) {
            return false;
        }
        this.mPaint.setColor(colorForState);
        this.mDirty = true;
        invalidateSelf();
        return true;
    }

    /* access modifiers changed from: package-private */
    public void setAddPaddingForCorners(boolean z7) {
        this.mAddPaddingForCorners = z7;
        invalidateSelf();
    }

    public void setAlpha(int i7) {
        this.mPaint.setAlpha(i7);
        this.mCornerShadowPaint.setAlpha(i7);
        this.mEdgeShadowPaint.setAlpha(i7);
    }

    /* access modifiers changed from: package-private */
    public void setColor(@Nullable ColorStateList colorStateList) {
        setBackground(colorStateList);
        invalidateSelf();
    }

    public void setColorFilter(ColorFilter colorFilter) {
        this.mPaint.setColorFilter(colorFilter);
    }

    /* access modifiers changed from: package-private */
    public void setCornerRadius(float f7) {
        if (f7 >= 0.0f) {
            float f8 = (float) ((int) (f7 + 0.5f));
            if (this.mCornerRadius != f8) {
                this.mCornerRadius = f8;
                this.mDirty = true;
                invalidateSelf();
                return;
            }
            return;
        }
        throw new IllegalArgumentException("Invalid radius " + f7 + ". Must be >= 0");
    }

    /* access modifiers changed from: package-private */
    public void setMaxShadowSize(float f7) {
        setShadowSize(this.mRawShadowSize, f7);
    }

    /* access modifiers changed from: package-private */
    public void setShadowSize(float f7) {
        setShadowSize(f7, this.mRawMaxShadowSize);
    }

    private void setShadowSize(float f7, float f8) {
        if (f7 < 0.0f) {
            throw new IllegalArgumentException("Invalid shadow size " + f7 + ". Must be >= 0");
        } else if (f8 >= 0.0f) {
            float even = (float) toEven(f7);
            float even2 = (float) toEven(f8);
            if (even > even2) {
                if (!this.mPrintedShadowClipWarning) {
                    this.mPrintedShadowClipWarning = true;
                }
                even = even2;
            }
            if (this.mRawShadowSize != even || this.mRawMaxShadowSize != even2) {
                this.mRawShadowSize = even;
                this.mRawMaxShadowSize = even2;
                this.mShadowSize = (float) ((int) ((even * SHADOW_MULTIPLIER) + ((float) this.mInsetShadow) + 0.5f));
                this.mDirty = true;
                invalidateSelf();
            }
        } else {
            throw new IllegalArgumentException("Invalid max shadow size " + f8 + ". Must be >= 0");
        }
    }
}
