package androidx.collection;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import java.util.ConcurrentModificationException;
import java.util.Map;

public class SimpleArrayMap<K, V> {
    private static final int BASE_SIZE = 4;
    private static final int CACHE_SIZE = 10;
    private static final boolean CONCURRENT_MODIFICATION_EXCEPTIONS = true;
    private static final boolean DEBUG = false;
    private static final String TAG = "ArrayMap";
    @Nullable
    static Object[] mBaseCache;
    static int mBaseCacheSize;
    @Nullable
    static Object[] mTwiceBaseCache;
    static int mTwiceBaseCacheSize;
    Object[] mArray;
    int[] mHashes;
    int mSize;

    public SimpleArrayMap() {
        this.mHashes = ContainerHelpers.EMPTY_INTS;
        this.mArray = ContainerHelpers.EMPTY_OBJECTS;
        this.mSize = 0;
    }

    private void allocArrays(int i7) {
        if (i7 == 8) {
            synchronized (SimpleArrayMap.class) {
                Object[] objArr = mTwiceBaseCache;
                if (objArr != null) {
                    this.mArray = objArr;
                    mTwiceBaseCache = (Object[]) objArr[0];
                    this.mHashes = (int[]) objArr[1];
                    objArr[1] = null;
                    objArr[0] = null;
                    mTwiceBaseCacheSize--;
                    return;
                }
            }
        } else if (i7 == 4) {
            synchronized (SimpleArrayMap.class) {
                Object[] objArr2 = mBaseCache;
                if (objArr2 != null) {
                    this.mArray = objArr2;
                    mBaseCache = (Object[]) objArr2[0];
                    this.mHashes = (int[]) objArr2[1];
                    objArr2[1] = null;
                    objArr2[0] = null;
                    mBaseCacheSize--;
                    return;
                }
            }
        }
        this.mHashes = new int[i7];
        this.mArray = new Object[(i7 << 1)];
    }

    private static int binarySearchHashes(int[] iArr, int i7, int i8) {
        try {
            return ContainerHelpers.binarySearch(iArr, i7, i8);
        } catch (ArrayIndexOutOfBoundsException unused) {
            throw new ConcurrentModificationException();
        }
    }

    private static void freeArrays(int[] iArr, Object[] objArr, int i7) {
        if (iArr.length == 8) {
            synchronized (SimpleArrayMap.class) {
                if (mTwiceBaseCacheSize < 10) {
                    objArr[0] = mTwiceBaseCache;
                    objArr[1] = iArr;
                    for (int i8 = (i7 << 1) - 1; i8 >= 2; i8--) {
                        objArr[i8] = null;
                    }
                    mTwiceBaseCache = objArr;
                    mTwiceBaseCacheSize++;
                }
            }
        } else if (iArr.length == 4) {
            synchronized (SimpleArrayMap.class) {
                if (mBaseCacheSize < 10) {
                    objArr[0] = mBaseCache;
                    objArr[1] = iArr;
                    for (int i9 = (i7 << 1) - 1; i9 >= 2; i9--) {
                        objArr[i9] = null;
                    }
                    mBaseCache = objArr;
                    mBaseCacheSize++;
                }
            }
        }
    }

    public void clear() {
        int i7 = this.mSize;
        if (i7 > 0) {
            int[] iArr = this.mHashes;
            Object[] objArr = this.mArray;
            this.mHashes = ContainerHelpers.EMPTY_INTS;
            this.mArray = ContainerHelpers.EMPTY_OBJECTS;
            this.mSize = 0;
            freeArrays(iArr, objArr, i7);
        }
        if (this.mSize > 0) {
            throw new ConcurrentModificationException();
        }
    }

    public boolean containsKey(@Nullable Object obj) {
        return indexOfKey(obj) >= 0;
    }

    public boolean containsValue(Object obj) {
        return indexOfValue(obj) >= 0;
    }

    public void ensureCapacity(int i7) {
        int i8 = this.mSize;
        int[] iArr = this.mHashes;
        if (iArr.length < i7) {
            Object[] objArr = this.mArray;
            allocArrays(i7);
            if (this.mSize > 0) {
                System.arraycopy(iArr, 0, this.mHashes, 0, i8);
                System.arraycopy(objArr, 0, this.mArray, 0, i8 << 1);
            }
            freeArrays(iArr, objArr, i8);
        }
        if (this.mSize != i8) {
            throw new ConcurrentModificationException();
        }
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof SimpleArrayMap) {
            SimpleArrayMap simpleArrayMap = (SimpleArrayMap) obj;
            if (size() != simpleArrayMap.size()) {
                return false;
            }
            for (int i7 = 0; i7 < this.mSize; i7++) {
                try {
                    K keyAt = keyAt(i7);
                    V valueAt = valueAt(i7);
                    Object obj2 = simpleArrayMap.get(keyAt);
                    if (valueAt == null) {
                        if (obj2 != null || !simpleArrayMap.containsKey(keyAt)) {
                            return false;
                        }
                    } else if (!valueAt.equals(obj2)) {
                        return false;
                    }
                } catch (ClassCastException | NullPointerException unused) {
                    return false;
                }
            }
            return true;
        }
        if (obj instanceof Map) {
            Map map = (Map) obj;
            if (size() != map.size()) {
                return false;
            }
            for (int i8 = 0; i8 < this.mSize; i8++) {
                try {
                    K keyAt2 = keyAt(i8);
                    V valueAt2 = valueAt(i8);
                    Object obj3 = map.get(keyAt2);
                    if (valueAt2 == null) {
                        if (obj3 != null || !map.containsKey(keyAt2)) {
                            return false;
                        }
                    } else if (!valueAt2.equals(obj3)) {
                        return false;
                    }
                } catch (ClassCastException | NullPointerException unused2) {
                }
            }
            return true;
        }
        return false;
    }

    @Nullable
    public V get(Object obj) {
        return getOrDefault(obj, null);
    }

    public V getOrDefault(Object obj, V v7) {
        int indexOfKey = indexOfKey(obj);
        return indexOfKey >= 0 ? (V) this.mArray[(indexOfKey << 1) + 1] : v7;
    }

    public int hashCode() {
        int[] iArr = this.mHashes;
        Object[] objArr = this.mArray;
        int i7 = this.mSize;
        int i8 = 1;
        int i9 = 0;
        int i10 = 0;
        while (i9 < i7) {
            Object obj = objArr[i8];
            i10 += (obj == null ? 0 : obj.hashCode()) ^ iArr[i9];
            i9++;
            i8 += 2;
        }
        return i10;
    }

    /* access modifiers changed from: package-private */
    public int indexOf(Object obj, int i7) {
        int i8 = this.mSize;
        if (i8 == 0) {
            return -1;
        }
        int binarySearchHashes = binarySearchHashes(this.mHashes, i8, i7);
        if (binarySearchHashes < 0 || obj.equals(this.mArray[binarySearchHashes << 1])) {
            return binarySearchHashes;
        }
        int i9 = binarySearchHashes + 1;
        while (i9 < i8 && this.mHashes[i9] == i7) {
            if (obj.equals(this.mArray[i9 << 1])) {
                return i9;
            }
            i9++;
        }
        int i10 = binarySearchHashes - 1;
        while (i10 >= 0 && this.mHashes[i10] == i7) {
            if (obj.equals(this.mArray[i10 << 1])) {
                return i10;
            }
            i10--;
        }
        return ~i9;
    }

    public int indexOfKey(@Nullable Object obj) {
        return obj == null ? indexOfNull() : indexOf(obj, obj.hashCode());
    }

    /* access modifiers changed from: package-private */
    public int indexOfNull() {
        int i7 = this.mSize;
        if (i7 == 0) {
            return -1;
        }
        int binarySearchHashes = binarySearchHashes(this.mHashes, i7, 0);
        if (binarySearchHashes < 0 || this.mArray[binarySearchHashes << 1] == null) {
            return binarySearchHashes;
        }
        int i8 = binarySearchHashes + 1;
        while (i8 < i7 && this.mHashes[i8] == 0) {
            if (this.mArray[i8 << 1] == null) {
                return i8;
            }
            i8++;
        }
        int i9 = binarySearchHashes - 1;
        while (i9 >= 0 && this.mHashes[i9] == 0) {
            if (this.mArray[i9 << 1] == null) {
                return i9;
            }
            i9--;
        }
        return ~i8;
    }

    /* access modifiers changed from: package-private */
    public int indexOfValue(Object obj) {
        int i7 = this.mSize * 2;
        Object[] objArr = this.mArray;
        if (obj == null) {
            for (int i8 = 1; i8 < i7; i8 += 2) {
                if (objArr[i8] == null) {
                    return i8 >> 1;
                }
            }
            return -1;
        }
        for (int i9 = 1; i9 < i7; i9 += 2) {
            if (obj.equals(objArr[i9])) {
                return i9 >> 1;
            }
        }
        return -1;
    }

    public boolean isEmpty() {
        return this.mSize <= 0;
    }

    public K keyAt(int i7) {
        return (K) this.mArray[i7 << 1];
    }

    @Nullable
    public V put(K k7, V v7) {
        int i7;
        int i8;
        int i9 = this.mSize;
        if (k7 == null) {
            i8 = indexOfNull();
            i7 = 0;
        } else {
            int hashCode = k7.hashCode();
            i7 = hashCode;
            i8 = indexOf(k7, hashCode);
        }
        if (i8 >= 0) {
            int i10 = (i8 << 1) + 1;
            Object[] objArr = this.mArray;
            V v8 = (V) objArr[i10];
            objArr[i10] = v7;
            return v8;
        }
        int i11 = ~i8;
        int[] iArr = this.mHashes;
        if (i9 >= iArr.length) {
            int i12 = 8;
            if (i9 >= 8) {
                i12 = (i9 >> 1) + i9;
            } else if (i9 < 4) {
                i12 = 4;
            }
            Object[] objArr2 = this.mArray;
            allocArrays(i12);
            if (i9 == this.mSize) {
                int[] iArr2 = this.mHashes;
                if (iArr2.length > 0) {
                    System.arraycopy(iArr, 0, iArr2, 0, iArr.length);
                    System.arraycopy(objArr2, 0, this.mArray, 0, objArr2.length);
                }
                freeArrays(iArr, objArr2, i9);
            } else {
                throw new ConcurrentModificationException();
            }
        }
        if (i11 < i9) {
            int[] iArr3 = this.mHashes;
            int i13 = i11 + 1;
            System.arraycopy(iArr3, i11, iArr3, i13, i9 - i11);
            Object[] objArr3 = this.mArray;
            System.arraycopy(objArr3, i11 << 1, objArr3, i13 << 1, (this.mSize - i11) << 1);
        }
        int i14 = this.mSize;
        if (i9 == i14) {
            int[] iArr4 = this.mHashes;
            if (i11 < iArr4.length) {
                iArr4[i11] = i7;
                Object[] objArr4 = this.mArray;
                int i15 = i11 << 1;
                objArr4[i15] = k7;
                objArr4[i15 + 1] = v7;
                this.mSize = i14 + 1;
                return null;
            }
        }
        throw new ConcurrentModificationException();
    }

    /* JADX DEBUG: Multi-variable search result rejected for r4v0, resolved type: androidx.collection.SimpleArrayMap<K, V> */
    /* JADX WARN: Multi-variable type inference failed */
    public void putAll(@NonNull SimpleArrayMap<? extends K, ? extends V> simpleArrayMap) {
        int i7 = simpleArrayMap.mSize;
        ensureCapacity(this.mSize + i7);
        if (this.mSize != 0) {
            for (int i8 = 0; i8 < i7; i8++) {
                put(simpleArrayMap.keyAt(i8), simpleArrayMap.valueAt(i8));
            }
        } else if (i7 > 0) {
            System.arraycopy(simpleArrayMap.mHashes, 0, this.mHashes, 0, i7);
            System.arraycopy(simpleArrayMap.mArray, 0, this.mArray, 0, i7 << 1);
            this.mSize = i7;
        }
    }

    @Nullable
    public V putIfAbsent(K k7, V v7) {
        V v8 = get(k7);
        return v8 == null ? put(k7, v7) : v8;
    }

    @Nullable
    public V remove(Object obj) {
        int indexOfKey = indexOfKey(obj);
        if (indexOfKey >= 0) {
            return removeAt(indexOfKey);
        }
        return null;
    }

    public V removeAt(int i7) {
        Object[] objArr = this.mArray;
        int i8 = i7 << 1;
        V v7 = (V) objArr[i8 + 1];
        int i9 = this.mSize;
        int i10 = 0;
        if (i9 <= 1) {
            freeArrays(this.mHashes, objArr, i9);
            this.mHashes = ContainerHelpers.EMPTY_INTS;
            this.mArray = ContainerHelpers.EMPTY_OBJECTS;
        } else {
            int i11 = i9 - 1;
            int[] iArr = this.mHashes;
            int i12 = 8;
            if (iArr.length <= 8 || i9 >= iArr.length / 3) {
                if (i7 < i11) {
                    int i13 = i7 + 1;
                    int i14 = i11 - i7;
                    System.arraycopy(iArr, i13, iArr, i7, i14);
                    Object[] objArr2 = this.mArray;
                    System.arraycopy(objArr2, i13 << 1, objArr2, i8, i14 << 1);
                }
                Object[] objArr3 = this.mArray;
                int i15 = i11 << 1;
                objArr3[i15] = null;
                objArr3[i15 + 1] = null;
            } else {
                if (i9 > 8) {
                    i12 = i9 + (i9 >> 1);
                }
                allocArrays(i12);
                if (i9 == this.mSize) {
                    if (i7 > 0) {
                        System.arraycopy(iArr, 0, this.mHashes, 0, i7);
                        System.arraycopy(objArr, 0, this.mArray, 0, i8);
                    }
                    if (i7 < i11) {
                        int i16 = i7 + 1;
                        int i17 = i11 - i7;
                        System.arraycopy(iArr, i16, this.mHashes, i7, i17);
                        System.arraycopy(objArr, i16 << 1, this.mArray, i8, i17 << 1);
                    }
                } else {
                    throw new ConcurrentModificationException();
                }
            }
            i10 = i11;
        }
        if (i9 == this.mSize) {
            this.mSize = i10;
            return v7;
        }
        throw new ConcurrentModificationException();
    }

    @Nullable
    public V replace(K k7, V v7) {
        int indexOfKey = indexOfKey(k7);
        if (indexOfKey >= 0) {
            return setValueAt(indexOfKey, v7);
        }
        return null;
    }

    public V setValueAt(int i7, V v7) {
        int i8 = (i7 << 1) + 1;
        Object[] objArr = this.mArray;
        V v8 = (V) objArr[i8];
        objArr[i8] = v7;
        return v8;
    }

    public int size() {
        return this.mSize;
    }

    public String toString() {
        if (isEmpty()) {
            return "{}";
        }
        StringBuilder sb = new StringBuilder(this.mSize * 28);
        sb.append('{');
        for (int i7 = 0; i7 < this.mSize; i7++) {
            if (i7 > 0) {
                sb.append(", ");
            }
            K keyAt = keyAt(i7);
            if (keyAt != this) {
                sb.append((Object) keyAt);
            } else {
                sb.append("(this Map)");
            }
            sb.append('=');
            V valueAt = valueAt(i7);
            if (valueAt != this) {
                sb.append((Object) valueAt);
            } else {
                sb.append("(this Map)");
            }
        }
        sb.append('}');
        return sb.toString();
    }

    public V valueAt(int i7) {
        return (V) this.mArray[(i7 << 1) + 1];
    }

    public SimpleArrayMap(int i7) {
        if (i7 == 0) {
            this.mHashes = ContainerHelpers.EMPTY_INTS;
            this.mArray = ContainerHelpers.EMPTY_OBJECTS;
        } else {
            allocArrays(i7);
        }
        this.mSize = 0;
    }

    public boolean remove(Object obj, Object obj2) {
        int indexOfKey = indexOfKey(obj);
        if (indexOfKey < 0) {
            return false;
        }
        V valueAt = valueAt(indexOfKey);
        if (obj2 != valueAt && (obj2 == null || !obj2.equals(valueAt))) {
            return false;
        }
        removeAt(indexOfKey);
        return true;
    }

    public boolean replace(K k7, V v7, V v8) {
        int indexOfKey = indexOfKey(k7);
        if (indexOfKey < 0) {
            return false;
        }
        V valueAt = valueAt(indexOfKey);
        if (valueAt != v7 && (v7 == null || !v7.equals(valueAt))) {
            return false;
        }
        setValueAt(indexOfKey, v8);
        return true;
    }

    public SimpleArrayMap(SimpleArrayMap<K, V> simpleArrayMap) {
        this();
        if (simpleArrayMap != null) {
            putAll(simpleArrayMap);
        }
    }
}
