package androidx.constraintlayout.motion.utils;

import java.util.Arrays;

/* access modifiers changed from: package-private */
public class ArcCurveFit extends CurveFit {
    public static final int ARC_START_FLIP = 3;
    public static final int ARC_START_HORIZONTAL = 2;
    public static final int ARC_START_LINEAR = 0;
    public static final int ARC_START_VERTICAL = 1;
    private static final int START_HORIZONTAL = 2;
    private static final int START_LINEAR = 3;
    private static final int START_VERTICAL = 1;
    Arc[] mArcs;
    private final double[] mTime;

    private static class Arc {
        private static final double EPSILON = 0.001d;
        private static final String TAG = "Arc";
        private static double[] ourPercent = new double[91];
        boolean linear = false;
        double mArcDistance;
        double mArcVelocity;
        double mEllipseA;
        double mEllipseB;
        double mEllipseCenterX;
        double mEllipseCenterY;
        double[] mLut;
        double mOneOverDeltaTime;
        double mTime1;
        double mTime2;
        double mTmpCosAngle;
        double mTmpSinAngle;
        boolean mVertical;
        double mX1;
        double mX2;
        double mY1;
        double mY2;

        Arc(int i7, double d7, double d8, double d9, double d10, double d11, double d12) {
            boolean z7 = false;
            int i8 = 1;
            this.mVertical = i7 == 1 ? true : z7;
            this.mTime1 = d7;
            this.mTime2 = d8;
            this.mOneOverDeltaTime = 1.0d / (d8 - d7);
            if (3 == i7) {
                this.linear = true;
            }
            double d13 = d11 - d9;
            double d14 = d12 - d10;
            if (this.linear || Math.abs(d13) < EPSILON || Math.abs(d14) < EPSILON) {
                this.linear = true;
                this.mX1 = d9;
                this.mX2 = d11;
                this.mY1 = d10;
                this.mY2 = d12;
                double hypot = Math.hypot(d14, d13);
                this.mArcDistance = hypot;
                this.mArcVelocity = hypot * this.mOneOverDeltaTime;
                double d15 = this.mTime2;
                double d16 = this.mTime1;
                this.mEllipseCenterX = d13 / (d15 - d16);
                this.mEllipseCenterY = d14 / (d15 - d16);
                return;
            }
            this.mLut = new double[101];
            boolean z8 = this.mVertical;
            this.mEllipseA = d13 * ((double) (z8 ? -1 : 1));
            this.mEllipseB = d14 * ((double) (!z8 ? -1 : i8));
            this.mEllipseCenterX = z8 ? d11 : d9;
            this.mEllipseCenterY = z8 ? d10 : d12;
            buildTable(d9, d10, d11, d12);
            this.mArcVelocity = this.mArcDistance * this.mOneOverDeltaTime;
        }

        private void buildTable(double d7, double d8, double d9, double d10) {
            double d11;
            double d12 = d9 - d7;
            double d13 = d8 - d10;
            int i7 = 0;
            double d14 = 0.0d;
            double d15 = 0.0d;
            double d16 = 0.0d;
            while (true) {
                double[] dArr = ourPercent;
                if (i7 >= dArr.length) {
                    break;
                }
                double radians = Math.toRadians((((double) i7) * 90.0d) / ((double) (dArr.length - 1)));
                double sin = Math.sin(radians) * d12;
                double cos = Math.cos(radians) * d13;
                if (i7 > 0) {
                    d11 = Math.hypot(sin - d15, cos - d16) + d14;
                    ourPercent[i7] = d11;
                } else {
                    d11 = d14;
                }
                i7++;
                d16 = cos;
                d14 = d11;
                d15 = sin;
            }
            this.mArcDistance = d14;
            int i8 = 0;
            while (true) {
                double[] dArr2 = ourPercent;
                if (i8 >= dArr2.length) {
                    break;
                }
                dArr2[i8] = dArr2[i8] / d14;
                i8++;
            }
            int i9 = 0;
            while (true) {
                double[] dArr3 = this.mLut;
                if (i9 < dArr3.length) {
                    double length = ((double) i9) / ((double) (dArr3.length - 1));
                    int binarySearch = Arrays.binarySearch(ourPercent, length);
                    if (binarySearch >= 0) {
                        this.mLut[i9] = (double) (binarySearch / (ourPercent.length - 1));
                    } else if (binarySearch == -1) {
                        this.mLut[i9] = 0.0d;
                    } else {
                        int i10 = -binarySearch;
                        int i11 = i10 - 2;
                        double[] dArr4 = ourPercent;
                        double d17 = dArr4[i11];
                        this.mLut[i9] = (((double) i11) + ((length - d17) / (dArr4[i10 - 1] - d17))) / ((double) (dArr4.length - 1));
                    }
                    i9++;
                } else {
                    return;
                }
            }
        }

        /* access modifiers changed from: package-private */
        public double getDX() {
            double d7 = this.mEllipseA * this.mTmpCosAngle;
            double hypot = this.mArcVelocity / Math.hypot(d7, (-this.mEllipseB) * this.mTmpSinAngle);
            if (this.mVertical) {
                d7 = -d7;
            }
            return d7 * hypot;
        }

        /* access modifiers changed from: package-private */
        public double getDY() {
            double d7 = this.mEllipseA * this.mTmpCosAngle;
            double d8 = (-this.mEllipseB) * this.mTmpSinAngle;
            double hypot = this.mArcVelocity / Math.hypot(d7, d8);
            return this.mVertical ? (-d8) * hypot : d8 * hypot;
        }

        public double getLinearDX(double d7) {
            return this.mEllipseCenterX;
        }

        public double getLinearDY(double d7) {
            return this.mEllipseCenterY;
        }

        public double getLinearX(double d7) {
            double d8 = (d7 - this.mTime1) * this.mOneOverDeltaTime;
            double d9 = this.mX1;
            return d9 + (d8 * (this.mX2 - d9));
        }

        public double getLinearY(double d7) {
            double d8 = (d7 - this.mTime1) * this.mOneOverDeltaTime;
            double d9 = this.mY1;
            return d9 + (d8 * (this.mY2 - d9));
        }

        /* access modifiers changed from: package-private */
        public double getX() {
            return this.mEllipseCenterX + (this.mEllipseA * this.mTmpSinAngle);
        }

        /* access modifiers changed from: package-private */
        public double getY() {
            return this.mEllipseCenterY + (this.mEllipseB * this.mTmpCosAngle);
        }

        /* access modifiers changed from: package-private */
        public double lookup(double d7) {
            if (d7 <= 0.0d) {
                return 0.0d;
            }
            if (d7 >= 1.0d) {
                return 1.0d;
            }
            double[] dArr = this.mLut;
            double length = d7 * ((double) (dArr.length - 1));
            int i7 = (int) length;
            double d8 = length - ((double) i7);
            double d9 = dArr[i7];
            return d9 + (d8 * (dArr[i7 + 1] - d9));
        }

        /* access modifiers changed from: package-private */
        public void setPoint(double d7) {
            double lookup = lookup((this.mVertical ? this.mTime2 - d7 : d7 - this.mTime1) * this.mOneOverDeltaTime) * 1.5707963267948966d;
            this.mTmpSinAngle = Math.sin(lookup);
            this.mTmpCosAngle = Math.cos(lookup);
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:9:0x0026, code lost:
        if (r5 == 1) goto L_0x0028;
     */
    public ArcCurveFit(int[] iArr, double[] dArr, double[][] dArr2) {
        this.mTime = dArr;
        this.mArcs = new Arc[(dArr.length - 1)];
        int i7 = 0;
        int i8 = 1;
        int i9 = 1;
        while (true) {
            Arc[] arcArr = this.mArcs;
            if (i7 < arcArr.length) {
                int i10 = iArr[i7];
                if (i10 != 0) {
                    if (i10 != 1) {
                        if (i10 != 2) {
                            if (i10 == 3) {
                            }
                        }
                        i8 = 2;
                        i9 = i8;
                    }
                    i8 = 1;
                    i9 = i8;
                } else {
                    i9 = 3;
                }
                double d7 = dArr[i7];
                int i11 = i7 + 1;
                double d8 = dArr[i11];
                double[] dArr3 = dArr2[i7];
                double d9 = dArr3[0];
                double d10 = dArr3[1];
                double[] dArr4 = dArr2[i11];
                arcArr[i7] = new Arc(i9, d7, d8, d9, d10, dArr4[0], dArr4[1]);
                i7 = i11;
            } else {
                return;
            }
        }
    }

    @Override // androidx.constraintlayout.motion.utils.CurveFit
    public double getPos(double d7, int i7) {
        Arc[] arcArr = this.mArcs;
        int i8 = 0;
        double d8 = arcArr[0].mTime1;
        if (d7 < d8) {
            d7 = d8;
        } else if (d7 > arcArr[arcArr.length - 1].mTime2) {
            d7 = arcArr[arcArr.length - 1].mTime2;
        }
        while (true) {
            Arc[] arcArr2 = this.mArcs;
            if (i8 >= arcArr2.length) {
                return Double.NaN;
            }
            Arc arc = arcArr2[i8];
            if (d7 > arc.mTime2) {
                i8++;
            } else if (arc.linear) {
                return i7 == 0 ? arc.getLinearX(d7) : arc.getLinearY(d7);
            } else {
                arc.setPoint(d7);
                Arc[] arcArr3 = this.mArcs;
                return i7 == 0 ? arcArr3[i8].getX() : arcArr3[i8].getY();
            }
        }
    }

    @Override // androidx.constraintlayout.motion.utils.CurveFit
    public double getSlope(double d7, int i7) {
        Arc[] arcArr = this.mArcs;
        int i8 = 0;
        double d8 = arcArr[0].mTime1;
        if (d7 < d8) {
            d7 = d8;
        }
        if (d7 > arcArr[arcArr.length - 1].mTime2) {
            d7 = arcArr[arcArr.length - 1].mTime2;
        }
        while (true) {
            Arc[] arcArr2 = this.mArcs;
            if (i8 >= arcArr2.length) {
                return Double.NaN;
            }
            Arc arc = arcArr2[i8];
            if (d7 > arc.mTime2) {
                i8++;
            } else if (arc.linear) {
                return i7 == 0 ? arc.getLinearDX(d7) : arc.getLinearDY(d7);
            } else {
                arc.setPoint(d7);
                Arc[] arcArr3 = this.mArcs;
                return i7 == 0 ? arcArr3[i8].getDX() : arcArr3[i8].getDY();
            }
        }
    }

    @Override // androidx.constraintlayout.motion.utils.CurveFit
    public double[] getTimePoints() {
        return this.mTime;
    }

    @Override // androidx.constraintlayout.motion.utils.CurveFit
    public void getPos(double d7, double[] dArr) {
        Arc[] arcArr = this.mArcs;
        double d8 = arcArr[0].mTime1;
        if (d7 < d8) {
            d7 = d8;
        }
        if (d7 > arcArr[arcArr.length - 1].mTime2) {
            d7 = arcArr[arcArr.length - 1].mTime2;
        }
        int i7 = 0;
        while (true) {
            Arc[] arcArr2 = this.mArcs;
            if (i7 < arcArr2.length) {
                Arc arc = arcArr2[i7];
                if (d7 > arc.mTime2) {
                    i7++;
                } else if (arc.linear) {
                    dArr[0] = arc.getLinearX(d7);
                    dArr[1] = this.mArcs[i7].getLinearY(d7);
                    return;
                } else {
                    arc.setPoint(d7);
                    dArr[0] = this.mArcs[i7].getX();
                    dArr[1] = this.mArcs[i7].getY();
                    return;
                }
            } else {
                return;
            }
        }
    }

    @Override // androidx.constraintlayout.motion.utils.CurveFit
    public void getSlope(double d7, double[] dArr) {
        Arc[] arcArr = this.mArcs;
        double d8 = arcArr[0].mTime1;
        if (d7 < d8) {
            d7 = d8;
        } else if (d7 > arcArr[arcArr.length - 1].mTime2) {
            d7 = arcArr[arcArr.length - 1].mTime2;
        }
        int i7 = 0;
        while (true) {
            Arc[] arcArr2 = this.mArcs;
            if (i7 < arcArr2.length) {
                Arc arc = arcArr2[i7];
                if (d7 > arc.mTime2) {
                    i7++;
                } else if (arc.linear) {
                    dArr[0] = arc.getLinearDX(d7);
                    dArr[1] = this.mArcs[i7].getLinearDY(d7);
                    return;
                } else {
                    arc.setPoint(d7);
                    dArr[0] = this.mArcs[i7].getDX();
                    dArr[1] = this.mArcs[i7].getDY();
                    return;
                }
            } else {
                return;
            }
        }
    }

    @Override // androidx.constraintlayout.motion.utils.CurveFit
    public void getPos(double d7, float[] fArr) {
        Arc[] arcArr = this.mArcs;
        double d8 = arcArr[0].mTime1;
        if (d7 < d8) {
            d7 = d8;
        } else if (d7 > arcArr[arcArr.length - 1].mTime2) {
            d7 = arcArr[arcArr.length - 1].mTime2;
        }
        int i7 = 0;
        while (true) {
            Arc[] arcArr2 = this.mArcs;
            if (i7 < arcArr2.length) {
                Arc arc = arcArr2[i7];
                if (d7 > arc.mTime2) {
                    i7++;
                } else if (arc.linear) {
                    fArr[0] = (float) arc.getLinearX(d7);
                    fArr[1] = (float) this.mArcs[i7].getLinearY(d7);
                    return;
                } else {
                    arc.setPoint(d7);
                    fArr[0] = (float) this.mArcs[i7].getX();
                    fArr[1] = (float) this.mArcs[i7].getY();
                    return;
                }
            } else {
                return;
            }
        }
    }
}
