package androidx.constraintlayout.motion.utils;

import java.lang.reflect.Array;

public class MonotonicCurveFit extends CurveFit {
    private static final String TAG = "MonotonicCurveFit";
    private double[] mT;
    private double[][] mTangent;
    private double[][] mY;

    public MonotonicCurveFit(double[] dArr, double[][] dArr2) {
        int length = dArr.length;
        int length2 = dArr2[0].length;
        int i7 = length - 1;
        int[] iArr = new int[2];
        iArr[1] = length2;
        iArr[0] = i7;
        double[][] dArr3 = (double[][]) Array.newInstance(Double.TYPE, iArr);
        int[] iArr2 = new int[2];
        iArr2[1] = length2;
        iArr2[0] = length;
        double[][] dArr4 = (double[][]) Array.newInstance(Double.TYPE, iArr2);
        for (int i8 = 0; i8 < length2; i8++) {
            int i9 = 0;
            while (i9 < i7) {
                int i10 = i9 + 1;
                double d7 = dArr[i10] - dArr[i9];
                double[] dArr5 = dArr3[i9];
                double d8 = (dArr2[i10][i8] - dArr2[i9][i8]) / d7;
                dArr5[i8] = d8;
                if (i9 == 0) {
                    dArr4[i9][i8] = d8;
                } else {
                    dArr4[i9][i8] = (dArr3[i9 - 1][i8] + d8) * 0.5d;
                }
                i9 = i10;
            }
            dArr4[i7][i8] = dArr3[length - 2][i8];
        }
        for (int i11 = 0; i11 < i7; i11++) {
            for (int i12 = 0; i12 < length2; i12++) {
                double d9 = dArr3[i11][i12];
                if (d9 == 0.0d) {
                    dArr4[i11][i12] = 0.0d;
                    dArr4[i11 + 1][i12] = 0.0d;
                } else {
                    double d10 = dArr4[i11][i12] / d9;
                    int i13 = i11 + 1;
                    double d11 = dArr4[i13][i12] / d9;
                    double hypot = Math.hypot(d10, d11);
                    if (hypot > 9.0d) {
                        double d12 = 3.0d / hypot;
                        double[] dArr6 = dArr4[i11];
                        double[] dArr7 = dArr3[i11];
                        dArr6[i12] = d10 * d12 * dArr7[i12];
                        dArr4[i13][i12] = d12 * d11 * dArr7[i12];
                    }
                }
            }
        }
        this.mT = dArr;
        this.mY = dArr2;
        this.mTangent = dArr4;
    }

    private static double diff(double d7, double d8, double d9, double d10, double d11, double d12) {
        double d13 = d8 * d8;
        double d14 = d8 * 6.0d;
        double d15 = 3.0d * d7;
        return (((((((((-6.0d * d13) * d10) + (d14 * d10)) + ((6.0d * d13) * d9)) - (d14 * d9)) + ((d15 * d12) * d13)) + ((d15 * d11) * d13)) - (((2.0d * d7) * d12) * d8)) - (((4.0d * d7) * d11) * d8)) + (d7 * d11);
    }

    private static double interpolate(double d7, double d8, double d9, double d10, double d11, double d12) {
        double d13 = d8 * d8;
        double d14 = d13 * d8;
        double d15 = 3.0d * d13;
        double d16 = d7 * d12;
        double d17 = d7 * d11;
        return ((((((((((-2.0d * d14) * d10) + (d15 * d10)) + ((d14 * 2.0d) * d9)) - (d15 * d9)) + d9) + (d16 * d14)) + (d14 * d17)) - (d16 * d13)) - (((d7 * 2.0d) * d11) * d13)) + (d17 * d8);
    }

    @Override // androidx.constraintlayout.motion.utils.CurveFit
    public double getPos(double d7, int i7) {
        double[] dArr = this.mT;
        int length = dArr.length;
        int i8 = 0;
        if (d7 <= dArr[0]) {
            return this.mY[0][i7];
        }
        int i9 = length - 1;
        if (d7 >= dArr[i9]) {
            return this.mY[i9][i7];
        }
        while (i8 < i9) {
            double[] dArr2 = this.mT;
            double d8 = dArr2[i8];
            if (d7 == d8) {
                return this.mY[i8][i7];
            }
            int i10 = i8 + 1;
            double d9 = dArr2[i10];
            if (d7 < d9) {
                double d10 = d9 - d8;
                double d11 = (d7 - d8) / d10;
                double[][] dArr3 = this.mY;
                double d12 = dArr3[i8][i7];
                double d13 = dArr3[i10][i7];
                double[][] dArr4 = this.mTangent;
                return interpolate(d10, d11, d12, d13, dArr4[i8][i7], dArr4[i10][i7]);
            }
            i8 = i10;
        }
        return 0.0d;
    }

    @Override // androidx.constraintlayout.motion.utils.CurveFit
    public double getSlope(double d7, int i7) {
        double[] dArr = this.mT;
        int length = dArr.length;
        int i8 = 0;
        double d8 = dArr[0];
        if (d7 >= d8) {
            d8 = dArr[length - 1];
            if (d7 < d8) {
                d8 = d7;
            }
        }
        while (i8 < length - 1) {
            double[] dArr2 = this.mT;
            int i9 = i8 + 1;
            double d9 = dArr2[i9];
            if (d8 <= d9) {
                double d10 = dArr2[i8];
                double d11 = d9 - d10;
                double[][] dArr3 = this.mY;
                double d12 = dArr3[i8][i7];
                double d13 = dArr3[i9][i7];
                double[][] dArr4 = this.mTangent;
                return diff(d11, (d8 - d10) / d11, d12, d13, dArr4[i8][i7], dArr4[i9][i7]) / d11;
            }
            i8 = i9;
        }
        return 0.0d;
    }

    @Override // androidx.constraintlayout.motion.utils.CurveFit
    public double[] getTimePoints() {
        return this.mT;
    }

    @Override // androidx.constraintlayout.motion.utils.CurveFit
    public void getPos(double d7, double[] dArr) {
        double[] dArr2 = this.mT;
        int length = dArr2.length;
        int i7 = 0;
        int length2 = this.mY[0].length;
        if (d7 <= dArr2[0]) {
            for (int i8 = 0; i8 < length2; i8++) {
                dArr[i8] = this.mY[0][i8];
            }
            return;
        }
        int i9 = length - 1;
        if (d7 >= dArr2[i9]) {
            while (i7 < length2) {
                dArr[i7] = this.mY[i9][i7];
                i7++;
            }
            return;
        }
        int i10 = 0;
        while (i10 < i9) {
            if (d7 == this.mT[i10]) {
                for (int i11 = 0; i11 < length2; i11++) {
                    dArr[i11] = this.mY[i10][i11];
                }
            }
            double[] dArr3 = this.mT;
            int i12 = i10 + 1;
            double d8 = dArr3[i12];
            if (d7 < d8) {
                double d9 = dArr3[i10];
                double d10 = d8 - d9;
                double d11 = (d7 - d9) / d10;
                while (i7 < length2) {
                    double[][] dArr4 = this.mY;
                    double d12 = dArr4[i10][i7];
                    double d13 = dArr4[i12][i7];
                    double[][] dArr5 = this.mTangent;
                    dArr[i7] = interpolate(d10, d11, d12, d13, dArr5[i10][i7], dArr5[i12][i7]);
                    i7++;
                }
                return;
            }
            i10 = i12;
        }
    }

    @Override // androidx.constraintlayout.motion.utils.CurveFit
    public void getSlope(double d7, double[] dArr) {
        double[] dArr2 = this.mT;
        int length = dArr2.length;
        int length2 = this.mY[0].length;
        double d8 = dArr2[0];
        if (d7 > d8) {
            d8 = dArr2[length - 1];
            if (d7 < d8) {
                d8 = d7;
            }
        }
        int i7 = 0;
        while (i7 < length - 1) {
            double[] dArr3 = this.mT;
            int i8 = i7 + 1;
            double d9 = dArr3[i8];
            if (d8 <= d9) {
                double d10 = dArr3[i7];
                double d11 = d9 - d10;
                double d12 = (d8 - d10) / d11;
                for (int i9 = 0; i9 < length2; i9++) {
                    double[][] dArr4 = this.mY;
                    double d13 = dArr4[i7][i9];
                    double d14 = dArr4[i8][i9];
                    double[][] dArr5 = this.mTangent;
                    dArr[i9] = diff(d11, d12, d13, d14, dArr5[i7][i9], dArr5[i8][i9]) / d11;
                }
                return;
            }
            i7 = i8;
        }
    }

    @Override // androidx.constraintlayout.motion.utils.CurveFit
    public void getPos(double d7, float[] fArr) {
        double[] dArr = this.mT;
        int length = dArr.length;
        int i7 = 0;
        int length2 = this.mY[0].length;
        if (d7 <= dArr[0]) {
            for (int i8 = 0; i8 < length2; i8++) {
                fArr[i8] = (float) this.mY[0][i8];
            }
            return;
        }
        int i9 = length - 1;
        if (d7 >= dArr[i9]) {
            while (i7 < length2) {
                fArr[i7] = (float) this.mY[i9][i7];
                i7++;
            }
            return;
        }
        int i10 = 0;
        while (i10 < i9) {
            if (d7 == this.mT[i10]) {
                for (int i11 = 0; i11 < length2; i11++) {
                    fArr[i11] = (float) this.mY[i10][i11];
                }
            }
            double[] dArr2 = this.mT;
            int i12 = i10 + 1;
            double d8 = dArr2[i12];
            if (d7 < d8) {
                double d9 = dArr2[i10];
                double d10 = d8 - d9;
                double d11 = (d7 - d9) / d10;
                while (i7 < length2) {
                    double[][] dArr3 = this.mY;
                    double d12 = dArr3[i10][i7];
                    double d13 = dArr3[i12][i7];
                    double[][] dArr4 = this.mTangent;
                    fArr[i7] = (float) interpolate(d10, d11, d12, d13, dArr4[i10][i7], dArr4[i12][i7]);
                    i7++;
                }
                return;
            }
            i10 = i12;
        }
    }
}
