package androidx.constraintlayout.motion.utils;

import java.util.Arrays;

public class Oscillator {
    public static final int BOUNCE = 6;
    public static final int COS_WAVE = 5;
    public static final int REVERSE_SAW_WAVE = 4;
    public static final int SAW_WAVE = 3;
    public static final int SIN_WAVE = 0;
    public static final int SQUARE_WAVE = 1;
    public static String TAG = "Oscillator";
    public static final int TRIANGLE_WAVE = 2;
    double PI2 = 6.283185307179586d;
    double[] mArea;
    private boolean mNormalized = false;
    float[] mPeriod = new float[0];
    double[] mPosition = new double[0];
    int mType;

    public void addPoint(double d7, float f7) {
        int length = this.mPeriod.length + 1;
        int binarySearch = Arrays.binarySearch(this.mPosition, d7);
        if (binarySearch < 0) {
            binarySearch = (-binarySearch) - 1;
        }
        this.mPosition = Arrays.copyOf(this.mPosition, length);
        this.mPeriod = Arrays.copyOf(this.mPeriod, length);
        this.mArea = new double[length];
        double[] dArr = this.mPosition;
        System.arraycopy(dArr, binarySearch, dArr, binarySearch + 1, (length - binarySearch) - 1);
        this.mPosition[binarySearch] = d7;
        this.mPeriod[binarySearch] = f7;
        this.mNormalized = false;
    }

    /* access modifiers changed from: package-private */
    public double getDP(double d7) {
        if (d7 <= 0.0d) {
            d7 = 1.0E-5d;
        } else if (d7 >= 1.0d) {
            d7 = 0.999999d;
        }
        int binarySearch = Arrays.binarySearch(this.mPosition, d7);
        if (binarySearch > 0 || binarySearch == 0) {
            return 0.0d;
        }
        int i7 = (-binarySearch) - 1;
        float[] fArr = this.mPeriod;
        float f7 = fArr[i7];
        int i8 = i7 - 1;
        float f8 = fArr[i8];
        double d8 = (double) (f7 - f8);
        double[] dArr = this.mPosition;
        double d9 = dArr[i7];
        double d10 = dArr[i8];
        double d11 = d8 / (d9 - d10);
        return (((double) f8) - (d11 * d10)) + (d7 * d11);
    }

    /* access modifiers changed from: package-private */
    public double getP(double d7) {
        if (d7 < 0.0d) {
            d7 = 0.0d;
        } else if (d7 > 1.0d) {
            d7 = 1.0d;
        }
        int binarySearch = Arrays.binarySearch(this.mPosition, d7);
        if (binarySearch > 0) {
            return 1.0d;
        }
        if (binarySearch == 0) {
            return 0.0d;
        }
        int i7 = (-binarySearch) - 1;
        float[] fArr = this.mPeriod;
        float f7 = fArr[i7];
        int i8 = i7 - 1;
        float f8 = fArr[i8];
        double d8 = (double) (f7 - f8);
        double[] dArr = this.mPosition;
        double d9 = dArr[i7];
        double d10 = dArr[i8];
        double d11 = d8 / (d9 - d10);
        return this.mArea[i8] + ((((double) f8) - (d11 * d10)) * (d7 - d10)) + ((d11 * ((d7 * d7) - (d10 * d10))) / 2.0d);
    }

    public double getSlope(double d7) {
        double dp;
        double signum;
        double dp2;
        double dp3;
        double sin;
        switch (this.mType) {
            case 1:
                return 0.0d;
            case 2:
                dp = getDP(d7) * 4.0d;
                signum = Math.signum((((getP(d7) * 4.0d) + 3.0d) % 4.0d) - 2.0d);
                return dp * signum;
            case 3:
                dp2 = getDP(d7);
                return dp2 * 2.0d;
            case 4:
                dp2 = -getDP(d7);
                return dp2 * 2.0d;
            case 5:
                dp3 = (-this.PI2) * getDP(d7);
                sin = Math.sin(this.PI2 * getP(d7));
                return dp3 * sin;
            case 6:
                dp = getDP(d7) * 4.0d;
                signum = (((getP(d7) * 4.0d) + 2.0d) % 4.0d) - 2.0d;
                return dp * signum;
            default:
                dp3 = this.PI2 * getDP(d7);
                sin = Math.cos(this.PI2 * getP(d7));
                return dp3 * sin;
        }
    }

    public double getValue(double d7) {
        double abs;
        switch (this.mType) {
            case 1:
                return Math.signum(0.5d - (getP(d7) % 1.0d));
            case 2:
                abs = Math.abs((((getP(d7) * 4.0d) + 1.0d) % 4.0d) - 2.0d);
                break;
            case 3:
                return (((getP(d7) * 2.0d) + 1.0d) % 2.0d) - 1.0d;
            case 4:
                abs = ((getP(d7) * 2.0d) + 1.0d) % 2.0d;
                break;
            case 5:
                return Math.cos(this.PI2 * getP(d7));
            case 6:
                double abs2 = 1.0d - Math.abs(((getP(d7) * 4.0d) % 4.0d) - 2.0d);
                abs = abs2 * abs2;
                break;
            default:
                return Math.sin(this.PI2 * getP(d7));
        }
        return 1.0d - abs;
    }

    public void normalize() {
        double d7 = 0.0d;
        int i7 = 0;
        while (true) {
            float[] fArr = this.mPeriod;
            if (i7 >= fArr.length) {
                break;
            }
            d7 += (double) fArr[i7];
            i7++;
        }
        double d8 = 0.0d;
        int i8 = 1;
        while (true) {
            float[] fArr2 = this.mPeriod;
            if (i8 >= fArr2.length) {
                break;
            }
            int i9 = i8 - 1;
            double[] dArr = this.mPosition;
            d8 += (dArr[i8] - dArr[i9]) * ((double) ((fArr2[i9] + fArr2[i8]) / 2.0f));
            i8++;
        }
        int i10 = 0;
        while (true) {
            float[] fArr3 = this.mPeriod;
            if (i10 >= fArr3.length) {
                break;
            }
            fArr3[i10] = (float) (((double) fArr3[i10]) * (d7 / d8));
            i10++;
        }
        this.mArea[0] = 0.0d;
        int i11 = 1;
        while (true) {
            float[] fArr4 = this.mPeriod;
            if (i11 < fArr4.length) {
                int i12 = i11 - 1;
                double[] dArr2 = this.mPosition;
                double d9 = dArr2[i11] - dArr2[i12];
                double[] dArr3 = this.mArea;
                dArr3[i11] = dArr3[i12] + (d9 * ((double) ((fArr4[i12] + fArr4[i11]) / 2.0f)));
                i11++;
            } else {
                this.mNormalized = true;
                return;
            }
        }
    }

    public void setType(int i7) {
        this.mType = i7;
    }

    public String toString() {
        return "pos =" + Arrays.toString(this.mPosition) + " period=" + Arrays.toString(this.mPeriod);
    }
}
