package androidx.constraintlayout.motion.utils;

import android.util.Log;
import androidx.constraintlayout.motion.widget.MotionInterpolator;

public class StopLogic extends MotionInterpolator {
    private boolean mBackwards = false;
    private float mLastPosition;
    private int mNumberOfStages;
    private float mStage1Duration;
    private float mStage1EndPosition;
    private float mStage1Velocity;
    private float mStage2Duration;
    private float mStage2EndPosition;
    private float mStage2Velocity;
    private float mStage3Duration;
    private float mStage3EndPosition;
    private float mStage3Velocity;
    private float mStartPosition;
    private String mType;

    private float calcY(float f7) {
        float f8 = this.mStage1Duration;
        if (f7 <= f8) {
            float f9 = this.mStage1Velocity;
            return (f9 * f7) + ((((this.mStage2Velocity - f9) * f7) * f7) / (f8 * 2.0f));
        }
        int i7 = this.mNumberOfStages;
        if (i7 == 1) {
            return this.mStage1EndPosition;
        }
        float f10 = f7 - f8;
        float f11 = this.mStage2Duration;
        if (f10 < f11) {
            float f12 = this.mStage1EndPosition;
            float f13 = this.mStage2Velocity;
            return f12 + (f13 * f10) + ((((this.mStage3Velocity - f13) * f10) * f10) / (f11 * 2.0f));
        } else if (i7 == 2) {
            return this.mStage2EndPosition;
        } else {
            float f14 = f10 - f11;
            float f15 = this.mStage3Duration;
            if (f14 >= f15) {
                return this.mStage3EndPosition;
            }
            float f16 = this.mStage2EndPosition;
            float f17 = this.mStage3Velocity;
            return (f16 + (f17 * f14)) - (((f17 * f14) * f14) / (f15 * 2.0f));
        }
    }

    private void setup(float f7, float f8, float f9, float f10, float f11) {
        if (f7 == 0.0f) {
            f7 = 1.0E-4f;
        }
        this.mStage1Velocity = f7;
        float f12 = f7 / f9;
        float f13 = (f12 * f7) / 2.0f;
        if (f7 < 0.0f) {
            float sqrt = (float) Math.sqrt((double) ((f8 - ((((-f7) / f9) * f7) / 2.0f)) * f9));
            if (sqrt < f10) {
                this.mType = "backward accelerate, decelerate";
                this.mNumberOfStages = 2;
                this.mStage1Velocity = f7;
                this.mStage2Velocity = sqrt;
                this.mStage3Velocity = 0.0f;
                float f14 = (sqrt - f7) / f9;
                this.mStage1Duration = f14;
                this.mStage2Duration = sqrt / f9;
                this.mStage1EndPosition = ((f7 + sqrt) * f14) / 2.0f;
                this.mStage2EndPosition = f8;
                this.mStage3EndPosition = f8;
                return;
            }
            this.mType = "backward accelerate cruse decelerate";
            this.mNumberOfStages = 3;
            this.mStage1Velocity = f7;
            this.mStage2Velocity = f10;
            this.mStage3Velocity = f10;
            float f15 = (f10 - f7) / f9;
            this.mStage1Duration = f15;
            float f16 = f10 / f9;
            this.mStage3Duration = f16;
            float f17 = ((f7 + f10) * f15) / 2.0f;
            float f18 = (f16 * f10) / 2.0f;
            this.mStage2Duration = ((f8 - f17) - f18) / f10;
            this.mStage1EndPosition = f17;
            this.mStage2EndPosition = f8 - f18;
            this.mStage3EndPosition = f8;
        } else if (f13 >= f8) {
            this.mType = "hard stop";
            this.mNumberOfStages = 1;
            this.mStage1Velocity = f7;
            this.mStage2Velocity = 0.0f;
            this.mStage1EndPosition = f8;
            this.mStage1Duration = (2.0f * f8) / f7;
        } else {
            float f19 = f8 - f13;
            float f20 = f19 / f7;
            if (f20 + f12 < f11) {
                this.mType = "cruse decelerate";
                this.mNumberOfStages = 2;
                this.mStage1Velocity = f7;
                this.mStage2Velocity = f7;
                this.mStage3Velocity = 0.0f;
                this.mStage1EndPosition = f19;
                this.mStage2EndPosition = f8;
                this.mStage1Duration = f20;
                this.mStage2Duration = f12;
                return;
            }
            float sqrt2 = (float) Math.sqrt((double) ((f9 * f8) + ((f7 * f7) / 2.0f)));
            float f21 = (sqrt2 - f7) / f9;
            this.mStage1Duration = f21;
            float f22 = sqrt2 / f9;
            this.mStage2Duration = f22;
            if (sqrt2 < f10) {
                this.mType = "accelerate decelerate";
                this.mNumberOfStages = 2;
                this.mStage1Velocity = f7;
                this.mStage2Velocity = sqrt2;
                this.mStage3Velocity = 0.0f;
                this.mStage1Duration = f21;
                this.mStage2Duration = f22;
                this.mStage1EndPosition = ((f7 + sqrt2) * f21) / 2.0f;
                this.mStage2EndPosition = f8;
                return;
            }
            this.mType = "accelerate cruse decelerate";
            this.mNumberOfStages = 3;
            this.mStage1Velocity = f7;
            this.mStage2Velocity = f10;
            this.mStage3Velocity = f10;
            float f23 = (f10 - f7) / f9;
            this.mStage1Duration = f23;
            float f24 = f10 / f9;
            this.mStage3Duration = f24;
            float f25 = ((f7 + f10) * f23) / 2.0f;
            float f26 = (f24 * f10) / 2.0f;
            this.mStage2Duration = ((f8 - f25) - f26) / f10;
            this.mStage1EndPosition = f25;
            this.mStage2EndPosition = f8 - f26;
            this.mStage3EndPosition = f8;
        }
    }

    public void config(float f7, float f8, float f9, float f10, float f11, float f12) {
        float f13;
        float f14;
        StopLogic stopLogic;
        this.mStartPosition = f7;
        boolean z7 = f7 > f8;
        this.mBackwards = z7;
        if (z7) {
            f13 = f7 - f8;
            stopLogic = this;
            f14 = -f9;
        } else {
            f13 = f8 - f7;
            stopLogic = this;
            f14 = f9;
        }
        stopLogic.setup(f14, f13, f11, f12, f10);
    }

    public void debug(String str, String str2, float f7) {
        StringBuilder sb;
        String str3;
        Log.v(str, str2 + " ===== " + this.mType);
        StringBuilder sb2 = new StringBuilder();
        sb2.append(str2);
        sb2.append(this.mBackwards ? "backwards" : "forward ");
        sb2.append(" time = ");
        sb2.append(f7);
        sb2.append("  stages ");
        sb2.append(this.mNumberOfStages);
        Log.v(str, sb2.toString());
        Log.v(str, str2 + " dur " + this.mStage1Duration + " vel " + this.mStage1Velocity + " pos " + this.mStage1EndPosition);
        if (this.mNumberOfStages > 1) {
            Log.v(str, str2 + " dur " + this.mStage2Duration + " vel " + this.mStage2Velocity + " pos " + this.mStage2EndPosition);
        }
        if (this.mNumberOfStages > 2) {
            Log.v(str, str2 + " dur " + this.mStage3Duration + " vel " + this.mStage3Velocity + " pos " + this.mStage3EndPosition);
        }
        float f8 = this.mStage1Duration;
        if (f7 <= f8) {
            sb = new StringBuilder();
            sb.append(str2);
            str3 = "stage 0";
        } else {
            int i7 = this.mNumberOfStages;
            if (i7 == 1) {
                sb = new StringBuilder();
                sb.append(str2);
                str3 = "end stage 0";
            } else {
                float f9 = f7 - f8;
                float f10 = this.mStage2Duration;
                if (f9 < f10) {
                    sb = new StringBuilder();
                    sb.append(str2);
                    str3 = " stage 1";
                } else if (i7 == 2) {
                    sb = new StringBuilder();
                    sb.append(str2);
                    str3 = "end stage 1";
                } else if (f9 - f10 < this.mStage3Duration) {
                    sb = new StringBuilder();
                    sb.append(str2);
                    str3 = " stage 2";
                } else {
                    sb = new StringBuilder();
                    sb.append(str2);
                    str3 = " end stage 2";
                }
            }
        }
        sb.append(str3);
        Log.v(str, sb.toString());
    }

    @Override // androidx.constraintlayout.motion.widget.MotionInterpolator
    public float getInterpolation(float f7) {
        float calcY = calcY(f7);
        this.mLastPosition = f7;
        boolean z7 = this.mBackwards;
        float f8 = this.mStartPosition;
        return z7 ? f8 - calcY : f8 + calcY;
    }

    @Override // androidx.constraintlayout.motion.widget.MotionInterpolator
    public float getVelocity() {
        return this.mBackwards ? -getVelocity(this.mLastPosition) : getVelocity(this.mLastPosition);
    }

    public float getVelocity(float f7) {
        float f8;
        float f9;
        float f10 = this.mStage1Duration;
        if (f7 <= f10) {
            f8 = this.mStage1Velocity;
            f9 = this.mStage2Velocity;
        } else {
            int i7 = this.mNumberOfStages;
            if (i7 == 1) {
                return 0.0f;
            }
            f7 -= f10;
            f10 = this.mStage2Duration;
            if (f7 < f10) {
                f8 = this.mStage2Velocity;
                f9 = this.mStage3Velocity;
            } else if (i7 == 2) {
                return this.mStage2EndPosition;
            } else {
                float f11 = f7 - f10;
                float f12 = this.mStage3Duration;
                if (f11 >= f12) {
                    return this.mStage3EndPosition;
                }
                float f13 = this.mStage3Velocity;
                return f13 - ((f11 * f13) / f12);
            }
        }
        return f8 + (((f9 - f8) * f7) / f10);
    }
}
