package androidx.constraintlayout.motion.widget;

import android.util.Log;
import android.util.SparseArray;
import android.view.View;
import androidx.constraintlayout.motion.utils.CurveFit;
import androidx.constraintlayout.widget.ConstraintAttribute;
import androidx.core.app.NotificationCompat;
import java.lang.reflect.Array;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.text.DecimalFormat;

public abstract class TimeCycleSplineSet {
    private static final int CURVE_OFFSET = 2;
    private static final int CURVE_PERIOD = 1;
    private static final int CURVE_VALUE = 0;
    private static final String TAG = "SplineSet";
    private static float VAL_2PI = 6.2831855f;
    private int count;
    float last_cycle = Float.NaN;
    long last_time;
    private float[] mCache = new float[3];
    protected boolean mContinue = false;
    protected CurveFit mCurveFit;
    protected int[] mTimePoints = new int[10];
    private String mType;
    protected float[][] mValues = ((float[][]) Array.newInstance(Float.TYPE, 10, 3));
    protected int mWaveShape = 0;

    /* access modifiers changed from: package-private */
    public static class AlphaSet extends TimeCycleSplineSet {
        AlphaSet() {
        }

        @Override // androidx.constraintlayout.motion.widget.TimeCycleSplineSet
        public boolean setProperty(View view, float f7, long j7, KeyCache keyCache) {
            view.setAlpha(get(f7, j7, view, keyCache));
            return this.mContinue;
        }
    }

    /* access modifiers changed from: package-private */
    public static class CustomSet extends TimeCycleSplineSet {
        String mAttributeName;
        float[] mCache;
        SparseArray<ConstraintAttribute> mConstraintAttributeList;
        float[] mTempValues;
        SparseArray<float[]> mWaveProperties = new SparseArray<>();

        public CustomSet(String str, SparseArray<ConstraintAttribute> sparseArray) {
            this.mAttributeName = str.split(",")[1];
            this.mConstraintAttributeList = sparseArray;
        }

        @Override // androidx.constraintlayout.motion.widget.TimeCycleSplineSet
        public void setPoint(int i7, float f7, float f8, int i8, float f9) {
            throw new RuntimeException("don't call for custom attribute call setPoint(pos, ConstraintAttribute,...)");
        }

        @Override // androidx.constraintlayout.motion.widget.TimeCycleSplineSet
        public boolean setProperty(View view, float f7, long j7, KeyCache keyCache) {
            this.mCurveFit.getPos((double) f7, this.mTempValues);
            float[] fArr = this.mTempValues;
            float f8 = fArr[fArr.length - 2];
            float f9 = fArr[fArr.length - 1];
            long j8 = j7 - this.last_time;
            if (Float.isNaN(this.last_cycle)) {
                float floatValue = keyCache.getFloatValue(view, this.mAttributeName, 0);
                this.last_cycle = floatValue;
                if (Float.isNaN(floatValue)) {
                    this.last_cycle = 0.0f;
                }
            }
            float f10 = (float) ((((double) this.last_cycle) + ((((double) j8) * 1.0E-9d) * ((double) f8))) % 1.0d);
            this.last_cycle = f10;
            this.last_time = j7;
            float calcWave = calcWave(f10);
            this.mContinue = false;
            int i7 = 0;
            while (true) {
                float[] fArr2 = this.mCache;
                if (i7 >= fArr2.length) {
                    break;
                }
                boolean z7 = this.mContinue;
                float f11 = this.mTempValues[i7];
                this.mContinue = z7 | (((double) f11) != 0.0d);
                fArr2[i7] = (f11 * calcWave) + f9;
                i7++;
            }
            this.mConstraintAttributeList.valueAt(0).setInterpolatedValue(view, this.mCache);
            if (f8 != 0.0f) {
                this.mContinue = true;
            }
            return this.mContinue;
        }

        @Override // androidx.constraintlayout.motion.widget.TimeCycleSplineSet
        public void setup(int i7) {
            int size = this.mConstraintAttributeList.size();
            int noOfInterpValues = this.mConstraintAttributeList.valueAt(0).noOfInterpValues();
            double[] dArr = new double[size];
            int i8 = noOfInterpValues + 2;
            this.mTempValues = new float[i8];
            this.mCache = new float[noOfInterpValues];
            int[] iArr = new int[2];
            iArr[1] = i8;
            iArr[0] = size;
            double[][] dArr2 = (double[][]) Array.newInstance(Double.TYPE, iArr);
            for (int i9 = 0; i9 < size; i9++) {
                int keyAt = this.mConstraintAttributeList.keyAt(i9);
                float[] valueAt = this.mWaveProperties.valueAt(i9);
                dArr[i9] = ((double) keyAt) * 0.01d;
                this.mConstraintAttributeList.valueAt(i9).getValuesToInterpolate(this.mTempValues);
                int i10 = 0;
                while (true) {
                    float[] fArr = this.mTempValues;
                    if (i10 >= fArr.length) {
                        break;
                    }
                    dArr2[i9][i10] = (double) fArr[i10];
                    i10++;
                }
                double[] dArr3 = dArr2[i9];
                dArr3[noOfInterpValues] = (double) valueAt[0];
                dArr3[noOfInterpValues + 1] = (double) valueAt[1];
            }
            this.mCurveFit = CurveFit.get(i7, dArr, dArr2);
        }

        public void setPoint(int i7, ConstraintAttribute constraintAttribute, float f7, int i8, float f8) {
            this.mConstraintAttributeList.append(i7, constraintAttribute);
            this.mWaveProperties.append(i7, new float[]{f7, f8});
            this.mWaveShape = Math.max(this.mWaveShape, i8);
        }
    }

    /* access modifiers changed from: package-private */
    public static class ElevationSet extends TimeCycleSplineSet {
        ElevationSet() {
        }

        @Override // androidx.constraintlayout.motion.widget.TimeCycleSplineSet
        public boolean setProperty(View view, float f7, long j7, KeyCache keyCache) {
            view.setElevation(get(f7, j7, view, keyCache));
            return this.mContinue;
        }
    }

    /* access modifiers changed from: package-private */
    public static class PathRotate extends TimeCycleSplineSet {
        PathRotate() {
        }

        public boolean setPathRotate(View view, KeyCache keyCache, float f7, long j7, double d7, double d8) {
            view.setRotation(get(f7, j7, view, keyCache) + ((float) Math.toDegrees(Math.atan2(d8, d7))));
            return this.mContinue;
        }

        @Override // androidx.constraintlayout.motion.widget.TimeCycleSplineSet
        public boolean setProperty(View view, float f7, long j7, KeyCache keyCache) {
            return this.mContinue;
        }
    }

    /* access modifiers changed from: package-private */
    public static class ProgressSet extends TimeCycleSplineSet {
        boolean mNoMethod = false;

        ProgressSet() {
        }

        @Override // androidx.constraintlayout.motion.widget.TimeCycleSplineSet
        public boolean setProperty(View view, float f7, long j7, KeyCache keyCache) {
            Method method;
            if (view instanceof MotionLayout) {
                ((MotionLayout) view).setProgress(get(f7, j7, view, keyCache));
            } else if (this.mNoMethod) {
                return false;
            } else {
                try {
                    method = view.getClass().getMethod("setProgress", Float.TYPE);
                } catch (NoSuchMethodException unused) {
                    this.mNoMethod = true;
                    method = null;
                }
                if (method != null) {
                    try {
                        method.invoke(view, Float.valueOf(get(f7, j7, view, keyCache)));
                    } catch (IllegalAccessException | InvocationTargetException e7) {
                        Log.e(TimeCycleSplineSet.TAG, "unable to setProgress", e7);
                    }
                }
            }
            return this.mContinue;
        }
    }

    /* access modifiers changed from: package-private */
    public static class RotationSet extends TimeCycleSplineSet {
        RotationSet() {
        }

        @Override // androidx.constraintlayout.motion.widget.TimeCycleSplineSet
        public boolean setProperty(View view, float f7, long j7, KeyCache keyCache) {
            view.setRotation(get(f7, j7, view, keyCache));
            return this.mContinue;
        }
    }

    /* access modifiers changed from: package-private */
    public static class RotationXset extends TimeCycleSplineSet {
        RotationXset() {
        }

        @Override // androidx.constraintlayout.motion.widget.TimeCycleSplineSet
        public boolean setProperty(View view, float f7, long j7, KeyCache keyCache) {
            view.setRotationX(get(f7, j7, view, keyCache));
            return this.mContinue;
        }
    }

    /* access modifiers changed from: package-private */
    public static class RotationYset extends TimeCycleSplineSet {
        RotationYset() {
        }

        @Override // androidx.constraintlayout.motion.widget.TimeCycleSplineSet
        public boolean setProperty(View view, float f7, long j7, KeyCache keyCache) {
            view.setRotationY(get(f7, j7, view, keyCache));
            return this.mContinue;
        }
    }

    /* access modifiers changed from: package-private */
    public static class ScaleXset extends TimeCycleSplineSet {
        ScaleXset() {
        }

        @Override // androidx.constraintlayout.motion.widget.TimeCycleSplineSet
        public boolean setProperty(View view, float f7, long j7, KeyCache keyCache) {
            view.setScaleX(get(f7, j7, view, keyCache));
            return this.mContinue;
        }
    }

    /* access modifiers changed from: package-private */
    public static class ScaleYset extends TimeCycleSplineSet {
        ScaleYset() {
        }

        @Override // androidx.constraintlayout.motion.widget.TimeCycleSplineSet
        public boolean setProperty(View view, float f7, long j7, KeyCache keyCache) {
            view.setScaleY(get(f7, j7, view, keyCache));
            return this.mContinue;
        }
    }

    /* access modifiers changed from: private */
    public static class Sort {
        private Sort() {
        }

        static void doubleQuickSort(int[] iArr, float[][] fArr, int i7, int i8) {
            int[] iArr2 = new int[(iArr.length + 10)];
            iArr2[0] = i8;
            iArr2[1] = i7;
            int i9 = 2;
            while (i9 > 0) {
                int i10 = i9 - 1;
                int i11 = iArr2[i10];
                i9 = i10 - 1;
                int i12 = iArr2[i9];
                if (i11 < i12) {
                    int partition = partition(iArr, fArr, i11, i12);
                    int i13 = i9 + 1;
                    iArr2[i9] = partition - 1;
                    int i14 = i13 + 1;
                    iArr2[i13] = i11;
                    int i15 = i14 + 1;
                    iArr2[i14] = i12;
                    i9 = i15 + 1;
                    iArr2[i15] = partition + 1;
                }
            }
        }

        private static int partition(int[] iArr, float[][] fArr, int i7, int i8) {
            int i9 = iArr[i8];
            int i10 = i7;
            while (i7 < i8) {
                if (iArr[i7] <= i9) {
                    swap(iArr, fArr, i10, i7);
                    i10++;
                }
                i7++;
            }
            swap(iArr, fArr, i10, i8);
            return i10;
        }

        private static void swap(int[] iArr, float[][] fArr, int i7, int i8) {
            int i9 = iArr[i7];
            iArr[i7] = iArr[i8];
            iArr[i8] = i9;
            float[] fArr2 = fArr[i7];
            fArr[i7] = fArr[i8];
            fArr[i8] = fArr2;
        }
    }

    /* access modifiers changed from: package-private */
    public static class TranslationXset extends TimeCycleSplineSet {
        TranslationXset() {
        }

        @Override // androidx.constraintlayout.motion.widget.TimeCycleSplineSet
        public boolean setProperty(View view, float f7, long j7, KeyCache keyCache) {
            view.setTranslationX(get(f7, j7, view, keyCache));
            return this.mContinue;
        }
    }

    /* access modifiers changed from: package-private */
    public static class TranslationYset extends TimeCycleSplineSet {
        TranslationYset() {
        }

        @Override // androidx.constraintlayout.motion.widget.TimeCycleSplineSet
        public boolean setProperty(View view, float f7, long j7, KeyCache keyCache) {
            view.setTranslationY(get(f7, j7, view, keyCache));
            return this.mContinue;
        }
    }

    /* access modifiers changed from: package-private */
    public static class TranslationZset extends TimeCycleSplineSet {
        TranslationZset() {
        }

        @Override // androidx.constraintlayout.motion.widget.TimeCycleSplineSet
        public boolean setProperty(View view, float f7, long j7, KeyCache keyCache) {
            view.setTranslationZ(get(f7, j7, view, keyCache));
            return this.mContinue;
        }
    }

    static TimeCycleSplineSet makeCustomSpline(String str, SparseArray<ConstraintAttribute> sparseArray) {
        return new CustomSet(str, sparseArray);
    }

    static TimeCycleSplineSet makeSpline(String str, long j7) {
        TimeCycleSplineSet timeCycleSplineSet;
        str.hashCode();
        char c7 = 65535;
        switch (str.hashCode()) {
            case -1249320806:
                if (str.equals("rotationX")) {
                    c7 = 0;
                    break;
                }
                break;
            case -1249320805:
                if (str.equals("rotationY")) {
                    c7 = 1;
                    break;
                }
                break;
            case -1225497657:
                if (str.equals("translationX")) {
                    c7 = 2;
                    break;
                }
                break;
            case -1225497656:
                if (str.equals("translationY")) {
                    c7 = 3;
                    break;
                }
                break;
            case -1225497655:
                if (str.equals("translationZ")) {
                    c7 = 4;
                    break;
                }
                break;
            case -1001078227:
                if (str.equals(NotificationCompat.CATEGORY_PROGRESS)) {
                    c7 = 5;
                    break;
                }
                break;
            case -908189618:
                if (str.equals("scaleX")) {
                    c7 = 6;
                    break;
                }
                break;
            case -908189617:
                if (str.equals("scaleY")) {
                    c7 = 7;
                    break;
                }
                break;
            case -40300674:
                if (str.equals("rotation")) {
                    c7 = '\b';
                    break;
                }
                break;
            case -4379043:
                if (str.equals("elevation")) {
                    c7 = '\t';
                    break;
                }
                break;
            case 37232917:
                if (str.equals("transitionPathRotate")) {
                    c7 = '\n';
                    break;
                }
                break;
            case 92909918:
                if (str.equals("alpha")) {
                    c7 = 11;
                    break;
                }
                break;
        }
        switch (c7) {
            case 0:
                timeCycleSplineSet = new RotationXset();
                break;
            case 1:
                timeCycleSplineSet = new RotationYset();
                break;
            case 2:
                timeCycleSplineSet = new TranslationXset();
                break;
            case 3:
                timeCycleSplineSet = new TranslationYset();
                break;
            case 4:
                timeCycleSplineSet = new TranslationZset();
                break;
            case 5:
                timeCycleSplineSet = new ProgressSet();
                break;
            case 6:
                timeCycleSplineSet = new ScaleXset();
                break;
            case 7:
                timeCycleSplineSet = new ScaleYset();
                break;
            case '\b':
                timeCycleSplineSet = new RotationSet();
                break;
            case '\t':
                timeCycleSplineSet = new ElevationSet();
                break;
            case '\n':
                timeCycleSplineSet = new PathRotate();
                break;
            case 11:
                timeCycleSplineSet = new AlphaSet();
                break;
            default:
                return null;
        }
        timeCycleSplineSet.setStartTime(j7);
        return timeCycleSplineSet;
    }

    /* access modifiers changed from: protected */
    public float calcWave(float f7) {
        switch (this.mWaveShape) {
            case 1:
                return Math.signum(f7 * VAL_2PI);
            case 2:
                return 1.0f - Math.abs(f7);
            case 3:
                return (((f7 * 2.0f) + 1.0f) % 2.0f) - 1.0f;
            case 4:
                return 1.0f - (((f7 * 2.0f) + 1.0f) % 2.0f);
            case 5:
                return (float) Math.cos((double) (f7 * VAL_2PI));
            case 6:
                float abs = 1.0f - Math.abs(((f7 * 4.0f) % 4.0f) - 2.0f);
                return 1.0f - (abs * abs);
            default:
                return (float) Math.sin((double) (f7 * VAL_2PI));
        }
    }

    public float get(float f7, long j7, View view, KeyCache keyCache) {
        this.mCurveFit.getPos((double) f7, this.mCache);
        float[] fArr = this.mCache;
        float f8 = fArr[1];
        int i7 = (f8 > 0.0f ? 1 : (f8 == 0.0f ? 0 : -1));
        if (i7 == 0) {
            this.mContinue = false;
            return fArr[2];
        }
        if (Float.isNaN(this.last_cycle)) {
            float floatValue = keyCache.getFloatValue(view, this.mType, 0);
            this.last_cycle = floatValue;
            if (Float.isNaN(floatValue)) {
                this.last_cycle = 0.0f;
            }
        }
        float f9 = (float) ((((double) this.last_cycle) + ((((double) (j7 - this.last_time)) * 1.0E-9d) * ((double) f8))) % 1.0d);
        this.last_cycle = f9;
        keyCache.setFloatValue(view, this.mType, 0, f9);
        this.last_time = j7;
        float f10 = this.mCache[0];
        float calcWave = (calcWave(this.last_cycle) * f10) + this.mCache[2];
        this.mContinue = (f10 == 0.0f && i7 == 0) ? false : true;
        return calcWave;
    }

    public CurveFit getCurveFit() {
        return this.mCurveFit;
    }

    public void setPoint(int i7, float f7, float f8, int i8, float f9) {
        int[] iArr = this.mTimePoints;
        int i9 = this.count;
        iArr[i9] = i7;
        float[] fArr = this.mValues[i9];
        fArr[0] = f7;
        fArr[1] = f8;
        fArr[2] = f9;
        this.mWaveShape = Math.max(this.mWaveShape, i8);
        this.count++;
    }

    public abstract boolean setProperty(View view, float f7, long j7, KeyCache keyCache);

    /* access modifiers changed from: protected */
    public void setStartTime(long j7) {
        this.last_time = j7;
    }

    public void setType(String str) {
        this.mType = str;
    }

    public void setup(int i7) {
        int i8 = this.count;
        if (i8 == 0) {
            Log.e(TAG, "Error no points added to " + this.mType);
            return;
        }
        Sort.doubleQuickSort(this.mTimePoints, this.mValues, 0, i8 - 1);
        int i9 = 1;
        int i10 = 0;
        while (true) {
            int[] iArr = this.mTimePoints;
            if (i9 >= iArr.length) {
                break;
            }
            if (iArr[i9] != iArr[i9 - 1]) {
                i10++;
            }
            i9++;
        }
        if (i10 == 0) {
            i10 = 1;
        }
        double[] dArr = new double[i10];
        int[] iArr2 = new int[2];
        iArr2[1] = 3;
        iArr2[0] = i10;
        double[][] dArr2 = (double[][]) Array.newInstance(Double.TYPE, iArr2);
        int i11 = 0;
        for (int i12 = 0; i12 < this.count; i12++) {
            if (i12 > 0) {
                int[] iArr3 = this.mTimePoints;
                if (iArr3[i12] == iArr3[i12 - 1]) {
                }
            }
            dArr[i11] = ((double) this.mTimePoints[i12]) * 0.01d;
            double[] dArr3 = dArr2[i11];
            float[] fArr = this.mValues[i12];
            dArr3[0] = (double) fArr[0];
            dArr3[1] = (double) fArr[1];
            dArr3[2] = (double) fArr[2];
            i11++;
        }
        this.mCurveFit = CurveFit.get(i7, dArr, dArr2);
    }

    public String toString() {
        String str = this.mType;
        DecimalFormat decimalFormat = new DecimalFormat("##.##");
        for (int i7 = 0; i7 < this.count; i7++) {
            str = str + "[" + this.mTimePoints[i7] + " , " + decimalFormat.format(this.mValues[i7]) + "] ";
        }
        return str;
    }
}
