package androidx.constraintlayout.solver;

import androidx.constraintlayout.solver.LinearSystem;
import androidx.constraintlayout.solver.SolverVariable;
import java.util.ArrayList;

public class ArrayRow implements LinearSystem.Row {
    private static final boolean DEBUG = false;
    private static final boolean FULL_NEW_CHECK = false;
    float constantValue = 0.0f;
    boolean isSimpleDefinition = false;
    boolean used = false;
    SolverVariable variable = null;
    public ArrayRowVariables variables;
    ArrayList<SolverVariable> variablesToUpdate = new ArrayList<>();

    public interface ArrayRowVariables {
        void add(SolverVariable solverVariable, float f7, boolean z7);

        void clear();

        boolean contains(SolverVariable solverVariable);

        void display();

        void divideByAmount(float f7);

        float get(SolverVariable solverVariable);

        int getCurrentSize();

        SolverVariable getVariable(int i7);

        float getVariableValue(int i7);

        int indexOf(SolverVariable solverVariable);

        void invert();

        void put(SolverVariable solverVariable, float f7);

        float remove(SolverVariable solverVariable, boolean z7);

        int sizeInBytes();

        float use(ArrayRow arrayRow, boolean z7);
    }

    public ArrayRow() {
    }

    private boolean isNew(SolverVariable solverVariable, LinearSystem linearSystem) {
        return solverVariable.usageInRowCount <= 1;
    }

    private SolverVariable pickPivotInVariables(boolean[] zArr, SolverVariable solverVariable) {
        SolverVariable.Type type;
        int currentSize = this.variables.getCurrentSize();
        SolverVariable solverVariable2 = null;
        float f7 = 0.0f;
        for (int i7 = 0; i7 < currentSize; i7++) {
            float variableValue = this.variables.getVariableValue(i7);
            if (variableValue < 0.0f) {
                SolverVariable variable2 = this.variables.getVariable(i7);
                if ((zArr == null || !zArr[variable2.id]) && variable2 != solverVariable && (((type = variable2.mType) == SolverVariable.Type.SLACK || type == SolverVariable.Type.ERROR) && variableValue < f7)) {
                    f7 = variableValue;
                    solverVariable2 = variable2;
                }
            }
        }
        return solverVariable2;
    }

    public ArrayRow addError(LinearSystem linearSystem, int i7) {
        this.variables.put(linearSystem.createErrorVariable(i7, "ep"), 1.0f);
        this.variables.put(linearSystem.createErrorVariable(i7, "em"), -1.0f);
        return this;
    }

    /* access modifiers changed from: package-private */
    public ArrayRow addSingleError(SolverVariable solverVariable, int i7) {
        this.variables.put(solverVariable, (float) i7);
        return this;
    }

    /* access modifiers changed from: package-private */
    public boolean chooseSubject(LinearSystem linearSystem) {
        boolean z7;
        SolverVariable chooseSubjectInVariables = chooseSubjectInVariables(linearSystem);
        if (chooseSubjectInVariables == null) {
            z7 = true;
        } else {
            pivot(chooseSubjectInVariables);
            z7 = false;
        }
        if (this.variables.getCurrentSize() == 0) {
            this.isSimpleDefinition = true;
        }
        return z7;
    }

    /* access modifiers changed from: package-private */
    public SolverVariable chooseSubjectInVariables(LinearSystem linearSystem) {
        int currentSize = this.variables.getCurrentSize();
        SolverVariable solverVariable = null;
        float f7 = 0.0f;
        float f8 = 0.0f;
        boolean z7 = false;
        boolean z8 = false;
        SolverVariable solverVariable2 = null;
        for (int i7 = 0; i7 < currentSize; i7++) {
            float variableValue = this.variables.getVariableValue(i7);
            SolverVariable variable2 = this.variables.getVariable(i7);
            if (variable2.mType == SolverVariable.Type.UNRESTRICTED) {
                if (solverVariable == null || f7 > variableValue) {
                    z7 = isNew(variable2, linearSystem);
                    f7 = variableValue;
                    solverVariable = variable2;
                } else if (!z7 && isNew(variable2, linearSystem)) {
                    f7 = variableValue;
                    solverVariable = variable2;
                    z7 = true;
                }
            } else if (solverVariable == null && variableValue < 0.0f) {
                if (solverVariable2 == null || f8 > variableValue) {
                    z8 = isNew(variable2, linearSystem);
                    f8 = variableValue;
                    solverVariable2 = variable2;
                } else if (!z8 && isNew(variable2, linearSystem)) {
                    f8 = variableValue;
                    solverVariable2 = variable2;
                    z8 = true;
                }
            }
        }
        return solverVariable != null ? solverVariable : solverVariable2;
    }

    @Override // androidx.constraintlayout.solver.LinearSystem.Row
    public void clear() {
        this.variables.clear();
        this.variable = null;
        this.constantValue = 0.0f;
    }

    /* access modifiers changed from: package-private */
    public ArrayRow createRowCentering(SolverVariable solverVariable, SolverVariable solverVariable2, int i7, float f7, SolverVariable solverVariable3, SolverVariable solverVariable4, int i8) {
        float f8;
        int i9;
        if (solverVariable2 == solverVariable3) {
            this.variables.put(solverVariable, 1.0f);
            this.variables.put(solverVariable4, 1.0f);
            this.variables.put(solverVariable2, -2.0f);
            return this;
        }
        if (f7 == 0.5f) {
            this.variables.put(solverVariable, 1.0f);
            this.variables.put(solverVariable2, -1.0f);
            this.variables.put(solverVariable3, -1.0f);
            this.variables.put(solverVariable4, 1.0f);
            if (i7 > 0 || i8 > 0) {
                i9 = (-i7) + i8;
            }
            return this;
        }
        if (f7 <= 0.0f) {
            this.variables.put(solverVariable, -1.0f);
            this.variables.put(solverVariable2, 1.0f);
            f8 = (float) i7;
        } else if (f7 >= 1.0f) {
            this.variables.put(solverVariable4, -1.0f);
            this.variables.put(solverVariable3, 1.0f);
            i9 = -i8;
        } else {
            float f9 = 1.0f - f7;
            this.variables.put(solverVariable, f9 * 1.0f);
            this.variables.put(solverVariable2, f9 * -1.0f);
            this.variables.put(solverVariable3, -1.0f * f7);
            this.variables.put(solverVariable4, 1.0f * f7);
            if (i7 > 0 || i8 > 0) {
                f8 = (((float) (-i7)) * f9) + (((float) i8) * f7);
            }
            return this;
        }
        this.constantValue = f8;
        return this;
        f8 = (float) i9;
        this.constantValue = f8;
        return this;
    }

    /* access modifiers changed from: package-private */
    public ArrayRow createRowDefinition(SolverVariable solverVariable, int i7) {
        this.variable = solverVariable;
        float f7 = (float) i7;
        solverVariable.computedValue = f7;
        this.constantValue = f7;
        this.isSimpleDefinition = true;
        return this;
    }

    /* access modifiers changed from: package-private */
    public ArrayRow createRowDimensionPercent(SolverVariable solverVariable, SolverVariable solverVariable2, float f7) {
        this.variables.put(solverVariable, -1.0f);
        this.variables.put(solverVariable2, f7);
        return this;
    }

    public ArrayRow createRowDimensionRatio(SolverVariable solverVariable, SolverVariable solverVariable2, SolverVariable solverVariable3, SolverVariable solverVariable4, float f7) {
        this.variables.put(solverVariable, -1.0f);
        this.variables.put(solverVariable2, 1.0f);
        this.variables.put(solverVariable3, f7);
        this.variables.put(solverVariable4, -f7);
        return this;
    }

    public ArrayRow createRowEqualDimension(float f7, float f8, float f9, SolverVariable solverVariable, int i7, SolverVariable solverVariable2, int i8, SolverVariable solverVariable3, int i9, SolverVariable solverVariable4, int i10) {
        if (f8 == 0.0f || f7 == f9) {
            this.constantValue = (float) (((-i7) - i8) + i9 + i10);
            this.variables.put(solverVariable, 1.0f);
            this.variables.put(solverVariable2, -1.0f);
            this.variables.put(solverVariable4, 1.0f);
            this.variables.put(solverVariable3, -1.0f);
        } else {
            float f10 = (f7 / f8) / (f9 / f8);
            this.constantValue = ((float) ((-i7) - i8)) + (((float) i9) * f10) + (((float) i10) * f10);
            this.variables.put(solverVariable, 1.0f);
            this.variables.put(solverVariable2, -1.0f);
            this.variables.put(solverVariable4, f10);
            this.variables.put(solverVariable3, -f10);
        }
        return this;
    }

    public ArrayRow createRowEqualMatchDimensions(float f7, float f8, float f9, SolverVariable solverVariable, SolverVariable solverVariable2, SolverVariable solverVariable3, SolverVariable solverVariable4) {
        this.constantValue = 0.0f;
        if (f8 == 0.0f || f7 == f9) {
            this.variables.put(solverVariable, 1.0f);
            this.variables.put(solverVariable2, -1.0f);
            this.variables.put(solverVariable4, 1.0f);
            this.variables.put(solverVariable3, -1.0f);
        } else if (f7 == 0.0f) {
            this.variables.put(solverVariable, 1.0f);
            this.variables.put(solverVariable2, -1.0f);
        } else if (f9 == 0.0f) {
            this.variables.put(solverVariable3, 1.0f);
            this.variables.put(solverVariable4, -1.0f);
        } else {
            float f10 = (f7 / f8) / (f9 / f8);
            this.variables.put(solverVariable, 1.0f);
            this.variables.put(solverVariable2, -1.0f);
            this.variables.put(solverVariable4, f10);
            this.variables.put(solverVariable3, -f10);
        }
        return this;
    }

    public ArrayRow createRowEquals(SolverVariable solverVariable, int i7) {
        ArrayRowVariables arrayRowVariables;
        float f7;
        if (i7 < 0) {
            this.constantValue = (float) (i7 * -1);
            arrayRowVariables = this.variables;
            f7 = 1.0f;
        } else {
            this.constantValue = (float) i7;
            arrayRowVariables = this.variables;
            f7 = -1.0f;
        }
        arrayRowVariables.put(solverVariable, f7);
        return this;
    }

    public ArrayRow createRowGreaterThan(SolverVariable solverVariable, int i7, SolverVariable solverVariable2) {
        this.constantValue = (float) i7;
        this.variables.put(solverVariable, -1.0f);
        return this;
    }

    public ArrayRow createRowLowerThan(SolverVariable solverVariable, SolverVariable solverVariable2, SolverVariable solverVariable3, int i7) {
        boolean z7 = false;
        if (i7 != 0) {
            if (i7 < 0) {
                i7 *= -1;
                z7 = true;
            }
            this.constantValue = (float) i7;
        }
        if (!z7) {
            this.variables.put(solverVariable, -1.0f);
            this.variables.put(solverVariable2, 1.0f);
            this.variables.put(solverVariable3, -1.0f);
        } else {
            this.variables.put(solverVariable, 1.0f);
            this.variables.put(solverVariable2, -1.0f);
            this.variables.put(solverVariable3, 1.0f);
        }
        return this;
    }

    public ArrayRow createRowWithAngle(SolverVariable solverVariable, SolverVariable solverVariable2, SolverVariable solverVariable3, SolverVariable solverVariable4, float f7) {
        this.variables.put(solverVariable3, 0.5f);
        this.variables.put(solverVariable4, 0.5f);
        this.variables.put(solverVariable, -0.5f);
        this.variables.put(solverVariable2, -0.5f);
        this.constantValue = -f7;
        return this;
    }

    /* access modifiers changed from: package-private */
    public void ensurePositiveConstant() {
        float f7 = this.constantValue;
        if (f7 < 0.0f) {
            this.constantValue = f7 * -1.0f;
            this.variables.invert();
        }
    }

    @Override // androidx.constraintlayout.solver.LinearSystem.Row
    public SolverVariable getKey() {
        return this.variable;
    }

    @Override // androidx.constraintlayout.solver.LinearSystem.Row
    public SolverVariable getPivotCandidate(LinearSystem linearSystem, boolean[] zArr) {
        return pickPivotInVariables(zArr, null);
    }

    /* access modifiers changed from: package-private */
    public boolean hasKeyVariable() {
        SolverVariable solverVariable = this.variable;
        return solverVariable != null && (solverVariable.mType == SolverVariable.Type.UNRESTRICTED || this.constantValue >= 0.0f);
    }

    /* access modifiers changed from: package-private */
    public boolean hasVariable(SolverVariable solverVariable) {
        return this.variables.contains(solverVariable);
    }

    @Override // androidx.constraintlayout.solver.LinearSystem.Row
    public void initFromRow(LinearSystem.Row row) {
        if (row instanceof ArrayRow) {
            ArrayRow arrayRow = (ArrayRow) row;
            this.variable = null;
            this.variables.clear();
            for (int i7 = 0; i7 < arrayRow.variables.getCurrentSize(); i7++) {
                this.variables.add(arrayRow.variables.getVariable(i7), arrayRow.variables.getVariableValue(i7), true);
            }
        }
    }

    @Override // androidx.constraintlayout.solver.LinearSystem.Row
    public boolean isEmpty() {
        return this.variable == null && this.constantValue == 0.0f && this.variables.getCurrentSize() == 0;
    }

    public SolverVariable pickPivot(SolverVariable solverVariable) {
        return pickPivotInVariables(null, solverVariable);
    }

    /* access modifiers changed from: package-private */
    public void pivot(SolverVariable solverVariable) {
        SolverVariable solverVariable2 = this.variable;
        if (solverVariable2 != null) {
            this.variables.put(solverVariable2, -1.0f);
            this.variable.definitionId = -1;
            this.variable = null;
        }
        float remove = this.variables.remove(solverVariable, true) * -1.0f;
        this.variable = solverVariable;
        if (remove != 1.0f) {
            this.constantValue /= remove;
            this.variables.divideByAmount(remove);
        }
    }

    public void reset() {
        this.variable = null;
        this.variables.clear();
        this.constantValue = 0.0f;
        this.isSimpleDefinition = false;
    }

    /* access modifiers changed from: package-private */
    public int sizeInBytes() {
        return (this.variable != null ? 4 : 0) + 4 + 4 + this.variables.sizeInBytes();
    }

    /* access modifiers changed from: package-private */
    /* JADX WARNING: Removed duplicated region for block: B:26:0x00b0  */
    /* JADX WARNING: Removed duplicated region for block: B:27:0x00b6  */
    public String toReadableString() {
        StringBuilder sb;
        boolean z7;
        float variableValue;
        int i7;
        StringBuilder sb2;
        StringBuilder sb3;
        String str;
        if (this.variable == null) {
            sb = new StringBuilder();
            sb.append("");
            sb.append("0");
        } else {
            sb = new StringBuilder();
            sb.append("");
            sb.append(this.variable);
        }
        String str2 = sb.toString() + " = ";
        if (this.constantValue != 0.0f) {
            str2 = str2 + this.constantValue;
            z7 = true;
        } else {
            z7 = false;
        }
        int currentSize = this.variables.getCurrentSize();
        for (int i8 = 0; i8 < currentSize; i8++) {
            SolverVariable variable2 = this.variables.getVariable(i8);
            if (!(variable2 == null || (variableValue = this.variables.getVariableValue(i8)) == 0.0f)) {
                String solverVariable = variable2.toString();
                if (!z7) {
                    if (variableValue < 0.0f) {
                        sb3 = new StringBuilder();
                        sb3.append(str2);
                        str = "- ";
                    }
                    if (variableValue == 1.0f) {
                        sb2 = new StringBuilder();
                    } else {
                        sb2 = new StringBuilder();
                        sb2.append(str2);
                        sb2.append(variableValue);
                        str2 = " ";
                    }
                    sb2.append(str2);
                    sb2.append(solverVariable);
                    str2 = sb2.toString();
                    z7 = true;
                } else if (i7 > 0) {
                    sb3.append(str2);
                    sb3.append(" + ");
                    str2 = sb3.toString();
                    if (variableValue == 1.0f) {
                    }
                    sb2.append(str2);
                    sb2.append(solverVariable);
                    str2 = sb2.toString();
                    z7 = true;
                } else {
                    sb3 = new StringBuilder();
                    sb3.append(str2);
                    str = " - ";
                }
                sb3.append(str);
                str2 = sb3.toString();
                variableValue *= -1.0f;
                if (variableValue == 1.0f) {
                }
                sb2.append(str2);
                sb2.append(solverVariable);
                str2 = sb2.toString();
                z7 = true;
            }
        }
        if (z7) {
            return str2;
        }
        return str2 + "0.0";
    }

    public String toString() {
        return toReadableString();
    }

    @Override // androidx.constraintlayout.solver.LinearSystem.Row
    public void updateFromFinalVariable(LinearSystem linearSystem, SolverVariable solverVariable, boolean z7) {
        if (solverVariable.isFinalValue) {
            this.constantValue += solverVariable.computedValue * this.variables.get(solverVariable);
            this.variables.remove(solverVariable, z7);
            if (z7) {
                solverVariable.removeFromRow(this);
            }
            if (LinearSystem.SIMPLIFY_SYNONYMS && this.variables.getCurrentSize() == 0) {
                this.isSimpleDefinition = true;
                linearSystem.hasSimpleDefinition = true;
            }
        }
    }

    @Override // androidx.constraintlayout.solver.LinearSystem.Row
    public void updateFromRow(LinearSystem linearSystem, ArrayRow arrayRow, boolean z7) {
        this.constantValue += arrayRow.constantValue * this.variables.use(arrayRow, z7);
        if (z7) {
            arrayRow.variable.removeFromRow(this);
        }
        if (LinearSystem.SIMPLIFY_SYNONYMS && this.variable != null && this.variables.getCurrentSize() == 0) {
            this.isSimpleDefinition = true;
            linearSystem.hasSimpleDefinition = true;
        }
    }

    public void updateFromSynonymVariable(LinearSystem linearSystem, SolverVariable solverVariable, boolean z7) {
        if (solverVariable.isSynonym) {
            float f7 = this.variables.get(solverVariable);
            this.constantValue += solverVariable.synonymDelta * f7;
            this.variables.remove(solverVariable, z7);
            if (z7) {
                solverVariable.removeFromRow(this);
            }
            this.variables.add(linearSystem.mCache.mIndexedVariables[solverVariable.synonym], f7, z7);
            if (LinearSystem.SIMPLIFY_SYNONYMS && this.variables.getCurrentSize() == 0) {
                this.isSimpleDefinition = true;
                linearSystem.hasSimpleDefinition = true;
            }
        }
    }

    @Override // androidx.constraintlayout.solver.LinearSystem.Row
    public void updateFromSystem(LinearSystem linearSystem) {
        if (linearSystem.mRows.length != 0) {
            boolean z7 = false;
            while (!z7) {
                int currentSize = this.variables.getCurrentSize();
                for (int i7 = 0; i7 < currentSize; i7++) {
                    SolverVariable variable2 = this.variables.getVariable(i7);
                    if (variable2.definitionId != -1 || variable2.isFinalValue || variable2.isSynonym) {
                        this.variablesToUpdate.add(variable2);
                    }
                }
                int size = this.variablesToUpdate.size();
                if (size > 0) {
                    for (int i8 = 0; i8 < size; i8++) {
                        SolverVariable solverVariable = this.variablesToUpdate.get(i8);
                        if (solverVariable.isFinalValue) {
                            updateFromFinalVariable(linearSystem, solverVariable, true);
                        } else if (solverVariable.isSynonym) {
                            updateFromSynonymVariable(linearSystem, solverVariable, true);
                        } else {
                            updateFromRow(linearSystem, linearSystem.mRows[solverVariable.definitionId], true);
                        }
                    }
                    this.variablesToUpdate.clear();
                } else {
                    z7 = true;
                }
            }
            if (LinearSystem.SIMPLIFY_SYNONYMS && this.variable != null && this.variables.getCurrentSize() == 0) {
                this.isSimpleDefinition = true;
                linearSystem.hasSimpleDefinition = true;
            }
        }
    }

    public ArrayRow(Cache cache) {
        this.variables = new ArrayLinkedVariables(this, cache);
    }

    @Override // androidx.constraintlayout.solver.LinearSystem.Row
    public void addError(SolverVariable solverVariable) {
        int i7 = solverVariable.strength;
        float f7 = 1.0f;
        if (i7 != 1) {
            if (i7 == 2) {
                f7 = 1000.0f;
            } else if (i7 == 3) {
                f7 = 1000000.0f;
            } else if (i7 == 4) {
                f7 = 1.0E9f;
            } else if (i7 == 5) {
                f7 = 1.0E12f;
            }
        }
        this.variables.put(solverVariable, f7);
    }

    public ArrayRow createRowEquals(SolverVariable solverVariable, SolverVariable solverVariable2, int i7) {
        boolean z7 = false;
        if (i7 != 0) {
            if (i7 < 0) {
                i7 *= -1;
                z7 = true;
            }
            this.constantValue = (float) i7;
        }
        if (!z7) {
            this.variables.put(solverVariable, -1.0f);
            this.variables.put(solverVariable2, 1.0f);
        } else {
            this.variables.put(solverVariable, 1.0f);
            this.variables.put(solverVariable2, -1.0f);
        }
        return this;
    }

    public ArrayRow createRowGreaterThan(SolverVariable solverVariable, SolverVariable solverVariable2, SolverVariable solverVariable3, int i7) {
        boolean z7 = false;
        if (i7 != 0) {
            if (i7 < 0) {
                i7 *= -1;
                z7 = true;
            }
            this.constantValue = (float) i7;
        }
        if (!z7) {
            this.variables.put(solverVariable, -1.0f);
            this.variables.put(solverVariable2, 1.0f);
            this.variables.put(solverVariable3, 1.0f);
        } else {
            this.variables.put(solverVariable, 1.0f);
            this.variables.put(solverVariable2, -1.0f);
            this.variables.put(solverVariable3, -1.0f);
        }
        return this;
    }
}
