package androidx.constraintlayout.solver;

import androidx.constraintlayout.solver.ArrayRow;
import java.util.Arrays;
import java.util.Comparator;

public class PriorityGoalRow extends ArrayRow {
    private static final boolean DEBUG = false;
    static final int NOT_FOUND = -1;
    private static final float epsilon = 1.0E-4f;
    private int TABLE_SIZE = 128;
    GoalVariableAccessor accessor = new GoalVariableAccessor(this);
    private SolverVariable[] arrayGoals = new SolverVariable[128];
    Cache mCache;
    private int numGoals = 0;
    private SolverVariable[] sortArray = new SolverVariable[128];

    class GoalVariableAccessor implements Comparable {
        PriorityGoalRow row;
        SolverVariable variable;

        public GoalVariableAccessor(PriorityGoalRow priorityGoalRow) {
            this.row = priorityGoalRow;
        }

        public void add(SolverVariable solverVariable) {
            for (int i7 = 0; i7 < 9; i7++) {
                float[] fArr = this.variable.goalStrengthVector;
                float f7 = fArr[i7] + solverVariable.goalStrengthVector[i7];
                fArr[i7] = f7;
                if (Math.abs(f7) < 1.0E-4f) {
                    this.variable.goalStrengthVector[i7] = 0.0f;
                }
            }
        }

        public boolean addToGoal(SolverVariable solverVariable, float f7) {
            boolean z7 = true;
            if (this.variable.inGoal) {
                for (int i7 = 0; i7 < 9; i7++) {
                    float[] fArr = this.variable.goalStrengthVector;
                    float f8 = fArr[i7] + (solverVariable.goalStrengthVector[i7] * f7);
                    fArr[i7] = f8;
                    if (Math.abs(f8) < 1.0E-4f) {
                        this.variable.goalStrengthVector[i7] = 0.0f;
                    } else {
                        z7 = false;
                    }
                }
                if (z7) {
                    PriorityGoalRow.this.removeGoal(this.variable);
                }
                return false;
            }
            for (int i8 = 0; i8 < 9; i8++) {
                float f9 = solverVariable.goalStrengthVector[i8];
                if (f9 != 0.0f) {
                    float f10 = f9 * f7;
                    if (Math.abs(f10) < 1.0E-4f) {
                        f10 = 0.0f;
                    }
                    this.variable.goalStrengthVector[i8] = f10;
                } else {
                    this.variable.goalStrengthVector[i8] = 0.0f;
                }
            }
            return true;
        }

        @Override // java.lang.Comparable
        public int compareTo(Object obj) {
            return this.variable.id - ((SolverVariable) obj).id;
        }

        public void init(SolverVariable solverVariable) {
            this.variable = solverVariable;
        }

        public final boolean isNegative() {
            for (int i7 = 8; i7 >= 0; i7--) {
                float f7 = this.variable.goalStrengthVector[i7];
                if (f7 > 0.0f) {
                    return false;
                }
                if (f7 < 0.0f) {
                    return true;
                }
            }
            return false;
        }

        public final boolean isNull() {
            for (int i7 = 0; i7 < 9; i7++) {
                if (this.variable.goalStrengthVector[i7] != 0.0f) {
                    return false;
                }
            }
            return true;
        }

        public final boolean isSmallerThan(SolverVariable solverVariable) {
            int i7 = 8;
            while (true) {
                if (i7 < 0) {
                    break;
                }
                float f7 = solverVariable.goalStrengthVector[i7];
                float f8 = this.variable.goalStrengthVector[i7];
                if (f8 == f7) {
                    i7--;
                } else if (f8 < f7) {
                    return true;
                }
            }
            return false;
        }

        public void reset() {
            Arrays.fill(this.variable.goalStrengthVector, 0.0f);
        }

        public String toString() {
            String str = "[ ";
            if (this.variable != null) {
                for (int i7 = 0; i7 < 9; i7++) {
                    str = str + this.variable.goalStrengthVector[i7] + " ";
                }
            }
            return str + "] " + this.variable;
        }
    }

    public PriorityGoalRow(Cache cache) {
        super(cache);
        this.mCache = cache;
    }

    private final void addToGoal(SolverVariable solverVariable) {
        int i7;
        int i8 = this.numGoals + 1;
        SolverVariable[] solverVariableArr = this.arrayGoals;
        if (i8 > solverVariableArr.length) {
            SolverVariable[] solverVariableArr2 = (SolverVariable[]) Arrays.copyOf(solverVariableArr, solverVariableArr.length * 2);
            this.arrayGoals = solverVariableArr2;
            this.sortArray = (SolverVariable[]) Arrays.copyOf(solverVariableArr2, solverVariableArr2.length * 2);
        }
        SolverVariable[] solverVariableArr3 = this.arrayGoals;
        int i9 = this.numGoals;
        solverVariableArr3[i9] = solverVariable;
        int i10 = i9 + 1;
        this.numGoals = i10;
        if (i10 > 1 && solverVariableArr3[i10 - 1].id > solverVariable.id) {
            int i11 = 0;
            while (true) {
                i7 = this.numGoals;
                if (i11 >= i7) {
                    break;
                }
                this.sortArray[i11] = this.arrayGoals[i11];
                i11++;
            }
            Arrays.sort(this.sortArray, 0, i7, new Comparator<SolverVariable>() {
                /* class androidx.constraintlayout.solver.PriorityGoalRow.AnonymousClass1 */

                public int compare(SolverVariable solverVariable, SolverVariable solverVariable2) {
                    return solverVariable.id - solverVariable2.id;
                }
            });
            for (int i12 = 0; i12 < this.numGoals; i12++) {
                this.arrayGoals[i12] = this.sortArray[i12];
            }
        }
        solverVariable.inGoal = true;
        solverVariable.addToRow(this);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private final void removeGoal(SolverVariable solverVariable) {
        int i7 = 0;
        while (i7 < this.numGoals) {
            if (this.arrayGoals[i7] == solverVariable) {
                while (true) {
                    int i8 = this.numGoals;
                    if (i7 < i8 - 1) {
                        SolverVariable[] solverVariableArr = this.arrayGoals;
                        int i9 = i7 + 1;
                        solverVariableArr[i7] = solverVariableArr[i9];
                        i7 = i9;
                    } else {
                        this.numGoals = i8 - 1;
                        solverVariable.inGoal = false;
                        return;
                    }
                }
            } else {
                i7++;
            }
        }
    }

    @Override // androidx.constraintlayout.solver.ArrayRow, androidx.constraintlayout.solver.LinearSystem.Row
    public void addError(SolverVariable solverVariable) {
        this.accessor.init(solverVariable);
        this.accessor.reset();
        solverVariable.goalStrengthVector[solverVariable.strength] = 1.0f;
        addToGoal(solverVariable);
    }

    @Override // androidx.constraintlayout.solver.ArrayRow, androidx.constraintlayout.solver.LinearSystem.Row
    public void clear() {
        this.numGoals = 0;
        this.constantValue = 0.0f;
    }

    @Override // androidx.constraintlayout.solver.ArrayRow, androidx.constraintlayout.solver.LinearSystem.Row
    public SolverVariable getPivotCandidate(LinearSystem linearSystem, boolean[] zArr) {
        int i7 = -1;
        for (int i8 = 0; i8 < this.numGoals; i8++) {
            SolverVariable solverVariable = this.arrayGoals[i8];
            if (!zArr[solverVariable.id]) {
                this.accessor.init(solverVariable);
                GoalVariableAccessor goalVariableAccessor = this.accessor;
                if (i7 == -1) {
                    if (!goalVariableAccessor.isNegative()) {
                    }
                } else if (!goalVariableAccessor.isSmallerThan(this.arrayGoals[i7])) {
                }
                i7 = i8;
            }
        }
        if (i7 == -1) {
            return null;
        }
        return this.arrayGoals[i7];
    }

    @Override // androidx.constraintlayout.solver.ArrayRow, androidx.constraintlayout.solver.LinearSystem.Row
    public boolean isEmpty() {
        return this.numGoals == 0;
    }

    @Override // androidx.constraintlayout.solver.ArrayRow
    public String toString() {
        String str = "" + " goal -> (" + this.constantValue + ") : ";
        for (int i7 = 0; i7 < this.numGoals; i7++) {
            this.accessor.init(this.arrayGoals[i7]);
            str = str + this.accessor + " ";
        }
        return str;
    }

    @Override // androidx.constraintlayout.solver.ArrayRow, androidx.constraintlayout.solver.LinearSystem.Row
    public void updateFromRow(LinearSystem linearSystem, ArrayRow arrayRow, boolean z7) {
        SolverVariable solverVariable = arrayRow.variable;
        if (solverVariable != null) {
            ArrayRow.ArrayRowVariables arrayRowVariables = arrayRow.variables;
            int currentSize = arrayRowVariables.getCurrentSize();
            for (int i7 = 0; i7 < currentSize; i7++) {
                SolverVariable variable = arrayRowVariables.getVariable(i7);
                float variableValue = arrayRowVariables.getVariableValue(i7);
                this.accessor.init(variable);
                if (this.accessor.addToGoal(solverVariable, variableValue)) {
                    addToGoal(variable);
                }
                this.constantValue += arrayRow.constantValue * variableValue;
            }
            removeGoal(solverVariable);
        }
    }
}
