package androidx.constraintlayout.solver;

import androidx.constraintlayout.solver.ArrayRow;
import java.io.PrintStream;
import java.util.Arrays;

public class SolverVariableValues implements ArrayRow.ArrayRowVariables {
    private static final boolean DEBUG = false;
    private static final boolean HASH = true;
    private static float epsilon = 0.001f;
    private int HASH_SIZE = 16;
    private final int NONE = -1;
    private int SIZE = 16;
    int head = -1;
    int[] keys = new int[16];
    protected final Cache mCache;
    int mCount = 0;
    private final ArrayRow mRow;
    int[] next = new int[16];
    int[] nextKeys = new int[16];
    int[] previous = new int[16];
    float[] values = new float[16];
    int[] variables = new int[16];

    SolverVariableValues(ArrayRow arrayRow, Cache cache) {
        this.mRow = arrayRow;
        this.mCache = cache;
        clear();
    }

    private void addToHashMap(SolverVariable solverVariable, int i7) {
        int[] iArr;
        int i8 = solverVariable.id % this.HASH_SIZE;
        int[] iArr2 = this.keys;
        int i9 = iArr2[i8];
        if (i9 == -1) {
            iArr2[i8] = i7;
        } else {
            while (true) {
                iArr = this.nextKeys;
                int i10 = iArr[i9];
                if (i10 == -1) {
                    break;
                }
                i9 = i10;
            }
            iArr[i9] = i7;
        }
        this.nextKeys[i7] = -1;
    }

    private void addVariable(int i7, SolverVariable solverVariable, float f7) {
        this.variables[i7] = solverVariable.id;
        this.values[i7] = f7;
        this.previous[i7] = -1;
        this.next[i7] = -1;
        solverVariable.addToRow(this.mRow);
        solverVariable.usageInRowCount++;
        this.mCount++;
    }

    private void displayHash() {
        for (int i7 = 0; i7 < this.HASH_SIZE; i7++) {
            if (this.keys[i7] != -1) {
                String str = hashCode() + " hash [" + i7 + "] => ";
                int i8 = this.keys[i7];
                boolean z7 = false;
                while (!z7) {
                    str = str + " " + this.variables[i8];
                    int i9 = this.nextKeys[i8];
                    if (i9 != -1) {
                        i8 = i9;
                    } else {
                        z7 = true;
                    }
                }
                System.out.println(str);
            }
        }
    }

    private int findEmptySlot() {
        for (int i7 = 0; i7 < this.SIZE; i7++) {
            if (this.variables[i7] == -1) {
                return i7;
            }
        }
        return -1;
    }

    private void increaseSize() {
        int i7 = this.SIZE * 2;
        this.variables = Arrays.copyOf(this.variables, i7);
        this.values = Arrays.copyOf(this.values, i7);
        this.previous = Arrays.copyOf(this.previous, i7);
        this.next = Arrays.copyOf(this.next, i7);
        this.nextKeys = Arrays.copyOf(this.nextKeys, i7);
        for (int i8 = this.SIZE; i8 < i7; i8++) {
            this.variables[i8] = -1;
            this.nextKeys[i8] = -1;
        }
        this.SIZE = i7;
    }

    private void insertVariable(int i7, SolverVariable solverVariable, float f7) {
        int findEmptySlot = findEmptySlot();
        addVariable(findEmptySlot, solverVariable, f7);
        if (i7 != -1) {
            this.previous[findEmptySlot] = i7;
            int[] iArr = this.next;
            iArr[findEmptySlot] = iArr[i7];
            iArr[i7] = findEmptySlot;
        } else {
            this.previous[findEmptySlot] = -1;
            if (this.mCount > 0) {
                this.next[findEmptySlot] = this.head;
                this.head = findEmptySlot;
            } else {
                this.next[findEmptySlot] = -1;
            }
        }
        int i8 = this.next[findEmptySlot];
        if (i8 != -1) {
            this.previous[i8] = findEmptySlot;
        }
        addToHashMap(solverVariable, findEmptySlot);
    }

    private void removeFromHashMap(SolverVariable solverVariable) {
        int i7;
        int i8 = solverVariable.id;
        int i9 = i8 % this.HASH_SIZE;
        int[] iArr = this.keys;
        int i10 = iArr[i9];
        if (i10 != -1) {
            if (this.variables[i10] == i8) {
                int[] iArr2 = this.nextKeys;
                iArr[i9] = iArr2[i10];
                iArr2[i10] = -1;
                return;
            }
            while (true) {
                int[] iArr3 = this.nextKeys;
                i7 = iArr3[i10];
                if (i7 != -1 && this.variables[i7] != i8) {
                    i10 = i7;
                } else if (i7 != -1 && this.variables[i7] == i8) {
                    iArr3[i10] = iArr3[i7];
                    iArr3[i7] = -1;
                    return;
                }
            }
            if (i7 != -1) {
            }
        }
    }

    @Override // androidx.constraintlayout.solver.ArrayRow.ArrayRowVariables
    public void add(SolverVariable solverVariable, float f7, boolean z7) {
        float f8 = epsilon;
        if (f7 <= (-f8) || f7 >= f8) {
            int indexOf = indexOf(solverVariable);
            if (indexOf == -1) {
                put(solverVariable, f7);
                return;
            }
            float[] fArr = this.values;
            float f9 = fArr[indexOf] + f7;
            fArr[indexOf] = f9;
            float f10 = epsilon;
            if (f9 > (-f10) && f9 < f10) {
                fArr[indexOf] = 0.0f;
                remove(solverVariable, z7);
            }
        }
    }

    @Override // androidx.constraintlayout.solver.ArrayRow.ArrayRowVariables
    public void clear() {
        int i7 = this.mCount;
        for (int i8 = 0; i8 < i7; i8++) {
            SolverVariable variable = getVariable(i8);
            if (variable != null) {
                variable.removeFromRow(this.mRow);
            }
        }
        for (int i9 = 0; i9 < this.SIZE; i9++) {
            this.variables[i9] = -1;
            this.nextKeys[i9] = -1;
        }
        for (int i10 = 0; i10 < this.HASH_SIZE; i10++) {
            this.keys[i10] = -1;
        }
        this.mCount = 0;
        this.head = -1;
    }

    @Override // androidx.constraintlayout.solver.ArrayRow.ArrayRowVariables
    public boolean contains(SolverVariable solverVariable) {
        return indexOf(solverVariable) != -1;
    }

    @Override // androidx.constraintlayout.solver.ArrayRow.ArrayRowVariables
    public void display() {
        int i7 = this.mCount;
        System.out.print("{ ");
        for (int i8 = 0; i8 < i7; i8++) {
            SolverVariable variable = getVariable(i8);
            if (variable != null) {
                PrintStream printStream = System.out;
                printStream.print(variable + " = " + getVariableValue(i8) + " ");
            }
        }
        System.out.println(" }");
    }

    @Override // androidx.constraintlayout.solver.ArrayRow.ArrayRowVariables
    public void divideByAmount(float f7) {
        int i7 = this.mCount;
        int i8 = this.head;
        for (int i9 = 0; i9 < i7; i9++) {
            float[] fArr = this.values;
            fArr[i8] = fArr[i8] / f7;
            i8 = this.next[i8];
            if (i8 == -1) {
                return;
            }
        }
    }

    @Override // androidx.constraintlayout.solver.ArrayRow.ArrayRowVariables
    public float get(SolverVariable solverVariable) {
        int indexOf = indexOf(solverVariable);
        if (indexOf != -1) {
            return this.values[indexOf];
        }
        return 0.0f;
    }

    @Override // androidx.constraintlayout.solver.ArrayRow.ArrayRowVariables
    public int getCurrentSize() {
        return this.mCount;
    }

    @Override // androidx.constraintlayout.solver.ArrayRow.ArrayRowVariables
    public SolverVariable getVariable(int i7) {
        int i8 = this.mCount;
        if (i8 == 0) {
            return null;
        }
        int i9 = this.head;
        for (int i10 = 0; i10 < i8; i10++) {
            if (i10 == i7 && i9 != -1) {
                return this.mCache.mIndexedVariables[this.variables[i9]];
            }
            i9 = this.next[i9];
            if (i9 == -1) {
                break;
            }
        }
        return null;
    }

    @Override // androidx.constraintlayout.solver.ArrayRow.ArrayRowVariables
    public float getVariableValue(int i7) {
        int i8 = this.mCount;
        int i9 = this.head;
        for (int i10 = 0; i10 < i8; i10++) {
            if (i10 == i7) {
                return this.values[i9];
            }
            i9 = this.next[i9];
            if (i9 == -1) {
                return 0.0f;
            }
        }
        return 0.0f;
    }

    @Override // androidx.constraintlayout.solver.ArrayRow.ArrayRowVariables
    public int indexOf(SolverVariable solverVariable) {
        if (!(this.mCount == 0 || solverVariable == null)) {
            int i7 = solverVariable.id;
            int i8 = this.keys[i7 % this.HASH_SIZE];
            if (i8 == -1) {
                return -1;
            }
            if (this.variables[i8] == i7) {
                return i8;
            }
            do {
                i8 = this.nextKeys[i8];
                if (i8 == -1) {
                    break;
                }
            } while (this.variables[i8] != i7);
            if (i8 != -1 && this.variables[i8] == i7) {
                return i8;
            }
        }
        return -1;
    }

    @Override // androidx.constraintlayout.solver.ArrayRow.ArrayRowVariables
    public void invert() {
        int i7 = this.mCount;
        int i8 = this.head;
        for (int i9 = 0; i9 < i7; i9++) {
            float[] fArr = this.values;
            fArr[i8] = fArr[i8] * -1.0f;
            i8 = this.next[i8];
            if (i8 == -1) {
                return;
            }
        }
    }

    @Override // androidx.constraintlayout.solver.ArrayRow.ArrayRowVariables
    public void put(SolverVariable solverVariable, float f7) {
        float f8 = epsilon;
        if (f7 <= (-f8) || f7 >= f8) {
            if (this.mCount == 0) {
                addVariable(0, solverVariable, f7);
                addToHashMap(solverVariable, 0);
                this.head = 0;
                return;
            }
            int indexOf = indexOf(solverVariable);
            if (indexOf != -1) {
                this.values[indexOf] = f7;
                return;
            }
            if (this.mCount + 1 >= this.SIZE) {
                increaseSize();
            }
            int i7 = this.mCount;
            int i8 = this.head;
            int i9 = -1;
            for (int i10 = 0; i10 < i7; i10++) {
                int i11 = this.variables[i8];
                int i12 = solverVariable.id;
                if (i11 == i12) {
                    this.values[i8] = f7;
                    return;
                }
                if (i11 < i12) {
                    i9 = i8;
                }
                i8 = this.next[i8];
                if (i8 == -1) {
                    break;
                }
            }
            insertVariable(i9, solverVariable, f7);
            return;
        }
        remove(solverVariable, true);
    }

    @Override // androidx.constraintlayout.solver.ArrayRow.ArrayRowVariables
    public float remove(SolverVariable solverVariable, boolean z7) {
        int indexOf = indexOf(solverVariable);
        if (indexOf == -1) {
            return 0.0f;
        }
        removeFromHashMap(solverVariable);
        float f7 = this.values[indexOf];
        if (this.head == indexOf) {
            this.head = this.next[indexOf];
        }
        this.variables[indexOf] = -1;
        int[] iArr = this.previous;
        int i7 = iArr[indexOf];
        if (i7 != -1) {
            int[] iArr2 = this.next;
            iArr2[i7] = iArr2[indexOf];
        }
        int i8 = this.next[indexOf];
        if (i8 != -1) {
            iArr[i8] = iArr[indexOf];
        }
        this.mCount--;
        solverVariable.usageInRowCount--;
        if (z7) {
            solverVariable.removeFromRow(this.mRow);
        }
        return f7;
    }

    @Override // androidx.constraintlayout.solver.ArrayRow.ArrayRowVariables
    public int sizeInBytes() {
        return 0;
    }

    public String toString() {
        StringBuilder sb;
        String str = hashCode() + " { ";
        int i7 = this.mCount;
        for (int i8 = 0; i8 < i7; i8++) {
            SolverVariable variable = getVariable(i8);
            if (variable != null) {
                String str2 = str + variable + " = " + getVariableValue(i8) + " ";
                int indexOf = indexOf(variable);
                String str3 = str2 + "[p: ";
                if (this.previous[indexOf] != -1) {
                    sb = new StringBuilder();
                    sb.append(str3);
                    sb.append(this.mCache.mIndexedVariables[this.variables[this.previous[indexOf]]]);
                } else {
                    sb = new StringBuilder();
                    sb.append(str3);
                    sb.append("none");
                }
                String str4 = sb.toString() + ", n: ";
                str = (this.next[indexOf] != -1 ? str4 + this.mCache.mIndexedVariables[this.variables[this.next[indexOf]]] : str4 + "none") + "]";
            }
        }
        return str + " }";
    }

    @Override // androidx.constraintlayout.solver.ArrayRow.ArrayRowVariables
    public float use(ArrayRow arrayRow, boolean z7) {
        float f7 = get(arrayRow.variable);
        remove(arrayRow.variable, z7);
        SolverVariableValues solverVariableValues = (SolverVariableValues) arrayRow.variables;
        int currentSize = solverVariableValues.getCurrentSize();
        int i7 = 0;
        int i8 = 0;
        while (i7 < currentSize) {
            int i9 = solverVariableValues.variables[i8];
            if (i9 != -1) {
                add(this.mCache.mIndexedVariables[i9], solverVariableValues.values[i8] * f7, z7);
                i7++;
            }
            i8++;
        }
        return f7;
    }
}
