package androidx.constraintlayout.solver.widgets;

import androidx.constraintlayout.solver.Cache;
import androidx.constraintlayout.solver.LinearSystem;
import androidx.constraintlayout.solver.Metrics;
import androidx.constraintlayout.solver.SolverVariable;
import androidx.constraintlayout.solver.widgets.ConstraintAnchor;
import androidx.constraintlayout.solver.widgets.analyzer.ChainRun;
import androidx.constraintlayout.solver.widgets.analyzer.DependencyNode;
import androidx.constraintlayout.solver.widgets.analyzer.HorizontalWidgetRun;
import androidx.constraintlayout.solver.widgets.analyzer.VerticalWidgetRun;
import androidx.constraintlayout.solver.widgets.analyzer.WidgetRun;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;

public class ConstraintWidget {
    public static final int ANCHOR_BASELINE = 4;
    public static final int ANCHOR_BOTTOM = 3;
    public static final int ANCHOR_LEFT = 0;
    public static final int ANCHOR_RIGHT = 1;
    public static final int ANCHOR_TOP = 2;
    private static final boolean AUTOTAG_CENTER = false;
    public static final int BOTH = 2;
    public static final int CHAIN_PACKED = 2;
    public static final int CHAIN_SPREAD = 0;
    public static final int CHAIN_SPREAD_INSIDE = 1;
    public static float DEFAULT_BIAS = 0.5f;
    static final int DIMENSION_HORIZONTAL = 0;
    static final int DIMENSION_VERTICAL = 1;
    protected static final int DIRECT = 2;
    public static final int GONE = 8;
    public static final int HORIZONTAL = 0;
    public static final int INVISIBLE = 4;
    public static final int MATCH_CONSTRAINT_PERCENT = 2;
    public static final int MATCH_CONSTRAINT_RATIO = 3;
    public static final int MATCH_CONSTRAINT_RATIO_RESOLVED = 4;
    public static final int MATCH_CONSTRAINT_SPREAD = 0;
    public static final int MATCH_CONSTRAINT_WRAP = 1;
    protected static final int SOLVER = 1;
    public static final int UNKNOWN = -1;
    private static final boolean USE_WRAP_DIMENSION_FOR_SPREAD = false;
    public static final int VERTICAL = 1;
    public static final int VISIBLE = 0;
    private static final int WRAP = -2;
    private boolean OPTIMIZE_WRAP;
    private boolean OPTIMIZE_WRAP_ON_RESOLVED;
    private boolean hasBaseline;
    public ChainRun horizontalChainRun;
    public int horizontalGroup;
    public HorizontalWidgetRun horizontalRun;
    private boolean inPlaceholder;
    public boolean[] isTerminalWidget;
    protected ArrayList<ConstraintAnchor> mAnchors;
    public ConstraintAnchor mBaseline;
    int mBaselineDistance;
    public ConstraintAnchor mBottom;
    boolean mBottomHasCentered;
    public ConstraintAnchor mCenter;
    ConstraintAnchor mCenterX;
    ConstraintAnchor mCenterY;
    private float mCircleConstraintAngle;
    private Object mCompanionWidget;
    private int mContainerItemSkip;
    private String mDebugName;
    public float mDimensionRatio;
    protected int mDimensionRatioSide;
    int mDistToBottom;
    int mDistToLeft;
    int mDistToRight;
    int mDistToTop;
    boolean mGroupsToSolver;
    int mHeight;
    float mHorizontalBiasPercent;
    boolean mHorizontalChainFixedPosition;
    int mHorizontalChainStyle;
    ConstraintWidget mHorizontalNextWidget;
    public int mHorizontalResolution;
    boolean mHorizontalWrapVisited;
    private boolean mInVirtuaLayout;
    public boolean mIsHeightWrapContent;
    private boolean[] mIsInBarrier;
    public boolean mIsWidthWrapContent;
    private int mLastHorizontalMeasureSpec;
    private int mLastVerticalMeasureSpec;
    public ConstraintAnchor mLeft;
    boolean mLeftHasCentered;
    public ConstraintAnchor[] mListAnchors;
    public DimensionBehaviour[] mListDimensionBehaviors;
    protected ConstraintWidget[] mListNextMatchConstraintsWidget;
    public int mMatchConstraintDefaultHeight;
    public int mMatchConstraintDefaultWidth;
    public int mMatchConstraintMaxHeight;
    public int mMatchConstraintMaxWidth;
    public int mMatchConstraintMinHeight;
    public int mMatchConstraintMinWidth;
    public float mMatchConstraintPercentHeight;
    public float mMatchConstraintPercentWidth;
    private int[] mMaxDimension;
    private boolean mMeasureRequested;
    protected int mMinHeight;
    protected int mMinWidth;
    protected ConstraintWidget[] mNextChainWidget;
    protected int mOffsetX;
    protected int mOffsetY;
    public ConstraintWidget mParent;
    int mRelX;
    int mRelY;
    float mResolvedDimensionRatio;
    int mResolvedDimensionRatioSide;
    boolean mResolvedHasRatio;
    public int[] mResolvedMatchConstraintDefault;
    public ConstraintAnchor mRight;
    boolean mRightHasCentered;
    public ConstraintAnchor mTop;
    boolean mTopHasCentered;
    private String mType;
    float mVerticalBiasPercent;
    boolean mVerticalChainFixedPosition;
    int mVerticalChainStyle;
    ConstraintWidget mVerticalNextWidget;
    public int mVerticalResolution;
    boolean mVerticalWrapVisited;
    private int mVisibility;
    public float[] mWeight;
    int mWidth;
    protected int mX;
    protected int mY;
    public boolean measured;
    private boolean resolvedHorizontal;
    private boolean resolvedVertical;
    public WidgetRun[] run;
    public ChainRun verticalChainRun;
    public int verticalGroup;
    public VerticalWidgetRun verticalRun;

    /* access modifiers changed from: package-private */
    /* renamed from: androidx.constraintlayout.solver.widgets.ConstraintWidget$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$androidx$constraintlayout$solver$widgets$ConstraintAnchor$Type;
        static final /* synthetic */ int[] $SwitchMap$androidx$constraintlayout$solver$widgets$ConstraintWidget$DimensionBehaviour;

        /* JADX WARNING: Can't wrap try/catch for region: R(29:0|(2:1|2)|3|(2:5|6)|7|9|10|11|(2:13|14)|15|17|18|19|20|21|22|23|24|25|26|27|28|29|30|31|32|33|34|36) */
        /* JADX WARNING: Can't wrap try/catch for region: R(31:0|1|2|3|(2:5|6)|7|9|10|11|13|14|15|17|18|19|20|21|22|23|24|25|26|27|28|29|30|31|32|33|34|36) */
        /* JADX WARNING: Can't wrap try/catch for region: R(32:0|1|2|3|5|6|7|9|10|11|13|14|15|17|18|19|20|21|22|23|24|25|26|27|28|29|30|31|32|33|34|36) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:19:0x0044 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:21:0x004e */
        /* JADX WARNING: Missing exception handler attribute for start block: B:23:0x0058 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:25:0x0062 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:27:0x006d */
        /* JADX WARNING: Missing exception handler attribute for start block: B:29:0x0078 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:31:0x0083 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:33:0x008f */
        static {
            int[] iArr = new int[DimensionBehaviour.values().length];
            $SwitchMap$androidx$constraintlayout$solver$widgets$ConstraintWidget$DimensionBehaviour = iArr;
            try {
                iArr[DimensionBehaviour.FIXED.ordinal()] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                $SwitchMap$androidx$constraintlayout$solver$widgets$ConstraintWidget$DimensionBehaviour[DimensionBehaviour.WRAP_CONTENT.ordinal()] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            try {
                $SwitchMap$androidx$constraintlayout$solver$widgets$ConstraintWidget$DimensionBehaviour[DimensionBehaviour.MATCH_PARENT.ordinal()] = 3;
            } catch (NoSuchFieldError unused3) {
            }
            try {
                $SwitchMap$androidx$constraintlayout$solver$widgets$ConstraintWidget$DimensionBehaviour[DimensionBehaviour.MATCH_CONSTRAINT.ordinal()] = 4;
            } catch (NoSuchFieldError unused4) {
            }
            int[] iArr2 = new int[ConstraintAnchor.Type.values().length];
            $SwitchMap$androidx$constraintlayout$solver$widgets$ConstraintAnchor$Type = iArr2;
            iArr2[ConstraintAnchor.Type.LEFT.ordinal()] = 1;
            $SwitchMap$androidx$constraintlayout$solver$widgets$ConstraintAnchor$Type[ConstraintAnchor.Type.TOP.ordinal()] = 2;
            $SwitchMap$androidx$constraintlayout$solver$widgets$ConstraintAnchor$Type[ConstraintAnchor.Type.RIGHT.ordinal()] = 3;
            $SwitchMap$androidx$constraintlayout$solver$widgets$ConstraintAnchor$Type[ConstraintAnchor.Type.BOTTOM.ordinal()] = 4;
            $SwitchMap$androidx$constraintlayout$solver$widgets$ConstraintAnchor$Type[ConstraintAnchor.Type.BASELINE.ordinal()] = 5;
            $SwitchMap$androidx$constraintlayout$solver$widgets$ConstraintAnchor$Type[ConstraintAnchor.Type.CENTER.ordinal()] = 6;
            $SwitchMap$androidx$constraintlayout$solver$widgets$ConstraintAnchor$Type[ConstraintAnchor.Type.CENTER_X.ordinal()] = 7;
            $SwitchMap$androidx$constraintlayout$solver$widgets$ConstraintAnchor$Type[ConstraintAnchor.Type.CENTER_Y.ordinal()] = 8;
            try {
                $SwitchMap$androidx$constraintlayout$solver$widgets$ConstraintAnchor$Type[ConstraintAnchor.Type.NONE.ordinal()] = 9;
            } catch (NoSuchFieldError unused5) {
            }
        }
    }

    public enum DimensionBehaviour {
        FIXED,
        WRAP_CONTENT,
        MATCH_CONSTRAINT,
        MATCH_PARENT
    }

    public ConstraintWidget() {
        this.measured = false;
        this.run = new WidgetRun[2];
        this.horizontalRun = null;
        this.verticalRun = null;
        this.isTerminalWidget = new boolean[]{true, true};
        this.mResolvedHasRatio = false;
        this.mMeasureRequested = true;
        this.OPTIMIZE_WRAP = false;
        this.OPTIMIZE_WRAP_ON_RESOLVED = true;
        this.resolvedHorizontal = false;
        this.resolvedVertical = false;
        this.mHorizontalResolution = -1;
        this.mVerticalResolution = -1;
        this.mMatchConstraintDefaultWidth = 0;
        this.mMatchConstraintDefaultHeight = 0;
        this.mResolvedMatchConstraintDefault = new int[2];
        this.mMatchConstraintMinWidth = 0;
        this.mMatchConstraintMaxWidth = 0;
        this.mMatchConstraintPercentWidth = 1.0f;
        this.mMatchConstraintMinHeight = 0;
        this.mMatchConstraintMaxHeight = 0;
        this.mMatchConstraintPercentHeight = 1.0f;
        this.mResolvedDimensionRatioSide = -1;
        this.mResolvedDimensionRatio = 1.0f;
        this.mMaxDimension = new int[]{Integer.MAX_VALUE, Integer.MAX_VALUE};
        this.mCircleConstraintAngle = 0.0f;
        this.hasBaseline = false;
        this.mInVirtuaLayout = false;
        this.mLastHorizontalMeasureSpec = 0;
        this.mLastVerticalMeasureSpec = 0;
        this.mLeft = new ConstraintAnchor(this, ConstraintAnchor.Type.LEFT);
        this.mTop = new ConstraintAnchor(this, ConstraintAnchor.Type.TOP);
        this.mRight = new ConstraintAnchor(this, ConstraintAnchor.Type.RIGHT);
        this.mBottom = new ConstraintAnchor(this, ConstraintAnchor.Type.BOTTOM);
        this.mBaseline = new ConstraintAnchor(this, ConstraintAnchor.Type.BASELINE);
        this.mCenterX = new ConstraintAnchor(this, ConstraintAnchor.Type.CENTER_X);
        this.mCenterY = new ConstraintAnchor(this, ConstraintAnchor.Type.CENTER_Y);
        ConstraintAnchor constraintAnchor = new ConstraintAnchor(this, ConstraintAnchor.Type.CENTER);
        this.mCenter = constraintAnchor;
        this.mListAnchors = new ConstraintAnchor[]{this.mLeft, this.mRight, this.mTop, this.mBottom, this.mBaseline, constraintAnchor};
        this.mAnchors = new ArrayList<>();
        this.mIsInBarrier = new boolean[2];
        DimensionBehaviour dimensionBehaviour = DimensionBehaviour.FIXED;
        this.mListDimensionBehaviors = new DimensionBehaviour[]{dimensionBehaviour, dimensionBehaviour};
        this.mParent = null;
        this.mWidth = 0;
        this.mHeight = 0;
        this.mDimensionRatio = 0.0f;
        this.mDimensionRatioSide = -1;
        this.mX = 0;
        this.mY = 0;
        this.mRelX = 0;
        this.mRelY = 0;
        this.mOffsetX = 0;
        this.mOffsetY = 0;
        this.mBaselineDistance = 0;
        float f7 = DEFAULT_BIAS;
        this.mHorizontalBiasPercent = f7;
        this.mVerticalBiasPercent = f7;
        this.mContainerItemSkip = 0;
        this.mVisibility = 0;
        this.mDebugName = null;
        this.mType = null;
        this.mGroupsToSolver = false;
        this.mHorizontalChainStyle = 0;
        this.mVerticalChainStyle = 0;
        this.mWeight = new float[]{-1.0f, -1.0f};
        this.mListNextMatchConstraintsWidget = new ConstraintWidget[]{null, null};
        this.mNextChainWidget = new ConstraintWidget[]{null, null};
        this.mHorizontalNextWidget = null;
        this.mVerticalNextWidget = null;
        this.horizontalGroup = -1;
        this.verticalGroup = -1;
        addAnchors();
    }

    private void addAnchors() {
        this.mAnchors.add(this.mLeft);
        this.mAnchors.add(this.mTop);
        this.mAnchors.add(this.mRight);
        this.mAnchors.add(this.mBottom);
        this.mAnchors.add(this.mCenterX);
        this.mAnchors.add(this.mCenterY);
        this.mAnchors.add(this.mCenter);
        this.mAnchors.add(this.mBaseline);
    }

    /* JADX WARNING: Removed duplicated region for block: B:102:0x01c8  */
    /* JADX WARNING: Removed duplicated region for block: B:210:0x037f  */
    /* JADX WARNING: Removed duplicated region for block: B:218:0x03c1  */
    /* JADX WARNING: Removed duplicated region for block: B:225:0x03dc  */
    /* JADX WARNING: Removed duplicated region for block: B:235:0x0403  */
    /* JADX WARNING: Removed duplicated region for block: B:245:0x041d  */
    /* JADX WARNING: Removed duplicated region for block: B:276:0x046d  */
    /* JADX WARNING: Removed duplicated region for block: B:27:0x0084  */
    /* JADX WARNING: Removed duplicated region for block: B:28:0x0088  */
    /* JADX WARNING: Removed duplicated region for block: B:298:0x04a0 A[ADDED_TO_REGION] */
    /* JADX WARNING: Removed duplicated region for block: B:30:0x008c  */
    /* JADX WARNING: Removed duplicated region for block: B:315:0x04cd  */
    /* JADX WARNING: Removed duplicated region for block: B:317:0x04da A[ADDED_TO_REGION] */
    /* JADX WARNING: Removed duplicated region for block: B:346:? A[ADDED_TO_REGION, RETURN, SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:350:? A[ADDED_TO_REGION, RETURN, SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:38:0x00ad  */
    /* JADX WARNING: Removed duplicated region for block: B:40:0x00b2  */
    /* JADX WARNING: Removed duplicated region for block: B:51:0x00df  */
    private void applyConstraints(LinearSystem linearSystem, boolean z7, boolean z8, boolean z9, boolean z10, SolverVariable solverVariable, SolverVariable solverVariable2, DimensionBehaviour dimensionBehaviour, boolean z11, ConstraintAnchor constraintAnchor, ConstraintAnchor constraintAnchor2, int i7, int i8, int i9, int i10, float f7, boolean z12, boolean z13, boolean z14, boolean z15, boolean z16, int i11, int i12, int i13, int i14, float f8, boolean z17) {
        boolean z18;
        int i15;
        int i16;
        SolverVariable solverVariable3;
        int i17;
        boolean z19;
        int i18;
        int i19;
        int i20;
        boolean z20;
        SolverVariable solverVariable4;
        SolverVariable solverVariable5;
        SolverVariable solverVariable6;
        int i21;
        SolverVariable solverVariable7;
        int i22;
        int i23;
        SolverVariable solverVariable8;
        int i24;
        SolverVariable solverVariable9;
        SolverVariable solverVariable10;
        int i25;
        ConstraintAnchor constraintAnchor3;
        DimensionBehaviour[] dimensionBehaviourArr;
        DimensionBehaviour dimensionBehaviour2;
        boolean z21;
        int i26;
        SolverVariable solverVariable11;
        ConstraintWidget constraintWidget;
        int i27;
        int i28;
        int i29;
        int i30;
        int i31;
        SolverVariable solverVariable12;
        int i32;
        int i33;
        boolean z22;
        int i34;
        ConstraintWidget constraintWidget2;
        int i35;
        SolverVariable solverVariable13;
        SolverVariable solverVariable14;
        ConstraintWidget constraintWidget3;
        SolverVariable solverVariable15;
        int i36;
        int i37;
        int i38;
        ConstraintWidget constraintWidget4;
        boolean z23;
        int i39;
        SolverVariable solverVariable16;
        int i40;
        int i41;
        int i42;
        int i43;
        int i44;
        ConstraintWidget constraintWidget5;
        int i45;
        ConstraintAnchor.Type type;
        ConstraintWidget constraintWidget6;
        SolverVariable solverVariable17;
        int i46;
        SolverVariable createObjectVariable = linearSystem.createObjectVariable(constraintAnchor);
        SolverVariable createObjectVariable2 = linearSystem.createObjectVariable(constraintAnchor2);
        SolverVariable createObjectVariable3 = linearSystem.createObjectVariable(constraintAnchor.getTarget());
        SolverVariable createObjectVariable4 = linearSystem.createObjectVariable(constraintAnchor2.getTarget());
        if (LinearSystem.getMetrics() != null) {
            LinearSystem.getMetrics().nonresolvedWidgets++;
        }
        boolean isConnected = constraintAnchor.isConnected();
        boolean isConnected2 = constraintAnchor2.isConnected();
        boolean isConnected3 = this.mCenter.isConnected();
        int i47 = isConnected2 ? (isConnected ? 1 : 0) + 1 : isConnected ? 1 : 0;
        if (isConnected3) {
            i47++;
        }
        int i48 = z12 ? 3 : i11;
        int i49 = AnonymousClass1.$SwitchMap$androidx$constraintlayout$solver$widgets$ConstraintWidget$DimensionBehaviour[dimensionBehaviour.ordinal()];
        if (i49 == 1 || i49 == 2 || i49 == 3 || i49 != 4) {
            i15 = i48;
        } else {
            i15 = i48;
            if (i15 != 4) {
                z18 = true;
                if (this.mVisibility != 8) {
                    i16 = 0;
                    z18 = false;
                } else {
                    i16 = i8;
                }
                if (!z17) {
                    if (!isConnected && !isConnected2 && !isConnected3) {
                        linearSystem.addEquality(createObjectVariable, i7);
                    } else if (isConnected && !isConnected2) {
                        solverVariable3 = createObjectVariable4;
                        i17 = 8;
                        linearSystem.addEquality(createObjectVariable, createObjectVariable3, constraintAnchor.getMargin(), 8);
                    }
                    solverVariable3 = createObjectVariable4;
                    i17 = 8;
                } else {
                    solverVariable3 = createObjectVariable4;
                    i17 = 8;
                }
                if (z18) {
                    if (z11) {
                        i46 = 0;
                        linearSystem.addEquality(createObjectVariable2, createObjectVariable, 0, 3);
                        if (i9 > 0) {
                            linearSystem.addGreaterThan(createObjectVariable2, createObjectVariable, i9, 8);
                        }
                        if (i10 < Integer.MAX_VALUE) {
                            linearSystem.addLowerThan(createObjectVariable2, createObjectVariable, i10, 8);
                        }
                    } else {
                        i46 = 0;
                        linearSystem.addEquality(createObjectVariable2, createObjectVariable, i16, i17);
                    }
                    i18 = i13;
                    i21 = i14;
                    i20 = i46;
                    solverVariable5 = createObjectVariable3;
                    solverVariable4 = createObjectVariable2;
                } else if (i47 == 2 || z12 || !(i15 == 1 || i15 == 0)) {
                    int i50 = i13 == -2 ? i16 : i13;
                    i21 = i14 == -2 ? i16 : i14;
                    if (i16 > 0 && i15 != 1) {
                        i16 = 0;
                    }
                    if (i50 > 0) {
                        linearSystem.addGreaterThan(createObjectVariable2, createObjectVariable, i50, 8);
                        i16 = Math.max(i16, i50);
                    }
                    if (i21 > 0) {
                        if (!z8 || i15 != 1) {
                            i45 = 8;
                            linearSystem.addLowerThan(createObjectVariable2, createObjectVariable, i21, 8);
                        } else {
                            i45 = 8;
                        }
                        i16 = Math.min(i16, i21);
                    } else {
                        i45 = 8;
                    }
                    if (i15 == 1) {
                        if (z8) {
                            linearSystem.addEquality(createObjectVariable2, createObjectVariable, i16, i45);
                        } else {
                            linearSystem.addEquality(createObjectVariable2, createObjectVariable, i16, 5);
                            linearSystem.addLowerThan(createObjectVariable2, createObjectVariable, i16, i45);
                        }
                        i20 = 0;
                        solverVariable5 = createObjectVariable3;
                        solverVariable4 = createObjectVariable2;
                        i18 = i50;
                    } else {
                        if (i15 == 2) {
                            ConstraintAnchor.Type type2 = constraintAnchor.getType();
                            ConstraintAnchor.Type type3 = ConstraintAnchor.Type.TOP;
                            if (type2 == type3 || constraintAnchor.getType() == ConstraintAnchor.Type.BOTTOM) {
                                solverVariable17 = linearSystem.createObjectVariable(this.mParent.getAnchor(type3));
                                constraintWidget6 = this.mParent;
                                type = ConstraintAnchor.Type.BOTTOM;
                            } else {
                                solverVariable17 = linearSystem.createObjectVariable(this.mParent.getAnchor(ConstraintAnchor.Type.LEFT));
                                constraintWidget6 = this.mParent;
                                type = ConstraintAnchor.Type.RIGHT;
                            }
                            solverVariable6 = solverVariable3;
                            i20 = 0;
                            i19 = i47;
                            solverVariable5 = createObjectVariable3;
                            solverVariable4 = createObjectVariable2;
                            linearSystem.addConstraint(linearSystem.createRow().createRowDimensionRatio(createObjectVariable2, createObjectVariable, linearSystem.createObjectVariable(constraintWidget6.getAnchor(type)), solverVariable17, f8));
                            z20 = z10;
                            i18 = i50;
                            z19 = false;
                        } else {
                            i20 = 0;
                            solverVariable5 = createObjectVariable3;
                            solverVariable4 = createObjectVariable2;
                            solverVariable6 = solverVariable3;
                            i19 = i47;
                            i18 = i50;
                            z19 = z18;
                            z20 = true;
                        }
                        if (z17) {
                            solverVariable10 = solverVariable;
                            solverVariable8 = solverVariable2;
                            solverVariable9 = solverVariable4;
                            i24 = i20;
                            solverVariable7 = createObjectVariable;
                            i23 = i19;
                            i22 = 2;
                        } else if (z14) {
                            solverVariable10 = solverVariable;
                            solverVariable8 = solverVariable2;
                            solverVariable9 = solverVariable4;
                            i24 = i20;
                            i23 = i19;
                            i22 = 2;
                            solverVariable7 = createObjectVariable;
                        } else {
                            if ((isConnected || isConnected2 || isConnected3) && (!isConnected || isConnected2)) {
                                if (isConnected || !isConnected2) {
                                    i27 = i20;
                                    if (isConnected && isConnected2) {
                                        ConstraintWidget constraintWidget7 = constraintAnchor.mTarget.mOwner;
                                        ConstraintWidget constraintWidget8 = constraintAnchor2.mTarget.mOwner;
                                        ConstraintWidget parent = getParent();
                                        int i51 = 6;
                                        if (z19) {
                                            if (i15 == 0) {
                                                if (i21 != 0 || i18 != 0) {
                                                    i44 = i27;
                                                    i33 = 1;
                                                    i31 = 1;
                                                    i43 = 5;
                                                    i29 = 5;
                                                } else if (!solverVariable5.isFinalValue || !solverVariable6.isFinalValue) {
                                                    i33 = i27;
                                                    i31 = i33;
                                                    i44 = 1;
                                                    i43 = 8;
                                                    i29 = 8;
                                                } else {
                                                    linearSystem.addEquality(createObjectVariable, solverVariable5, constraintAnchor.getMargin(), 8);
                                                    linearSystem.addEquality(solverVariable4, solverVariable6, -constraintAnchor2.getMargin(), 8);
                                                    return;
                                                }
                                                if ((constraintWidget7 instanceof Barrier) || (constraintWidget8 instanceof Barrier)) {
                                                    solverVariable12 = solverVariable2;
                                                    i28 = i43;
                                                    i29 = 4;
                                                } else {
                                                    solverVariable12 = solverVariable2;
                                                    i28 = i43;
                                                }
                                                i30 = i44;
                                                i32 = 6;
                                            } else {
                                                if (i15 == 1) {
                                                    solverVariable12 = solverVariable2;
                                                    i32 = 6;
                                                    i33 = 1;
                                                    i31 = 1;
                                                    i30 = 0;
                                                    i29 = 4;
                                                } else if (i15 != 3) {
                                                    solverVariable12 = solverVariable2;
                                                    i32 = 6;
                                                    i33 = 0;
                                                    i31 = 0;
                                                } else if (this.mResolvedDimensionRatioSide == -1) {
                                                    solverVariable12 = solverVariable2;
                                                    i33 = 1;
                                                    i32 = z15 ? z8 ? 5 : 4 : 8;
                                                    i31 = 1;
                                                    i30 = 1;
                                                    i29 = 5;
                                                } else if (z12) {
                                                    if (!(i12 == 2 || i12 == 1)) {
                                                        i42 = 8;
                                                        i41 = 5;
                                                    } else {
                                                        i42 = 5;
                                                        i41 = 4;
                                                    }
                                                    solverVariable12 = solverVariable2;
                                                    i28 = i42;
                                                    i29 = i41;
                                                    i32 = 6;
                                                    i33 = 1;
                                                    i31 = 1;
                                                    i30 = 1;
                                                } else {
                                                    if (i21 > 0) {
                                                        solverVariable12 = solverVariable2;
                                                        i32 = 6;
                                                        i33 = 1;
                                                        i31 = 1;
                                                        i30 = 1;
                                                        i29 = 5;
                                                    } else if (i21 != 0 || i18 != 0) {
                                                        solverVariable12 = solverVariable2;
                                                        i32 = 6;
                                                        i33 = 1;
                                                        i31 = 1;
                                                        i30 = 1;
                                                        i29 = 4;
                                                    } else if (!z15) {
                                                        solverVariable12 = solverVariable2;
                                                        i32 = 6;
                                                        i33 = 1;
                                                        i31 = 1;
                                                        i30 = 1;
                                                        i29 = 8;
                                                    } else {
                                                        solverVariable12 = solverVariable2;
                                                        i28 = (constraintWidget7 == parent || constraintWidget8 == parent) ? 5 : 4;
                                                        i32 = 6;
                                                        i33 = 1;
                                                        i31 = 1;
                                                        i30 = 1;
                                                        i29 = 4;
                                                    }
                                                    i28 = 5;
                                                }
                                                i28 = 8;
                                            }
                                            if (i31 == 0 && solverVariable5 == solverVariable6 && constraintWidget7 != parent) {
                                                i31 = 0;
                                                z22 = false;
                                            } else {
                                                z22 = true;
                                            }
                                            if (i33 == 0) {
                                                if (z19 || z13 || z15 || solverVariable5 != solverVariable || solverVariable6 != solverVariable12) {
                                                    i35 = i28;
                                                    z23 = z22;
                                                    z21 = z8;
                                                    i39 = i32;
                                                } else {
                                                    z21 = false;
                                                    i39 = 8;
                                                    z23 = false;
                                                    i35 = 8;
                                                }
                                                i34 = i15;
                                                constraintWidget2 = parent;
                                                constraintWidget3 = constraintWidget8;
                                                solverVariable13 = solverVariable4;
                                                solverVariable14 = createObjectVariable;
                                                linearSystem.addCentering(createObjectVariable, solverVariable5, constraintAnchor.getMargin(), f7, solverVariable6, solverVariable4, constraintAnchor2.getMargin(), i39);
                                                z22 = z23;
                                            } else {
                                                i34 = i15;
                                                constraintWidget2 = parent;
                                                constraintWidget3 = constraintWidget8;
                                                solverVariable13 = solverVariable4;
                                                solverVariable14 = createObjectVariable;
                                                i35 = i28;
                                                z21 = z8;
                                            }
                                            if (this.mVisibility == 8 || constraintAnchor2.hasDependents()) {
                                                if (i31 == 0) {
                                                    int i52 = (!z21 || solverVariable5 == solverVariable6 || z19 || (!(constraintWidget7 instanceof Barrier) && !(constraintWidget3 instanceof Barrier))) ? i35 : 6;
                                                    linearSystem.addGreaterThan(solverVariable14, solverVariable5, constraintAnchor.getMargin(), i52);
                                                    solverVariable15 = solverVariable13;
                                                    linearSystem.addLowerThan(solverVariable15, solverVariable6, -constraintAnchor2.getMargin(), i52);
                                                    i35 = i52;
                                                } else {
                                                    solverVariable15 = solverVariable13;
                                                }
                                                if (z21 || !z16 || (constraintWidget7 instanceof Barrier) || (constraintWidget3 instanceof Barrier)) {
                                                    i37 = i29;
                                                    i36 = i35;
                                                } else {
                                                    i37 = 6;
                                                    i36 = 6;
                                                    z22 = true;
                                                }
                                                if (z22) {
                                                    if (i30 == 0 || (z15 && !z9)) {
                                                        constraintWidget4 = constraintWidget2;
                                                    } else {
                                                        constraintWidget4 = constraintWidget2;
                                                        if (!(constraintWidget7 == constraintWidget4 || constraintWidget3 == constraintWidget4)) {
                                                            i51 = i37;
                                                        }
                                                        if ((constraintWidget7 instanceof Guideline) || (constraintWidget3 instanceof Guideline)) {
                                                            i51 = 5;
                                                        }
                                                        if ((constraintWidget7 instanceof Barrier) || (constraintWidget3 instanceof Barrier)) {
                                                            i51 = 5;
                                                        }
                                                        i37 = Math.max(z15 ? 5 : i51, i37);
                                                    }
                                                    if (z21) {
                                                        i37 = Math.min(i36, i37);
                                                        if (z12 && !z15 && (constraintWidget7 == constraintWidget4 || constraintWidget3 == constraintWidget4)) {
                                                            i37 = 4;
                                                        }
                                                    }
                                                    linearSystem.addEquality(solverVariable14, solverVariable5, constraintAnchor.getMargin(), i37);
                                                    linearSystem.addEquality(solverVariable15, solverVariable6, -constraintAnchor2.getMargin(), i37);
                                                }
                                                if (z21) {
                                                    int margin = solverVariable == solverVariable5 ? constraintAnchor.getMargin() : 0;
                                                    if (solverVariable5 != solverVariable) {
                                                        linearSystem.addGreaterThan(solverVariable14, solverVariable, margin, 5);
                                                    }
                                                }
                                                if (z21 || !z19) {
                                                    solverVariable11 = solverVariable15;
                                                } else {
                                                    solverVariable11 = solverVariable15;
                                                    if (i9 == 0 && i18 == 0) {
                                                        if (!z19 || i34 != 3) {
                                                            i26 = 0;
                                                            i38 = 5;
                                                        } else {
                                                            i38 = 8;
                                                            i26 = 0;
                                                        }
                                                        linearSystem.addGreaterThan(solverVariable11, solverVariable14, i26, i38);
                                                        if (!z21 && z20) {
                                                            if (constraintAnchor2.mTarget != null) {
                                                                i26 = constraintAnchor2.getMargin();
                                                            }
                                                            if (solverVariable6 == solverVariable2) {
                                                                return;
                                                            }
                                                            if (!this.OPTIMIZE_WRAP || !solverVariable11.isFinalValue || (constraintWidget = this.mParent) == null) {
                                                                linearSystem.addGreaterThan(solverVariable2, solverVariable11, i26, 5);
                                                                return;
                                                            }
                                                            ConstraintWidgetContainer constraintWidgetContainer = (ConstraintWidgetContainer) constraintWidget;
                                                            if (z7) {
                                                                constraintWidgetContainer.addHorizontalWrapMaxVariable(constraintAnchor2);
                                                                return;
                                                            } else {
                                                                constraintWidgetContainer.addVerticalWrapMaxVariable(constraintAnchor2);
                                                                return;
                                                            }
                                                        } else {
                                                            return;
                                                        }
                                                    }
                                                }
                                                i26 = 0;
                                                if (!z21) {
                                                    return;
                                                }
                                                return;
                                            }
                                            return;
                                        } else if (!solverVariable5.isFinalValue || !solverVariable6.isFinalValue) {
                                            solverVariable12 = solverVariable2;
                                            i32 = 6;
                                            i33 = 1;
                                            i31 = 1;
                                        } else {
                                            linearSystem.addCentering(createObjectVariable, solverVariable5, constraintAnchor.getMargin(), f7, solverVariable6, solverVariable4, constraintAnchor2.getMargin(), 8);
                                            if (z8 && z20) {
                                                if (constraintAnchor2.mTarget != null) {
                                                    i40 = constraintAnchor2.getMargin();
                                                    solverVariable16 = solverVariable2;
                                                } else {
                                                    solverVariable16 = solverVariable2;
                                                    i40 = 0;
                                                }
                                                if (solverVariable6 != solverVariable16) {
                                                    linearSystem.addGreaterThan(solverVariable16, solverVariable4, i40, 5);
                                                    return;
                                                }
                                                return;
                                            }
                                            return;
                                        }
                                        i30 = 0;
                                        i29 = 4;
                                        i28 = 5;
                                        if (i31 == 0) {
                                        }
                                        z22 = true;
                                        if (i33 == 0) {
                                        }
                                        if (this.mVisibility == 8) {
                                        }
                                        if (i31 == 0) {
                                        }
                                        if (z21) {
                                        }
                                        i37 = i29;
                                        i36 = i35;
                                        if (z22) {
                                        }
                                        if (z21) {
                                        }
                                        if (z21) {
                                        }
                                        solverVariable11 = solverVariable15;
                                        i26 = 0;
                                        if (!z21) {
                                        }
                                    }
                                } else {
                                    linearSystem.addEquality(solverVariable4, solverVariable6, -constraintAnchor2.getMargin(), 8);
                                    if (z8) {
                                        if (!this.OPTIMIZE_WRAP || !createObjectVariable.isFinalValue || (constraintWidget5 = this.mParent) == null) {
                                            i27 = i20;
                                            linearSystem.addGreaterThan(createObjectVariable, solverVariable, i27, 5);
                                        } else {
                                            ConstraintWidgetContainer constraintWidgetContainer2 = (ConstraintWidgetContainer) constraintWidget5;
                                            i27 = i20;
                                            if (z7) {
                                                constraintWidgetContainer2.addHorizontalWrapMinVariable(constraintAnchor);
                                            } else {
                                                constraintWidgetContainer2.addVerticalWrapMinVariable(constraintAnchor);
                                            }
                                        }
                                    }
                                }
                                i26 = i27;
                                solverVariable11 = solverVariable4;
                                z21 = z8;
                                if (!z21) {
                                }
                            }
                            solverVariable11 = solverVariable4;
                            i26 = i20;
                            z21 = z8;
                            if (!z21) {
                            }
                        }
                        if (i23 < i22 && z8 && z20) {
                            linearSystem.addGreaterThan(solverVariable7, solverVariable10, i24, 8);
                            int i53 = (z7 || this.mBaseline.mTarget == null) ? 1 : i24;
                            if (z7 || (constraintAnchor3 = this.mBaseline.mTarget) == null) {
                                i25 = i53;
                            } else {
                                ConstraintWidget constraintWidget9 = constraintAnchor3.mOwner;
                                i25 = (constraintWidget9.mDimensionRatio != 0.0f && (dimensionBehaviourArr = constraintWidget9.mListDimensionBehaviors)[i24] == (dimensionBehaviour2 = DimensionBehaviour.MATCH_CONSTRAINT) && dimensionBehaviourArr[1] == dimensionBehaviour2) ? 1 : i24;
                            }
                            if (i25 != 0) {
                                linearSystem.addGreaterThan(solverVariable8, solverVariable9, i24, 8);
                                return;
                            }
                            return;
                        }
                        return;
                    }
                } else {
                    int max = Math.max(i13, i16);
                    if (i14 > 0) {
                        max = Math.min(i14, max);
                    }
                    linearSystem.addEquality(createObjectVariable2, createObjectVariable, max, 8);
                    z20 = z10;
                    i18 = i13;
                    i21 = i14;
                    i20 = 0;
                    z19 = false;
                    solverVariable5 = createObjectVariable3;
                    solverVariable4 = createObjectVariable2;
                    solverVariable6 = solverVariable3;
                    i19 = i47;
                    if (z17) {
                    }
                    if (i23 < i22) {
                        return;
                    }
                    return;
                }
                z19 = z18;
                solverVariable6 = solverVariable3;
                z20 = z10;
                i19 = i47;
                if (z17) {
                }
                if (i23 < i22) {
                }
            }
        }
        z18 = false;
        if (this.mVisibility != 8) {
        }
        if (!z17) {
        }
        if (z18) {
        }
        z19 = z18;
        solverVariable6 = solverVariable3;
        z20 = z10;
        i19 = i47;
        if (z17) {
        }
        if (i23 < i22) {
        }
    }

    private boolean isChainHead(int i7) {
        ConstraintAnchor constraintAnchor;
        ConstraintAnchor constraintAnchor2;
        int i8 = i7 * 2;
        ConstraintAnchor[] constraintAnchorArr = this.mListAnchors;
        ConstraintAnchor constraintAnchor3 = constraintAnchorArr[i8];
        ConstraintAnchor constraintAnchor4 = constraintAnchor3.mTarget;
        return (constraintAnchor4 == null || constraintAnchor4.mTarget == constraintAnchor3 || (constraintAnchor2 = (constraintAnchor = constraintAnchorArr[i8 + 1]).mTarget) == null || constraintAnchor2.mTarget != constraintAnchor) ? false : true;
    }

    public void addChildrenToSolverByDependency(ConstraintWidgetContainer constraintWidgetContainer, LinearSystem linearSystem, HashSet<ConstraintWidget> hashSet, int i7, boolean z7) {
        if (z7) {
            if (hashSet.contains(this)) {
                Optimizer.checkMatchParent(constraintWidgetContainer, linearSystem, this);
                hashSet.remove(this);
                addToSolver(linearSystem, constraintWidgetContainer.optimizeFor(64));
            } else {
                return;
            }
        }
        if (i7 == 0) {
            HashSet<ConstraintAnchor> dependents = this.mLeft.getDependents();
            if (dependents != null) {
                Iterator<ConstraintAnchor> it = dependents.iterator();
                while (it.hasNext()) {
                    it.next().mOwner.addChildrenToSolverByDependency(constraintWidgetContainer, linearSystem, hashSet, i7, true);
                }
            }
            HashSet<ConstraintAnchor> dependents2 = this.mRight.getDependents();
            if (dependents2 != null) {
                Iterator<ConstraintAnchor> it2 = dependents2.iterator();
                while (it2.hasNext()) {
                    it2.next().mOwner.addChildrenToSolverByDependency(constraintWidgetContainer, linearSystem, hashSet, i7, true);
                }
                return;
            }
            return;
        }
        HashSet<ConstraintAnchor> dependents3 = this.mTop.getDependents();
        if (dependents3 != null) {
            Iterator<ConstraintAnchor> it3 = dependents3.iterator();
            while (it3.hasNext()) {
                it3.next().mOwner.addChildrenToSolverByDependency(constraintWidgetContainer, linearSystem, hashSet, i7, true);
            }
        }
        HashSet<ConstraintAnchor> dependents4 = this.mBottom.getDependents();
        if (dependents4 != null) {
            Iterator<ConstraintAnchor> it4 = dependents4.iterator();
            while (it4.hasNext()) {
                it4.next().mOwner.addChildrenToSolverByDependency(constraintWidgetContainer, linearSystem, hashSet, i7, true);
            }
        }
        HashSet<ConstraintAnchor> dependents5 = this.mBaseline.getDependents();
        if (dependents5 != null) {
            Iterator<ConstraintAnchor> it5 = dependents5.iterator();
            while (it5.hasNext()) {
                it5.next().mOwner.addChildrenToSolverByDependency(constraintWidgetContainer, linearSystem, hashSet, i7, true);
            }
        }
    }

    /* access modifiers changed from: package-private */
    public boolean addFirst() {
        return (this instanceof VirtualLayout) || (this instanceof Guideline);
    }

    /* JADX WARNING: Removed duplicated region for block: B:176:0x02d0  */
    /* JADX WARNING: Removed duplicated region for block: B:180:0x02da  */
    /* JADX WARNING: Removed duplicated region for block: B:183:0x02df  */
    /* JADX WARNING: Removed duplicated region for block: B:190:0x02f4  */
    /* JADX WARNING: Removed duplicated region for block: B:195:0x02fd  */
    /* JADX WARNING: Removed duplicated region for block: B:196:0x0300  */
    /* JADX WARNING: Removed duplicated region for block: B:209:0x0332  */
    /* JADX WARNING: Removed duplicated region for block: B:218:0x037c  */
    /* JADX WARNING: Removed duplicated region for block: B:234:0x0438  */
    /* JADX WARNING: Removed duplicated region for block: B:251:0x049c  */
    /* JADX WARNING: Removed duplicated region for block: B:255:0x04b0  */
    /* JADX WARNING: Removed duplicated region for block: B:256:0x04b2  */
    /* JADX WARNING: Removed duplicated region for block: B:258:0x04b5  */
    /* JADX WARNING: Removed duplicated region for block: B:293:0x0546  */
    /* JADX WARNING: Removed duplicated region for block: B:294:0x0549  */
    /* JADX WARNING: Removed duplicated region for block: B:298:0x058f  */
    /* JADX WARNING: Removed duplicated region for block: B:303:0x05b5  */
    /* JADX WARNING: Removed duplicated region for block: B:306:0x05bf  */
    public void addToSolver(LinearSystem linearSystem, boolean z7) {
        boolean z8;
        boolean z9;
        boolean z10;
        boolean z11;
        int i7;
        int i8;
        int i9;
        boolean z12;
        int i10;
        boolean z13;
        int i11;
        DimensionBehaviour dimensionBehaviour;
        SolverVariable solverVariable;
        SolverVariable solverVariable2;
        SolverVariable solverVariable3;
        DimensionBehaviour dimensionBehaviour2;
        boolean z14;
        boolean z15;
        SolverVariable solverVariable4;
        boolean z16;
        ConstraintWidget constraintWidget;
        LinearSystem linearSystem2;
        SolverVariable solverVariable5;
        SolverVariable solverVariable6;
        int i12;
        int i13;
        int i14;
        int i15;
        SolverVariable solverVariable7;
        SolverVariable solverVariable8;
        SolverVariable solverVariable9;
        ConstraintWidget constraintWidget2;
        SolverVariable solverVariable10;
        SolverVariable solverVariable11;
        SolverVariable solverVariable12;
        SolverVariable solverVariable13;
        LinearSystem linearSystem3;
        boolean z17;
        HorizontalWidgetRun horizontalWidgetRun;
        int i16;
        boolean z18;
        boolean z19;
        HorizontalWidgetRun horizontalWidgetRun2;
        VerticalWidgetRun verticalWidgetRun;
        boolean z20;
        ConstraintWidget constraintWidget3;
        ConstraintWidget constraintWidget4;
        SolverVariable createObjectVariable = linearSystem.createObjectVariable(this.mLeft);
        SolverVariable createObjectVariable2 = linearSystem.createObjectVariable(this.mRight);
        SolverVariable createObjectVariable3 = linearSystem.createObjectVariable(this.mTop);
        SolverVariable createObjectVariable4 = linearSystem.createObjectVariable(this.mBottom);
        SolverVariable createObjectVariable5 = linearSystem.createObjectVariable(this.mBaseline);
        ConstraintWidget constraintWidget5 = this.mParent;
        if (constraintWidget5 != null) {
            boolean z21 = constraintWidget5 != null && constraintWidget5.mListDimensionBehaviors[0] == DimensionBehaviour.WRAP_CONTENT;
            z8 = constraintWidget5 != null && constraintWidget5.mListDimensionBehaviors[1] == DimensionBehaviour.WRAP_CONTENT;
            z9 = z21;
        } else {
            z9 = false;
            z8 = false;
        }
        if (this.mVisibility == 8 && !hasDependencies()) {
            boolean[] zArr = this.mIsInBarrier;
            if (!zArr[0] && !zArr[1]) {
                return;
            }
        }
        boolean z22 = this.resolvedHorizontal;
        if (z22 || this.resolvedVertical) {
            if (z22) {
                linearSystem.addEquality(createObjectVariable, this.mX);
                linearSystem.addEquality(createObjectVariable2, this.mX + this.mWidth);
                if (z9 && (constraintWidget4 = this.mParent) != null) {
                    if (this.OPTIMIZE_WRAP_ON_RESOLVED) {
                        ConstraintWidgetContainer constraintWidgetContainer = (ConstraintWidgetContainer) constraintWidget4;
                        constraintWidgetContainer.addVerticalWrapMinVariable(this.mLeft);
                        constraintWidgetContainer.addHorizontalWrapMaxVariable(this.mRight);
                    } else {
                        linearSystem.addGreaterThan(linearSystem.createObjectVariable(constraintWidget4.mRight), createObjectVariable2, 0, 5);
                    }
                }
            }
            if (this.resolvedVertical) {
                linearSystem.addEquality(createObjectVariable3, this.mY);
                linearSystem.addEquality(createObjectVariable4, this.mY + this.mHeight);
                if (this.mBaseline.hasDependents()) {
                    linearSystem.addEquality(createObjectVariable5, this.mY + this.mBaselineDistance);
                }
                if (z8 && (constraintWidget3 = this.mParent) != null) {
                    if (this.OPTIMIZE_WRAP_ON_RESOLVED) {
                        ConstraintWidgetContainer constraintWidgetContainer2 = (ConstraintWidgetContainer) constraintWidget3;
                        constraintWidgetContainer2.addVerticalWrapMinVariable(this.mTop);
                        constraintWidgetContainer2.addVerticalWrapMaxVariable(this.mBottom);
                    } else {
                        linearSystem.addGreaterThan(linearSystem.createObjectVariable(constraintWidget3.mBottom), createObjectVariable4, 0, 5);
                    }
                }
            }
            if (this.resolvedHorizontal && this.resolvedVertical) {
                this.resolvedHorizontal = false;
                this.resolvedVertical = false;
                return;
            }
        }
        Metrics metrics = LinearSystem.sMetrics;
        if (metrics != null) {
            metrics.widgets++;
        }
        if (!(!z7 || (horizontalWidgetRun2 = this.horizontalRun) == null || (verticalWidgetRun = this.verticalRun) == null)) {
            DependencyNode dependencyNode = horizontalWidgetRun2.start;
            if (dependencyNode.resolved && horizontalWidgetRun2.end.resolved && verticalWidgetRun.start.resolved && verticalWidgetRun.end.resolved) {
                if (metrics != null) {
                    metrics.graphSolved++;
                }
                linearSystem.addEquality(createObjectVariable, dependencyNode.value);
                linearSystem.addEquality(createObjectVariable2, this.horizontalRun.end.value);
                linearSystem.addEquality(createObjectVariable3, this.verticalRun.start.value);
                linearSystem.addEquality(createObjectVariable4, this.verticalRun.end.value);
                linearSystem.addEquality(createObjectVariable5, this.verticalRun.baseline.value);
                if (this.mParent != null) {
                    if (z9 && this.isTerminalWidget[0] && !isInHorizontalChain()) {
                        linearSystem.addGreaterThan(linearSystem.createObjectVariable(this.mParent.mRight), createObjectVariable2, 0, 8);
                    }
                    if (z8 && this.isTerminalWidget[1] && !isInVerticalChain()) {
                        z20 = false;
                        linearSystem.addGreaterThan(linearSystem.createObjectVariable(this.mParent.mBottom), createObjectVariable4, 0, 8);
                        this.resolvedHorizontal = z20;
                        this.resolvedVertical = z20;
                        return;
                    }
                }
                z20 = false;
                this.resolvedHorizontal = z20;
                this.resolvedVertical = z20;
                return;
            }
        }
        if (metrics != null) {
            metrics.linearSolved++;
        }
        if (this.mParent != null) {
            if (isChainHead(0)) {
                ((ConstraintWidgetContainer) this.mParent).addChain(this, 0);
                z18 = true;
            } else {
                z18 = isInHorizontalChain();
            }
            if (isChainHead(1)) {
                ((ConstraintWidgetContainer) this.mParent).addChain(this, 1);
                z19 = true;
            } else {
                z19 = isInVerticalChain();
            }
            if (!z18 && z9 && this.mVisibility != 8 && this.mLeft.mTarget == null && this.mRight.mTarget == null) {
                linearSystem.addGreaterThan(linearSystem.createObjectVariable(this.mParent.mRight), createObjectVariable2, 0, 1);
            }
            if (!z19 && z8 && this.mVisibility != 8 && this.mTop.mTarget == null && this.mBottom.mTarget == null && this.mBaseline == null) {
                linearSystem.addGreaterThan(linearSystem.createObjectVariable(this.mParent.mBottom), createObjectVariable4, 0, 1);
            }
            z10 = z18;
            z11 = z19;
        } else {
            z11 = false;
            z10 = false;
        }
        int i17 = this.mWidth;
        int i18 = this.mMinWidth;
        if (i17 >= i18) {
            i18 = i17;
        }
        int i19 = this.mHeight;
        int i20 = this.mMinHeight;
        if (i19 >= i20) {
            i20 = i19;
        }
        DimensionBehaviour[] dimensionBehaviourArr = this.mListDimensionBehaviors;
        DimensionBehaviour dimensionBehaviour3 = dimensionBehaviourArr[0];
        DimensionBehaviour dimensionBehaviour4 = DimensionBehaviour.MATCH_CONSTRAINT;
        boolean z23 = dimensionBehaviour3 != dimensionBehaviour4;
        DimensionBehaviour dimensionBehaviour5 = dimensionBehaviourArr[1];
        boolean z24 = dimensionBehaviour5 != dimensionBehaviour4;
        int i21 = this.mDimensionRatioSide;
        this.mResolvedDimensionRatioSide = i21;
        float f7 = this.mDimensionRatio;
        this.mResolvedDimensionRatio = f7;
        int i22 = this.mMatchConstraintDefaultWidth;
        SolverVariable solverVariable14 = createObjectVariable2;
        int i23 = this.mMatchConstraintDefaultHeight;
        if (f7 <= 0.0f || this.mVisibility == 8) {
            i7 = i22;
            i8 = i23;
            i10 = i18;
            i9 = i20;
        } else {
            if (dimensionBehaviour3 == dimensionBehaviour4 && i22 == 0) {
                i22 = 3;
            }
            if (dimensionBehaviour5 == dimensionBehaviour4 && i23 == 0) {
                i23 = 3;
            }
            if (dimensionBehaviour3 == dimensionBehaviour4 && dimensionBehaviour5 == dimensionBehaviour4 && i22 == 3 && i23 == 3) {
                setupDimensionRatio(z9, z8, z23, z24);
            } else if (dimensionBehaviour3 == dimensionBehaviour4 && i22 == 3) {
                this.mResolvedDimensionRatioSide = 0;
                int i24 = (int) (f7 * ((float) i19));
                if (dimensionBehaviour5 != dimensionBehaviour4) {
                    i7 = 4;
                    i8 = i23;
                    i9 = i20;
                    z12 = false;
                    i10 = i24;
                    int[] iArr = this.mResolvedMatchConstraintDefault;
                    iArr[0] = i7;
                    iArr[1] = i8;
                    this.mResolvedHasRatio = z12;
                    if (z12) {
                    }
                    z13 = false;
                    if (!z12) {
                    }
                    DimensionBehaviour dimensionBehaviour6 = this.mListDimensionBehaviors[0];
                    DimensionBehaviour dimensionBehaviour7 = DimensionBehaviour.WRAP_CONTENT;
                    if (dimensionBehaviour6 != dimensionBehaviour7) {
                    }
                    if (!r9) {
                    }
                    boolean z25 = !this.mCenter.isConnected();
                    boolean[] zArr2 = this.mIsInBarrier;
                    boolean z26 = zArr2[0];
                    boolean z27 = zArr2[1];
                    DependencyNode dependencyNode2 = horizontalWidgetRun.start;
                    if (!z7) {
                    }
                } else {
                    i10 = i24;
                    i7 = i22;
                    i8 = i23;
                    i9 = i20;
                    z12 = true;
                    int[] iArr2 = this.mResolvedMatchConstraintDefault;
                    iArr2[0] = i7;
                    iArr2[1] = i8;
                    this.mResolvedHasRatio = z12;
                    if (z12) {
                    }
                    z13 = false;
                    if (!z12) {
                    }
                    DimensionBehaviour dimensionBehaviour62 = this.mListDimensionBehaviors[0];
                    DimensionBehaviour dimensionBehaviour72 = DimensionBehaviour.WRAP_CONTENT;
                    if (dimensionBehaviour62 != dimensionBehaviour72) {
                    }
                    if (!r9) {
                    }
                    boolean z252 = !this.mCenter.isConnected();
                    boolean[] zArr22 = this.mIsInBarrier;
                    boolean z262 = zArr22[0];
                    boolean z272 = zArr22[1];
                    DependencyNode dependencyNode22 = horizontalWidgetRun.start;
                    if (!z7) {
                    }
                }
            } else if (dimensionBehaviour5 == dimensionBehaviour4 && i23 == 3) {
                this.mResolvedDimensionRatioSide = 1;
                if (i21 == -1) {
                    this.mResolvedDimensionRatio = 1.0f / f7;
                }
                int i25 = (int) (this.mResolvedDimensionRatio * ((float) i17));
                if (dimensionBehaviour3 != dimensionBehaviour4) {
                    i8 = 4;
                    i9 = i25;
                    i7 = i22;
                    i10 = i18;
                } else {
                    i9 = i25;
                    i7 = i22;
                    i8 = i23;
                    i10 = i18;
                    z12 = true;
                    int[] iArr22 = this.mResolvedMatchConstraintDefault;
                    iArr22[0] = i7;
                    iArr22[1] = i8;
                    this.mResolvedHasRatio = z12;
                    if (z12) {
                        int i26 = this.mResolvedDimensionRatioSide;
                        i11 = -1;
                        if (i26 == 0 || i26 == -1) {
                            z13 = true;
                            boolean z28 = !z12 && ((i16 = this.mResolvedDimensionRatioSide) == 1 || i16 == i11);
                            DimensionBehaviour dimensionBehaviour622 = this.mListDimensionBehaviors[0];
                            DimensionBehaviour dimensionBehaviour722 = DimensionBehaviour.WRAP_CONTENT;
                            boolean z29 = dimensionBehaviour622 != dimensionBehaviour722 && (this instanceof ConstraintWidgetContainer);
                            int i27 = !z29 ? 0 : i10;
                            boolean z2522 = !this.mCenter.isConnected();
                            boolean[] zArr222 = this.mIsInBarrier;
                            boolean z2622 = zArr222[0];
                            boolean z2722 = zArr222[1];
                            if (this.mHorizontalResolution != 2 && !this.resolvedHorizontal) {
                                if (z7 && (horizontalWidgetRun = this.horizontalRun) != null) {
                                    DependencyNode dependencyNode222 = horizontalWidgetRun.start;
                                    if (dependencyNode222.resolved && horizontalWidgetRun.end.resolved) {
                                        if (!z7) {
                                            linearSystem.addEquality(createObjectVariable, dependencyNode222.value);
                                            linearSystem.addEquality(solverVariable14, this.horizontalRun.end.value);
                                            if (this.mParent != null && z9 && this.isTerminalWidget[0] && !isInHorizontalChain()) {
                                                linearSystem.addGreaterThan(linearSystem.createObjectVariable(this.mParent.mRight), solverVariable14, 0, 8);
                                            }
                                            z14 = z9;
                                            z16 = z8;
                                            dimensionBehaviour2 = dimensionBehaviour4;
                                            solverVariable14 = solverVariable14;
                                            solverVariable4 = createObjectVariable;
                                            dimensionBehaviour = dimensionBehaviour722;
                                            z15 = z12;
                                            solverVariable3 = createObjectVariable5;
                                            solverVariable2 = createObjectVariable4;
                                            solverVariable = createObjectVariable3;
                                            if (z7) {
                                                constraintWidget = this;
                                                VerticalWidgetRun verticalWidgetRun2 = constraintWidget.verticalRun;
                                                if (verticalWidgetRun2 != null) {
                                                    DependencyNode dependencyNode3 = verticalWidgetRun2.start;
                                                    if (dependencyNode3.resolved && verticalWidgetRun2.end.resolved) {
                                                        linearSystem2 = linearSystem;
                                                        solverVariable5 = solverVariable;
                                                        linearSystem2.addEquality(solverVariable5, dependencyNode3.value);
                                                        solverVariable6 = solverVariable2;
                                                        linearSystem2.addEquality(solverVariable6, constraintWidget.verticalRun.end.value);
                                                        solverVariable7 = solverVariable3;
                                                        linearSystem2.addEquality(solverVariable7, constraintWidget.verticalRun.baseline.value);
                                                        ConstraintWidget constraintWidget6 = constraintWidget.mParent;
                                                        if (constraintWidget6 == null || z11 || !z16) {
                                                            i15 = 8;
                                                            i13 = 0;
                                                            i12 = 1;
                                                        } else {
                                                            i12 = 1;
                                                            if (constraintWidget.isTerminalWidget[1]) {
                                                                i15 = 8;
                                                                i13 = 0;
                                                                linearSystem2.addGreaterThan(linearSystem2.createObjectVariable(constraintWidget6.mBottom), solverVariable6, 0, 8);
                                                            } else {
                                                                i15 = 8;
                                                                i13 = 0;
                                                            }
                                                        }
                                                        i14 = i13;
                                                        if ((constraintWidget.mVerticalResolution != 2 ? i13 : i14) != 0 || constraintWidget.resolvedVertical) {
                                                            solverVariable9 = solverVariable6;
                                                            solverVariable8 = solverVariable5;
                                                        } else {
                                                            boolean z30 = (constraintWidget.mListDimensionBehaviors[i12] != dimensionBehaviour || !(constraintWidget instanceof ConstraintWidgetContainer)) ? i13 : i12;
                                                            if (z30) {
                                                                i9 = i13;
                                                            }
                                                            ConstraintWidget constraintWidget7 = constraintWidget.mParent;
                                                            SolverVariable createObjectVariable6 = constraintWidget7 != null ? linearSystem2.createObjectVariable(constraintWidget7.mBottom) : null;
                                                            ConstraintWidget constraintWidget8 = constraintWidget.mParent;
                                                            SolverVariable createObjectVariable7 = constraintWidget8 != null ? linearSystem2.createObjectVariable(constraintWidget8.mTop) : null;
                                                            if (constraintWidget.mBaselineDistance > 0 || constraintWidget.mVisibility == i15) {
                                                                if (constraintWidget.mBaseline.mTarget != null) {
                                                                    linearSystem2.addEquality(solverVariable7, solverVariable5, getBaselineDistance(), i15);
                                                                    linearSystem2.addEquality(solverVariable7, linearSystem2.createObjectVariable(constraintWidget.mBaseline.mTarget), i13, i15);
                                                                    if (z16) {
                                                                        linearSystem2.addGreaterThan(createObjectVariable6, linearSystem2.createObjectVariable(constraintWidget.mBottom), i13, 5);
                                                                    }
                                                                    z17 = i13;
                                                                    boolean z31 = constraintWidget.isTerminalWidget[i12];
                                                                    DimensionBehaviour[] dimensionBehaviourArr2 = constraintWidget.mListDimensionBehaviors;
                                                                    solverVariable9 = solverVariable6;
                                                                    solverVariable8 = solverVariable5;
                                                                    applyConstraints(linearSystem, false, z16, z14, z31, createObjectVariable7, createObjectVariable6, dimensionBehaviourArr2[i12], z30, constraintWidget.mTop, constraintWidget.mBottom, constraintWidget.mY, i9, constraintWidget.mMinHeight, constraintWidget.mMaxDimension[i12], constraintWidget.mVerticalBiasPercent, z28, dimensionBehaviourArr2[0] != dimensionBehaviour2, z11, z10, z2722, i8, i7, constraintWidget.mMatchConstraintMinHeight, constraintWidget.mMatchConstraintMaxHeight, constraintWidget.mMatchConstraintPercentHeight, z17);
                                                                } else if (constraintWidget.mVisibility == i15) {
                                                                    linearSystem2.addEquality(solverVariable7, solverVariable5, i13, i15);
                                                                } else {
                                                                    linearSystem2.addEquality(solverVariable7, solverVariable5, getBaselineDistance(), i15);
                                                                }
                                                            }
                                                            z17 = z2522;
                                                            boolean z312 = constraintWidget.isTerminalWidget[i12];
                                                            DimensionBehaviour[] dimensionBehaviourArr22 = constraintWidget.mListDimensionBehaviors;
                                                            solverVariable9 = solverVariable6;
                                                            solverVariable8 = solverVariable5;
                                                            applyConstraints(linearSystem, false, z16, z14, z312, createObjectVariable7, createObjectVariable6, dimensionBehaviourArr22[i12], z30, constraintWidget.mTop, constraintWidget.mBottom, constraintWidget.mY, i9, constraintWidget.mMinHeight, constraintWidget.mMaxDimension[i12], constraintWidget.mVerticalBiasPercent, z28, dimensionBehaviourArr22[0] != dimensionBehaviour2, z11, z10, z2722, i8, i7, constraintWidget.mMatchConstraintMinHeight, constraintWidget.mMatchConstraintMaxHeight, constraintWidget.mMatchConstraintPercentHeight, z17);
                                                        }
                                                        if (!z15) {
                                                            int i28 = 8;
                                                            constraintWidget2 = this;
                                                            int i29 = constraintWidget2.mResolvedDimensionRatioSide;
                                                            float f8 = constraintWidget2.mResolvedDimensionRatio;
                                                            if (i29 == 1) {
                                                                linearSystem3 = linearSystem;
                                                                solverVariable13 = solverVariable9;
                                                                solverVariable12 = solverVariable8;
                                                                solverVariable11 = solverVariable14;
                                                                solverVariable10 = solverVariable4;
                                                            } else {
                                                                i28 = 8;
                                                                linearSystem3 = linearSystem;
                                                                solverVariable13 = solverVariable14;
                                                                solverVariable12 = solverVariable4;
                                                                solverVariable11 = solverVariable9;
                                                                solverVariable10 = solverVariable8;
                                                            }
                                                            linearSystem3.addRatio(solverVariable13, solverVariable12, solverVariable11, solverVariable10, f8, i28);
                                                        } else {
                                                            constraintWidget2 = this;
                                                        }
                                                        if (constraintWidget2.mCenter.isConnected()) {
                                                            linearSystem.addCenterPoint(constraintWidget2, constraintWidget2.mCenter.getTarget().getOwner(), (float) Math.toRadians((double) (constraintWidget2.mCircleConstraintAngle + 90.0f)), constraintWidget2.mCenter.getMargin());
                                                        }
                                                        constraintWidget2.resolvedHorizontal = false;
                                                        constraintWidget2.resolvedVertical = false;
                                                        return;
                                                    }
                                                }
                                                linearSystem2 = linearSystem;
                                                solverVariable7 = solverVariable3;
                                                solverVariable6 = solverVariable2;
                                                solverVariable5 = solverVariable;
                                                i15 = 8;
                                                i13 = 0;
                                                i12 = 1;
                                            } else {
                                                i15 = 8;
                                                i13 = 0;
                                                i12 = 1;
                                                constraintWidget = this;
                                                linearSystem2 = linearSystem;
                                                solverVariable7 = solverVariable3;
                                                solverVariable6 = solverVariable2;
                                                solverVariable5 = solverVariable;
                                            }
                                            i14 = i12;
                                            if ((constraintWidget.mVerticalResolution != 2 ? i13 : i14) != 0) {
                                            }
                                            solverVariable9 = solverVariable6;
                                            solverVariable8 = solverVariable5;
                                            if (!z15) {
                                            }
                                            if (constraintWidget2.mCenter.isConnected()) {
                                            }
                                            constraintWidget2.resolvedHorizontal = false;
                                            constraintWidget2.resolvedVertical = false;
                                            return;
                                        }
                                    }
                                }
                                ConstraintWidget constraintWidget9 = this.mParent;
                                SolverVariable createObjectVariable8 = constraintWidget9 != null ? linearSystem.createObjectVariable(constraintWidget9.mRight) : null;
                                ConstraintWidget constraintWidget10 = this.mParent;
                                SolverVariable createObjectVariable9 = constraintWidget10 != null ? linearSystem.createObjectVariable(constraintWidget10.mLeft) : null;
                                boolean z32 = this.isTerminalWidget[0];
                                DimensionBehaviour[] dimensionBehaviourArr3 = this.mListDimensionBehaviors;
                                z14 = z9;
                                z16 = z8;
                                dimensionBehaviour2 = dimensionBehaviour4;
                                solverVariable3 = createObjectVariable5;
                                solverVariable2 = createObjectVariable4;
                                solverVariable = createObjectVariable3;
                                solverVariable14 = solverVariable14;
                                dimensionBehaviour = dimensionBehaviour722;
                                solverVariable4 = createObjectVariable;
                                z15 = z12;
                                applyConstraints(linearSystem, true, z9, z8, z32, createObjectVariable9, createObjectVariable8, dimensionBehaviourArr3[0], z29, this.mLeft, this.mRight, this.mX, i27, this.mMinWidth, this.mMaxDimension[0], this.mHorizontalBiasPercent, z13, dimensionBehaviourArr3[1] == dimensionBehaviour4, z10, z11, z2622, i7, i8, this.mMatchConstraintMinWidth, this.mMatchConstraintMaxWidth, this.mMatchConstraintPercentWidth, z2522);
                                if (z7) {
                                }
                                i14 = i12;
                                if ((constraintWidget.mVerticalResolution != 2 ? i13 : i14) != 0) {
                                }
                                solverVariable9 = solverVariable6;
                                solverVariable8 = solverVariable5;
                                if (!z15) {
                                }
                                if (constraintWidget2.mCenter.isConnected()) {
                                }
                                constraintWidget2.resolvedHorizontal = false;
                                constraintWidget2.resolvedVertical = false;
                                return;
                            }
                            z14 = z9;
                            dimensionBehaviour2 = dimensionBehaviour4;
                            dimensionBehaviour = dimensionBehaviour722;
                            z15 = z12;
                            solverVariable3 = createObjectVariable5;
                            solverVariable2 = createObjectVariable4;
                            solverVariable = createObjectVariable3;
                            solverVariable4 = createObjectVariable;
                            z16 = z8;
                            if (z7) {
                            }
                            i14 = i12;
                            if ((constraintWidget.mVerticalResolution != 2 ? i13 : i14) != 0) {
                            }
                            solverVariable9 = solverVariable6;
                            solverVariable8 = solverVariable5;
                            if (!z15) {
                            }
                            if (constraintWidget2.mCenter.isConnected()) {
                            }
                            constraintWidget2.resolvedHorizontal = false;
                            constraintWidget2.resolvedVertical = false;
                            return;
                        }
                    } else {
                        i11 = -1;
                    }
                    z13 = false;
                    if (!z12) {
                    }
                    DimensionBehaviour dimensionBehaviour6222 = this.mListDimensionBehaviors[0];
                    DimensionBehaviour dimensionBehaviour7222 = DimensionBehaviour.WRAP_CONTENT;
                    if (dimensionBehaviour6222 != dimensionBehaviour7222) {
                    }
                    if (!z29) {
                    }
                    boolean z25222 = !this.mCenter.isConnected();
                    boolean[] zArr2222 = this.mIsInBarrier;
                    boolean z26222 = zArr2222[0];
                    boolean z27222 = zArr2222[1];
                    DependencyNode dependencyNode2222 = horizontalWidgetRun.start;
                    if (!z7) {
                    }
                }
            }
            i7 = i22;
            i8 = i23;
            i10 = i18;
            i9 = i20;
            z12 = true;
            int[] iArr222 = this.mResolvedMatchConstraintDefault;
            iArr222[0] = i7;
            iArr222[1] = i8;
            this.mResolvedHasRatio = z12;
            if (z12) {
            }
            z13 = false;
            if (!z12) {
            }
            DimensionBehaviour dimensionBehaviour62222 = this.mListDimensionBehaviors[0];
            DimensionBehaviour dimensionBehaviour72222 = DimensionBehaviour.WRAP_CONTENT;
            if (dimensionBehaviour62222 != dimensionBehaviour72222) {
            }
            if (!z29) {
            }
            boolean z252222 = !this.mCenter.isConnected();
            boolean[] zArr22222 = this.mIsInBarrier;
            boolean z262222 = zArr22222[0];
            boolean z272222 = zArr22222[1];
            DependencyNode dependencyNode22222 = horizontalWidgetRun.start;
            if (!z7) {
            }
        }
        z12 = false;
        int[] iArr2222 = this.mResolvedMatchConstraintDefault;
        iArr2222[0] = i7;
        iArr2222[1] = i8;
        this.mResolvedHasRatio = z12;
        if (z12) {
        }
        z13 = false;
        if (!z12) {
        }
        DimensionBehaviour dimensionBehaviour622222 = this.mListDimensionBehaviors[0];
        DimensionBehaviour dimensionBehaviour722222 = DimensionBehaviour.WRAP_CONTENT;
        if (dimensionBehaviour622222 != dimensionBehaviour722222) {
        }
        if (!z29) {
        }
        boolean z2522222 = !this.mCenter.isConnected();
        boolean[] zArr222222 = this.mIsInBarrier;
        boolean z2622222 = zArr222222[0];
        boolean z2722222 = zArr222222[1];
        DependencyNode dependencyNode222222 = horizontalWidgetRun.start;
        if (!z7) {
        }
    }

    public boolean allowedInBarrier() {
        return this.mVisibility != 8;
    }

    public void connect(ConstraintAnchor.Type type, ConstraintWidget constraintWidget, ConstraintAnchor.Type type2) {
        connect(type, constraintWidget, type2, 0);
    }

    public void connectCircularConstraint(ConstraintWidget constraintWidget, float f7, int i7) {
        ConstraintAnchor.Type type = ConstraintAnchor.Type.CENTER;
        immediateConnect(type, constraintWidget, type, i7, 0);
        this.mCircleConstraintAngle = f7;
    }

    public void copy(ConstraintWidget constraintWidget, HashMap<ConstraintWidget, ConstraintWidget> hashMap) {
        this.mHorizontalResolution = constraintWidget.mHorizontalResolution;
        this.mVerticalResolution = constraintWidget.mVerticalResolution;
        this.mMatchConstraintDefaultWidth = constraintWidget.mMatchConstraintDefaultWidth;
        this.mMatchConstraintDefaultHeight = constraintWidget.mMatchConstraintDefaultHeight;
        int[] iArr = this.mResolvedMatchConstraintDefault;
        int[] iArr2 = constraintWidget.mResolvedMatchConstraintDefault;
        iArr[0] = iArr2[0];
        iArr[1] = iArr2[1];
        this.mMatchConstraintMinWidth = constraintWidget.mMatchConstraintMinWidth;
        this.mMatchConstraintMaxWidth = constraintWidget.mMatchConstraintMaxWidth;
        this.mMatchConstraintMinHeight = constraintWidget.mMatchConstraintMinHeight;
        this.mMatchConstraintMaxHeight = constraintWidget.mMatchConstraintMaxHeight;
        this.mMatchConstraintPercentHeight = constraintWidget.mMatchConstraintPercentHeight;
        this.mIsWidthWrapContent = constraintWidget.mIsWidthWrapContent;
        this.mIsHeightWrapContent = constraintWidget.mIsHeightWrapContent;
        this.mResolvedDimensionRatioSide = constraintWidget.mResolvedDimensionRatioSide;
        this.mResolvedDimensionRatio = constraintWidget.mResolvedDimensionRatio;
        int[] iArr3 = constraintWidget.mMaxDimension;
        this.mMaxDimension = Arrays.copyOf(iArr3, iArr3.length);
        this.mCircleConstraintAngle = constraintWidget.mCircleConstraintAngle;
        this.hasBaseline = constraintWidget.hasBaseline;
        this.inPlaceholder = constraintWidget.inPlaceholder;
        this.mLeft.reset();
        this.mTop.reset();
        this.mRight.reset();
        this.mBottom.reset();
        this.mBaseline.reset();
        this.mCenterX.reset();
        this.mCenterY.reset();
        this.mCenter.reset();
        this.mListDimensionBehaviors = (DimensionBehaviour[]) Arrays.copyOf(this.mListDimensionBehaviors, 2);
        ConstraintWidget constraintWidget2 = null;
        this.mParent = this.mParent == null ? null : hashMap.get(constraintWidget.mParent);
        this.mWidth = constraintWidget.mWidth;
        this.mHeight = constraintWidget.mHeight;
        this.mDimensionRatio = constraintWidget.mDimensionRatio;
        this.mDimensionRatioSide = constraintWidget.mDimensionRatioSide;
        this.mX = constraintWidget.mX;
        this.mY = constraintWidget.mY;
        this.mRelX = constraintWidget.mRelX;
        this.mRelY = constraintWidget.mRelY;
        this.mOffsetX = constraintWidget.mOffsetX;
        this.mOffsetY = constraintWidget.mOffsetY;
        this.mBaselineDistance = constraintWidget.mBaselineDistance;
        this.mMinWidth = constraintWidget.mMinWidth;
        this.mMinHeight = constraintWidget.mMinHeight;
        this.mHorizontalBiasPercent = constraintWidget.mHorizontalBiasPercent;
        this.mVerticalBiasPercent = constraintWidget.mVerticalBiasPercent;
        this.mCompanionWidget = constraintWidget.mCompanionWidget;
        this.mContainerItemSkip = constraintWidget.mContainerItemSkip;
        this.mVisibility = constraintWidget.mVisibility;
        this.mDebugName = constraintWidget.mDebugName;
        this.mType = constraintWidget.mType;
        this.mDistToTop = constraintWidget.mDistToTop;
        this.mDistToLeft = constraintWidget.mDistToLeft;
        this.mDistToRight = constraintWidget.mDistToRight;
        this.mDistToBottom = constraintWidget.mDistToBottom;
        this.mLeftHasCentered = constraintWidget.mLeftHasCentered;
        this.mRightHasCentered = constraintWidget.mRightHasCentered;
        this.mTopHasCentered = constraintWidget.mTopHasCentered;
        this.mBottomHasCentered = constraintWidget.mBottomHasCentered;
        this.mHorizontalWrapVisited = constraintWidget.mHorizontalWrapVisited;
        this.mVerticalWrapVisited = constraintWidget.mVerticalWrapVisited;
        this.mHorizontalChainStyle = constraintWidget.mHorizontalChainStyle;
        this.mVerticalChainStyle = constraintWidget.mVerticalChainStyle;
        this.mHorizontalChainFixedPosition = constraintWidget.mHorizontalChainFixedPosition;
        this.mVerticalChainFixedPosition = constraintWidget.mVerticalChainFixedPosition;
        float[] fArr = this.mWeight;
        float[] fArr2 = constraintWidget.mWeight;
        fArr[0] = fArr2[0];
        fArr[1] = fArr2[1];
        ConstraintWidget[] constraintWidgetArr = this.mListNextMatchConstraintsWidget;
        ConstraintWidget[] constraintWidgetArr2 = constraintWidget.mListNextMatchConstraintsWidget;
        constraintWidgetArr[0] = constraintWidgetArr2[0];
        constraintWidgetArr[1] = constraintWidgetArr2[1];
        ConstraintWidget[] constraintWidgetArr3 = this.mNextChainWidget;
        ConstraintWidget[] constraintWidgetArr4 = constraintWidget.mNextChainWidget;
        constraintWidgetArr3[0] = constraintWidgetArr4[0];
        constraintWidgetArr3[1] = constraintWidgetArr4[1];
        ConstraintWidget constraintWidget3 = constraintWidget.mHorizontalNextWidget;
        this.mHorizontalNextWidget = constraintWidget3 == null ? null : hashMap.get(constraintWidget3);
        ConstraintWidget constraintWidget4 = constraintWidget.mVerticalNextWidget;
        if (constraintWidget4 != null) {
            constraintWidget2 = hashMap.get(constraintWidget4);
        }
        this.mVerticalNextWidget = constraintWidget2;
    }

    public void createObjectVariables(LinearSystem linearSystem) {
        linearSystem.createObjectVariable(this.mLeft);
        linearSystem.createObjectVariable(this.mTop);
        linearSystem.createObjectVariable(this.mRight);
        linearSystem.createObjectVariable(this.mBottom);
        if (this.mBaselineDistance > 0) {
            linearSystem.createObjectVariable(this.mBaseline);
        }
    }

    public void ensureMeasureRequested() {
        this.mMeasureRequested = true;
    }

    public void ensureWidgetRuns() {
        if (this.horizontalRun == null) {
            this.horizontalRun = new HorizontalWidgetRun(this);
        }
        if (this.verticalRun == null) {
            this.verticalRun = new VerticalWidgetRun(this);
        }
    }

    public ConstraintAnchor getAnchor(ConstraintAnchor.Type type) {
        switch (AnonymousClass1.$SwitchMap$androidx$constraintlayout$solver$widgets$ConstraintAnchor$Type[type.ordinal()]) {
            case 1:
                return this.mLeft;
            case 2:
                return this.mTop;
            case 3:
                return this.mRight;
            case 4:
                return this.mBottom;
            case 5:
                return this.mBaseline;
            case 6:
                return this.mCenter;
            case 7:
                return this.mCenterX;
            case 8:
                return this.mCenterY;
            case 9:
                return null;
            default:
                throw new AssertionError(type.name());
        }
    }

    public ArrayList<ConstraintAnchor> getAnchors() {
        return this.mAnchors;
    }

    public int getBaselineDistance() {
        return this.mBaselineDistance;
    }

    public float getBiasPercent(int i7) {
        if (i7 == 0) {
            return this.mHorizontalBiasPercent;
        }
        if (i7 == 1) {
            return this.mVerticalBiasPercent;
        }
        return -1.0f;
    }

    public int getBottom() {
        return getY() + this.mHeight;
    }

    public Object getCompanionWidget() {
        return this.mCompanionWidget;
    }

    public int getContainerItemSkip() {
        return this.mContainerItemSkip;
    }

    public String getDebugName() {
        return this.mDebugName;
    }

    public DimensionBehaviour getDimensionBehaviour(int i7) {
        if (i7 == 0) {
            return getHorizontalDimensionBehaviour();
        }
        if (i7 == 1) {
            return getVerticalDimensionBehaviour();
        }
        return null;
    }

    public float getDimensionRatio() {
        return this.mDimensionRatio;
    }

    public int getDimensionRatioSide() {
        return this.mDimensionRatioSide;
    }

    public boolean getHasBaseline() {
        return this.hasBaseline;
    }

    public int getHeight() {
        if (this.mVisibility == 8) {
            return 0;
        }
        return this.mHeight;
    }

    public float getHorizontalBiasPercent() {
        return this.mHorizontalBiasPercent;
    }

    public ConstraintWidget getHorizontalChainControlWidget() {
        if (!isInHorizontalChain()) {
            return null;
        }
        ConstraintWidget constraintWidget = this;
        ConstraintWidget constraintWidget2 = null;
        while (constraintWidget2 == null && constraintWidget != null) {
            ConstraintAnchor anchor = constraintWidget.getAnchor(ConstraintAnchor.Type.LEFT);
            ConstraintAnchor target = anchor == null ? null : anchor.getTarget();
            ConstraintWidget owner = target == null ? null : target.getOwner();
            if (owner == getParent()) {
                return constraintWidget;
            }
            ConstraintAnchor target2 = owner == null ? null : owner.getAnchor(ConstraintAnchor.Type.RIGHT).getTarget();
            if (target2 == null || target2.getOwner() == constraintWidget) {
                constraintWidget = owner;
            } else {
                constraintWidget2 = constraintWidget;
            }
        }
        return constraintWidget2;
    }

    public int getHorizontalChainStyle() {
        return this.mHorizontalChainStyle;
    }

    public DimensionBehaviour getHorizontalDimensionBehaviour() {
        return this.mListDimensionBehaviors[0];
    }

    public int getHorizontalMargin() {
        ConstraintAnchor constraintAnchor = this.mLeft;
        int i7 = 0;
        if (constraintAnchor != null) {
            i7 = 0 + constraintAnchor.mMargin;
        }
        ConstraintAnchor constraintAnchor2 = this.mRight;
        return constraintAnchor2 != null ? i7 + constraintAnchor2.mMargin : i7;
    }

    public int getLastHorizontalMeasureSpec() {
        return this.mLastHorizontalMeasureSpec;
    }

    public int getLastVerticalMeasureSpec() {
        return this.mLastVerticalMeasureSpec;
    }

    public int getLeft() {
        return getX();
    }

    public int getLength(int i7) {
        if (i7 == 0) {
            return getWidth();
        }
        if (i7 == 1) {
            return getHeight();
        }
        return 0;
    }

    public int getMaxHeight() {
        return this.mMaxDimension[1];
    }

    public int getMaxWidth() {
        return this.mMaxDimension[0];
    }

    public int getMinHeight() {
        return this.mMinHeight;
    }

    public int getMinWidth() {
        return this.mMinWidth;
    }

    public ConstraintWidget getNextChainMember(int i7) {
        ConstraintAnchor constraintAnchor;
        ConstraintAnchor constraintAnchor2;
        if (i7 == 0) {
            ConstraintAnchor constraintAnchor3 = this.mRight;
            ConstraintAnchor constraintAnchor4 = constraintAnchor3.mTarget;
            if (constraintAnchor4 == null || constraintAnchor4.mTarget != constraintAnchor3) {
                return null;
            }
            return constraintAnchor4.mOwner;
        } else if (i7 == 1 && (constraintAnchor2 = (constraintAnchor = this.mBottom).mTarget) != null && constraintAnchor2.mTarget == constraintAnchor) {
            return constraintAnchor2.mOwner;
        } else {
            return null;
        }
    }

    public int getOptimizerWrapHeight() {
        int i7;
        int i8 = this.mHeight;
        if (this.mListDimensionBehaviors[1] != DimensionBehaviour.MATCH_CONSTRAINT) {
            return i8;
        }
        if (this.mMatchConstraintDefaultHeight == 1) {
            i7 = Math.max(this.mMatchConstraintMinHeight, i8);
        } else {
            i7 = this.mMatchConstraintMinHeight;
            if (i7 > 0) {
                this.mHeight = i7;
            } else {
                i7 = 0;
            }
        }
        int i9 = this.mMatchConstraintMaxHeight;
        return (i9 <= 0 || i9 >= i7) ? i7 : i9;
    }

    public int getOptimizerWrapWidth() {
        int i7;
        int i8 = this.mWidth;
        if (this.mListDimensionBehaviors[0] != DimensionBehaviour.MATCH_CONSTRAINT) {
            return i8;
        }
        if (this.mMatchConstraintDefaultWidth == 1) {
            i7 = Math.max(this.mMatchConstraintMinWidth, i8);
        } else {
            i7 = this.mMatchConstraintMinWidth;
            if (i7 > 0) {
                this.mWidth = i7;
            } else {
                i7 = 0;
            }
        }
        int i9 = this.mMatchConstraintMaxWidth;
        return (i9 <= 0 || i9 >= i7) ? i7 : i9;
    }

    public ConstraintWidget getParent() {
        return this.mParent;
    }

    public ConstraintWidget getPreviousChainMember(int i7) {
        ConstraintAnchor constraintAnchor;
        ConstraintAnchor constraintAnchor2;
        if (i7 == 0) {
            ConstraintAnchor constraintAnchor3 = this.mLeft;
            ConstraintAnchor constraintAnchor4 = constraintAnchor3.mTarget;
            if (constraintAnchor4 == null || constraintAnchor4.mTarget != constraintAnchor3) {
                return null;
            }
            return constraintAnchor4.mOwner;
        } else if (i7 == 1 && (constraintAnchor2 = (constraintAnchor = this.mTop).mTarget) != null && constraintAnchor2.mTarget == constraintAnchor) {
            return constraintAnchor2.mOwner;
        } else {
            return null;
        }
    }

    /* access modifiers changed from: package-private */
    public int getRelativePositioning(int i7) {
        if (i7 == 0) {
            return this.mRelX;
        }
        if (i7 == 1) {
            return this.mRelY;
        }
        return 0;
    }

    public int getRight() {
        return getX() + this.mWidth;
    }

    /* access modifiers changed from: protected */
    public int getRootX() {
        return this.mX + this.mOffsetX;
    }

    /* access modifiers changed from: protected */
    public int getRootY() {
        return this.mY + this.mOffsetY;
    }

    public WidgetRun getRun(int i7) {
        if (i7 == 0) {
            return this.horizontalRun;
        }
        if (i7 == 1) {
            return this.verticalRun;
        }
        return null;
    }

    public int getTop() {
        return getY();
    }

    public String getType() {
        return this.mType;
    }

    public float getVerticalBiasPercent() {
        return this.mVerticalBiasPercent;
    }

    public ConstraintWidget getVerticalChainControlWidget() {
        if (!isInVerticalChain()) {
            return null;
        }
        ConstraintWidget constraintWidget = this;
        ConstraintWidget constraintWidget2 = null;
        while (constraintWidget2 == null && constraintWidget != null) {
            ConstraintAnchor anchor = constraintWidget.getAnchor(ConstraintAnchor.Type.TOP);
            ConstraintAnchor target = anchor == null ? null : anchor.getTarget();
            ConstraintWidget owner = target == null ? null : target.getOwner();
            if (owner == getParent()) {
                return constraintWidget;
            }
            ConstraintAnchor target2 = owner == null ? null : owner.getAnchor(ConstraintAnchor.Type.BOTTOM).getTarget();
            if (target2 == null || target2.getOwner() == constraintWidget) {
                constraintWidget = owner;
            } else {
                constraintWidget2 = constraintWidget;
            }
        }
        return constraintWidget2;
    }

    public int getVerticalChainStyle() {
        return this.mVerticalChainStyle;
    }

    public DimensionBehaviour getVerticalDimensionBehaviour() {
        return this.mListDimensionBehaviors[1];
    }

    public int getVerticalMargin() {
        int i7 = 0;
        if (this.mLeft != null) {
            i7 = 0 + this.mTop.mMargin;
        }
        return this.mRight != null ? i7 + this.mBottom.mMargin : i7;
    }

    public int getVisibility() {
        return this.mVisibility;
    }

    public int getWidth() {
        if (this.mVisibility == 8) {
            return 0;
        }
        return this.mWidth;
    }

    public int getX() {
        ConstraintWidget constraintWidget = this.mParent;
        return (constraintWidget == null || !(constraintWidget instanceof ConstraintWidgetContainer)) ? this.mX : ((ConstraintWidgetContainer) constraintWidget).mPaddingLeft + this.mX;
    }

    public int getY() {
        ConstraintWidget constraintWidget = this.mParent;
        return (constraintWidget == null || !(constraintWidget instanceof ConstraintWidgetContainer)) ? this.mY : ((ConstraintWidgetContainer) constraintWidget).mPaddingTop + this.mY;
    }

    public boolean hasBaseline() {
        return this.hasBaseline;
    }

    public boolean hasDanglingDimension(int i7) {
        if (i7 == 0) {
            return (this.mLeft.mTarget != null ? 1 : 0) + (this.mRight.mTarget != null ? 1 : 0) < 2;
        }
        return ((this.mTop.mTarget != null ? 1 : 0) + (this.mBottom.mTarget != null ? 1 : 0)) + (this.mBaseline.mTarget != null ? 1 : 0) < 2;
    }

    public boolean hasDependencies() {
        int size = this.mAnchors.size();
        for (int i7 = 0; i7 < size; i7++) {
            if (this.mAnchors.get(i7).hasDependents()) {
                return true;
            }
        }
        return false;
    }

    public void immediateConnect(ConstraintAnchor.Type type, ConstraintWidget constraintWidget, ConstraintAnchor.Type type2, int i7, int i8) {
        getAnchor(type).connect(constraintWidget.getAnchor(type2), i7, i8, true);
    }

    public boolean isHeightWrapContent() {
        return this.mIsHeightWrapContent;
    }

    public boolean isInHorizontalChain() {
        ConstraintAnchor constraintAnchor = this.mLeft;
        ConstraintAnchor constraintAnchor2 = constraintAnchor.mTarget;
        if (constraintAnchor2 != null && constraintAnchor2.mTarget == constraintAnchor) {
            return true;
        }
        ConstraintAnchor constraintAnchor3 = this.mRight;
        ConstraintAnchor constraintAnchor4 = constraintAnchor3.mTarget;
        return constraintAnchor4 != null && constraintAnchor4.mTarget == constraintAnchor3;
    }

    public boolean isInPlaceholder() {
        return this.inPlaceholder;
    }

    public boolean isInVerticalChain() {
        ConstraintAnchor constraintAnchor = this.mTop;
        ConstraintAnchor constraintAnchor2 = constraintAnchor.mTarget;
        if (constraintAnchor2 != null && constraintAnchor2.mTarget == constraintAnchor) {
            return true;
        }
        ConstraintAnchor constraintAnchor3 = this.mBottom;
        ConstraintAnchor constraintAnchor4 = constraintAnchor3.mTarget;
        return constraintAnchor4 != null && constraintAnchor4.mTarget == constraintAnchor3;
    }

    public boolean isInVirtualLayout() {
        return this.mInVirtuaLayout;
    }

    public boolean isMeasureRequested() {
        return this.mMeasureRequested && this.mVisibility != 8;
    }

    public boolean isResolvedHorizontally() {
        return this.resolvedHorizontal || (this.mLeft.hasFinalValue() && this.mRight.hasFinalValue());
    }

    public boolean isResolvedVertically() {
        return this.resolvedVertical || (this.mTop.hasFinalValue() && this.mBottom.hasFinalValue());
    }

    public boolean isRoot() {
        return this.mParent == null;
    }

    public boolean isSpreadHeight() {
        return this.mMatchConstraintDefaultHeight == 0 && this.mDimensionRatio == 0.0f && this.mMatchConstraintMinHeight == 0 && this.mMatchConstraintMaxHeight == 0 && this.mListDimensionBehaviors[1] == DimensionBehaviour.MATCH_CONSTRAINT;
    }

    public boolean isSpreadWidth() {
        return this.mMatchConstraintDefaultWidth == 0 && this.mDimensionRatio == 0.0f && this.mMatchConstraintMinWidth == 0 && this.mMatchConstraintMaxWidth == 0 && this.mListDimensionBehaviors[0] == DimensionBehaviour.MATCH_CONSTRAINT;
    }

    public boolean isWidthWrapContent() {
        return this.mIsWidthWrapContent;
    }

    public boolean oppositeDimensionDependsOn(int i7) {
        char c7 = i7 == 0 ? (char) 1 : 0;
        DimensionBehaviour[] dimensionBehaviourArr = this.mListDimensionBehaviors;
        DimensionBehaviour dimensionBehaviour = dimensionBehaviourArr[i7];
        DimensionBehaviour dimensionBehaviour2 = dimensionBehaviourArr[c7];
        DimensionBehaviour dimensionBehaviour3 = DimensionBehaviour.MATCH_CONSTRAINT;
        return dimensionBehaviour == dimensionBehaviour3 && dimensionBehaviour2 == dimensionBehaviour3;
    }

    public boolean oppositeDimensionsTied() {
        DimensionBehaviour[] dimensionBehaviourArr = this.mListDimensionBehaviors;
        DimensionBehaviour dimensionBehaviour = dimensionBehaviourArr[0];
        DimensionBehaviour dimensionBehaviour2 = DimensionBehaviour.MATCH_CONSTRAINT;
        return dimensionBehaviour == dimensionBehaviour2 && dimensionBehaviourArr[1] == dimensionBehaviour2;
    }

    public void reset() {
        this.mLeft.reset();
        this.mTop.reset();
        this.mRight.reset();
        this.mBottom.reset();
        this.mBaseline.reset();
        this.mCenterX.reset();
        this.mCenterY.reset();
        this.mCenter.reset();
        this.mParent = null;
        this.mCircleConstraintAngle = 0.0f;
        this.mWidth = 0;
        this.mHeight = 0;
        this.mDimensionRatio = 0.0f;
        this.mDimensionRatioSide = -1;
        this.mX = 0;
        this.mY = 0;
        this.mOffsetX = 0;
        this.mOffsetY = 0;
        this.mBaselineDistance = 0;
        this.mMinWidth = 0;
        this.mMinHeight = 0;
        float f7 = DEFAULT_BIAS;
        this.mHorizontalBiasPercent = f7;
        this.mVerticalBiasPercent = f7;
        DimensionBehaviour[] dimensionBehaviourArr = this.mListDimensionBehaviors;
        DimensionBehaviour dimensionBehaviour = DimensionBehaviour.FIXED;
        dimensionBehaviourArr[0] = dimensionBehaviour;
        dimensionBehaviourArr[1] = dimensionBehaviour;
        this.mCompanionWidget = null;
        this.mContainerItemSkip = 0;
        this.mVisibility = 0;
        this.mType = null;
        this.mHorizontalWrapVisited = false;
        this.mVerticalWrapVisited = false;
        this.mHorizontalChainStyle = 0;
        this.mVerticalChainStyle = 0;
        this.mHorizontalChainFixedPosition = false;
        this.mVerticalChainFixedPosition = false;
        float[] fArr = this.mWeight;
        fArr[0] = -1.0f;
        fArr[1] = -1.0f;
        this.mHorizontalResolution = -1;
        this.mVerticalResolution = -1;
        int[] iArr = this.mMaxDimension;
        iArr[0] = Integer.MAX_VALUE;
        iArr[1] = Integer.MAX_VALUE;
        this.mMatchConstraintDefaultWidth = 0;
        this.mMatchConstraintDefaultHeight = 0;
        this.mMatchConstraintPercentWidth = 1.0f;
        this.mMatchConstraintPercentHeight = 1.0f;
        this.mMatchConstraintMaxWidth = Integer.MAX_VALUE;
        this.mMatchConstraintMaxHeight = Integer.MAX_VALUE;
        this.mMatchConstraintMinWidth = 0;
        this.mMatchConstraintMinHeight = 0;
        this.mResolvedHasRatio = false;
        this.mResolvedDimensionRatioSide = -1;
        this.mResolvedDimensionRatio = 1.0f;
        this.mGroupsToSolver = false;
        boolean[] zArr = this.isTerminalWidget;
        zArr[0] = true;
        zArr[1] = true;
        this.mInVirtuaLayout = false;
        boolean[] zArr2 = this.mIsInBarrier;
        zArr2[0] = false;
        zArr2[1] = false;
        this.mMeasureRequested = true;
    }

    public void resetAllConstraints() {
        resetAnchors();
        setVerticalBiasPercent(DEFAULT_BIAS);
        setHorizontalBiasPercent(DEFAULT_BIAS);
    }

    public void resetAnchor(ConstraintAnchor constraintAnchor) {
        if (getParent() == null || !(getParent() instanceof ConstraintWidgetContainer) || !((ConstraintWidgetContainer) getParent()).handlesInternalConstraints()) {
            ConstraintAnchor anchor = getAnchor(ConstraintAnchor.Type.LEFT);
            ConstraintAnchor anchor2 = getAnchor(ConstraintAnchor.Type.RIGHT);
            ConstraintAnchor anchor3 = getAnchor(ConstraintAnchor.Type.TOP);
            ConstraintAnchor anchor4 = getAnchor(ConstraintAnchor.Type.BOTTOM);
            ConstraintAnchor anchor5 = getAnchor(ConstraintAnchor.Type.CENTER);
            ConstraintAnchor anchor6 = getAnchor(ConstraintAnchor.Type.CENTER_X);
            ConstraintAnchor anchor7 = getAnchor(ConstraintAnchor.Type.CENTER_Y);
            if (constraintAnchor == anchor5) {
                if (anchor.isConnected() && anchor2.isConnected() && anchor.getTarget() == anchor2.getTarget()) {
                    anchor.reset();
                    anchor2.reset();
                }
                if (anchor3.isConnected() && anchor4.isConnected() && anchor3.getTarget() == anchor4.getTarget()) {
                    anchor3.reset();
                    anchor4.reset();
                }
                this.mHorizontalBiasPercent = 0.5f;
            } else {
                if (constraintAnchor == anchor6) {
                    if (anchor.isConnected() && anchor2.isConnected() && anchor.getTarget().getOwner() == anchor2.getTarget().getOwner()) {
                        anchor.reset();
                        anchor2.reset();
                    }
                    this.mHorizontalBiasPercent = 0.5f;
                } else if (constraintAnchor == anchor7) {
                    if (anchor3.isConnected() && anchor4.isConnected() && anchor3.getTarget().getOwner() == anchor4.getTarget().getOwner()) {
                        anchor3.reset();
                        anchor4.reset();
                    }
                } else if (constraintAnchor == anchor || constraintAnchor == anchor2 ? !(!anchor.isConnected() || anchor.getTarget() != anchor2.getTarget()) : (constraintAnchor == anchor3 || constraintAnchor == anchor4) && anchor3.isConnected() && anchor3.getTarget() == anchor4.getTarget()) {
                    anchor5.reset();
                }
                constraintAnchor.reset();
            }
            this.mVerticalBiasPercent = 0.5f;
            constraintAnchor.reset();
        }
    }

    public void resetAnchors() {
        ConstraintWidget parent = getParent();
        if (parent == null || !(parent instanceof ConstraintWidgetContainer) || !((ConstraintWidgetContainer) getParent()).handlesInternalConstraints()) {
            int size = this.mAnchors.size();
            for (int i7 = 0; i7 < size; i7++) {
                this.mAnchors.get(i7).reset();
            }
        }
    }

    public void resetFinalResolution() {
        this.resolvedHorizontal = false;
        this.resolvedVertical = false;
        int size = this.mAnchors.size();
        for (int i7 = 0; i7 < size; i7++) {
            this.mAnchors.get(i7).resetFinalResolution();
        }
    }

    public void resetSolverVariables(Cache cache) {
        this.mLeft.resetSolverVariable(cache);
        this.mTop.resetSolverVariable(cache);
        this.mRight.resetSolverVariable(cache);
        this.mBottom.resetSolverVariable(cache);
        this.mBaseline.resetSolverVariable(cache);
        this.mCenter.resetSolverVariable(cache);
        this.mCenterX.resetSolverVariable(cache);
        this.mCenterY.resetSolverVariable(cache);
    }

    public void setBaselineDistance(int i7) {
        this.mBaselineDistance = i7;
        this.hasBaseline = i7 > 0;
    }

    public void setCompanionWidget(Object obj) {
        this.mCompanionWidget = obj;
    }

    public void setContainerItemSkip(int i7) {
        if (i7 < 0) {
            i7 = 0;
        }
        this.mContainerItemSkip = i7;
    }

    public void setDebugName(String str) {
        this.mDebugName = str;
    }

    public void setDebugSolverName(LinearSystem linearSystem, String str) {
        this.mDebugName = str;
        SolverVariable createObjectVariable = linearSystem.createObjectVariable(this.mLeft);
        SolverVariable createObjectVariable2 = linearSystem.createObjectVariable(this.mTop);
        SolverVariable createObjectVariable3 = linearSystem.createObjectVariable(this.mRight);
        SolverVariable createObjectVariable4 = linearSystem.createObjectVariable(this.mBottom);
        createObjectVariable.setName(str + ".left");
        createObjectVariable2.setName(str + ".top");
        createObjectVariable3.setName(str + ".right");
        createObjectVariable4.setName(str + ".bottom");
        SolverVariable createObjectVariable5 = linearSystem.createObjectVariable(this.mBaseline);
        createObjectVariable5.setName(str + ".baseline");
    }

    public void setDimension(int i7, int i8) {
        this.mWidth = i7;
        int i9 = this.mMinWidth;
        if (i7 < i9) {
            this.mWidth = i9;
        }
        this.mHeight = i8;
        int i10 = this.mMinHeight;
        if (i8 < i10) {
            this.mHeight = i10;
        }
    }

    public void setDimensionRatio(float f7, int i7) {
        this.mDimensionRatio = f7;
        this.mDimensionRatioSide = i7;
    }

    public void setFinalBaseline(int i7) {
        if (this.hasBaseline) {
            int i8 = i7 - this.mBaselineDistance;
            int i9 = this.mHeight + i8;
            this.mY = i8;
            this.mTop.setFinalValue(i8);
            this.mBottom.setFinalValue(i9);
            this.mBaseline.setFinalValue(i7);
            this.resolvedVertical = true;
        }
    }

    public void setFinalFrame(int i7, int i8, int i9, int i10, int i11, int i12) {
        setFrame(i7, i8, i9, i10);
        setBaselineDistance(i11);
        if (i12 == 0) {
            this.resolvedHorizontal = true;
        } else {
            if (i12 == 1) {
                this.resolvedHorizontal = false;
            } else if (i12 == 2) {
                this.resolvedHorizontal = true;
            } else {
                this.resolvedHorizontal = false;
            }
            this.resolvedVertical = true;
            return;
        }
        this.resolvedVertical = false;
    }

    public void setFinalHorizontal(int i7, int i8) {
        this.mLeft.setFinalValue(i7);
        this.mRight.setFinalValue(i8);
        this.mX = i7;
        this.mWidth = i8 - i7;
        this.resolvedHorizontal = true;
    }

    public void setFinalLeft(int i7) {
        this.mLeft.setFinalValue(i7);
        this.mX = i7;
    }

    public void setFinalTop(int i7) {
        this.mTop.setFinalValue(i7);
        this.mY = i7;
    }

    public void setFinalVertical(int i7, int i8) {
        this.mTop.setFinalValue(i7);
        this.mBottom.setFinalValue(i8);
        this.mY = i7;
        this.mHeight = i8 - i7;
        if (this.hasBaseline) {
            this.mBaseline.setFinalValue(i7 + this.mBaselineDistance);
        }
        this.resolvedVertical = true;
    }

    public void setFrame(int i7, int i8, int i9) {
        if (i9 == 0) {
            setHorizontalDimension(i7, i8);
        } else if (i9 == 1) {
            setVerticalDimension(i7, i8);
        }
    }

    public void setGoneMargin(ConstraintAnchor.Type type, int i7) {
        ConstraintAnchor constraintAnchor;
        int i8 = AnonymousClass1.$SwitchMap$androidx$constraintlayout$solver$widgets$ConstraintAnchor$Type[type.ordinal()];
        if (i8 == 1) {
            constraintAnchor = this.mLeft;
        } else if (i8 == 2) {
            constraintAnchor = this.mTop;
        } else if (i8 == 3) {
            constraintAnchor = this.mRight;
        } else if (i8 == 4) {
            constraintAnchor = this.mBottom;
        } else {
            return;
        }
        constraintAnchor.mGoneMargin = i7;
    }

    public void setHasBaseline(boolean z7) {
        this.hasBaseline = z7;
    }

    public void setHeight(int i7) {
        this.mHeight = i7;
        int i8 = this.mMinHeight;
        if (i7 < i8) {
            this.mHeight = i8;
        }
    }

    public void setHeightWrapContent(boolean z7) {
        this.mIsHeightWrapContent = z7;
    }

    public void setHorizontalBiasPercent(float f7) {
        this.mHorizontalBiasPercent = f7;
    }

    public void setHorizontalChainStyle(int i7) {
        this.mHorizontalChainStyle = i7;
    }

    public void setHorizontalDimension(int i7, int i8) {
        this.mX = i7;
        int i9 = i8 - i7;
        this.mWidth = i9;
        int i10 = this.mMinWidth;
        if (i9 < i10) {
            this.mWidth = i10;
        }
    }

    public void setHorizontalDimensionBehaviour(DimensionBehaviour dimensionBehaviour) {
        this.mListDimensionBehaviors[0] = dimensionBehaviour;
    }

    public void setHorizontalMatchStyle(int i7, int i8, int i9, float f7) {
        this.mMatchConstraintDefaultWidth = i7;
        this.mMatchConstraintMinWidth = i8;
        if (i9 == Integer.MAX_VALUE) {
            i9 = 0;
        }
        this.mMatchConstraintMaxWidth = i9;
        this.mMatchConstraintPercentWidth = f7;
        if (f7 > 0.0f && f7 < 1.0f && i7 == 0) {
            this.mMatchConstraintDefaultWidth = 2;
        }
    }

    public void setHorizontalWeight(float f7) {
        this.mWeight[0] = f7;
    }

    /* access modifiers changed from: protected */
    public void setInBarrier(int i7, boolean z7) {
        this.mIsInBarrier[i7] = z7;
    }

    public void setInPlaceholder(boolean z7) {
        this.inPlaceholder = z7;
    }

    public void setInVirtualLayout(boolean z7) {
        this.mInVirtuaLayout = z7;
    }

    public void setLastMeasureSpec(int i7, int i8) {
        this.mLastHorizontalMeasureSpec = i7;
        this.mLastVerticalMeasureSpec = i8;
        setMeasureRequested(false);
    }

    public void setLength(int i7, int i8) {
        if (i8 == 0) {
            setWidth(i7);
        } else if (i8 == 1) {
            setHeight(i7);
        }
    }

    public void setMaxHeight(int i7) {
        this.mMaxDimension[1] = i7;
    }

    public void setMaxWidth(int i7) {
        this.mMaxDimension[0] = i7;
    }

    public void setMeasureRequested(boolean z7) {
        this.mMeasureRequested = z7;
    }

    public void setMinHeight(int i7) {
        if (i7 < 0) {
            i7 = 0;
        }
        this.mMinHeight = i7;
    }

    public void setMinWidth(int i7) {
        if (i7 < 0) {
            i7 = 0;
        }
        this.mMinWidth = i7;
    }

    public void setOffset(int i7, int i8) {
        this.mOffsetX = i7;
        this.mOffsetY = i8;
    }

    public void setOrigin(int i7, int i8) {
        this.mX = i7;
        this.mY = i8;
    }

    public void setParent(ConstraintWidget constraintWidget) {
        this.mParent = constraintWidget;
    }

    /* access modifiers changed from: package-private */
    public void setRelativePositioning(int i7, int i8) {
        if (i8 == 0) {
            this.mRelX = i7;
        } else if (i8 == 1) {
            this.mRelY = i7;
        }
    }

    public void setType(String str) {
        this.mType = str;
    }

    public void setVerticalBiasPercent(float f7) {
        this.mVerticalBiasPercent = f7;
    }

    public void setVerticalChainStyle(int i7) {
        this.mVerticalChainStyle = i7;
    }

    public void setVerticalDimension(int i7, int i8) {
        this.mY = i7;
        int i9 = i8 - i7;
        this.mHeight = i9;
        int i10 = this.mMinHeight;
        if (i9 < i10) {
            this.mHeight = i10;
        }
    }

    public void setVerticalDimensionBehaviour(DimensionBehaviour dimensionBehaviour) {
        this.mListDimensionBehaviors[1] = dimensionBehaviour;
    }

    public void setVerticalMatchStyle(int i7, int i8, int i9, float f7) {
        this.mMatchConstraintDefaultHeight = i7;
        this.mMatchConstraintMinHeight = i8;
        if (i9 == Integer.MAX_VALUE) {
            i9 = 0;
        }
        this.mMatchConstraintMaxHeight = i9;
        this.mMatchConstraintPercentHeight = f7;
        if (f7 > 0.0f && f7 < 1.0f && i7 == 0) {
            this.mMatchConstraintDefaultHeight = 2;
        }
    }

    public void setVerticalWeight(float f7) {
        this.mWeight[1] = f7;
    }

    public void setVisibility(int i7) {
        this.mVisibility = i7;
    }

    public void setWidth(int i7) {
        this.mWidth = i7;
        int i8 = this.mMinWidth;
        if (i7 < i8) {
            this.mWidth = i8;
        }
    }

    public void setWidthWrapContent(boolean z7) {
        this.mIsWidthWrapContent = z7;
    }

    public void setX(int i7) {
        this.mX = i7;
    }

    public void setY(int i7) {
        this.mY = i7;
    }

    public void setupDimensionRatio(boolean z7, boolean z8, boolean z9, boolean z10) {
        if (this.mResolvedDimensionRatioSide == -1) {
            if (z9 && !z10) {
                this.mResolvedDimensionRatioSide = 0;
            } else if (!z9 && z10) {
                this.mResolvedDimensionRatioSide = 1;
                if (this.mDimensionRatioSide == -1) {
                    this.mResolvedDimensionRatio = 1.0f / this.mResolvedDimensionRatio;
                }
            }
        }
        if (this.mResolvedDimensionRatioSide == 0 && (!this.mTop.isConnected() || !this.mBottom.isConnected())) {
            this.mResolvedDimensionRatioSide = 1;
        } else if (this.mResolvedDimensionRatioSide == 1 && (!this.mLeft.isConnected() || !this.mRight.isConnected())) {
            this.mResolvedDimensionRatioSide = 0;
        }
        if (this.mResolvedDimensionRatioSide == -1 && (!this.mTop.isConnected() || !this.mBottom.isConnected() || !this.mLeft.isConnected() || !this.mRight.isConnected())) {
            if (this.mTop.isConnected() && this.mBottom.isConnected()) {
                this.mResolvedDimensionRatioSide = 0;
            } else if (this.mLeft.isConnected() && this.mRight.isConnected()) {
                this.mResolvedDimensionRatio = 1.0f / this.mResolvedDimensionRatio;
                this.mResolvedDimensionRatioSide = 1;
            }
        }
        if (this.mResolvedDimensionRatioSide == -1) {
            int i7 = this.mMatchConstraintMinWidth;
            if (i7 > 0 && this.mMatchConstraintMinHeight == 0) {
                this.mResolvedDimensionRatioSide = 0;
            } else if (i7 == 0 && this.mMatchConstraintMinHeight > 0) {
                this.mResolvedDimensionRatio = 1.0f / this.mResolvedDimensionRatio;
                this.mResolvedDimensionRatioSide = 1;
            }
        }
    }

    public String toString() {
        String str;
        StringBuilder sb = new StringBuilder();
        String str2 = "";
        if (this.mType != null) {
            str = "type: " + this.mType + " ";
        } else {
            str = str2;
        }
        sb.append(str);
        if (this.mDebugName != null) {
            str2 = "id: " + this.mDebugName + " ";
        }
        sb.append(str2);
        sb.append("(");
        sb.append(this.mX);
        sb.append(", ");
        sb.append(this.mY);
        sb.append(") - (");
        sb.append(this.mWidth);
        sb.append(" x ");
        sb.append(this.mHeight);
        sb.append(")");
        return sb.toString();
    }

    public void updateFromRuns(boolean z7, boolean z8) {
        int i7;
        int i8;
        boolean isResolved = z7 & this.horizontalRun.isResolved();
        boolean isResolved2 = z8 & this.verticalRun.isResolved();
        HorizontalWidgetRun horizontalWidgetRun = this.horizontalRun;
        int i9 = horizontalWidgetRun.start.value;
        VerticalWidgetRun verticalWidgetRun = this.verticalRun;
        int i10 = verticalWidgetRun.start.value;
        int i11 = horizontalWidgetRun.end.value;
        int i12 = verticalWidgetRun.end.value;
        int i13 = i12 - i10;
        if (i11 - i9 < 0 || i13 < 0 || i9 == Integer.MIN_VALUE || i9 == Integer.MAX_VALUE || i10 == Integer.MIN_VALUE || i10 == Integer.MAX_VALUE || i11 == Integer.MIN_VALUE || i11 == Integer.MAX_VALUE || i12 == Integer.MIN_VALUE || i12 == Integer.MAX_VALUE) {
            i11 = 0;
            i9 = 0;
            i12 = 0;
            i10 = 0;
        }
        int i14 = i11 - i9;
        int i15 = i12 - i10;
        if (isResolved) {
            this.mX = i9;
        }
        if (isResolved2) {
            this.mY = i10;
        }
        if (this.mVisibility == 8) {
            this.mWidth = 0;
            this.mHeight = 0;
            return;
        }
        if (isResolved) {
            if (this.mListDimensionBehaviors[0] == DimensionBehaviour.FIXED && i14 < (i8 = this.mWidth)) {
                i14 = i8;
            }
            this.mWidth = i14;
            int i16 = this.mMinWidth;
            if (i14 < i16) {
                this.mWidth = i16;
            }
        }
        if (isResolved2) {
            if (this.mListDimensionBehaviors[1] == DimensionBehaviour.FIXED && i15 < (i7 = this.mHeight)) {
                i15 = i7;
            }
            this.mHeight = i15;
            int i17 = this.mMinHeight;
            if (i15 < i17) {
                this.mHeight = i17;
            }
        }
    }

    public void updateFromSolver(LinearSystem linearSystem, boolean z7) {
        VerticalWidgetRun verticalWidgetRun;
        HorizontalWidgetRun horizontalWidgetRun;
        int objectVariableValue = linearSystem.getObjectVariableValue(this.mLeft);
        int objectVariableValue2 = linearSystem.getObjectVariableValue(this.mTop);
        int objectVariableValue3 = linearSystem.getObjectVariableValue(this.mRight);
        int objectVariableValue4 = linearSystem.getObjectVariableValue(this.mBottom);
        if (z7 && (horizontalWidgetRun = this.horizontalRun) != null) {
            DependencyNode dependencyNode = horizontalWidgetRun.start;
            if (dependencyNode.resolved) {
                DependencyNode dependencyNode2 = horizontalWidgetRun.end;
                if (dependencyNode2.resolved) {
                    objectVariableValue = dependencyNode.value;
                    objectVariableValue3 = dependencyNode2.value;
                }
            }
        }
        if (z7 && (verticalWidgetRun = this.verticalRun) != null) {
            DependencyNode dependencyNode3 = verticalWidgetRun.start;
            if (dependencyNode3.resolved) {
                DependencyNode dependencyNode4 = verticalWidgetRun.end;
                if (dependencyNode4.resolved) {
                    objectVariableValue2 = dependencyNode3.value;
                    objectVariableValue4 = dependencyNode4.value;
                }
            }
        }
        int i7 = objectVariableValue4 - objectVariableValue2;
        if (objectVariableValue3 - objectVariableValue < 0 || i7 < 0 || objectVariableValue == Integer.MIN_VALUE || objectVariableValue == Integer.MAX_VALUE || objectVariableValue2 == Integer.MIN_VALUE || objectVariableValue2 == Integer.MAX_VALUE || objectVariableValue3 == Integer.MIN_VALUE || objectVariableValue3 == Integer.MAX_VALUE || objectVariableValue4 == Integer.MIN_VALUE || objectVariableValue4 == Integer.MAX_VALUE) {
            objectVariableValue = 0;
            objectVariableValue4 = 0;
            objectVariableValue2 = 0;
            objectVariableValue3 = 0;
        }
        setFrame(objectVariableValue, objectVariableValue2, objectVariableValue3, objectVariableValue4);
    }

    public ConstraintWidget(int i7, int i8) {
        this(0, 0, i7, i8);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:83:0x0187, code lost:
        if (r8.isConnected() != false) goto L_0x01b2;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:91:0x01b0, code lost:
        if (r8.isConnected() != false) goto L_0x01b2;
     */
    public void connect(ConstraintAnchor.Type type, ConstraintWidget constraintWidget, ConstraintAnchor.Type type2, int i7) {
        ConstraintAnchor constraintAnchor;
        ConstraintAnchor constraintAnchor2;
        ConstraintAnchor anchor;
        ConstraintAnchor.Type type3;
        ConstraintAnchor anchor2;
        ConstraintAnchor.Type type4;
        ConstraintAnchor.Type type5;
        boolean z7;
        ConstraintAnchor.Type type6;
        ConstraintAnchor.Type type7 = ConstraintAnchor.Type.CENTER;
        if (type == type7) {
            ConstraintAnchor.Type type8 = ConstraintAnchor.Type.LEFT;
            if (type2 == type7) {
                ConstraintAnchor anchor3 = getAnchor(type8);
                ConstraintAnchor.Type type9 = ConstraintAnchor.Type.RIGHT;
                ConstraintAnchor anchor4 = getAnchor(type9);
                ConstraintAnchor.Type type10 = ConstraintAnchor.Type.TOP;
                ConstraintAnchor anchor5 = getAnchor(type10);
                ConstraintAnchor.Type type11 = ConstraintAnchor.Type.BOTTOM;
                ConstraintAnchor anchor6 = getAnchor(type11);
                boolean z8 = true;
                if ((anchor3 == null || !anchor3.isConnected()) && (anchor4 == null || !anchor4.isConnected())) {
                    connect(type8, constraintWidget, type8, 0);
                    connect(type9, constraintWidget, type9, 0);
                    z7 = true;
                } else {
                    z7 = false;
                }
                if ((anchor5 == null || !anchor5.isConnected()) && (anchor6 == null || !anchor6.isConnected())) {
                    connect(type10, constraintWidget, type10, 0);
                    connect(type11, constraintWidget, type11, 0);
                } else {
                    z8 = false;
                }
                if (!z7 || !z8) {
                    if (z7) {
                        type6 = ConstraintAnchor.Type.CENTER_X;
                    } else if (z8) {
                        type6 = ConstraintAnchor.Type.CENTER_Y;
                    } else {
                        return;
                    }
                    anchor = getAnchor(type6);
                    anchor2 = constraintWidget.getAnchor(type6);
                    anchor.connect(anchor2, 0);
                }
                anchor = getAnchor(type7);
                anchor2 = constraintWidget.getAnchor(type7);
                anchor.connect(anchor2, 0);
            }
            if (type2 == type8 || type2 == ConstraintAnchor.Type.RIGHT) {
                connect(type8, constraintWidget, type2, 0);
                type5 = ConstraintAnchor.Type.RIGHT;
            } else {
                ConstraintAnchor.Type type12 = ConstraintAnchor.Type.TOP;
                if (type2 == type12 || type2 == ConstraintAnchor.Type.BOTTOM) {
                    connect(type12, constraintWidget, type2, 0);
                    type5 = ConstraintAnchor.Type.BOTTOM;
                } else {
                    return;
                }
            }
            connect(type5, constraintWidget, type2, 0);
            anchor = getAnchor(type7);
        } else {
            ConstraintAnchor.Type type13 = ConstraintAnchor.Type.CENTER_X;
            if (type == type13 && (type2 == (type4 = ConstraintAnchor.Type.LEFT) || type2 == ConstraintAnchor.Type.RIGHT)) {
                ConstraintAnchor anchor7 = getAnchor(type4);
                ConstraintAnchor anchor8 = constraintWidget.getAnchor(type2);
                ConstraintAnchor anchor9 = getAnchor(ConstraintAnchor.Type.RIGHT);
                anchor7.connect(anchor8, 0);
                anchor9.connect(anchor8, 0);
                getAnchor(type13).connect(anchor8, 0);
                return;
            }
            ConstraintAnchor.Type type14 = ConstraintAnchor.Type.CENTER_Y;
            if (type == type14 && (type2 == (type3 = ConstraintAnchor.Type.TOP) || type2 == ConstraintAnchor.Type.BOTTOM)) {
                anchor2 = constraintWidget.getAnchor(type2);
                getAnchor(type3).connect(anchor2, 0);
                getAnchor(ConstraintAnchor.Type.BOTTOM).connect(anchor2, 0);
                anchor = getAnchor(type14);
                anchor.connect(anchor2, 0);
            } else if (type == type13 && type2 == type13) {
                ConstraintAnchor.Type type15 = ConstraintAnchor.Type.LEFT;
                getAnchor(type15).connect(constraintWidget.getAnchor(type15), 0);
                ConstraintAnchor.Type type16 = ConstraintAnchor.Type.RIGHT;
                getAnchor(type16).connect(constraintWidget.getAnchor(type16), 0);
                anchor = getAnchor(type13);
            } else if (type == type14 && type2 == type14) {
                ConstraintAnchor.Type type17 = ConstraintAnchor.Type.TOP;
                getAnchor(type17).connect(constraintWidget.getAnchor(type17), 0);
                ConstraintAnchor.Type type18 = ConstraintAnchor.Type.BOTTOM;
                getAnchor(type18).connect(constraintWidget.getAnchor(type18), 0);
                anchor = getAnchor(type14);
            } else {
                ConstraintAnchor anchor10 = getAnchor(type);
                ConstraintAnchor anchor11 = constraintWidget.getAnchor(type2);
                if (anchor10.isValidConnection(anchor11)) {
                    ConstraintAnchor.Type type19 = ConstraintAnchor.Type.BASELINE;
                    if (type == type19) {
                        ConstraintAnchor anchor12 = getAnchor(ConstraintAnchor.Type.TOP);
                        ConstraintAnchor anchor13 = getAnchor(ConstraintAnchor.Type.BOTTOM);
                        if (anchor12 != null) {
                            anchor12.reset();
                        }
                        if (anchor13 != null) {
                            anchor13.reset();
                        }
                        i7 = 0;
                    } else {
                        if (type == ConstraintAnchor.Type.TOP || type == ConstraintAnchor.Type.BOTTOM) {
                            ConstraintAnchor anchor14 = getAnchor(type19);
                            if (anchor14 != null) {
                                anchor14.reset();
                            }
                            ConstraintAnchor anchor15 = getAnchor(type7);
                            if (anchor15.getTarget() != anchor11) {
                                anchor15.reset();
                            }
                            constraintAnchor = getAnchor(type).getOpposite();
                            constraintAnchor2 = getAnchor(type14);
                        } else if (type == ConstraintAnchor.Type.LEFT || type == ConstraintAnchor.Type.RIGHT) {
                            ConstraintAnchor anchor16 = getAnchor(type7);
                            if (anchor16.getTarget() != anchor11) {
                                anchor16.reset();
                            }
                            constraintAnchor = getAnchor(type).getOpposite();
                            constraintAnchor2 = getAnchor(type13);
                        }
                        constraintAnchor.reset();
                        constraintAnchor2.reset();
                    }
                    anchor10.connect(anchor11, i7);
                    return;
                }
                return;
            }
        }
        anchor2 = constraintWidget.getAnchor(type2);
        anchor.connect(anchor2, 0);
    }

    /* JADX WARNING: Removed duplicated region for block: B:38:0x008b  */
    /* JADX WARNING: Removed duplicated region for block: B:42:? A[RETURN, SYNTHETIC] */
    public void setDimensionRatio(String str) {
        float f7;
        if (str == null || str.length() == 0) {
            this.mDimensionRatio = 0.0f;
            return;
        }
        int length = str.length();
        int indexOf = str.indexOf(44);
        int i7 = 0;
        int i8 = -1;
        if (indexOf > 0 && indexOf < length - 1) {
            String substring = str.substring(0, indexOf);
            if (!substring.equalsIgnoreCase("W")) {
                i7 = substring.equalsIgnoreCase("H") ? 1 : -1;
            }
            i8 = i7;
            i7 = indexOf + 1;
        }
        int indexOf2 = str.indexOf(58);
        if (indexOf2 < 0 || indexOf2 >= length - 1) {
            String substring2 = str.substring(i7);
            if (substring2.length() > 0) {
                f7 = Float.parseFloat(substring2);
                if (f7 > 0.0f) {
                    this.mDimensionRatio = f7;
                    this.mDimensionRatioSide = i8;
                    return;
                }
                return;
            }
        } else {
            String substring3 = str.substring(i7, indexOf2);
            String substring4 = str.substring(indexOf2 + 1);
            if (substring3.length() > 0 && substring4.length() > 0) {
                try {
                    float parseFloat = Float.parseFloat(substring3);
                    float parseFloat2 = Float.parseFloat(substring4);
                    if (parseFloat > 0.0f && parseFloat2 > 0.0f) {
                        f7 = i8 == 1 ? Math.abs(parseFloat2 / parseFloat) : Math.abs(parseFloat / parseFloat2);
                        if (f7 > 0.0f) {
                        }
                    }
                } catch (NumberFormatException unused) {
                }
            }
        }
        f7 = 0.0f;
        if (f7 > 0.0f) {
        }
    }

    public void setFrame(int i7, int i8, int i9, int i10) {
        int i11;
        int i12;
        int i13 = i9 - i7;
        int i14 = i10 - i8;
        this.mX = i7;
        this.mY = i8;
        if (this.mVisibility == 8) {
            this.mWidth = 0;
            this.mHeight = 0;
            return;
        }
        DimensionBehaviour[] dimensionBehaviourArr = this.mListDimensionBehaviors;
        DimensionBehaviour dimensionBehaviour = dimensionBehaviourArr[0];
        DimensionBehaviour dimensionBehaviour2 = DimensionBehaviour.FIXED;
        if (dimensionBehaviour == dimensionBehaviour2 && i13 < (i12 = this.mWidth)) {
            i13 = i12;
        }
        if (dimensionBehaviourArr[1] == dimensionBehaviour2 && i14 < (i11 = this.mHeight)) {
            i14 = i11;
        }
        this.mWidth = i13;
        this.mHeight = i14;
        int i15 = this.mMinHeight;
        if (i14 < i15) {
            this.mHeight = i15;
        }
        int i16 = this.mMinWidth;
        if (i13 < i16) {
            this.mWidth = i16;
        }
    }

    public ConstraintWidget(int i7, int i8, int i9, int i10) {
        this.measured = false;
        this.run = new WidgetRun[2];
        this.horizontalRun = null;
        this.verticalRun = null;
        this.isTerminalWidget = new boolean[]{true, true};
        this.mResolvedHasRatio = false;
        this.mMeasureRequested = true;
        this.OPTIMIZE_WRAP = false;
        this.OPTIMIZE_WRAP_ON_RESOLVED = true;
        this.resolvedHorizontal = false;
        this.resolvedVertical = false;
        this.mHorizontalResolution = -1;
        this.mVerticalResolution = -1;
        this.mMatchConstraintDefaultWidth = 0;
        this.mMatchConstraintDefaultHeight = 0;
        this.mResolvedMatchConstraintDefault = new int[2];
        this.mMatchConstraintMinWidth = 0;
        this.mMatchConstraintMaxWidth = 0;
        this.mMatchConstraintPercentWidth = 1.0f;
        this.mMatchConstraintMinHeight = 0;
        this.mMatchConstraintMaxHeight = 0;
        this.mMatchConstraintPercentHeight = 1.0f;
        this.mResolvedDimensionRatioSide = -1;
        this.mResolvedDimensionRatio = 1.0f;
        this.mMaxDimension = new int[]{Integer.MAX_VALUE, Integer.MAX_VALUE};
        this.mCircleConstraintAngle = 0.0f;
        this.hasBaseline = false;
        this.mInVirtuaLayout = false;
        this.mLastHorizontalMeasureSpec = 0;
        this.mLastVerticalMeasureSpec = 0;
        this.mLeft = new ConstraintAnchor(this, ConstraintAnchor.Type.LEFT);
        this.mTop = new ConstraintAnchor(this, ConstraintAnchor.Type.TOP);
        this.mRight = new ConstraintAnchor(this, ConstraintAnchor.Type.RIGHT);
        this.mBottom = new ConstraintAnchor(this, ConstraintAnchor.Type.BOTTOM);
        this.mBaseline = new ConstraintAnchor(this, ConstraintAnchor.Type.BASELINE);
        this.mCenterX = new ConstraintAnchor(this, ConstraintAnchor.Type.CENTER_X);
        this.mCenterY = new ConstraintAnchor(this, ConstraintAnchor.Type.CENTER_Y);
        ConstraintAnchor constraintAnchor = new ConstraintAnchor(this, ConstraintAnchor.Type.CENTER);
        this.mCenter = constraintAnchor;
        this.mListAnchors = new ConstraintAnchor[]{this.mLeft, this.mRight, this.mTop, this.mBottom, this.mBaseline, constraintAnchor};
        this.mAnchors = new ArrayList<>();
        this.mIsInBarrier = new boolean[2];
        DimensionBehaviour dimensionBehaviour = DimensionBehaviour.FIXED;
        this.mListDimensionBehaviors = new DimensionBehaviour[]{dimensionBehaviour, dimensionBehaviour};
        this.mParent = null;
        this.mDimensionRatio = 0.0f;
        this.mDimensionRatioSide = -1;
        this.mRelX = 0;
        this.mRelY = 0;
        this.mOffsetX = 0;
        this.mOffsetY = 0;
        this.mBaselineDistance = 0;
        float f7 = DEFAULT_BIAS;
        this.mHorizontalBiasPercent = f7;
        this.mVerticalBiasPercent = f7;
        this.mContainerItemSkip = 0;
        this.mVisibility = 0;
        this.mDebugName = null;
        this.mType = null;
        this.mGroupsToSolver = false;
        this.mHorizontalChainStyle = 0;
        this.mVerticalChainStyle = 0;
        this.mWeight = new float[]{-1.0f, -1.0f};
        this.mListNextMatchConstraintsWidget = new ConstraintWidget[]{null, null};
        this.mNextChainWidget = new ConstraintWidget[]{null, null};
        this.mHorizontalNextWidget = null;
        this.mVerticalNextWidget = null;
        this.horizontalGroup = -1;
        this.verticalGroup = -1;
        this.mX = i7;
        this.mY = i8;
        this.mWidth = i9;
        this.mHeight = i10;
        addAnchors();
    }

    public void connect(ConstraintAnchor constraintAnchor, ConstraintAnchor constraintAnchor2, int i7) {
        if (constraintAnchor.getOwner() == this) {
            connect(constraintAnchor.getType(), constraintAnchor2.getOwner(), constraintAnchor2.getType(), i7);
        }
    }

    public ConstraintWidget(String str) {
        this.measured = false;
        this.run = new WidgetRun[2];
        this.horizontalRun = null;
        this.verticalRun = null;
        this.isTerminalWidget = new boolean[]{true, true};
        this.mResolvedHasRatio = false;
        this.mMeasureRequested = true;
        this.OPTIMIZE_WRAP = false;
        this.OPTIMIZE_WRAP_ON_RESOLVED = true;
        this.resolvedHorizontal = false;
        this.resolvedVertical = false;
        this.mHorizontalResolution = -1;
        this.mVerticalResolution = -1;
        this.mMatchConstraintDefaultWidth = 0;
        this.mMatchConstraintDefaultHeight = 0;
        this.mResolvedMatchConstraintDefault = new int[2];
        this.mMatchConstraintMinWidth = 0;
        this.mMatchConstraintMaxWidth = 0;
        this.mMatchConstraintPercentWidth = 1.0f;
        this.mMatchConstraintMinHeight = 0;
        this.mMatchConstraintMaxHeight = 0;
        this.mMatchConstraintPercentHeight = 1.0f;
        this.mResolvedDimensionRatioSide = -1;
        this.mResolvedDimensionRatio = 1.0f;
        this.mMaxDimension = new int[]{Integer.MAX_VALUE, Integer.MAX_VALUE};
        this.mCircleConstraintAngle = 0.0f;
        this.hasBaseline = false;
        this.mInVirtuaLayout = false;
        this.mLastHorizontalMeasureSpec = 0;
        this.mLastVerticalMeasureSpec = 0;
        this.mLeft = new ConstraintAnchor(this, ConstraintAnchor.Type.LEFT);
        this.mTop = new ConstraintAnchor(this, ConstraintAnchor.Type.TOP);
        this.mRight = new ConstraintAnchor(this, ConstraintAnchor.Type.RIGHT);
        this.mBottom = new ConstraintAnchor(this, ConstraintAnchor.Type.BOTTOM);
        this.mBaseline = new ConstraintAnchor(this, ConstraintAnchor.Type.BASELINE);
        this.mCenterX = new ConstraintAnchor(this, ConstraintAnchor.Type.CENTER_X);
        this.mCenterY = new ConstraintAnchor(this, ConstraintAnchor.Type.CENTER_Y);
        ConstraintAnchor constraintAnchor = new ConstraintAnchor(this, ConstraintAnchor.Type.CENTER);
        this.mCenter = constraintAnchor;
        this.mListAnchors = new ConstraintAnchor[]{this.mLeft, this.mRight, this.mTop, this.mBottom, this.mBaseline, constraintAnchor};
        this.mAnchors = new ArrayList<>();
        this.mIsInBarrier = new boolean[2];
        DimensionBehaviour dimensionBehaviour = DimensionBehaviour.FIXED;
        this.mListDimensionBehaviors = new DimensionBehaviour[]{dimensionBehaviour, dimensionBehaviour};
        this.mParent = null;
        this.mWidth = 0;
        this.mHeight = 0;
        this.mDimensionRatio = 0.0f;
        this.mDimensionRatioSide = -1;
        this.mX = 0;
        this.mY = 0;
        this.mRelX = 0;
        this.mRelY = 0;
        this.mOffsetX = 0;
        this.mOffsetY = 0;
        this.mBaselineDistance = 0;
        float f7 = DEFAULT_BIAS;
        this.mHorizontalBiasPercent = f7;
        this.mVerticalBiasPercent = f7;
        this.mContainerItemSkip = 0;
        this.mVisibility = 0;
        this.mDebugName = null;
        this.mType = null;
        this.mGroupsToSolver = false;
        this.mHorizontalChainStyle = 0;
        this.mVerticalChainStyle = 0;
        this.mWeight = new float[]{-1.0f, -1.0f};
        this.mListNextMatchConstraintsWidget = new ConstraintWidget[]{null, null};
        this.mNextChainWidget = new ConstraintWidget[]{null, null};
        this.mHorizontalNextWidget = null;
        this.mVerticalNextWidget = null;
        this.horizontalGroup = -1;
        this.verticalGroup = -1;
        addAnchors();
        setDebugName(str);
    }

    public ConstraintWidget(String str, int i7, int i8) {
        this(i7, i8);
        setDebugName(str);
    }

    public ConstraintWidget(String str, int i7, int i8, int i9, int i10) {
        this(i7, i8, i9, i10);
        setDebugName(str);
    }
}
