package androidx.constraintlayout.solver.widgets;

import androidx.constraintlayout.solver.LinearSystem;
import androidx.constraintlayout.solver.widgets.ConstraintWidget;
import java.util.ArrayList;
import java.util.HashMap;

public class Flow extends VirtualLayout {
    public static final int HORIZONTAL_ALIGN_CENTER = 2;
    public static final int HORIZONTAL_ALIGN_END = 1;
    public static final int HORIZONTAL_ALIGN_START = 0;
    public static final int VERTICAL_ALIGN_BASELINE = 3;
    public static final int VERTICAL_ALIGN_BOTTOM = 1;
    public static final int VERTICAL_ALIGN_CENTER = 2;
    public static final int VERTICAL_ALIGN_TOP = 0;
    public static final int WRAP_ALIGNED = 2;
    public static final int WRAP_CHAIN = 1;
    public static final int WRAP_NONE = 0;
    private ConstraintWidget[] mAlignedBiggestElementsInCols = null;
    private ConstraintWidget[] mAlignedBiggestElementsInRows = null;
    private int[] mAlignedDimensions = null;
    private ArrayList<WidgetsList> mChainList = new ArrayList<>();
    private ConstraintWidget[] mDisplayedWidgets;
    private int mDisplayedWidgetsCount = 0;
    private float mFirstHorizontalBias = 0.5f;
    private int mFirstHorizontalStyle = -1;
    private float mFirstVerticalBias = 0.5f;
    private int mFirstVerticalStyle = -1;
    private int mHorizontalAlign = 2;
    private float mHorizontalBias = 0.5f;
    private int mHorizontalGap = 0;
    private int mHorizontalStyle = -1;
    private float mLastHorizontalBias = 0.5f;
    private int mLastHorizontalStyle = -1;
    private float mLastVerticalBias = 0.5f;
    private int mLastVerticalStyle = -1;
    private int mMaxElementsWrap = -1;
    private int mOrientation = 0;
    private int mVerticalAlign = 2;
    private float mVerticalBias = 0.5f;
    private int mVerticalGap = 0;
    private int mVerticalStyle = -1;
    private int mWrapMode = 0;

    /* access modifiers changed from: private */
    public class WidgetsList {
        private ConstraintWidget biggest = null;
        int biggestDimension = 0;
        private ConstraintAnchor mBottom;
        private int mCount = 0;
        private int mHeight = 0;
        private ConstraintAnchor mLeft;
        private int mMax = 0;
        private int mNbMatchConstraintsWidgets = 0;
        private int mOrientation;
        private int mPaddingBottom = 0;
        private int mPaddingLeft = 0;
        private int mPaddingRight = 0;
        private int mPaddingTop = 0;
        private ConstraintAnchor mRight;
        private int mStartIndex = 0;
        private ConstraintAnchor mTop;
        private int mWidth = 0;

        public WidgetsList(int i7, ConstraintAnchor constraintAnchor, ConstraintAnchor constraintAnchor2, ConstraintAnchor constraintAnchor3, ConstraintAnchor constraintAnchor4, int i8) {
            this.mOrientation = i7;
            this.mLeft = constraintAnchor;
            this.mTop = constraintAnchor2;
            this.mRight = constraintAnchor3;
            this.mBottom = constraintAnchor4;
            this.mPaddingLeft = Flow.this.getPaddingLeft();
            this.mPaddingTop = Flow.this.getPaddingTop();
            this.mPaddingRight = Flow.this.getPaddingRight();
            this.mPaddingBottom = Flow.this.getPaddingBottom();
            this.mMax = i8;
        }

        private void recomputeDimensions() {
            this.mWidth = 0;
            this.mHeight = 0;
            this.biggest = null;
            this.biggestDimension = 0;
            int i7 = this.mCount;
            int i8 = 0;
            while (i8 < i7 && this.mStartIndex + i8 < Flow.this.mDisplayedWidgetsCount) {
                ConstraintWidget constraintWidget = Flow.this.mDisplayedWidgets[this.mStartIndex + i8];
                if (this.mOrientation == 0) {
                    int width = constraintWidget.getWidth();
                    int i9 = Flow.this.mHorizontalGap;
                    if (constraintWidget.getVisibility() == 8) {
                        i9 = 0;
                    }
                    this.mWidth += width + i9;
                    int widgetHeight = Flow.this.getWidgetHeight(constraintWidget, this.mMax);
                    if (this.biggest == null || this.biggestDimension < widgetHeight) {
                        this.biggest = constraintWidget;
                        this.biggestDimension = widgetHeight;
                        this.mHeight = widgetHeight;
                    }
                } else {
                    int widgetWidth = Flow.this.getWidgetWidth(constraintWidget, this.mMax);
                    int widgetHeight2 = Flow.this.getWidgetHeight(constraintWidget, this.mMax);
                    int i10 = Flow.this.mVerticalGap;
                    if (constraintWidget.getVisibility() == 8) {
                        i10 = 0;
                    }
                    this.mHeight += widgetHeight2 + i10;
                    if (this.biggest == null || this.biggestDimension < widgetWidth) {
                        this.biggest = constraintWidget;
                        this.biggestDimension = widgetWidth;
                        this.mWidth = widgetWidth;
                    }
                }
                i8++;
            }
        }

        public void add(ConstraintWidget constraintWidget) {
            int i7 = 0;
            if (this.mOrientation == 0) {
                int widgetWidth = Flow.this.getWidgetWidth(constraintWidget, this.mMax);
                if (constraintWidget.getHorizontalDimensionBehaviour() == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT) {
                    this.mNbMatchConstraintsWidgets++;
                    widgetWidth = 0;
                }
                int i8 = Flow.this.mHorizontalGap;
                if (constraintWidget.getVisibility() != 8) {
                    i7 = i8;
                }
                this.mWidth += widgetWidth + i7;
                int widgetHeight = Flow.this.getWidgetHeight(constraintWidget, this.mMax);
                if (this.biggest == null || this.biggestDimension < widgetHeight) {
                    this.biggest = constraintWidget;
                    this.biggestDimension = widgetHeight;
                    this.mHeight = widgetHeight;
                }
            } else {
                int widgetWidth2 = Flow.this.getWidgetWidth(constraintWidget, this.mMax);
                int widgetHeight2 = Flow.this.getWidgetHeight(constraintWidget, this.mMax);
                if (constraintWidget.getVerticalDimensionBehaviour() == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT) {
                    this.mNbMatchConstraintsWidgets++;
                    widgetHeight2 = 0;
                }
                int i9 = Flow.this.mVerticalGap;
                if (constraintWidget.getVisibility() != 8) {
                    i7 = i9;
                }
                this.mHeight += widgetHeight2 + i7;
                if (this.biggest == null || this.biggestDimension < widgetWidth2) {
                    this.biggest = constraintWidget;
                    this.biggestDimension = widgetWidth2;
                    this.mWidth = widgetWidth2;
                }
            }
            this.mCount++;
        }

        public void clear() {
            this.biggestDimension = 0;
            this.biggest = null;
            this.mWidth = 0;
            this.mHeight = 0;
            this.mStartIndex = 0;
            this.mCount = 0;
            this.mNbMatchConstraintsWidgets = 0;
        }

        /* JADX WARNING: Removed duplicated region for block: B:123:0x0232  */
        /* JADX WARNING: Removed duplicated region for block: B:127:0x024c  */
        /* JADX WARNING: Removed duplicated region for block: B:139:0x029a  */
        /* JADX WARNING: Removed duplicated region for block: B:141:0x02a5  */
        /* JADX WARNING: Removed duplicated region for block: B:148:0x02d0  */
        /* JADX WARNING: Removed duplicated region for block: B:55:0x00df  */
        public void createConstraints(boolean z7, int i7, boolean z8) {
            int i8;
            ConstraintWidget constraintWidget;
            ConstraintAnchor constraintAnchor;
            ConstraintAnchor constraintAnchor2;
            ConstraintAnchor constraintAnchor3;
            ConstraintAnchor constraintAnchor4;
            ConstraintAnchor constraintAnchor5;
            ConstraintAnchor constraintAnchor6;
            ConstraintWidget constraintWidget2;
            int i9;
            char c7;
            ConstraintAnchor constraintAnchor7;
            ConstraintAnchor constraintAnchor8;
            int i10 = this.mCount;
            int i11 = 0;
            while (i11 < i10 && this.mStartIndex + i11 < Flow.this.mDisplayedWidgetsCount) {
                ConstraintWidget constraintWidget3 = Flow.this.mDisplayedWidgets[this.mStartIndex + i11];
                if (constraintWidget3 != null) {
                    constraintWidget3.resetAnchors();
                }
                i11++;
            }
            if (!(i10 == 0 || this.biggest == null)) {
                boolean z9 = z8 && i7 == 0;
                int i12 = -1;
                int i13 = -1;
                for (int i14 = 0; i14 < i10; i14++) {
                    int i15 = z7 ? (i10 - 1) - i14 : i14;
                    if (this.mStartIndex + i15 >= Flow.this.mDisplayedWidgetsCount) {
                        break;
                    }
                    if (Flow.this.mDisplayedWidgets[this.mStartIndex + i15].getVisibility() == 0) {
                        if (i12 == -1) {
                            i12 = i14;
                        }
                        i13 = i14;
                    }
                }
                ConstraintWidget constraintWidget4 = null;
                if (this.mOrientation == 0) {
                    ConstraintWidget constraintWidget5 = this.biggest;
                    constraintWidget5.setVerticalChainStyle(Flow.this.mVerticalStyle);
                    int i16 = this.mPaddingTop;
                    if (i7 > 0) {
                        i16 += Flow.this.mVerticalGap;
                    }
                    constraintWidget5.mTop.connect(this.mTop, i16);
                    if (z8) {
                        constraintWidget5.mBottom.connect(this.mBottom, this.mPaddingBottom);
                    }
                    if (i7 > 0) {
                        this.mTop.mOwner.mBottom.connect(constraintWidget5.mTop, 0);
                    }
                    if (Flow.this.mVerticalAlign == 3 && !constraintWidget5.hasBaseline()) {
                        int i17 = 0;
                        while (true) {
                            if (i17 >= i10) {
                                break;
                            }
                            int i18 = z7 ? (i10 - 1) - i17 : i17;
                            if (this.mStartIndex + i18 >= Flow.this.mDisplayedWidgetsCount) {
                                break;
                            }
                            constraintWidget2 = Flow.this.mDisplayedWidgets[this.mStartIndex + i18];
                            if (constraintWidget2.hasBaseline()) {
                                break;
                            }
                            i17++;
                        }
                        i9 = 0;
                        while (i9 < i10) {
                            int i19 = z7 ? (i10 - 1) - i9 : i9;
                            if (this.mStartIndex + i19 < Flow.this.mDisplayedWidgetsCount) {
                                ConstraintWidget constraintWidget6 = Flow.this.mDisplayedWidgets[this.mStartIndex + i19];
                                if (i9 == 0) {
                                    constraintWidget6.connect(constraintWidget6.mLeft, this.mLeft, this.mPaddingLeft);
                                }
                                if (i19 == 0) {
                                    int i20 = Flow.this.mHorizontalStyle;
                                    float f7 = Flow.this.mHorizontalBias;
                                    if (this.mStartIndex == 0 && Flow.this.mFirstHorizontalStyle != -1) {
                                        i20 = Flow.this.mFirstHorizontalStyle;
                                        f7 = Flow.this.mFirstHorizontalBias;
                                    } else if (z8 && Flow.this.mLastHorizontalStyle != -1) {
                                        i20 = Flow.this.mLastHorizontalStyle;
                                        f7 = Flow.this.mLastHorizontalBias;
                                    }
                                    constraintWidget6.setHorizontalChainStyle(i20);
                                    constraintWidget6.setHorizontalBiasPercent(f7);
                                }
                                if (i9 == i10 - 1) {
                                    constraintWidget6.connect(constraintWidget6.mRight, this.mRight, this.mPaddingRight);
                                }
                                if (constraintWidget4 != null) {
                                    constraintWidget6.mLeft.connect(constraintWidget4.mRight, Flow.this.mHorizontalGap);
                                    if (i9 == i12) {
                                        constraintWidget6.mLeft.setGoneMargin(this.mPaddingLeft);
                                    }
                                    constraintWidget4.mRight.connect(constraintWidget6.mLeft, 0);
                                    if (i9 == i13 + 1) {
                                        constraintWidget4.mRight.setGoneMargin(this.mPaddingRight);
                                    }
                                }
                                if (constraintWidget6 != constraintWidget5) {
                                    c7 = 3;
                                    if (Flow.this.mVerticalAlign != 3 || !constraintWidget2.hasBaseline() || constraintWidget6 == constraintWidget2 || !constraintWidget6.hasBaseline()) {
                                        int i21 = Flow.this.mVerticalAlign;
                                        if (i21 != 0) {
                                            if (i21 != 1) {
                                                ConstraintAnchor constraintAnchor9 = constraintWidget6.mTop;
                                                if (z9) {
                                                    constraintAnchor9.connect(this.mTop, this.mPaddingTop);
                                                    constraintWidget6.mBottom.connect(this.mBottom, this.mPaddingBottom);
                                                } else {
                                                    constraintAnchor9.connect(constraintWidget5.mTop, 0);
                                                }
                                            }
                                            constraintAnchor8 = constraintWidget6.mBottom;
                                            constraintAnchor7 = constraintWidget5.mBottom;
                                        } else {
                                            constraintAnchor8 = constraintWidget6.mTop;
                                            constraintAnchor7 = constraintWidget5.mTop;
                                        }
                                    } else {
                                        constraintAnchor8 = constraintWidget6.mBaseline;
                                        constraintAnchor7 = constraintWidget2.mBaseline;
                                    }
                                    constraintAnchor8.connect(constraintAnchor7, 0);
                                } else {
                                    c7 = 3;
                                }
                                i9++;
                                constraintWidget4 = constraintWidget6;
                            } else {
                                return;
                            }
                        }
                        return;
                    }
                    constraintWidget2 = constraintWidget5;
                    i9 = 0;
                    while (i9 < i10) {
                    }
                    return;
                }
                ConstraintWidget constraintWidget7 = this.biggest;
                constraintWidget7.setHorizontalChainStyle(Flow.this.mHorizontalStyle);
                int i22 = this.mPaddingLeft;
                if (i7 > 0) {
                    i22 += Flow.this.mHorizontalGap;
                }
                if (z7) {
                    constraintWidget7.mRight.connect(this.mRight, i22);
                    if (z8) {
                        constraintWidget7.mLeft.connect(this.mLeft, this.mPaddingRight);
                    }
                    if (i7 > 0) {
                        constraintAnchor6 = this.mRight.mOwner.mLeft;
                        constraintAnchor5 = constraintWidget7.mRight;
                    }
                    i8 = 0;
                    while (i8 < i10 && this.mStartIndex + i8 < Flow.this.mDisplayedWidgetsCount) {
                        constraintWidget = Flow.this.mDisplayedWidgets[this.mStartIndex + i8];
                        if (i8 == 0) {
                            constraintWidget.connect(constraintWidget.mTop, this.mTop, this.mPaddingTop);
                            int i23 = Flow.this.mVerticalStyle;
                            float f8 = Flow.this.mVerticalBias;
                            if (this.mStartIndex == 0 && Flow.this.mFirstVerticalStyle != -1) {
                                i23 = Flow.this.mFirstVerticalStyle;
                                f8 = Flow.this.mFirstVerticalBias;
                            } else if (z8 && Flow.this.mLastVerticalStyle != -1) {
                                i23 = Flow.this.mLastVerticalStyle;
                                f8 = Flow.this.mLastVerticalBias;
                            }
                            constraintWidget.setVerticalChainStyle(i23);
                            constraintWidget.setVerticalBiasPercent(f8);
                        }
                        if (i8 == i10 - 1) {
                            constraintWidget.connect(constraintWidget.mBottom, this.mBottom, this.mPaddingBottom);
                        }
                        if (constraintWidget4 != null) {
                            constraintWidget.mTop.connect(constraintWidget4.mBottom, Flow.this.mVerticalGap);
                            if (i8 == i12) {
                                constraintWidget.mTop.setGoneMargin(this.mPaddingTop);
                            }
                            constraintWidget4.mBottom.connect(constraintWidget.mTop, 0);
                            if (i8 == i13 + 1) {
                                constraintWidget4.mBottom.setGoneMargin(this.mPaddingBottom);
                            }
                        }
                        if (constraintWidget != constraintWidget7) {
                            int i24 = Flow.this.mHorizontalAlign;
                            if (z7) {
                                if (i24 != 0) {
                                    if (i24 == 1) {
                                        constraintAnchor4 = constraintWidget.mLeft;
                                        constraintAnchor3 = constraintWidget7.mLeft;
                                        constraintAnchor4.connect(constraintAnchor3, 0);
                                    } else if (i24 == 2) {
                                        constraintWidget.mLeft.connect(constraintWidget7.mLeft, 0);
                                    }
                                }
                                constraintAnchor4 = constraintWidget.mRight;
                                constraintAnchor3 = constraintWidget7.mRight;
                                constraintAnchor4.connect(constraintAnchor3, 0);
                            } else {
                                if (i24 != 0) {
                                    if (i24 != 1) {
                                        if (i24 == 2) {
                                            ConstraintAnchor constraintAnchor10 = constraintWidget.mLeft;
                                            if (z9) {
                                                constraintAnchor10.connect(this.mLeft, this.mPaddingLeft);
                                                constraintWidget.mRight.connect(this.mRight, this.mPaddingRight);
                                            } else {
                                                constraintAnchor10.connect(constraintWidget7.mLeft, 0);
                                            }
                                        }
                                        i8++;
                                        constraintWidget4 = constraintWidget;
                                    }
                                    constraintAnchor2 = constraintWidget.mRight;
                                    constraintAnchor = constraintWidget7.mRight;
                                } else {
                                    constraintAnchor2 = constraintWidget.mLeft;
                                    constraintAnchor = constraintWidget7.mLeft;
                                }
                                constraintAnchor2.connect(constraintAnchor, 0);
                                i8++;
                                constraintWidget4 = constraintWidget;
                            }
                        }
                        i8++;
                        constraintWidget4 = constraintWidget;
                    }
                    return;
                }
                constraintWidget7.mLeft.connect(this.mLeft, i22);
                if (z8) {
                    constraintWidget7.mRight.connect(this.mRight, this.mPaddingRight);
                }
                if (i7 > 0) {
                    constraintAnchor6 = this.mLeft.mOwner.mRight;
                    constraintAnchor5 = constraintWidget7.mLeft;
                }
                i8 = 0;
                while (i8 < i10) {
                    constraintWidget = Flow.this.mDisplayedWidgets[this.mStartIndex + i8];
                    if (i8 == 0) {
                    }
                    if (i8 == i10 - 1) {
                    }
                    if (constraintWidget4 != null) {
                    }
                    if (constraintWidget != constraintWidget7) {
                    }
                    i8++;
                    constraintWidget4 = constraintWidget;
                }
                constraintAnchor6.connect(constraintAnchor5, 0);
                i8 = 0;
                while (i8 < i10) {
                }
            }
        }

        public int getHeight() {
            return this.mOrientation == 1 ? this.mHeight - Flow.this.mVerticalGap : this.mHeight;
        }

        public int getWidth() {
            return this.mOrientation == 0 ? this.mWidth - Flow.this.mHorizontalGap : this.mWidth;
        }

        public void measureMatchConstraints(int i7) {
            int i8;
            ConstraintWidget.DimensionBehaviour dimensionBehaviour;
            int i9;
            ConstraintWidget.DimensionBehaviour dimensionBehaviour2;
            Flow flow;
            int i10 = this.mNbMatchConstraintsWidgets;
            if (i10 != 0) {
                int i11 = this.mCount;
                int i12 = i7 / i10;
                int i13 = 0;
                while (i13 < i11 && this.mStartIndex + i13 < Flow.this.mDisplayedWidgetsCount) {
                    ConstraintWidget constraintWidget = Flow.this.mDisplayedWidgets[this.mStartIndex + i13];
                    if (this.mOrientation == 0) {
                        if (constraintWidget != null && constraintWidget.getHorizontalDimensionBehaviour() == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT && constraintWidget.mMatchConstraintDefaultWidth == 0) {
                            flow = Flow.this;
                            dimensionBehaviour2 = ConstraintWidget.DimensionBehaviour.FIXED;
                            dimensionBehaviour = constraintWidget.getVerticalDimensionBehaviour();
                            i8 = constraintWidget.getHeight();
                            i9 = i12;
                        }
                        i13++;
                    } else {
                        if (constraintWidget != null && constraintWidget.getVerticalDimensionBehaviour() == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT && constraintWidget.mMatchConstraintDefaultHeight == 0) {
                            flow = Flow.this;
                            dimensionBehaviour2 = constraintWidget.getHorizontalDimensionBehaviour();
                            i9 = constraintWidget.getWidth();
                            dimensionBehaviour = ConstraintWidget.DimensionBehaviour.FIXED;
                            i8 = i12;
                        }
                        i13++;
                    }
                    flow.measure(constraintWidget, dimensionBehaviour2, i9, dimensionBehaviour, i8);
                    i13++;
                }
                recomputeDimensions();
            }
        }

        public void setStartIndex(int i7) {
            this.mStartIndex = i7;
        }

        public void setup(int i7, ConstraintAnchor constraintAnchor, ConstraintAnchor constraintAnchor2, ConstraintAnchor constraintAnchor3, ConstraintAnchor constraintAnchor4, int i8, int i9, int i10, int i11, int i12) {
            this.mOrientation = i7;
            this.mLeft = constraintAnchor;
            this.mTop = constraintAnchor2;
            this.mRight = constraintAnchor3;
            this.mBottom = constraintAnchor4;
            this.mPaddingLeft = i8;
            this.mPaddingTop = i9;
            this.mPaddingRight = i10;
            this.mPaddingBottom = i11;
            this.mMax = i12;
        }
    }

    private void createAlignedConstraints(boolean z7) {
        ConstraintWidget constraintWidget;
        if (!(this.mAlignedDimensions == null || this.mAlignedBiggestElementsInCols == null || this.mAlignedBiggestElementsInRows == null)) {
            for (int i7 = 0; i7 < this.mDisplayedWidgetsCount; i7++) {
                this.mDisplayedWidgets[i7].resetAnchors();
            }
            int[] iArr = this.mAlignedDimensions;
            int i8 = iArr[0];
            int i9 = iArr[1];
            ConstraintWidget constraintWidget2 = null;
            for (int i10 = 0; i10 < i8; i10++) {
                ConstraintWidget constraintWidget3 = this.mAlignedBiggestElementsInCols[z7 ? (i8 - i10) - 1 : i10];
                if (!(constraintWidget3 == null || constraintWidget3.getVisibility() == 8)) {
                    if (i10 == 0) {
                        constraintWidget3.connect(constraintWidget3.mLeft, this.mLeft, getPaddingLeft());
                        constraintWidget3.setHorizontalChainStyle(this.mHorizontalStyle);
                        constraintWidget3.setHorizontalBiasPercent(this.mHorizontalBias);
                    }
                    if (i10 == i8 - 1) {
                        constraintWidget3.connect(constraintWidget3.mRight, this.mRight, getPaddingRight());
                    }
                    if (i10 > 0) {
                        constraintWidget3.connect(constraintWidget3.mLeft, constraintWidget2.mRight, this.mHorizontalGap);
                        constraintWidget2.connect(constraintWidget2.mRight, constraintWidget3.mLeft, 0);
                    }
                    constraintWidget2 = constraintWidget3;
                }
            }
            for (int i11 = 0; i11 < i9; i11++) {
                ConstraintWidget constraintWidget4 = this.mAlignedBiggestElementsInRows[i11];
                if (!(constraintWidget4 == null || constraintWidget4.getVisibility() == 8)) {
                    if (i11 == 0) {
                        constraintWidget4.connect(constraintWidget4.mTop, this.mTop, getPaddingTop());
                        constraintWidget4.setVerticalChainStyle(this.mVerticalStyle);
                        constraintWidget4.setVerticalBiasPercent(this.mVerticalBias);
                    }
                    if (i11 == i9 - 1) {
                        constraintWidget4.connect(constraintWidget4.mBottom, this.mBottom, getPaddingBottom());
                    }
                    if (i11 > 0) {
                        constraintWidget4.connect(constraintWidget4.mTop, constraintWidget2.mBottom, this.mVerticalGap);
                        constraintWidget2.connect(constraintWidget2.mBottom, constraintWidget4.mTop, 0);
                    }
                    constraintWidget2 = constraintWidget4;
                }
            }
            for (int i12 = 0; i12 < i8; i12++) {
                for (int i13 = 0; i13 < i9; i13++) {
                    int i14 = (i13 * i8) + i12;
                    if (this.mOrientation == 1) {
                        i14 = (i12 * i9) + i13;
                    }
                    ConstraintWidget[] constraintWidgetArr = this.mDisplayedWidgets;
                    if (!(i14 >= constraintWidgetArr.length || (constraintWidget = constraintWidgetArr[i14]) == null || constraintWidget.getVisibility() == 8)) {
                        ConstraintWidget constraintWidget5 = this.mAlignedBiggestElementsInCols[i12];
                        ConstraintWidget constraintWidget6 = this.mAlignedBiggestElementsInRows[i13];
                        if (constraintWidget != constraintWidget5) {
                            constraintWidget.connect(constraintWidget.mLeft, constraintWidget5.mLeft, 0);
                            constraintWidget.connect(constraintWidget.mRight, constraintWidget5.mRight, 0);
                        }
                        if (constraintWidget != constraintWidget6) {
                            constraintWidget.connect(constraintWidget.mTop, constraintWidget6.mTop, 0);
                            constraintWidget.connect(constraintWidget.mBottom, constraintWidget6.mBottom, 0);
                        }
                    }
                }
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private final int getWidgetHeight(ConstraintWidget constraintWidget, int i7) {
        if (constraintWidget == null) {
            return 0;
        }
        if (constraintWidget.getVerticalDimensionBehaviour() == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT) {
            int i8 = constraintWidget.mMatchConstraintDefaultHeight;
            if (i8 == 0) {
                return 0;
            }
            if (i8 == 2) {
                int i9 = (int) (constraintWidget.mMatchConstraintPercentHeight * ((float) i7));
                if (i9 != constraintWidget.getHeight()) {
                    constraintWidget.setMeasureRequested(true);
                    measure(constraintWidget, constraintWidget.getHorizontalDimensionBehaviour(), constraintWidget.getWidth(), ConstraintWidget.DimensionBehaviour.FIXED, i9);
                }
                return i9;
            } else if (i8 == 1) {
                return constraintWidget.getHeight();
            } else {
                if (i8 == 3) {
                    return (int) ((((float) constraintWidget.getWidth()) * constraintWidget.mDimensionRatio) + 0.5f);
                }
            }
        }
        return constraintWidget.getHeight();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private final int getWidgetWidth(ConstraintWidget constraintWidget, int i7) {
        if (constraintWidget == null) {
            return 0;
        }
        if (constraintWidget.getHorizontalDimensionBehaviour() == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT) {
            int i8 = constraintWidget.mMatchConstraintDefaultWidth;
            if (i8 == 0) {
                return 0;
            }
            if (i8 == 2) {
                int i9 = (int) (constraintWidget.mMatchConstraintPercentWidth * ((float) i7));
                if (i9 != constraintWidget.getWidth()) {
                    constraintWidget.setMeasureRequested(true);
                    measure(constraintWidget, ConstraintWidget.DimensionBehaviour.FIXED, i9, constraintWidget.getVerticalDimensionBehaviour(), constraintWidget.getHeight());
                }
                return i9;
            } else if (i8 == 1) {
                return constraintWidget.getWidth();
            } else {
                if (i8 == 3) {
                    return (int) ((((float) constraintWidget.getHeight()) * constraintWidget.mDimensionRatio) + 0.5f);
                }
            }
        }
        return constraintWidget.getWidth();
    }

    /*  JADX ERROR: JadxOverflowException in pass: RegionMakerVisitor
        jadx.core.utils.exceptions.JadxOverflowException: Regions count limit reached
        	at jadx.core.utils.ErrorsCounter.addError(ErrorsCounter.java:57)
        	at jadx.core.utils.ErrorsCounter.error(ErrorsCounter.java:31)
        	at jadx.core.dex.attributes.nodes.NotificationAttrNode.addError(NotificationAttrNode.java:15)
        */
    /* JADX WARNING: Removed duplicated region for block: B:114:0x011b A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:37:0x005c  */
    private void measureAligned(androidx.constraintlayout.solver.widgets.ConstraintWidget[] r11, int r12, int r13, int r14, int[] r15) {
        /*
        // Method dump skipped, instructions count: 290
        */
        throw new UnsupportedOperationException("Method not decompiled: androidx.constraintlayout.solver.widgets.Flow.measureAligned(androidx.constraintlayout.solver.widgets.ConstraintWidget[], int, int, int, int[]):void");
    }

    private void measureChainWrap(ConstraintWidget[] constraintWidgetArr, int i7, int i8, int i9, int[] iArr) {
        ConstraintAnchor constraintAnchor;
        int i10;
        int i11;
        int i12;
        ConstraintAnchor constraintAnchor2;
        int i13;
        int i14;
        if (i7 != 0) {
            this.mChainList.clear();
            WidgetsList widgetsList = new WidgetsList(i8, this.mLeft, this.mTop, this.mRight, this.mBottom, i9);
            this.mChainList.add(widgetsList);
            int i15 = 0;
            int i16 = 0;
            int i17 = 0;
            if (i8 == 0) {
                while (i17 < i7) {
                    ConstraintWidget constraintWidget = constraintWidgetArr[i17];
                    int widgetWidth = getWidgetWidth(constraintWidget, i9);
                    if (constraintWidget.getHorizontalDimensionBehaviour() == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT) {
                        i15++;
                    }
                    boolean z7 = (i16 == i9 || (this.mHorizontalGap + i16) + widgetWidth > i9) && widgetsList.biggest != null;
                    if (!z7 && i17 > 0 && (i14 = this.mMaxElementsWrap) > 0 && i17 % i14 == 0) {
                        z7 = true;
                    }
                    if (z7) {
                        widgetsList = new WidgetsList(i8, this.mLeft, this.mTop, this.mRight, this.mBottom, i9);
                        widgetsList.setStartIndex(i17);
                        this.mChainList.add(widgetsList);
                    } else if (i17 > 0) {
                        i16 += this.mHorizontalGap + widgetWidth;
                        widgetsList.add(constraintWidget);
                        i17++;
                        i15 = i15;
                    }
                    i16 = widgetWidth;
                    widgetsList.add(constraintWidget);
                    i17++;
                    i15 = i15;
                }
            } else {
                while (i17 < i7) {
                    ConstraintWidget constraintWidget2 = constraintWidgetArr[i17];
                    int widgetHeight = getWidgetHeight(constraintWidget2, i9);
                    if (constraintWidget2.getVerticalDimensionBehaviour() == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT) {
                        i15++;
                    }
                    boolean z8 = (i16 == i9 || (this.mVerticalGap + i16) + widgetHeight > i9) && widgetsList.biggest != null;
                    if (!z8 && i17 > 0 && (i13 = this.mMaxElementsWrap) > 0 && i17 % i13 == 0) {
                        z8 = true;
                    }
                    if (z8) {
                        widgetsList = new WidgetsList(i8, this.mLeft, this.mTop, this.mRight, this.mBottom, i9);
                        widgetsList.setStartIndex(i17);
                        this.mChainList.add(widgetsList);
                    } else if (i17 > 0) {
                        i16 += this.mVerticalGap + widgetHeight;
                        widgetsList.add(constraintWidget2);
                        i17++;
                        i15 = i15;
                    }
                    i16 = widgetHeight;
                    widgetsList.add(constraintWidget2);
                    i17++;
                    i15 = i15;
                }
            }
            int size = this.mChainList.size();
            ConstraintAnchor constraintAnchor3 = this.mLeft;
            ConstraintAnchor constraintAnchor4 = this.mTop;
            ConstraintAnchor constraintAnchor5 = this.mRight;
            ConstraintAnchor constraintAnchor6 = this.mBottom;
            int paddingLeft = getPaddingLeft();
            int paddingTop = getPaddingTop();
            int paddingRight = getPaddingRight();
            int paddingBottom = getPaddingBottom();
            ConstraintWidget.DimensionBehaviour horizontalDimensionBehaviour = getHorizontalDimensionBehaviour();
            ConstraintWidget.DimensionBehaviour dimensionBehaviour = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
            boolean z9 = horizontalDimensionBehaviour == dimensionBehaviour || getVerticalDimensionBehaviour() == dimensionBehaviour;
            if (i15 > 0 && z9) {
                for (int i18 = 0; i18 < size; i18++) {
                    WidgetsList widgetsList2 = this.mChainList.get(i18);
                    widgetsList2.measureMatchConstraints(i9 - (i8 == 0 ? widgetsList2.getWidth() : widgetsList2.getHeight()));
                }
            }
            int i19 = paddingTop;
            int i20 = paddingRight;
            int i21 = 0;
            int i22 = 0;
            int i23 = 0;
            int i24 = paddingLeft;
            ConstraintAnchor constraintAnchor7 = constraintAnchor4;
            ConstraintAnchor constraintAnchor8 = constraintAnchor3;
            int i25 = paddingBottom;
            while (i23 < size) {
                WidgetsList widgetsList3 = this.mChainList.get(i23);
                if (i8 == 0) {
                    if (i23 < size - 1) {
                        constraintAnchor2 = this.mChainList.get(i23 + 1).biggest.mTop;
                        i12 = 0;
                    } else {
                        constraintAnchor2 = this.mBottom;
                        i12 = getPaddingBottom();
                    }
                    ConstraintAnchor constraintAnchor9 = widgetsList3.biggest.mBottom;
                    i10 = i23;
                    widgetsList3.setup(i8, constraintAnchor8, constraintAnchor7, constraintAnchor5, constraintAnchor2, i24, i19, i20, i12, i9);
                    int max = Math.max(i22, widgetsList3.getWidth());
                    i21 += widgetsList3.getHeight();
                    if (i10 > 0) {
                        i21 += this.mVerticalGap;
                    }
                    constraintAnchor8 = constraintAnchor8;
                    i22 = max;
                    i19 = 0;
                    constraintAnchor7 = constraintAnchor9;
                    constraintAnchor = constraintAnchor5;
                    constraintAnchor6 = constraintAnchor2;
                    i25 = i12;
                } else {
                    i10 = i23;
                    if (i10 < size - 1) {
                        constraintAnchor = this.mChainList.get(i10 + 1).biggest.mLeft;
                        i11 = 0;
                    } else {
                        constraintAnchor = this.mRight;
                        i11 = getPaddingRight();
                    }
                    ConstraintAnchor constraintAnchor10 = widgetsList3.biggest.mRight;
                    widgetsList3.setup(i8, constraintAnchor8, constraintAnchor7, constraintAnchor, constraintAnchor6, i24, i19, i11, i25, i9);
                    i22 += widgetsList3.getWidth();
                    int max2 = Math.max(i21, widgetsList3.getHeight());
                    if (i10 > 0) {
                        i22 += this.mHorizontalGap;
                    }
                    i21 = max2;
                    i24 = 0;
                    i20 = i11;
                    constraintAnchor8 = constraintAnchor10;
                }
                i23 = i10 + 1;
                constraintAnchor5 = constraintAnchor;
            }
            iArr[0] = i22;
            iArr[1] = i21;
        }
    }

    private void measureNoWrap(ConstraintWidget[] constraintWidgetArr, int i7, int i8, int i9, int[] iArr) {
        WidgetsList widgetsList;
        if (i7 != 0) {
            if (this.mChainList.size() == 0) {
                widgetsList = new WidgetsList(i8, this.mLeft, this.mTop, this.mRight, this.mBottom, i9);
                this.mChainList.add(widgetsList);
            } else {
                WidgetsList widgetsList2 = this.mChainList.get(0);
                widgetsList2.clear();
                widgetsList = widgetsList2;
                widgetsList.setup(i8, this.mLeft, this.mTop, this.mRight, this.mBottom, getPaddingLeft(), getPaddingTop(), getPaddingRight(), getPaddingBottom(), i9);
            }
            for (int i10 = 0; i10 < i7; i10++) {
                widgetsList.add(constraintWidgetArr[i10]);
            }
            iArr[0] = widgetsList.getWidth();
            iArr[1] = widgetsList.getHeight();
        }
    }

    @Override // androidx.constraintlayout.solver.widgets.ConstraintWidget
    public void addToSolver(LinearSystem linearSystem, boolean z7) {
        super.addToSolver(linearSystem, z7);
        boolean isRtl = getParent() != null ? ((ConstraintWidgetContainer) getParent()).isRtl() : false;
        int i7 = this.mWrapMode;
        if (i7 != 0) {
            if (i7 == 1) {
                int size = this.mChainList.size();
                int i8 = 0;
                while (i8 < size) {
                    this.mChainList.get(i8).createConstraints(isRtl, i8, i8 == size + -1);
                    i8++;
                }
            } else if (i7 == 2) {
                createAlignedConstraints(isRtl);
            }
        } else if (this.mChainList.size() > 0) {
            this.mChainList.get(0).createConstraints(isRtl, 0, true);
        }
        needsCallbackFromSolver(false);
    }

    @Override // androidx.constraintlayout.solver.widgets.ConstraintWidget, androidx.constraintlayout.solver.widgets.HelperWidget
    public void copy(ConstraintWidget constraintWidget, HashMap<ConstraintWidget, ConstraintWidget> hashMap) {
        super.copy(constraintWidget, hashMap);
        Flow flow = (Flow) constraintWidget;
        this.mHorizontalStyle = flow.mHorizontalStyle;
        this.mVerticalStyle = flow.mVerticalStyle;
        this.mFirstHorizontalStyle = flow.mFirstHorizontalStyle;
        this.mFirstVerticalStyle = flow.mFirstVerticalStyle;
        this.mLastHorizontalStyle = flow.mLastHorizontalStyle;
        this.mLastVerticalStyle = flow.mLastVerticalStyle;
        this.mHorizontalBias = flow.mHorizontalBias;
        this.mVerticalBias = flow.mVerticalBias;
        this.mFirstHorizontalBias = flow.mFirstHorizontalBias;
        this.mFirstVerticalBias = flow.mFirstVerticalBias;
        this.mLastHorizontalBias = flow.mLastHorizontalBias;
        this.mLastVerticalBias = flow.mLastVerticalBias;
        this.mHorizontalGap = flow.mHorizontalGap;
        this.mVerticalGap = flow.mVerticalGap;
        this.mHorizontalAlign = flow.mHorizontalAlign;
        this.mVerticalAlign = flow.mVerticalAlign;
        this.mWrapMode = flow.mWrapMode;
        this.mMaxElementsWrap = flow.mMaxElementsWrap;
        this.mOrientation = flow.mOrientation;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:15:0x0047, code lost:
        if (r18.mVerticalStyle == -1) goto L_0x0054;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:20:0x0052, code lost:
        if (r18.mVerticalStyle == -1) goto L_0x0054;
     */
    @Override // androidx.constraintlayout.solver.widgets.VirtualLayout
    public void measure(int i7, int i8, int i9, int i10) {
        int i11;
        int i12;
        int[] iArr;
        boolean z7;
        if (this.mWidgetsCount <= 0 || measureChildren()) {
            int paddingLeft = getPaddingLeft();
            int paddingRight = getPaddingRight();
            int paddingTop = getPaddingTop();
            int paddingBottom = getPaddingBottom();
            int[] iArr2 = new int[2];
            int i13 = (i8 - paddingLeft) - paddingRight;
            int i14 = this.mOrientation;
            if (i14 == 1) {
                i13 = (i10 - paddingTop) - paddingBottom;
            }
            if (i14 == 0) {
                if (this.mHorizontalStyle == -1) {
                    this.mHorizontalStyle = 0;
                }
            } else if (this.mHorizontalStyle == -1) {
                this.mHorizontalStyle = 0;
            }
            this.mVerticalStyle = 0;
            ConstraintWidget[] constraintWidgetArr = this.mWidgets;
            int i15 = 0;
            int i16 = 0;
            while (true) {
                i11 = this.mWidgetsCount;
                if (i15 >= i11) {
                    break;
                }
                if (this.mWidgets[i15].getVisibility() == 8) {
                    i16++;
                }
                i15++;
            }
            if (i16 > 0) {
                constraintWidgetArr = new ConstraintWidget[(i11 - i16)];
                int i17 = 0;
                for (int i18 = 0; i18 < this.mWidgetsCount; i18++) {
                    ConstraintWidget constraintWidget = this.mWidgets[i18];
                    if (constraintWidget.getVisibility() != 8) {
                        constraintWidgetArr[i17] = constraintWidget;
                        i17++;
                    }
                }
                i12 = i17;
            } else {
                i12 = i11;
            }
            this.mDisplayedWidgets = constraintWidgetArr;
            this.mDisplayedWidgetsCount = i12;
            int i19 = this.mWrapMode;
            if (i19 == 0) {
                iArr = iArr2;
                z7 = true;
                measureNoWrap(constraintWidgetArr, i12, this.mOrientation, i13, iArr2);
            } else if (i19 == 1) {
                z7 = true;
                iArr = iArr2;
                measureChainWrap(constraintWidgetArr, i12, this.mOrientation, i13, iArr2);
            } else if (i19 != 2) {
                z7 = true;
                iArr = iArr2;
            } else {
                z7 = true;
                iArr = iArr2;
                measureAligned(constraintWidgetArr, i12, this.mOrientation, i13, iArr2);
            }
            int i20 = iArr[0] + paddingLeft + paddingRight;
            char c7 = z7 ? 1 : 0;
            char c8 = z7 ? 1 : 0;
            char c9 = z7 ? 1 : 0;
            char c10 = z7 ? 1 : 0;
            char c11 = z7 ? 1 : 0;
            char c12 = z7 ? 1 : 0;
            int i21 = iArr[c7] + paddingTop + paddingBottom;
            if (i7 == 1073741824) {
                i20 = i8;
            } else if (i7 == Integer.MIN_VALUE) {
                i20 = Math.min(i20, i8);
            } else if (i7 != 0) {
                i20 = 0;
            }
            if (i9 == 1073741824) {
                i21 = i10;
            } else if (i9 == Integer.MIN_VALUE) {
                i21 = Math.min(i21, i10);
            } else if (i9 != 0) {
                i21 = 0;
            }
            setMeasure(i20, i21);
            setWidth(i20);
            setHeight(i21);
            if (this.mWidgetsCount <= 0) {
                z7 = false;
            }
            needsCallbackFromSolver(z7);
            return;
        }
        setMeasure(0, 0);
        needsCallbackFromSolver(false);
    }

    public void setFirstHorizontalBias(float f7) {
        this.mFirstHorizontalBias = f7;
    }

    public void setFirstHorizontalStyle(int i7) {
        this.mFirstHorizontalStyle = i7;
    }

    public void setFirstVerticalBias(float f7) {
        this.mFirstVerticalBias = f7;
    }

    public void setFirstVerticalStyle(int i7) {
        this.mFirstVerticalStyle = i7;
    }

    public void setHorizontalAlign(int i7) {
        this.mHorizontalAlign = i7;
    }

    public void setHorizontalBias(float f7) {
        this.mHorizontalBias = f7;
    }

    public void setHorizontalGap(int i7) {
        this.mHorizontalGap = i7;
    }

    public void setHorizontalStyle(int i7) {
        this.mHorizontalStyle = i7;
    }

    public void setLastHorizontalBias(float f7) {
        this.mLastHorizontalBias = f7;
    }

    public void setLastHorizontalStyle(int i7) {
        this.mLastHorizontalStyle = i7;
    }

    public void setLastVerticalBias(float f7) {
        this.mLastVerticalBias = f7;
    }

    public void setLastVerticalStyle(int i7) {
        this.mLastVerticalStyle = i7;
    }

    public void setMaxElementsWrap(int i7) {
        this.mMaxElementsWrap = i7;
    }

    public void setOrientation(int i7) {
        this.mOrientation = i7;
    }

    public void setVerticalAlign(int i7) {
        this.mVerticalAlign = i7;
    }

    public void setVerticalBias(float f7) {
        this.mVerticalBias = f7;
    }

    public void setVerticalGap(int i7) {
        this.mVerticalGap = i7;
    }

    public void setVerticalStyle(int i7) {
        this.mVerticalStyle = i7;
    }

    public void setWrapMode(int i7) {
        this.mWrapMode = i7;
    }
}
