package androidx.constraintlayout.solver.widgets.analyzer;

import androidx.constraintlayout.solver.widgets.Barrier;
import androidx.constraintlayout.solver.widgets.ConstraintAnchor;
import androidx.constraintlayout.solver.widgets.ConstraintWidget;
import androidx.constraintlayout.solver.widgets.ConstraintWidgetContainer;
import androidx.constraintlayout.solver.widgets.Guideline;
import androidx.constraintlayout.solver.widgets.HelperWidget;
import androidx.constraintlayout.solver.widgets.analyzer.BasicMeasure;
import java.io.PrintStream;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.Iterator;

public class DependencyGraph {
    private static final boolean USE_GROUPS = true;
    private ConstraintWidgetContainer container;
    private ConstraintWidgetContainer mContainer;
    ArrayList<RunGroup> mGroups = new ArrayList<>();
    private BasicMeasure.Measure mMeasure = new BasicMeasure.Measure();
    private BasicMeasure.Measurer mMeasurer = null;
    private boolean mNeedBuildGraph = true;
    private boolean mNeedRedoMeasures = true;
    private ArrayList<WidgetRun> mRuns = new ArrayList<>();
    private ArrayList<RunGroup> runGroups = new ArrayList<>();

    public DependencyGraph(ConstraintWidgetContainer constraintWidgetContainer) {
        this.container = constraintWidgetContainer;
        this.mContainer = constraintWidgetContainer;
    }

    private void applyGroup(DependencyNode dependencyNode, int i7, int i8, DependencyNode dependencyNode2, ArrayList<RunGroup> arrayList, RunGroup runGroup) {
        WidgetRun widgetRun = dependencyNode.run;
        if (widgetRun.runGroup == null) {
            ConstraintWidgetContainer constraintWidgetContainer = this.container;
            if (!(widgetRun == constraintWidgetContainer.horizontalRun || widgetRun == constraintWidgetContainer.verticalRun)) {
                if (runGroup == null) {
                    runGroup = new RunGroup(widgetRun, i8);
                    arrayList.add(runGroup);
                }
                widgetRun.runGroup = runGroup;
                runGroup.add(widgetRun);
                for (Dependency dependency : widgetRun.start.dependencies) {
                    if (dependency instanceof DependencyNode) {
                        applyGroup((DependencyNode) dependency, i7, 0, dependencyNode2, arrayList, runGroup);
                    }
                }
                for (Dependency dependency2 : widgetRun.end.dependencies) {
                    if (dependency2 instanceof DependencyNode) {
                        applyGroup((DependencyNode) dependency2, i7, 1, dependencyNode2, arrayList, runGroup);
                    }
                }
                if (i7 == 1 && (widgetRun instanceof VerticalWidgetRun)) {
                    for (Dependency dependency3 : ((VerticalWidgetRun) widgetRun).baseline.dependencies) {
                        if (dependency3 instanceof DependencyNode) {
                            applyGroup((DependencyNode) dependency3, i7, 2, dependencyNode2, arrayList, runGroup);
                        }
                    }
                }
                for (DependencyNode dependencyNode3 : widgetRun.start.targets) {
                    if (dependencyNode3 == dependencyNode2) {
                        runGroup.dual = true;
                    }
                    applyGroup(dependencyNode3, i7, 0, dependencyNode2, arrayList, runGroup);
                }
                for (DependencyNode dependencyNode4 : widgetRun.end.targets) {
                    if (dependencyNode4 == dependencyNode2) {
                        runGroup.dual = true;
                    }
                    applyGroup(dependencyNode4, i7, 1, dependencyNode2, arrayList, runGroup);
                }
                if (i7 == 1 && (widgetRun instanceof VerticalWidgetRun)) {
                    for (DependencyNode dependencyNode5 : ((VerticalWidgetRun) widgetRun).baseline.targets) {
                        applyGroup(dependencyNode5, i7, 2, dependencyNode2, arrayList, runGroup);
                    }
                }
            }
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:37:0x0074, code lost:
        if (r2.mMatchConstraintDefaultHeight == 0) goto L_0x0065;
     */
    private boolean basicMeasureWidgets(ConstraintWidgetContainer constraintWidgetContainer) {
        int i7;
        ConstraintWidget.DimensionBehaviour dimensionBehaviour;
        int i8;
        ConstraintWidget.DimensionBehaviour dimensionBehaviour2;
        ConstraintWidget constraintWidget;
        DependencyGraph dependencyGraph;
        DimensionDependency dimensionDependency;
        int height;
        ConstraintWidget.DimensionBehaviour dimensionBehaviour3;
        ConstraintWidget.DimensionBehaviour dimensionBehaviour4;
        ConstraintWidget.DimensionBehaviour dimensionBehaviour5;
        Iterator<ConstraintWidget> it = constraintWidgetContainer.mChildren.iterator();
        while (it.hasNext()) {
            ConstraintWidget next = it.next();
            ConstraintWidget.DimensionBehaviour[] dimensionBehaviourArr = next.mListDimensionBehaviors;
            ConstraintWidget.DimensionBehaviour dimensionBehaviour6 = dimensionBehaviourArr[0];
            ConstraintWidget.DimensionBehaviour dimensionBehaviour7 = dimensionBehaviourArr[1];
            if (next.getVisibility() != 8) {
                if (next.mMatchConstraintPercentWidth < 1.0f && dimensionBehaviour6 == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT) {
                    next.mMatchConstraintDefaultWidth = 2;
                }
                if (next.mMatchConstraintPercentHeight < 1.0f && dimensionBehaviour7 == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT) {
                    next.mMatchConstraintDefaultHeight = 2;
                }
                if (next.getDimensionRatio() > 0.0f) {
                    ConstraintWidget.DimensionBehaviour dimensionBehaviour8 = ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT;
                    if (dimensionBehaviour6 == dimensionBehaviour8 && (dimensionBehaviour7 == ConstraintWidget.DimensionBehaviour.WRAP_CONTENT || dimensionBehaviour7 == ConstraintWidget.DimensionBehaviour.FIXED)) {
                        next.mMatchConstraintDefaultWidth = 3;
                    } else {
                        if (!(dimensionBehaviour7 == dimensionBehaviour8 && (dimensionBehaviour6 == ConstraintWidget.DimensionBehaviour.WRAP_CONTENT || dimensionBehaviour6 == ConstraintWidget.DimensionBehaviour.FIXED))) {
                            if (dimensionBehaviour6 == dimensionBehaviour8 && dimensionBehaviour7 == dimensionBehaviour8) {
                                if (next.mMatchConstraintDefaultWidth == 0) {
                                    next.mMatchConstraintDefaultWidth = 3;
                                }
                            }
                        }
                        next.mMatchConstraintDefaultHeight = 3;
                    }
                }
                ConstraintWidget.DimensionBehaviour dimensionBehaviour9 = ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT;
                if (dimensionBehaviour6 == dimensionBehaviour9 && next.mMatchConstraintDefaultWidth == 1 && (next.mLeft.mTarget == null || next.mRight.mTarget == null)) {
                    dimensionBehaviour6 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
                }
                if (dimensionBehaviour7 == dimensionBehaviour9 && next.mMatchConstraintDefaultHeight == 1 && (next.mTop.mTarget == null || next.mBottom.mTarget == null)) {
                    dimensionBehaviour7 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
                }
                HorizontalWidgetRun horizontalWidgetRun = next.horizontalRun;
                horizontalWidgetRun.dimensionBehavior = dimensionBehaviour6;
                int i9 = next.mMatchConstraintDefaultWidth;
                horizontalWidgetRun.matchConstraintsType = i9;
                VerticalWidgetRun verticalWidgetRun = next.verticalRun;
                verticalWidgetRun.dimensionBehavior = dimensionBehaviour7;
                int i10 = next.mMatchConstraintDefaultHeight;
                verticalWidgetRun.matchConstraintsType = i10;
                ConstraintWidget.DimensionBehaviour dimensionBehaviour10 = ConstraintWidget.DimensionBehaviour.MATCH_PARENT;
                if ((dimensionBehaviour6 == dimensionBehaviour10 || dimensionBehaviour6 == ConstraintWidget.DimensionBehaviour.FIXED || dimensionBehaviour6 == ConstraintWidget.DimensionBehaviour.WRAP_CONTENT) && (dimensionBehaviour7 == dimensionBehaviour10 || dimensionBehaviour7 == ConstraintWidget.DimensionBehaviour.FIXED || dimensionBehaviour7 == ConstraintWidget.DimensionBehaviour.WRAP_CONTENT)) {
                    int width = next.getWidth();
                    if (dimensionBehaviour6 == dimensionBehaviour10) {
                        i8 = (constraintWidgetContainer.getWidth() - next.mLeft.mMargin) - next.mRight.mMargin;
                        dimensionBehaviour2 = ConstraintWidget.DimensionBehaviour.FIXED;
                    } else {
                        i8 = width;
                        dimensionBehaviour2 = dimensionBehaviour6;
                    }
                    int height2 = next.getHeight();
                    if (dimensionBehaviour7 == dimensionBehaviour10) {
                        i7 = (constraintWidgetContainer.getHeight() - next.mTop.mMargin) - next.mBottom.mMargin;
                        dimensionBehaviour = ConstraintWidget.DimensionBehaviour.FIXED;
                    } else {
                        i7 = height2;
                        dimensionBehaviour = dimensionBehaviour7;
                    }
                    dependencyGraph = this;
                    constraintWidget = next;
                } else {
                    if (dimensionBehaviour6 == dimensionBehaviour9 && (dimensionBehaviour7 == (dimensionBehaviour5 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT) || dimensionBehaviour7 == ConstraintWidget.DimensionBehaviour.FIXED)) {
                        if (i9 == 3) {
                            if (dimensionBehaviour7 == dimensionBehaviour5) {
                                measure(next, dimensionBehaviour5, 0, dimensionBehaviour5, 0);
                            }
                            i7 = next.getHeight();
                            i8 = (int) ((((float) i7) * next.mDimensionRatio) + 0.5f);
                            dimensionBehaviour = ConstraintWidget.DimensionBehaviour.FIXED;
                            dependencyGraph = this;
                            constraintWidget = next;
                            dimensionBehaviour2 = dimensionBehaviour;
                        } else if (i9 == 1) {
                            measure(next, dimensionBehaviour5, 0, dimensionBehaviour7, 0);
                            dimensionDependency = next.horizontalRun.dimension;
                            height = next.getWidth();
                            dimensionDependency.wrapValue = height;
                        } else {
                            if (i9 == 2) {
                                ConstraintWidget.DimensionBehaviour dimensionBehaviour11 = constraintWidgetContainer.mListDimensionBehaviors[0];
                                dimensionBehaviour5 = ConstraintWidget.DimensionBehaviour.FIXED;
                                if (dimensionBehaviour11 == dimensionBehaviour5 || dimensionBehaviour11 == dimensionBehaviour10) {
                                    i8 = (int) ((next.mMatchConstraintPercentWidth * ((float) constraintWidgetContainer.getWidth())) + 0.5f);
                                    i7 = next.getHeight();
                                }
                            } else {
                                ConstraintAnchor[] constraintAnchorArr = next.mListAnchors;
                                if (constraintAnchorArr[0].mTarget == null || constraintAnchorArr[1].mTarget == null) {
                                    i8 = 0;
                                    i7 = 0;
                                }
                            }
                            dependencyGraph = this;
                            constraintWidget = next;
                            dimensionBehaviour2 = dimensionBehaviour5;
                            dimensionBehaviour = dimensionBehaviour7;
                        }
                    }
                    if (dimensionBehaviour7 == dimensionBehaviour9 && (dimensionBehaviour6 == (dimensionBehaviour4 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT) || dimensionBehaviour6 == ConstraintWidget.DimensionBehaviour.FIXED)) {
                        if (i10 == 3) {
                            if (dimensionBehaviour6 == dimensionBehaviour4) {
                                measure(next, dimensionBehaviour4, 0, dimensionBehaviour4, 0);
                            }
                            i8 = next.getWidth();
                            float f7 = next.mDimensionRatio;
                            if (next.getDimensionRatioSide() == -1) {
                                f7 = 1.0f / f7;
                            }
                            i7 = (int) ((((float) i8) * f7) + 0.5f);
                            dimensionBehaviour = ConstraintWidget.DimensionBehaviour.FIXED;
                            dependencyGraph = this;
                            constraintWidget = next;
                            dimensionBehaviour2 = dimensionBehaviour;
                        } else if (i10 == 1) {
                            measure(next, dimensionBehaviour6, 0, dimensionBehaviour4, 0);
                            dimensionDependency = next.verticalRun.dimension;
                            height = next.getHeight();
                            dimensionDependency.wrapValue = height;
                        } else if (i10 == 2) {
                            ConstraintWidget.DimensionBehaviour dimensionBehaviour12 = constraintWidgetContainer.mListDimensionBehaviors[1];
                            dimensionBehaviour = ConstraintWidget.DimensionBehaviour.FIXED;
                            if (dimensionBehaviour12 == dimensionBehaviour || dimensionBehaviour12 == dimensionBehaviour10) {
                                float f8 = next.mMatchConstraintPercentHeight;
                                i8 = next.getWidth();
                                dependencyGraph = this;
                                constraintWidget = next;
                                dimensionBehaviour2 = dimensionBehaviour6;
                                i7 = (int) ((f8 * ((float) constraintWidgetContainer.getHeight())) + 0.5f);
                            }
                        } else {
                            ConstraintAnchor[] constraintAnchorArr2 = next.mListAnchors;
                            if (constraintAnchorArr2[2].mTarget == null || constraintAnchorArr2[3].mTarget == null) {
                                i8 = 0;
                                i7 = 0;
                                dependencyGraph = this;
                                constraintWidget = next;
                                dimensionBehaviour2 = dimensionBehaviour4;
                                dimensionBehaviour = dimensionBehaviour7;
                            }
                        }
                    }
                    if (dimensionBehaviour6 == dimensionBehaviour9 && dimensionBehaviour7 == dimensionBehaviour9) {
                        if (i9 == 1 || i10 == 1) {
                            ConstraintWidget.DimensionBehaviour dimensionBehaviour13 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
                            measure(next, dimensionBehaviour13, 0, dimensionBehaviour13, 0);
                            next.horizontalRun.dimension.wrapValue = next.getWidth();
                            dimensionDependency = next.verticalRun.dimension;
                            height = next.getHeight();
                            dimensionDependency.wrapValue = height;
                        } else if (i10 == 2 && i9 == 2) {
                            ConstraintWidget.DimensionBehaviour[] dimensionBehaviourArr2 = constraintWidgetContainer.mListDimensionBehaviors;
                            ConstraintWidget.DimensionBehaviour dimensionBehaviour14 = dimensionBehaviourArr2[0];
                            dimensionBehaviour = ConstraintWidget.DimensionBehaviour.FIXED;
                            if ((dimensionBehaviour14 == dimensionBehaviour || dimensionBehaviour14 == dimensionBehaviour) && ((dimensionBehaviour3 = dimensionBehaviourArr2[1]) == dimensionBehaviour || dimensionBehaviour3 == dimensionBehaviour)) {
                                float f9 = next.mMatchConstraintPercentWidth;
                                float f10 = next.mMatchConstraintPercentHeight;
                                i8 = (int) ((f9 * ((float) constraintWidgetContainer.getWidth())) + 0.5f);
                                i7 = (int) ((f10 * ((float) constraintWidgetContainer.getHeight())) + 0.5f);
                                dependencyGraph = this;
                                constraintWidget = next;
                                dimensionBehaviour2 = dimensionBehaviour;
                            }
                        }
                    }
                }
                dependencyGraph.measure(constraintWidget, dimensionBehaviour2, i8, dimensionBehaviour, i7);
                next.horizontalRun.dimension.resolve(next.getWidth());
                next.verticalRun.dimension.resolve(next.getHeight());
            }
            next.measured = true;
        }
        return false;
    }

    private int computeWrap(ConstraintWidgetContainer constraintWidgetContainer, int i7) {
        int size = this.mGroups.size();
        long j7 = 0;
        for (int i8 = 0; i8 < size; i8++) {
            j7 = Math.max(j7, this.mGroups.get(i8).computeWrapSize(constraintWidgetContainer, i7));
        }
        return (int) j7;
    }

    private void displayGraph() {
        Iterator<WidgetRun> it = this.mRuns.iterator();
        String str = "digraph {\n";
        while (it.hasNext()) {
            str = generateDisplayGraph(it.next(), str);
        }
        PrintStream printStream = System.out;
        printStream.println("content:<<\n" + (str + "\n}\n") + "\n>>");
    }

    private void findGroup(WidgetRun widgetRun, int i7, ArrayList<RunGroup> arrayList) {
        for (Dependency dependency : widgetRun.start.dependencies) {
            if (dependency instanceof DependencyNode) {
                applyGroup((DependencyNode) dependency, i7, 0, widgetRun.end, arrayList, null);
            } else if (dependency instanceof WidgetRun) {
                applyGroup(((WidgetRun) dependency).start, i7, 0, widgetRun.end, arrayList, null);
            }
        }
        for (Dependency dependency2 : widgetRun.end.dependencies) {
            if (dependency2 instanceof DependencyNode) {
                applyGroup((DependencyNode) dependency2, i7, 1, widgetRun.start, arrayList, null);
            } else if (dependency2 instanceof WidgetRun) {
                applyGroup(((WidgetRun) dependency2).end, i7, 1, widgetRun.start, arrayList, null);
            }
        }
        if (i7 == 1) {
            for (Dependency dependency3 : ((VerticalWidgetRun) widgetRun).baseline.dependencies) {
                if (dependency3 instanceof DependencyNode) {
                    applyGroup((DependencyNode) dependency3, i7, 2, null, arrayList, null);
                }
            }
        }
    }

    private String generateChainDisplayGraph(ChainRun chainRun, String str) {
        StringBuilder sb;
        String str2;
        StringBuilder sb2;
        String str3;
        int i7 = chainRun.orientation;
        String str4 = "cluster_" + chainRun.widget.getDebugName();
        if (i7 == 0) {
            sb.append(str4);
            str2 = "_h";
        } else {
            sb = new StringBuilder();
            sb.append(str4);
            str2 = "_v";
        }
        sb.append(str2);
        String str5 = "subgraph " + sb.toString() + " {\n";
        Iterator<WidgetRun> it = chainRun.widgets.iterator();
        String str6 = "";
        while (it.hasNext()) {
            WidgetRun next = it.next();
            String debugName = next.widget.getDebugName();
            if (i7 == 0) {
                sb2.append(debugName);
                str3 = "_HORIZONTAL";
            } else {
                sb2 = new StringBuilder();
                sb2.append(debugName);
                str3 = "_VERTICAL";
            }
            sb2.append(str3);
            str5 = str5 + sb2.toString() + ";\n";
            str6 = generateDisplayGraph(next, str6);
        }
        return str + str6 + (str5 + "}\n");
    }

    /* JADX WARNING: Code restructure failed: missing block: B:29:0x0091, code lost:
        if (r9.widget.getDimensionRatio() > 0.0f) goto L_0x0093;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:49:0x012c, code lost:
        if (r9.widget.getDimensionRatio() > 0.0f) goto L_0x0093;
     */
    /* JADX WARNING: Removed duplicated region for block: B:62:0x01a2  */
    /* JADX WARNING: Removed duplicated region for block: B:64:0x01a9 A[RETURN] */
    private String generateDisplayGraph(WidgetRun widgetRun, String str) {
        String str2;
        StringBuilder sb;
        boolean z7;
        DependencyNode dependencyNode = widgetRun.start;
        DependencyNode dependencyNode2 = widgetRun.end;
        if (!(widgetRun instanceof HelperReferences) && dependencyNode.dependencies.isEmpty() && (dependencyNode2.dependencies.isEmpty() && dependencyNode.targets.isEmpty()) && dependencyNode2.targets.isEmpty()) {
            return str;
        }
        boolean isCenteredConnection = isCenteredConnection(dependencyNode, dependencyNode2);
        String generateDisplayNode = generateDisplayNode(dependencyNode2, isCenteredConnection, generateDisplayNode(dependencyNode, isCenteredConnection, str + nodeDefinition(widgetRun)));
        boolean z8 = widgetRun instanceof VerticalWidgetRun;
        if (z8) {
            generateDisplayNode = generateDisplayNode(((VerticalWidgetRun) widgetRun).baseline, isCenteredConnection, generateDisplayNode);
        }
        if ((widgetRun instanceof HorizontalWidgetRun) || (((z7 = widgetRun instanceof ChainRun)) && ((ChainRun) widgetRun).orientation == 0)) {
            ConstraintWidget.DimensionBehaviour horizontalDimensionBehaviour = widgetRun.widget.getHorizontalDimensionBehaviour();
            if (horizontalDimensionBehaviour != ConstraintWidget.DimensionBehaviour.FIXED && horizontalDimensionBehaviour != ConstraintWidget.DimensionBehaviour.WRAP_CONTENT) {
                if (horizontalDimensionBehaviour == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT) {
                }
                if (widgetRun instanceof ChainRun) {
                }
            } else if (dependencyNode.targets.isEmpty() || !dependencyNode2.targets.isEmpty()) {
                if (dependencyNode.targets.isEmpty() && !dependencyNode2.targets.isEmpty()) {
                    str2 = "\n" + dependencyNode.name() + " -> " + dependencyNode2.name() + "\n";
                    sb = new StringBuilder();
                    sb.append(generateDisplayNode);
                    sb.append(str2);
                    generateDisplayNode = sb.toString();
                }
                return widgetRun instanceof ChainRun ? generateChainDisplayGraph((ChainRun) widgetRun, generateDisplayNode) : generateDisplayNode;
            } else {
                str2 = "\n" + dependencyNode2.name() + " -> " + dependencyNode.name() + "\n";
                sb = new StringBuilder();
                sb.append(generateDisplayNode);
                sb.append(str2);
                generateDisplayNode = sb.toString();
                if (widgetRun instanceof ChainRun) {
                }
            }
        } else {
            if (z8 || (z7 && ((ChainRun) widgetRun).orientation == 1)) {
                ConstraintWidget.DimensionBehaviour verticalDimensionBehaviour = widgetRun.widget.getVerticalDimensionBehaviour();
                if (verticalDimensionBehaviour == ConstraintWidget.DimensionBehaviour.FIXED || verticalDimensionBehaviour == ConstraintWidget.DimensionBehaviour.WRAP_CONTENT) {
                    if (!dependencyNode.targets.isEmpty() && dependencyNode2.targets.isEmpty()) {
                        str2 = "\n" + dependencyNode2.name() + " -> " + dependencyNode.name() + "\n";
                        sb = new StringBuilder();
                        sb.append(generateDisplayNode);
                        sb.append(str2);
                        generateDisplayNode = sb.toString();
                    } else if (dependencyNode.targets.isEmpty() && !dependencyNode2.targets.isEmpty()) {
                        str2 = "\n" + dependencyNode.name() + " -> " + dependencyNode2.name() + "\n";
                        sb = new StringBuilder();
                        sb.append(generateDisplayNode);
                        sb.append(str2);
                        generateDisplayNode = sb.toString();
                    }
                } else if (verticalDimensionBehaviour == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT) {
                }
            }
            if (widgetRun instanceof ChainRun) {
            }
        }
        widgetRun.widget.getDebugName();
        if (widgetRun instanceof ChainRun) {
        }
    }

    private String generateDisplayNode(DependencyNode dependencyNode, boolean z7, String str) {
        Iterator<DependencyNode> it = dependencyNode.targets.iterator();
        while (it.hasNext()) {
            String str2 = ("\n" + dependencyNode.name()) + " -> " + it.next().name();
            if (dependencyNode.margin > 0 || z7 || (dependencyNode.run instanceof HelperReferences)) {
                String str3 = str2 + "[";
                if (dependencyNode.margin > 0) {
                    str3 = str3 + "label=\"" + dependencyNode.margin + "\"";
                    if (z7) {
                        str3 = str3 + ",";
                    }
                }
                if (z7) {
                    str3 = str3 + " style=dashed ";
                }
                if (dependencyNode.run instanceof HelperReferences) {
                    str3 = str3 + " style=bold,color=gray ";
                }
                str2 = str3 + "]";
            }
            str = str + (str2 + "\n");
        }
        return str;
    }

    private boolean isCenteredConnection(DependencyNode dependencyNode, DependencyNode dependencyNode2) {
        int i7 = 0;
        for (DependencyNode dependencyNode3 : dependencyNode.targets) {
            if (dependencyNode3 != dependencyNode2) {
                i7++;
            }
        }
        int i8 = 0;
        for (DependencyNode dependencyNode4 : dependencyNode2.targets) {
            if (dependencyNode4 != dependencyNode) {
                i8++;
            }
        }
        return i7 > 0 && i8 > 0;
    }

    private void measure(ConstraintWidget constraintWidget, ConstraintWidget.DimensionBehaviour dimensionBehaviour, int i7, ConstraintWidget.DimensionBehaviour dimensionBehaviour2, int i8) {
        BasicMeasure.Measure measure = this.mMeasure;
        measure.horizontalBehavior = dimensionBehaviour;
        measure.verticalBehavior = dimensionBehaviour2;
        measure.horizontalDimension = i7;
        measure.verticalDimension = i8;
        this.mMeasurer.measure(constraintWidget, measure);
        constraintWidget.setWidth(this.mMeasure.measuredWidth);
        constraintWidget.setHeight(this.mMeasure.measuredHeight);
        constraintWidget.setHasBaseline(this.mMeasure.measuredHasBaseline);
        constraintWidget.setBaselineDistance(this.mMeasure.measuredBaseline);
    }

    /* JADX WARNING: Removed duplicated region for block: B:34:0x0127  */
    /* JADX WARNING: Removed duplicated region for block: B:36:0x013a  */
    /* JADX WARNING: Removed duplicated region for block: B:37:0x015f  */
    /* JADX WARNING: Removed duplicated region for block: B:40:0x017f  */
    /* JADX WARNING: Removed duplicated region for block: B:45:0x01b5  */
    private String nodeDefinition(WidgetRun widgetRun) {
        StringBuilder sb;
        String str;
        StringBuilder sb2;
        StringBuilder sb3;
        String str2;
        String str3;
        StringBuilder sb4;
        String str4;
        StringBuilder sb5;
        String str5;
        boolean z7 = widgetRun instanceof VerticalWidgetRun;
        String debugName = widgetRun.widget.getDebugName();
        ConstraintWidget constraintWidget = widgetRun.widget;
        ConstraintWidget.DimensionBehaviour horizontalDimensionBehaviour = !z7 ? constraintWidget.getHorizontalDimensionBehaviour() : constraintWidget.getVerticalDimensionBehaviour();
        RunGroup runGroup = widgetRun.runGroup;
        if (!z7) {
            sb.append(debugName);
            str = "_HORIZONTAL";
        } else {
            sb = new StringBuilder();
            sb.append(debugName);
            str = "_VERTICAL";
        }
        sb.append(str);
        String str6 = ((sb.toString() + " [shape=none, label=<") + "<TABLE BORDER=\"0\" CELLSPACING=\"0\" CELLPADDING=\"2\">") + "  <TR>";
        if (!z7) {
            sb2.append(str6);
            sb2.append("    <TD ");
            String sb6 = sb2.toString();
            if (widgetRun.start.resolved) {
                sb6 = sb6 + " BGCOLOR=\"green\"";
            }
            sb3 = new StringBuilder();
            sb3.append(sb6);
            str2 = " PORT=\"LEFT\" BORDER=\"1\">L</TD>";
        } else {
            sb2 = new StringBuilder();
            sb2.append(str6);
            sb2.append("    <TD ");
            String sb7 = sb2.toString();
            if (widgetRun.start.resolved) {
                sb7 = sb7 + " BGCOLOR=\"green\"";
            }
            sb3 = new StringBuilder();
            sb3.append(sb7);
            str2 = " PORT=\"TOP\" BORDER=\"1\">T</TD>";
        }
        sb3.append(str2);
        String str7 = sb3.toString() + "    <TD BORDER=\"1\" ";
        boolean z8 = widgetRun.dimension.resolved;
        if (z8 && !widgetRun.widget.measured) {
            sb5 = new StringBuilder();
            sb5.append(str7);
            str5 = " BGCOLOR=\"green\" ";
        } else if (!z8 || !widgetRun.widget.measured) {
            if (!z8 && widgetRun.widget.measured) {
                sb5 = new StringBuilder();
                sb5.append(str7);
                str5 = " BGCOLOR=\"yellow\" ";
            }
            if (horizontalDimensionBehaviour == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT) {
                str7 = str7 + "style=\"dashed\"";
            }
            if (runGroup == null) {
                str3 = " [" + (runGroup.groupIndex + 1) + "/" + RunGroup.index + "]";
            } else {
                str3 = "";
            }
            String str8 = str7 + ">" + debugName + str3 + " </TD>";
            if (z7) {
                String str9 = str8 + "    <TD ";
                if (widgetRun.end.resolved) {
                    str9 = str9 + " BGCOLOR=\"green\"";
                }
                sb4 = new StringBuilder();
                sb4.append(str9);
                str4 = " PORT=\"RIGHT\" BORDER=\"1\">R</TD>";
            } else {
                String str10 = str8 + "    <TD ";
                if ((widgetRun instanceof VerticalWidgetRun) && ((VerticalWidgetRun) widgetRun).baseline.resolved) {
                    str10 = str10 + " BGCOLOR=\"green\"";
                }
                String str11 = (str10 + " PORT=\"BASELINE\" BORDER=\"1\">b</TD>") + "    <TD ";
                if (widgetRun.end.resolved) {
                    str11 = str11 + " BGCOLOR=\"green\"";
                }
                sb4 = new StringBuilder();
                sb4.append(str11);
                str4 = " PORT=\"BOTTOM\" BORDER=\"1\">B</TD>";
            }
            sb4.append(str4);
            return (sb4.toString() + "  </TR></TABLE>") + ">];\n";
        } else {
            sb5 = new StringBuilder();
            sb5.append(str7);
            str5 = " BGCOLOR=\"lightgray\" ";
        }
        sb5.append(str5);
        str7 = sb5.toString();
        if (horizontalDimensionBehaviour == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT) {
        }
        if (runGroup == null) {
        }
        String str82 = str7 + ">" + debugName + str3 + " </TD>";
        if (z7) {
        }
        sb4.append(str4);
        return (sb4.toString() + "  </TR></TABLE>") + ">];\n";
    }

    public void buildGraph() {
        buildGraph(this.mRuns);
        this.mGroups.clear();
        RunGroup.index = 0;
        findGroup(this.container.horizontalRun, 0, this.mGroups);
        findGroup(this.container.verticalRun, 1, this.mGroups);
        this.mNeedBuildGraph = false;
    }

    public void defineTerminalWidgets(ConstraintWidget.DimensionBehaviour dimensionBehaviour, ConstraintWidget.DimensionBehaviour dimensionBehaviour2) {
        if (this.mNeedBuildGraph) {
            buildGraph();
            Iterator<ConstraintWidget> it = this.container.mChildren.iterator();
            boolean z7 = false;
            while (it.hasNext()) {
                ConstraintWidget next = it.next();
                boolean[] zArr = next.isTerminalWidget;
                zArr[0] = true;
                zArr[1] = true;
                if (next instanceof Barrier) {
                    z7 = true;
                }
            }
            if (!z7) {
                Iterator<RunGroup> it2 = this.mGroups.iterator();
                while (it2.hasNext()) {
                    RunGroup next2 = it2.next();
                    ConstraintWidget.DimensionBehaviour dimensionBehaviour3 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
                    next2.defineTerminalWidgets(dimensionBehaviour == dimensionBehaviour3, dimensionBehaviour2 == dimensionBehaviour3);
                }
            }
        }
    }

    public boolean directMeasure(boolean z7) {
        boolean z8;
        boolean z9 = true;
        boolean z10 = z7 & true;
        if (this.mNeedBuildGraph || this.mNeedRedoMeasures) {
            Iterator<ConstraintWidget> it = this.container.mChildren.iterator();
            while (it.hasNext()) {
                ConstraintWidget next = it.next();
                next.ensureWidgetRuns();
                next.measured = false;
                next.horizontalRun.reset();
                next.verticalRun.reset();
            }
            this.container.ensureWidgetRuns();
            ConstraintWidgetContainer constraintWidgetContainer = this.container;
            constraintWidgetContainer.measured = false;
            constraintWidgetContainer.horizontalRun.reset();
            this.container.verticalRun.reset();
            this.mNeedRedoMeasures = false;
        }
        if (basicMeasureWidgets(this.mContainer)) {
            return false;
        }
        this.container.setX(0);
        this.container.setY(0);
        ConstraintWidget.DimensionBehaviour dimensionBehaviour = this.container.getDimensionBehaviour(0);
        ConstraintWidget.DimensionBehaviour dimensionBehaviour2 = this.container.getDimensionBehaviour(1);
        if (this.mNeedBuildGraph) {
            buildGraph();
        }
        int x7 = this.container.getX();
        int y7 = this.container.getY();
        this.container.horizontalRun.start.resolve(x7);
        this.container.verticalRun.start.resolve(y7);
        measureWidgets();
        ConstraintWidget.DimensionBehaviour dimensionBehaviour3 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
        if (dimensionBehaviour == dimensionBehaviour3 || dimensionBehaviour2 == dimensionBehaviour3) {
            if (z10) {
                Iterator<WidgetRun> it2 = this.mRuns.iterator();
                while (true) {
                    if (it2.hasNext()) {
                        if (!it2.next().supportsWrapComputation()) {
                            z10 = false;
                            break;
                        }
                    } else {
                        break;
                    }
                }
            }
            if (z10 && dimensionBehaviour == ConstraintWidget.DimensionBehaviour.WRAP_CONTENT) {
                this.container.setHorizontalDimensionBehaviour(ConstraintWidget.DimensionBehaviour.FIXED);
                ConstraintWidgetContainer constraintWidgetContainer2 = this.container;
                constraintWidgetContainer2.setWidth(computeWrap(constraintWidgetContainer2, 0));
                ConstraintWidgetContainer constraintWidgetContainer3 = this.container;
                constraintWidgetContainer3.horizontalRun.dimension.resolve(constraintWidgetContainer3.getWidth());
            }
            if (z10 && dimensionBehaviour2 == ConstraintWidget.DimensionBehaviour.WRAP_CONTENT) {
                this.container.setVerticalDimensionBehaviour(ConstraintWidget.DimensionBehaviour.FIXED);
                ConstraintWidgetContainer constraintWidgetContainer4 = this.container;
                constraintWidgetContainer4.setHeight(computeWrap(constraintWidgetContainer4, 1));
                ConstraintWidgetContainer constraintWidgetContainer5 = this.container;
                constraintWidgetContainer5.verticalRun.dimension.resolve(constraintWidgetContainer5.getHeight());
            }
        }
        ConstraintWidgetContainer constraintWidgetContainer6 = this.container;
        ConstraintWidget.DimensionBehaviour dimensionBehaviour4 = constraintWidgetContainer6.mListDimensionBehaviors[0];
        ConstraintWidget.DimensionBehaviour dimensionBehaviour5 = ConstraintWidget.DimensionBehaviour.FIXED;
        if (dimensionBehaviour4 == dimensionBehaviour5 || dimensionBehaviour4 == ConstraintWidget.DimensionBehaviour.MATCH_PARENT) {
            int width = constraintWidgetContainer6.getWidth() + x7;
            this.container.horizontalRun.end.resolve(width);
            this.container.horizontalRun.dimension.resolve(width - x7);
            measureWidgets();
            ConstraintWidgetContainer constraintWidgetContainer7 = this.container;
            ConstraintWidget.DimensionBehaviour dimensionBehaviour6 = constraintWidgetContainer7.mListDimensionBehaviors[1];
            if (dimensionBehaviour6 == dimensionBehaviour5 || dimensionBehaviour6 == ConstraintWidget.DimensionBehaviour.MATCH_PARENT) {
                int height = constraintWidgetContainer7.getHeight() + y7;
                this.container.verticalRun.end.resolve(height);
                this.container.verticalRun.dimension.resolve(height - y7);
            }
            measureWidgets();
            z8 = true;
        } else {
            z8 = false;
        }
        Iterator<WidgetRun> it3 = this.mRuns.iterator();
        while (it3.hasNext()) {
            WidgetRun next2 = it3.next();
            if (next2.widget != this.container || next2.resolved) {
                next2.applyToWidget();
            }
        }
        Iterator<WidgetRun> it4 = this.mRuns.iterator();
        while (true) {
            if (!it4.hasNext()) {
                break;
            }
            WidgetRun next3 = it4.next();
            if ((z8 || next3.widget != this.container) && (!next3.start.resolved || ((!next3.end.resolved && !(next3 instanceof GuidelineReference)) || (!next3.dimension.resolved && !(next3 instanceof ChainRun) && !(next3 instanceof GuidelineReference))))) {
                z9 = false;
            }
        }
        z9 = false;
        this.container.setHorizontalDimensionBehaviour(dimensionBehaviour);
        this.container.setVerticalDimensionBehaviour(dimensionBehaviour2);
        return z9;
    }

    public boolean directMeasureSetup(boolean z7) {
        if (this.mNeedBuildGraph) {
            Iterator<ConstraintWidget> it = this.container.mChildren.iterator();
            while (it.hasNext()) {
                ConstraintWidget next = it.next();
                next.ensureWidgetRuns();
                next.measured = false;
                HorizontalWidgetRun horizontalWidgetRun = next.horizontalRun;
                horizontalWidgetRun.dimension.resolved = false;
                horizontalWidgetRun.resolved = false;
                horizontalWidgetRun.reset();
                VerticalWidgetRun verticalWidgetRun = next.verticalRun;
                verticalWidgetRun.dimension.resolved = false;
                verticalWidgetRun.resolved = false;
                verticalWidgetRun.reset();
            }
            this.container.ensureWidgetRuns();
            ConstraintWidgetContainer constraintWidgetContainer = this.container;
            constraintWidgetContainer.measured = false;
            HorizontalWidgetRun horizontalWidgetRun2 = constraintWidgetContainer.horizontalRun;
            horizontalWidgetRun2.dimension.resolved = false;
            horizontalWidgetRun2.resolved = false;
            horizontalWidgetRun2.reset();
            VerticalWidgetRun verticalWidgetRun2 = this.container.verticalRun;
            verticalWidgetRun2.dimension.resolved = false;
            verticalWidgetRun2.resolved = false;
            verticalWidgetRun2.reset();
            buildGraph();
        }
        if (basicMeasureWidgets(this.mContainer)) {
            return false;
        }
        this.container.setX(0);
        this.container.setY(0);
        this.container.horizontalRun.start.resolve(0);
        this.container.verticalRun.start.resolve(0);
        return true;
    }

    /* JADX WARNING: Removed duplicated region for block: B:40:0x00e6  */
    /* JADX WARNING: Removed duplicated region for block: B:50:0x010c  */
    /* JADX WARNING: Removed duplicated region for block: B:78:0x013a A[EDGE_INSN: B:78:0x013a->B:64:0x013a ?: BREAK  , SYNTHETIC] */
    public boolean directMeasureWithOrientation(boolean z7, int i7) {
        boolean z8;
        Iterator<WidgetRun> it;
        Iterator<WidgetRun> it2;
        ConstraintWidget.DimensionBehaviour dimensionBehaviour;
        int i8;
        DimensionDependency dimensionDependency;
        boolean z9 = true;
        boolean z10 = z7 & true;
        ConstraintWidget.DimensionBehaviour dimensionBehaviour2 = this.container.getDimensionBehaviour(0);
        ConstraintWidget.DimensionBehaviour dimensionBehaviour3 = this.container.getDimensionBehaviour(1);
        int x7 = this.container.getX();
        int y7 = this.container.getY();
        if (z10 && (dimensionBehaviour2 == (dimensionBehaviour = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT) || dimensionBehaviour3 == dimensionBehaviour)) {
            Iterator<WidgetRun> it3 = this.mRuns.iterator();
            while (true) {
                if (!it3.hasNext()) {
                    break;
                }
                WidgetRun next = it3.next();
                if (next.orientation == i7 && !next.supportsWrapComputation()) {
                    z10 = false;
                    break;
                }
            }
            if (i7 == 0) {
                if (z10 && dimensionBehaviour2 == ConstraintWidget.DimensionBehaviour.WRAP_CONTENT) {
                    this.container.setHorizontalDimensionBehaviour(ConstraintWidget.DimensionBehaviour.FIXED);
                    ConstraintWidgetContainer constraintWidgetContainer = this.container;
                    constraintWidgetContainer.setWidth(computeWrap(constraintWidgetContainer, 0));
                    ConstraintWidgetContainer constraintWidgetContainer2 = this.container;
                    dimensionDependency = constraintWidgetContainer2.horizontalRun.dimension;
                    i8 = constraintWidgetContainer2.getWidth();
                }
            } else if (z10 && dimensionBehaviour3 == ConstraintWidget.DimensionBehaviour.WRAP_CONTENT) {
                this.container.setVerticalDimensionBehaviour(ConstraintWidget.DimensionBehaviour.FIXED);
                ConstraintWidgetContainer constraintWidgetContainer3 = this.container;
                constraintWidgetContainer3.setHeight(computeWrap(constraintWidgetContainer3, 1));
                ConstraintWidgetContainer constraintWidgetContainer4 = this.container;
                dimensionDependency = constraintWidgetContainer4.verticalRun.dimension;
                i8 = constraintWidgetContainer4.getHeight();
            }
            dimensionDependency.resolve(i8);
        }
        ConstraintWidgetContainer constraintWidgetContainer5 = this.container;
        if (i7 == 0) {
            ConstraintWidget.DimensionBehaviour dimensionBehaviour4 = constraintWidgetContainer5.mListDimensionBehaviors[0];
            if (dimensionBehaviour4 == ConstraintWidget.DimensionBehaviour.FIXED || dimensionBehaviour4 == ConstraintWidget.DimensionBehaviour.MATCH_PARENT) {
                int width = constraintWidgetContainer5.getWidth() + x7;
                this.container.horizontalRun.end.resolve(width);
                this.container.horizontalRun.dimension.resolve(width - x7);
                z8 = true;
                measureWidgets();
                it = this.mRuns.iterator();
                while (it.hasNext()) {
                    WidgetRun next2 = it.next();
                    if (next2.orientation == i7 && (next2.widget != this.container || next2.resolved)) {
                        next2.applyToWidget();
                    }
                }
                it2 = this.mRuns.iterator();
                while (true) {
                    if (!it2.hasNext()) {
                        break;
                    }
                    WidgetRun next3 = it2.next();
                    if (next3.orientation == i7 && ((z8 || next3.widget != this.container) && (!next3.start.resolved || !next3.end.resolved || (!(next3 instanceof ChainRun) && !next3.dimension.resolved)))) {
                        z9 = false;
                    }
                }
                z9 = false;
                this.container.setHorizontalDimensionBehaviour(dimensionBehaviour2);
                this.container.setVerticalDimensionBehaviour(dimensionBehaviour3);
                return z9;
            }
        } else {
            ConstraintWidget.DimensionBehaviour dimensionBehaviour5 = constraintWidgetContainer5.mListDimensionBehaviors[1];
            if (dimensionBehaviour5 == ConstraintWidget.DimensionBehaviour.FIXED || dimensionBehaviour5 == ConstraintWidget.DimensionBehaviour.MATCH_PARENT) {
                int height = constraintWidgetContainer5.getHeight() + y7;
                this.container.verticalRun.end.resolve(height);
                this.container.verticalRun.dimension.resolve(height - y7);
                z8 = true;
                measureWidgets();
                it = this.mRuns.iterator();
                while (it.hasNext()) {
                }
                it2 = this.mRuns.iterator();
                while (true) {
                    if (!it2.hasNext()) {
                    }
                }
                z9 = false;
                this.container.setHorizontalDimensionBehaviour(dimensionBehaviour2);
                this.container.setVerticalDimensionBehaviour(dimensionBehaviour3);
                return z9;
            }
        }
        z8 = false;
        measureWidgets();
        it = this.mRuns.iterator();
        while (it.hasNext()) {
        }
        it2 = this.mRuns.iterator();
        while (true) {
            if (!it2.hasNext()) {
            }
        }
        z9 = false;
        this.container.setHorizontalDimensionBehaviour(dimensionBehaviour2);
        this.container.setVerticalDimensionBehaviour(dimensionBehaviour3);
        return z9;
    }

    public void invalidateGraph() {
        this.mNeedBuildGraph = true;
    }

    public void invalidateMeasures() {
        this.mNeedRedoMeasures = true;
    }

    public void measureWidgets() {
        DimensionDependency dimensionDependency;
        DimensionDependency dimensionDependency2;
        int width;
        DimensionDependency dimensionDependency3;
        int width2;
        Iterator<ConstraintWidget> it = this.container.mChildren.iterator();
        while (it.hasNext()) {
            ConstraintWidget next = it.next();
            if (!next.measured) {
                ConstraintWidget.DimensionBehaviour[] dimensionBehaviourArr = next.mListDimensionBehaviors;
                boolean z7 = false;
                ConstraintWidget.DimensionBehaviour dimensionBehaviour = dimensionBehaviourArr[0];
                ConstraintWidget.DimensionBehaviour dimensionBehaviour2 = dimensionBehaviourArr[1];
                int i7 = next.mMatchConstraintDefaultWidth;
                int i8 = next.mMatchConstraintDefaultHeight;
                ConstraintWidget.DimensionBehaviour dimensionBehaviour3 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
                boolean z8 = dimensionBehaviour == dimensionBehaviour3 || (dimensionBehaviour == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT && i7 == 1);
                if (dimensionBehaviour2 == dimensionBehaviour3 || (dimensionBehaviour2 == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT && i8 == 1)) {
                    z7 = true;
                }
                DimensionDependency dimensionDependency4 = next.horizontalRun.dimension;
                boolean z9 = dimensionDependency4.resolved;
                DimensionDependency dimensionDependency5 = next.verticalRun.dimension;
                boolean z10 = dimensionDependency5.resolved;
                if (!z9 || !z10) {
                    if (!z9 || !z7) {
                        if (z10 && z8) {
                            measure(next, dimensionBehaviour3, dimensionDependency4.value, ConstraintWidget.DimensionBehaviour.FIXED, dimensionDependency5.value);
                            if (dimensionBehaviour == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT) {
                                dimensionDependency3 = next.horizontalRun.dimension;
                                width2 = next.getWidth();
                            } else {
                                dimensionDependency2 = next.horizontalRun.dimension;
                                width = next.getWidth();
                                dimensionDependency2.resolve(width);
                            }
                        }
                        if (next.measured && (dimensionDependency = next.verticalRun.baselineDimension) != null) {
                            dimensionDependency.resolve(next.getBaselineDistance());
                        }
                    } else {
                        measure(next, ConstraintWidget.DimensionBehaviour.FIXED, dimensionDependency4.value, dimensionBehaviour3, dimensionDependency5.value);
                        if (dimensionBehaviour2 == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT) {
                            dimensionDependency3 = next.verticalRun.dimension;
                            width2 = next.getHeight();
                        } else {
                            dimensionDependency2 = next.verticalRun.dimension;
                            width = next.getHeight();
                            dimensionDependency2.resolve(width);
                        }
                    }
                    dimensionDependency3.wrapValue = width2;
                    dimensionDependency.resolve(next.getBaselineDistance());
                } else {
                    ConstraintWidget.DimensionBehaviour dimensionBehaviour4 = ConstraintWidget.DimensionBehaviour.FIXED;
                    measure(next, dimensionBehaviour4, dimensionDependency4.value, dimensionBehaviour4, dimensionDependency5.value);
                }
                next.measured = true;
                dimensionDependency.resolve(next.getBaselineDistance());
            }
        }
    }

    public void setMeasurer(BasicMeasure.Measurer measurer) {
        this.mMeasurer = measurer;
    }

    public void buildGraph(ArrayList<WidgetRun> arrayList) {
        WidgetRun helperReferences;
        arrayList.clear();
        this.mContainer.horizontalRun.clear();
        this.mContainer.verticalRun.clear();
        arrayList.add(this.mContainer.horizontalRun);
        arrayList.add(this.mContainer.verticalRun);
        Iterator<ConstraintWidget> it = this.mContainer.mChildren.iterator();
        HashSet hashSet = null;
        while (it.hasNext()) {
            ConstraintWidget next = it.next();
            if (next instanceof Guideline) {
                helperReferences = new GuidelineReference(next);
            } else {
                if (next.isInHorizontalChain()) {
                    if (next.horizontalChainRun == null) {
                        next.horizontalChainRun = new ChainRun(next, 0);
                    }
                    if (hashSet == null) {
                        hashSet = new HashSet();
                    }
                    hashSet.add(next.horizontalChainRun);
                } else {
                    arrayList.add(next.horizontalRun);
                }
                if (next.isInVerticalChain()) {
                    if (next.verticalChainRun == null) {
                        next.verticalChainRun = new ChainRun(next, 1);
                    }
                    if (hashSet == null) {
                        hashSet = new HashSet();
                    }
                    hashSet.add(next.verticalChainRun);
                } else {
                    arrayList.add(next.verticalRun);
                }
                if (next instanceof HelperWidget) {
                    helperReferences = new HelperReferences(next);
                }
            }
            arrayList.add(helperReferences);
        }
        if (hashSet != null) {
            arrayList.addAll(hashSet);
        }
        Iterator<WidgetRun> it2 = arrayList.iterator();
        while (it2.hasNext()) {
            it2.next().clear();
        }
        Iterator<WidgetRun> it3 = arrayList.iterator();
        while (it3.hasNext()) {
            WidgetRun next2 = it3.next();
            if (next2.widget != this.mContainer) {
                next2.apply();
            }
        }
    }
}
