package androidx.core.content.res;

import androidx.annotation.ColorInt;
import androidx.annotation.FloatRange;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.core.graphics.ColorUtils;
import kotlin.jvm.internal.x;

class CamColor {
    private static final float CHROMA_SEARCH_ENDPOINT = 0.4f;
    private static final float DE_MAX = 1.0f;
    private static final float DL_MAX = 0.2f;
    private static final float LIGHTNESS_SEARCH_ENDPOINT = 0.01f;
    private final float mAstar;
    private final float mBstar;
    private final float mChroma;
    private final float mHue;
    private final float mJ;
    private final float mJstar;
    private final float mM;
    private final float mQ;
    private final float mS;

    CamColor(float f7, float f8, float f9, float f10, float f11, float f12, float f13, float f14, float f15) {
        this.mHue = f7;
        this.mChroma = f8;
        this.mJ = f9;
        this.mQ = f10;
        this.mM = f11;
        this.mS = f12;
        this.mJstar = f13;
        this.mAstar = f14;
        this.mBstar = f15;
    }

    @Nullable
    private static CamColor findCamByJ(@FloatRange(from = 0.0d, to = 360.0d) float f7, @FloatRange(from = 0.0d, to = Double.POSITIVE_INFINITY, toInclusive = false) float f8, @FloatRange(from = 0.0d, to = 100.0d) float f9) {
        float f10 = 100.0f;
        float f11 = 1000.0f;
        float f12 = 0.0f;
        CamColor camColor = null;
        float f13 = 1000.0f;
        while (Math.abs(f12 - f10) > LIGHTNESS_SEARCH_ENDPOINT) {
            float f14 = ((f10 - f12) / 2.0f) + f12;
            int viewedInSrgb = fromJch(f14, f8, f7).viewedInSrgb();
            float lStarFromInt = CamUtils.lStarFromInt(viewedInSrgb);
            float abs = Math.abs(f9 - lStarFromInt);
            if (abs < 0.2f) {
                CamColor fromColor = fromColor(viewedInSrgb);
                float distance = fromColor.distance(fromJch(fromColor.getJ(), fromColor.getChroma(), f7));
                if (distance <= 1.0f) {
                    camColor = fromColor;
                    f11 = abs;
                    f13 = distance;
                }
            }
            if (f11 == 0.0f && f13 == 0.0f) {
                break;
            } else if (lStarFromInt < f9) {
                f12 = f14;
            } else {
                f10 = f14;
            }
        }
        return camColor;
    }

    @NonNull
    static CamColor fromColor(@ColorInt int i7) {
        return fromColorInViewingConditions(i7, ViewingConditions.DEFAULT);
    }

    @NonNull
    static CamColor fromColorInViewingConditions(@ColorInt int i7, @NonNull ViewingConditions viewingConditions) {
        float[] xyzFromInt = CamUtils.xyzFromInt(i7);
        float[][] fArr = CamUtils.XYZ_TO_CAM16RGB;
        float f7 = xyzFromInt[0];
        float[] fArr2 = fArr[0];
        float f8 = xyzFromInt[1];
        float f9 = xyzFromInt[2];
        float f10 = (fArr2[0] * f7) + (fArr2[1] * f8) + (fArr2[2] * f9);
        float[] fArr3 = fArr[1];
        float f11 = (fArr3[0] * f7) + (fArr3[1] * f8) + (fArr3[2] * f9);
        float[] fArr4 = fArr[2];
        float f12 = (f7 * fArr4[0]) + (f8 * fArr4[1]) + (f9 * fArr4[2]);
        float f13 = viewingConditions.getRgbD()[0] * f10;
        float f14 = viewingConditions.getRgbD()[1] * f11;
        float f15 = viewingConditions.getRgbD()[2] * f12;
        float pow = (float) Math.pow(((double) (viewingConditions.getFl() * Math.abs(f13))) / 100.0d, 0.42d);
        float pow2 = (float) Math.pow(((double) (viewingConditions.getFl() * Math.abs(f14))) / 100.0d, 0.42d);
        float pow3 = (float) Math.pow(((double) (viewingConditions.getFl() * Math.abs(f15))) / 100.0d, 0.42d);
        float signum = ((Math.signum(f13) * 400.0f) * pow) / (pow + 27.13f);
        float signum2 = ((Math.signum(f14) * 400.0f) * pow2) / (pow2 + 27.13f);
        float signum3 = ((Math.signum(f15) * 400.0f) * pow3) / (pow3 + 27.13f);
        double d7 = (double) signum3;
        float f16 = ((float) (((((double) signum) * 11.0d) + (((double) signum2) * -12.0d)) + d7)) / 11.0f;
        float f17 = ((float) (((double) (signum + signum2)) - (d7 * 2.0d))) / 9.0f;
        float f18 = signum2 * 20.0f;
        float f19 = (((signum * 20.0f) + f18) + (21.0f * signum3)) / 20.0f;
        float f20 = (((signum * 40.0f) + f18) + signum3) / 20.0f;
        float atan2 = (((float) Math.atan2((double) f17, (double) f16)) * 180.0f) / 3.1415927f;
        if (atan2 < 0.0f) {
            atan2 += 360.0f;
        } else if (atan2 >= 360.0f) {
            atan2 -= 360.0f;
        }
        float f21 = (3.1415927f * atan2) / 180.0f;
        float pow4 = ((float) Math.pow((double) ((f20 * viewingConditions.getNbb()) / viewingConditions.getAw()), (double) (viewingConditions.getC() * viewingConditions.getZ()))) * 100.0f;
        float flRoot = viewingConditions.getFlRoot() * (4.0f / viewingConditions.getC()) * ((float) Math.sqrt((double) (pow4 / 100.0f))) * (viewingConditions.getAw() + 4.0f);
        float pow5 = ((float) Math.pow(1.64d - Math.pow(0.29d, (double) viewingConditions.getN()), 0.73d)) * ((float) Math.pow((double) ((((((((float) (Math.cos(((((double) (((double) atan2) < 20.14d ? 360.0f + atan2 : atan2)) * 3.141592653589793d) / 180.0d) + 2.0d) + 3.8d)) * 0.25f) * 3846.1538f) * viewingConditions.getNc()) * viewingConditions.getNcb()) * ((float) Math.sqrt((double) ((f16 * f16) + (f17 * f17))))) / (f19 + 0.305f)), 0.9d));
        float sqrt = pow5 * ((float) Math.sqrt(((double) pow4) / 100.0d));
        float flRoot2 = sqrt * viewingConditions.getFlRoot();
        float sqrt2 = ((float) Math.sqrt((double) ((pow5 * viewingConditions.getC()) / (viewingConditions.getAw() + 4.0f)))) * 50.0f;
        float f22 = (1.7f * pow4) / ((0.007f * pow4) + 1.0f);
        float log = ((float) Math.log((double) ((0.0228f * flRoot2) + 1.0f))) * 43.85965f;
        double d8 = (double) f21;
        return new CamColor(atan2, sqrt, pow4, flRoot, flRoot2, sqrt2, f22, log * ((float) Math.cos(d8)), log * ((float) Math.sin(d8)));
    }

    @NonNull
    private static CamColor fromJch(@FloatRange(from = 0.0d, to = 100.0d) float f7, @FloatRange(from = 0.0d, to = Double.POSITIVE_INFINITY, toInclusive = false) float f8, @FloatRange(from = 0.0d, to = 360.0d) float f9) {
        return fromJchInFrame(f7, f8, f9, ViewingConditions.DEFAULT);
    }

    @NonNull
    private static CamColor fromJchInFrame(@FloatRange(from = 0.0d, to = 100.0d) float f7, @FloatRange(from = 0.0d, to = Double.POSITIVE_INFINITY, toInclusive = false) float f8, @FloatRange(from = 0.0d, to = 360.0d) float f9, ViewingConditions viewingConditions) {
        double d7 = ((double) f7) / 100.0d;
        float c7 = (4.0f / viewingConditions.getC()) * ((float) Math.sqrt(d7)) * (viewingConditions.getAw() + 4.0f) * viewingConditions.getFlRoot();
        float flRoot = f8 * viewingConditions.getFlRoot();
        float sqrt = ((float) Math.sqrt((double) (((f8 / ((float) Math.sqrt(d7))) * viewingConditions.getC()) / (viewingConditions.getAw() + 4.0f)))) * 50.0f;
        float f10 = (1.7f * f7) / ((0.007f * f7) + 1.0f);
        float log = ((float) Math.log((((double) flRoot) * 0.0228d) + 1.0d)) * 43.85965f;
        double d8 = (double) ((3.1415927f * f9) / 180.0f);
        return new CamColor(f9, f8, f7, c7, flRoot, sqrt, f10, log * ((float) Math.cos(d8)), log * ((float) Math.sin(d8)));
    }

    static int toColor(@FloatRange(from = 0.0d, to = 360.0d) float f7, @FloatRange(from = 0.0d, to = Double.POSITIVE_INFINITY, toInclusive = false) float f8, @FloatRange(from = 0.0d, to = 100.0d) float f9) {
        return toColor(f7, f8, f9, ViewingConditions.DEFAULT);
    }

    /* access modifiers changed from: package-private */
    public float distance(@NonNull CamColor camColor) {
        float jStar = getJStar() - camColor.getJStar();
        float aStar = getAStar() - camColor.getAStar();
        float bStar = getBStar() - camColor.getBStar();
        return (float) (Math.pow(Math.sqrt((double) ((jStar * jStar) + (aStar * aStar) + (bStar * bStar))), 0.63d) * 1.41d);
    }

    /* access modifiers changed from: package-private */
    @FloatRange(from = x.f19884e, fromInclusive = false, to = x.f19883d, toInclusive = false)
    public float getAStar() {
        return this.mAstar;
    }

    /* access modifiers changed from: package-private */
    @FloatRange(from = x.f19884e, fromInclusive = false, to = x.f19883d, toInclusive = false)
    public float getBStar() {
        return this.mBstar;
    }

    /* access modifiers changed from: package-private */
    @FloatRange(from = 0.0d, to = x.f19883d, toInclusive = false)
    public float getChroma() {
        return this.mChroma;
    }

    /* access modifiers changed from: package-private */
    @FloatRange(from = 0.0d, to = 360.0d, toInclusive = false)
    public float getHue() {
        return this.mHue;
    }

    /* access modifiers changed from: package-private */
    @FloatRange(from = 0.0d, to = 100.0d)
    public float getJ() {
        return this.mJ;
    }

    /* access modifiers changed from: package-private */
    @FloatRange(from = 0.0d, to = 100.0d)
    public float getJStar() {
        return this.mJstar;
    }

    /* access modifiers changed from: package-private */
    @FloatRange(from = 0.0d, to = x.f19883d, toInclusive = false)
    public float getM() {
        return this.mM;
    }

    /* access modifiers changed from: package-private */
    @FloatRange(from = 0.0d, to = x.f19883d, toInclusive = false)
    public float getQ() {
        return this.mQ;
    }

    /* access modifiers changed from: package-private */
    @FloatRange(from = 0.0d, to = x.f19883d, toInclusive = false)
    public float getS() {
        return this.mS;
    }

    /* access modifiers changed from: package-private */
    @ColorInt
    public int viewed(@NonNull ViewingConditions viewingConditions) {
        float pow = (float) Math.pow(((double) ((((double) getChroma()) == 0.0d || ((double) getJ()) == 0.0d) ? 0.0f : getChroma() / ((float) Math.sqrt(((double) getJ()) / 100.0d)))) / Math.pow(1.64d - Math.pow(0.29d, (double) viewingConditions.getN()), 0.73d), 1.1111111111111112d);
        double hue = (double) ((getHue() * 3.1415927f) / 180.0f);
        float aw = viewingConditions.getAw() * ((float) Math.pow(((double) getJ()) / 100.0d, (1.0d / ((double) viewingConditions.getC())) / ((double) viewingConditions.getZ())));
        float cos = ((float) (Math.cos(2.0d + hue) + 3.8d)) * 0.25f * 3846.1538f * viewingConditions.getNc() * viewingConditions.getNcb();
        float nbb = aw / viewingConditions.getNbb();
        float sin = (float) Math.sin(hue);
        float cos2 = (float) Math.cos(hue);
        float f7 = (((0.305f + nbb) * 23.0f) * pow) / (((cos * 23.0f) + ((11.0f * pow) * cos2)) + ((pow * 108.0f) * sin));
        float f8 = cos2 * f7;
        float f9 = f7 * sin;
        float f10 = nbb * 460.0f;
        float f11 = (((451.0f * f8) + f10) + (288.0f * f9)) / 1403.0f;
        float f12 = ((f10 - (891.0f * f8)) - (261.0f * f9)) / 1403.0f;
        float f13 = ((f10 - (f8 * 220.0f)) - (f9 * 6300.0f)) / 1403.0f;
        float signum = Math.signum(f11) * (100.0f / viewingConditions.getFl()) * ((float) Math.pow((double) ((float) Math.max(0.0d, (((double) Math.abs(f11)) * 27.13d) / (400.0d - ((double) Math.abs(f11))))), 2.380952380952381d));
        float signum2 = Math.signum(f12) * (100.0f / viewingConditions.getFl()) * ((float) Math.pow((double) ((float) Math.max(0.0d, (((double) Math.abs(f12)) * 27.13d) / (400.0d - ((double) Math.abs(f12))))), 2.380952380952381d));
        float signum3 = Math.signum(f13) * (100.0f / viewingConditions.getFl()) * ((float) Math.pow((double) ((float) Math.max(0.0d, (((double) Math.abs(f13)) * 27.13d) / (400.0d - ((double) Math.abs(f13))))), 2.380952380952381d));
        float f14 = signum / viewingConditions.getRgbD()[0];
        float f15 = signum2 / viewingConditions.getRgbD()[1];
        float f16 = signum3 / viewingConditions.getRgbD()[2];
        float[][] fArr = CamUtils.CAM16RGB_TO_XYZ;
        float[] fArr2 = fArr[0];
        float f17 = (fArr2[0] * f14) + (fArr2[1] * f15) + (fArr2[2] * f16);
        float[] fArr3 = fArr[1];
        float[] fArr4 = fArr[2];
        return ColorUtils.XYZToColor((double) f17, (double) ((fArr3[0] * f14) + (fArr3[1] * f15) + (fArr3[2] * f16)), (double) ((f14 * fArr4[0]) + (f15 * fArr4[1]) + (f16 * fArr4[2])));
    }

    /* access modifiers changed from: package-private */
    @ColorInt
    public int viewedInSrgb() {
        return viewed(ViewingConditions.DEFAULT);
    }

    @ColorInt
    static int toColor(@FloatRange(from = 0.0d, to = 360.0d) float f7, @FloatRange(from = 0.0d, to = Double.POSITIVE_INFINITY, toInclusive = false) float f8, @FloatRange(from = 0.0d, to = 100.0d) float f9, @NonNull ViewingConditions viewingConditions) {
        if (((double) f8) < 1.0d || ((double) Math.round(f9)) <= 0.0d || ((double) Math.round(f9)) >= 100.0d) {
            return CamUtils.intFromLStar(f9);
        }
        float min = f7 < 0.0f ? 0.0f : Math.min(360.0f, f7);
        CamColor camColor = null;
        boolean z7 = true;
        float f10 = 0.0f;
        float f11 = f8;
        while (Math.abs(f10 - f8) >= CHROMA_SEARCH_ENDPOINT) {
            CamColor findCamByJ = findCamByJ(min, f11, f9);
            if (!z7) {
                if (findCamByJ == null) {
                    f8 = f11;
                } else {
                    f10 = f11;
                    camColor = findCamByJ;
                }
                f11 = ((f8 - f10) / 2.0f) + f10;
            } else if (findCamByJ != null) {
                return findCamByJ.viewed(viewingConditions);
            } else {
                f11 = ((f8 - f10) / 2.0f) + f10;
                z7 = false;
            }
        }
        return camColor == null ? CamUtils.intFromLStar(f9) : camColor.viewed(viewingConditions);
    }
}
