package androidx.core.content.res;

import android.graphics.Color;
import androidx.annotation.NonNull;
import androidx.core.graphics.ColorUtils;

final class CamUtils {
    static final float[][] CAM16RGB_TO_XYZ = {new float[]{1.8620678f, -1.0112547f, 0.14918678f}, new float[]{0.38752654f, 0.62144744f, -0.00897398f}, new float[]{-0.0158415f, -0.03412294f, 1.0499644f}};
    static final float[][] SRGB_TO_XYZ = {new float[]{0.41233894f, 0.35762063f, 0.18051042f}, new float[]{0.2126f, 0.7152f, 0.0722f}, new float[]{0.01932141f, 0.11916382f, 0.9503448f}};
    static final float[] WHITE_POINT_D65 = {95.047f, 100.0f, 108.883f};
    static final float[][] XYZ_TO_CAM16RGB = {new float[]{0.401288f, 0.650173f, -0.051461f}, new float[]{-0.250268f, 1.204414f, 0.045854f}, new float[]{-0.002079f, 0.048952f, 0.953127f}};

    private CamUtils() {
    }

    static int intFromLStar(float f7) {
        if (f7 < 1.0f) {
            return -16777216;
        }
        if (f7 > 99.0f) {
            return -1;
        }
        float f8 = (f7 + 16.0f) / 116.0f;
        float f9 = (f7 > 8.0f ? 1 : (f7 == 8.0f ? 0 : -1)) > 0 ? f8 * f8 * f8 : f7 / 903.2963f;
        float f10 = f8 * f8 * f8;
        boolean z7 = f10 > 0.008856452f;
        float f11 = z7 ? f10 : ((f8 * 116.0f) - 16.0f) / 903.2963f;
        if (!z7) {
            f10 = ((f8 * 116.0f) - 16.0f) / 903.2963f;
        }
        float[] fArr = WHITE_POINT_D65;
        return ColorUtils.XYZToColor((double) (f11 * fArr[0]), (double) (f9 * fArr[1]), (double) (f10 * fArr[2]));
    }

    static float lStarFromInt(int i7) {
        return lStarFromY(yFromInt(i7));
    }

    static float lStarFromY(float f7) {
        float f8 = f7 / 100.0f;
        return f8 <= 0.008856452f ? f8 * 903.2963f : (((float) Math.cbrt((double) f8)) * 116.0f) - 16.0f;
    }

    static float lerp(float f7, float f8, float f9) {
        return f7 + ((f8 - f7) * f9);
    }

    static float linearized(int i7) {
        float f7 = ((float) i7) / 255.0f;
        return (f7 <= 0.04045f ? f7 / 12.92f : (float) Math.pow((double) ((f7 + 0.055f) / 1.055f), 2.4000000953674316d)) * 100.0f;
    }

    @NonNull
    static float[] xyzFromInt(int i7) {
        float linearized = linearized(Color.red(i7));
        float linearized2 = linearized(Color.green(i7));
        float linearized3 = linearized(Color.blue(i7));
        float[][] fArr = SRGB_TO_XYZ;
        float[] fArr2 = fArr[0];
        float f7 = (fArr2[0] * linearized) + (fArr2[1] * linearized2) + (fArr2[2] * linearized3);
        float[] fArr3 = fArr[1];
        float f8 = (fArr3[0] * linearized) + (fArr3[1] * linearized2) + (fArr3[2] * linearized3);
        float[] fArr4 = fArr[2];
        return new float[]{f7, f8, (linearized * fArr4[0]) + (linearized2 * fArr4[1]) + (linearized3 * fArr4[2])};
    }

    static float yFromInt(int i7) {
        float linearized = linearized(Color.red(i7));
        float linearized2 = linearized(Color.green(i7));
        float linearized3 = linearized(Color.blue(i7));
        float[] fArr = SRGB_TO_XYZ[1];
        return (linearized * fArr[0]) + (linearized2 * fArr[1]) + (linearized3 * fArr[2]);
    }

    static float yFromLStar(float f7) {
        return (f7 > 8.0f ? (float) Math.pow((((double) f7) + 16.0d) / 116.0d, 3.0d) : f7 / 903.2963f) * 100.0f;
    }
}
