package androidx.core.graphics;

import android.graphics.Path;
import android.graphics.PointF;
import androidx.annotation.DoNotInline;
import androidx.annotation.FloatRange;
import androidx.annotation.NonNull;
import androidx.annotation.RequiresApi;
import java.util.ArrayList;
import java.util.Collection;

public final class PathUtils {

    /* access modifiers changed from: package-private */
    @RequiresApi(26)
    public static class Api26Impl {
        private Api26Impl() {
        }

        @DoNotInline
        static float[] approximate(Path path, float f7) {
            return path.approximate(f7);
        }
    }

    private PathUtils() {
    }

    @NonNull
    @RequiresApi(26)
    public static Collection<PathSegment> flatten(@NonNull Path path) {
        return flatten(path, 0.5f);
    }

    @NonNull
    @RequiresApi(26)
    public static Collection<PathSegment> flatten(@NonNull Path path, @FloatRange(from = 0.0d) float f7) {
        float[] approximate = Api26Impl.approximate(path, f7);
        int length = approximate.length / 3;
        ArrayList arrayList = new ArrayList(length);
        for (int i7 = 1; i7 < length; i7++) {
            int i8 = i7 * 3;
            int i9 = (i7 - 1) * 3;
            float f8 = approximate[i8];
            float f9 = approximate[i8 + 1];
            float f10 = approximate[i8 + 2];
            float f11 = approximate[i9];
            float f12 = approximate[i9 + 1];
            float f13 = approximate[i9 + 2];
            if (!(f8 == f11 || (f9 == f12 && f10 == f13))) {
                arrayList.add(new PathSegment(new PointF(f12, f13), f11, new PointF(f9, f10), f8));
            }
        }
        return arrayList;
    }
}
