package androidx.core.location;

import android.location.GnssStatus;
import androidx.annotation.DoNotInline;
import androidx.annotation.RequiresApi;
import androidx.annotation.RestrictTo;
import androidx.core.util.Preconditions;

/* access modifiers changed from: package-private */
@RequiresApi(24)
@RestrictTo({RestrictTo.Scope.LIBRARY})
public class GnssStatusWrapper extends GnssStatusCompat {
    private final GnssStatus mWrapped;

    @RequiresApi(26)
    static class Api26Impl {
        private Api26Impl() {
        }

        @DoNotInline
        static float getCarrierFrequencyHz(GnssStatus gnssStatus, int i7) {
            return gnssStatus.getCarrierFrequencyHz(i7);
        }

        @DoNotInline
        static boolean hasCarrierFrequencyHz(GnssStatus gnssStatus, int i7) {
            return gnssStatus.hasCarrierFrequencyHz(i7);
        }
    }

    @RequiresApi(30)
    static class Api30Impl {
        private Api30Impl() {
        }

        @DoNotInline
        static float getBasebandCn0DbHz(GnssStatus gnssStatus, int i7) {
            return gnssStatus.getBasebandCn0DbHz(i7);
        }

        @DoNotInline
        static boolean hasBasebandCn0DbHz(GnssStatus gnssStatus, int i7) {
            return gnssStatus.hasBasebandCn0DbHz(i7);
        }
    }

    GnssStatusWrapper(Object obj) {
        this.mWrapped = (GnssStatus) Preconditions.checkNotNull((GnssStatus) obj);
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (!(obj instanceof GnssStatusWrapper)) {
            return false;
        }
        return this.mWrapped.equals(((GnssStatusWrapper) obj).mWrapped);
    }

    @Override // androidx.core.location.GnssStatusCompat
    public float getAzimuthDegrees(int i7) {
        return this.mWrapped.getAzimuthDegrees(i7);
    }

    @Override // androidx.core.location.GnssStatusCompat
    public float getBasebandCn0DbHz(int i7) {
        return Api30Impl.getBasebandCn0DbHz(this.mWrapped, i7);
    }

    @Override // androidx.core.location.GnssStatusCompat
    public float getCarrierFrequencyHz(int i7) {
        return Api26Impl.getCarrierFrequencyHz(this.mWrapped, i7);
    }

    @Override // androidx.core.location.GnssStatusCompat
    public float getCn0DbHz(int i7) {
        return this.mWrapped.getCn0DbHz(i7);
    }

    @Override // androidx.core.location.GnssStatusCompat
    public int getConstellationType(int i7) {
        return this.mWrapped.getConstellationType(i7);
    }

    @Override // androidx.core.location.GnssStatusCompat
    public float getElevationDegrees(int i7) {
        return this.mWrapped.getElevationDegrees(i7);
    }

    @Override // androidx.core.location.GnssStatusCompat
    public int getSatelliteCount() {
        return this.mWrapped.getSatelliteCount();
    }

    @Override // androidx.core.location.GnssStatusCompat
    public int getSvid(int i7) {
        return this.mWrapped.getSvid(i7);
    }

    @Override // androidx.core.location.GnssStatusCompat
    public boolean hasAlmanacData(int i7) {
        return this.mWrapped.hasAlmanacData(i7);
    }

    @Override // androidx.core.location.GnssStatusCompat
    public boolean hasBasebandCn0DbHz(int i7) {
        return Api30Impl.hasBasebandCn0DbHz(this.mWrapped, i7);
    }

    @Override // androidx.core.location.GnssStatusCompat
    public boolean hasCarrierFrequencyHz(int i7) {
        return Api26Impl.hasCarrierFrequencyHz(this.mWrapped, i7);
    }

    @Override // androidx.core.location.GnssStatusCompat
    public boolean hasEphemerisData(int i7) {
        return this.mWrapped.hasEphemerisData(i7);
    }

    public int hashCode() {
        return this.mWrapped.hashCode();
    }

    @Override // androidx.core.location.GnssStatusCompat
    public boolean usedInFix(int i7) {
        return this.mWrapped.usedInFix(i7);
    }
}
