package androidx.core.location;

import android.annotation.SuppressLint;
import android.location.LocationRequest;
import android.os.Build;
import androidx.annotation.FloatRange;
import androidx.annotation.IntRange;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.annotation.RequiresApi;
import androidx.annotation.RestrictTo;
import androidx.core.util.Preconditions;
import androidx.core.util.TimeUtils;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;

public final class LocationRequestCompat {
    private static final long IMPLICIT_MIN_UPDATE_INTERVAL = -1;
    public static final long PASSIVE_INTERVAL = Long.MAX_VALUE;
    public static final int QUALITY_BALANCED_POWER_ACCURACY = 102;
    public static final int QUALITY_HIGH_ACCURACY = 100;
    public static final int QUALITY_LOW_POWER = 104;
    final long mDurationMillis;
    final long mIntervalMillis;
    final long mMaxUpdateDelayMillis;
    final int mMaxUpdates;
    final float mMinUpdateDistanceMeters;
    final long mMinUpdateIntervalMillis;
    final int mQuality;

    @RequiresApi(19)
    private static class Api19Impl {
        private static Method sCreateFromDeprecatedProviderMethod;
        private static Class<?> sLocationRequestClass;
        private static Method sSetExpireInMethod;
        private static Method sSetFastestIntervalMethod;
        private static Method sSetNumUpdatesMethod;
        private static Method sSetQualityMethod;

        private Api19Impl() {
        }

        public static Object toLocationRequest(LocationRequestCompat locationRequestCompat, String str) {
            try {
                if (sLocationRequestClass == null) {
                    sLocationRequestClass = Class.forName("android.location.LocationRequest");
                }
                if (sCreateFromDeprecatedProviderMethod == null) {
                    Method declaredMethod = sLocationRequestClass.getDeclaredMethod("createFromDeprecatedProvider", String.class, Long.TYPE, Float.TYPE, Boolean.TYPE);
                    sCreateFromDeprecatedProviderMethod = declaredMethod;
                    declaredMethod.setAccessible(true);
                }
                Object invoke = sCreateFromDeprecatedProviderMethod.invoke(null, str, Long.valueOf(locationRequestCompat.getIntervalMillis()), Float.valueOf(locationRequestCompat.getMinUpdateDistanceMeters()), Boolean.FALSE);
                if (invoke == null) {
                    return null;
                }
                if (sSetQualityMethod == null) {
                    Method declaredMethod2 = sLocationRequestClass.getDeclaredMethod("setQuality", Integer.TYPE);
                    sSetQualityMethod = declaredMethod2;
                    declaredMethod2.setAccessible(true);
                }
                sSetQualityMethod.invoke(invoke, Integer.valueOf(locationRequestCompat.getQuality()));
                if (sSetFastestIntervalMethod == null) {
                    Method declaredMethod3 = sLocationRequestClass.getDeclaredMethod("setFastestInterval", Long.TYPE);
                    sSetFastestIntervalMethod = declaredMethod3;
                    declaredMethod3.setAccessible(true);
                }
                sSetFastestIntervalMethod.invoke(invoke, Long.valueOf(locationRequestCompat.getMinUpdateIntervalMillis()));
                if (locationRequestCompat.getMaxUpdates() < Integer.MAX_VALUE) {
                    if (sSetNumUpdatesMethod == null) {
                        Method declaredMethod4 = sLocationRequestClass.getDeclaredMethod("setNumUpdates", Integer.TYPE);
                        sSetNumUpdatesMethod = declaredMethod4;
                        declaredMethod4.setAccessible(true);
                    }
                    sSetNumUpdatesMethod.invoke(invoke, Integer.valueOf(locationRequestCompat.getMaxUpdates()));
                }
                if (locationRequestCompat.getDurationMillis() < Long.MAX_VALUE) {
                    if (sSetExpireInMethod == null) {
                        Method declaredMethod5 = sLocationRequestClass.getDeclaredMethod("setExpireIn", Long.TYPE);
                        sSetExpireInMethod = declaredMethod5;
                        declaredMethod5.setAccessible(true);
                    }
                    sSetExpireInMethod.invoke(invoke, Long.valueOf(locationRequestCompat.getDurationMillis()));
                }
                return invoke;
            } catch (ClassNotFoundException | IllegalAccessException | NoSuchMethodException | InvocationTargetException unused) {
                return null;
            }
        }
    }

    /* access modifiers changed from: private */
    @RequiresApi(31)
    public static class Api31Impl {
        private Api31Impl() {
        }

        /*  JADX ERROR: JadxRuntimeException in pass: InlineMethods
            jadx.core.utils.exceptions.JadxRuntimeException: Failed to process method for inline: androidx.core.location.f0.a():void
            	at jadx.core.dex.visitors.InlineMethods.processInvokeInsn(InlineMethods.java:68)
            	at jadx.core.dex.visitors.InlineMethods.visit(InlineMethods.java:43)
            Caused by: java.lang.IndexOutOfBoundsException: Index: 0, Size: 0
            	at java.util.ArrayList.rangeCheck(ArrayList.java:659)
            	at java.util.ArrayList.get(ArrayList.java:435)
            	at jadx.core.dex.visitors.MarkMethodsForInline.inlineMth(MarkMethodsForInline.java:82)
            	at jadx.core.dex.visitors.MarkMethodsForInline.process(MarkMethodsForInline.java:58)
            	at jadx.core.dex.visitors.InlineMethods.processInvokeInsn(InlineMethods.java:57)
            	... 1 more
            */
        @androidx.annotation.DoNotInline
        public static android.location.LocationRequest toLocationRequest(androidx.core.location.LocationRequestCompat r3) {
            /*
                androidx.core.location.f0.a()
                long r0 = r3.getIntervalMillis()
                android.location.LocationRequest$Builder r0 = androidx.core.location.e0.a(r0)
                int r1 = r3.getQuality()
                android.location.LocationRequest$Builder r0 = androidx.core.location.x.a(r0, r1)
                long r1 = r3.getMinUpdateIntervalMillis()
                android.location.LocationRequest$Builder r0 = androidx.core.location.y.a(r0, r1)
                long r1 = r3.getDurationMillis()
                android.location.LocationRequest$Builder r0 = androidx.core.location.z.a(r0, r1)
                int r1 = r3.getMaxUpdates()
                android.location.LocationRequest$Builder r0 = androidx.core.location.a0.a(r0, r1)
                float r1 = r3.getMinUpdateDistanceMeters()
                android.location.LocationRequest$Builder r0 = androidx.core.location.b0.a(r0, r1)
                long r1 = r3.getMaxUpdateDelayMillis()
                android.location.LocationRequest$Builder r3 = androidx.core.location.c0.a(r0, r1)
                android.location.LocationRequest r3 = androidx.core.location.d0.a(r3)
                return r3
            */
            throw new UnsupportedOperationException("Method not decompiled: androidx.core.location.LocationRequestCompat.Api31Impl.toLocationRequest(androidx.core.location.LocationRequestCompat):android.location.LocationRequest");
        }
    }

    public static final class Builder {
        private long mDurationMillis;
        private long mIntervalMillis;
        private long mMaxUpdateDelayMillis;
        private int mMaxUpdates;
        private float mMinUpdateDistanceMeters;
        private long mMinUpdateIntervalMillis;
        private int mQuality;

        public Builder(long j7) {
            setIntervalMillis(j7);
            this.mQuality = 102;
            this.mDurationMillis = Long.MAX_VALUE;
            this.mMaxUpdates = Integer.MAX_VALUE;
            this.mMinUpdateIntervalMillis = -1;
            this.mMinUpdateDistanceMeters = 0.0f;
            this.mMaxUpdateDelayMillis = 0;
        }

        @NonNull
        public LocationRequestCompat build() {
            Preconditions.checkState((this.mIntervalMillis == Long.MAX_VALUE && this.mMinUpdateIntervalMillis == -1) ? false : true, "passive location requests must have an explicit minimum update interval");
            long j7 = this.mIntervalMillis;
            return new LocationRequestCompat(j7, this.mQuality, this.mDurationMillis, this.mMaxUpdates, Math.min(this.mMinUpdateIntervalMillis, j7), this.mMinUpdateDistanceMeters, this.mMaxUpdateDelayMillis);
        }

        @NonNull
        public Builder clearMinUpdateIntervalMillis() {
            this.mMinUpdateIntervalMillis = -1;
            return this;
        }

        @NonNull
        public Builder setDurationMillis(@IntRange(from = 1) long j7) {
            this.mDurationMillis = Preconditions.checkArgumentInRange(j7, 1L, Long.MAX_VALUE, "durationMillis");
            return this;
        }

        @NonNull
        public Builder setIntervalMillis(@IntRange(from = 0) long j7) {
            this.mIntervalMillis = Preconditions.checkArgumentInRange(j7, 0L, Long.MAX_VALUE, "intervalMillis");
            return this;
        }

        @NonNull
        public Builder setMaxUpdateDelayMillis(@IntRange(from = 0) long j7) {
            this.mMaxUpdateDelayMillis = j7;
            this.mMaxUpdateDelayMillis = Preconditions.checkArgumentInRange(j7, 0L, Long.MAX_VALUE, "maxUpdateDelayMillis");
            return this;
        }

        @NonNull
        public Builder setMaxUpdates(@IntRange(from = 1, to = 2147483647L) int i7) {
            this.mMaxUpdates = Preconditions.checkArgumentInRange(i7, 1, Integer.MAX_VALUE, "maxUpdates");
            return this;
        }

        @NonNull
        public Builder setMinUpdateDistanceMeters(@FloatRange(from = 0.0d, to = 3.4028234663852886E38d) float f7) {
            this.mMinUpdateDistanceMeters = f7;
            this.mMinUpdateDistanceMeters = Preconditions.checkArgumentInRange(f7, 0.0f, Float.MAX_VALUE, "minUpdateDistanceMeters");
            return this;
        }

        @NonNull
        public Builder setMinUpdateIntervalMillis(@IntRange(from = 0) long j7) {
            this.mMinUpdateIntervalMillis = Preconditions.checkArgumentInRange(j7, 0L, Long.MAX_VALUE, "minUpdateIntervalMillis");
            return this;
        }

        @NonNull
        public Builder setQuality(int i7) {
            Preconditions.checkArgument(i7 == 104 || i7 == 102 || i7 == 100, "quality must be a defined QUALITY constant, not %d", Integer.valueOf(i7));
            this.mQuality = i7;
            return this;
        }

        public Builder(@NonNull LocationRequestCompat locationRequestCompat) {
            this.mIntervalMillis = locationRequestCompat.mIntervalMillis;
            this.mQuality = locationRequestCompat.mQuality;
            this.mDurationMillis = locationRequestCompat.mDurationMillis;
            this.mMaxUpdates = locationRequestCompat.mMaxUpdates;
            this.mMinUpdateIntervalMillis = locationRequestCompat.mMinUpdateIntervalMillis;
            this.mMinUpdateDistanceMeters = locationRequestCompat.mMinUpdateDistanceMeters;
            this.mMaxUpdateDelayMillis = locationRequestCompat.mMaxUpdateDelayMillis;
        }
    }

    @Retention(RetentionPolicy.SOURCE)
    @RestrictTo({RestrictTo.Scope.LIBRARY})
    public @interface Quality {
    }

    LocationRequestCompat(long j7, int i7, long j8, int i8, long j9, float f7, long j10) {
        this.mIntervalMillis = j7;
        this.mQuality = i7;
        this.mMinUpdateIntervalMillis = j9;
        this.mDurationMillis = j8;
        this.mMaxUpdates = i8;
        this.mMinUpdateDistanceMeters = f7;
        this.mMaxUpdateDelayMillis = j10;
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (!(obj instanceof LocationRequestCompat)) {
            return false;
        }
        LocationRequestCompat locationRequestCompat = (LocationRequestCompat) obj;
        return this.mQuality == locationRequestCompat.mQuality && this.mIntervalMillis == locationRequestCompat.mIntervalMillis && this.mMinUpdateIntervalMillis == locationRequestCompat.mMinUpdateIntervalMillis && this.mDurationMillis == locationRequestCompat.mDurationMillis && this.mMaxUpdates == locationRequestCompat.mMaxUpdates && Float.compare(locationRequestCompat.mMinUpdateDistanceMeters, this.mMinUpdateDistanceMeters) == 0 && this.mMaxUpdateDelayMillis == locationRequestCompat.mMaxUpdateDelayMillis;
    }

    @IntRange(from = 1)
    public long getDurationMillis() {
        return this.mDurationMillis;
    }

    @IntRange(from = 0)
    public long getIntervalMillis() {
        return this.mIntervalMillis;
    }

    @IntRange(from = 0)
    public long getMaxUpdateDelayMillis() {
        return this.mMaxUpdateDelayMillis;
    }

    @IntRange(from = 1, to = 2147483647L)
    public int getMaxUpdates() {
        return this.mMaxUpdates;
    }

    @FloatRange(from = 0.0d, to = 3.4028234663852886E38d)
    public float getMinUpdateDistanceMeters() {
        return this.mMinUpdateDistanceMeters;
    }

    @IntRange(from = 0)
    public long getMinUpdateIntervalMillis() {
        long j7 = this.mMinUpdateIntervalMillis;
        return j7 == -1 ? this.mIntervalMillis : j7;
    }

    public int getQuality() {
        return this.mQuality;
    }

    public int hashCode() {
        long j7 = this.mIntervalMillis;
        long j8 = this.mMinUpdateIntervalMillis;
        return (((this.mQuality * 31) + ((int) (j7 ^ (j7 >>> 32)))) * 31) + ((int) (j8 ^ (j8 >>> 32)));
    }

    @NonNull
    @RequiresApi(31)
    public LocationRequest toLocationRequest() {
        return Api31Impl.toLocationRequest(this);
    }

    /* JADX WARNING: Removed duplicated region for block: B:15:0x0042  */
    /* JADX WARNING: Removed duplicated region for block: B:18:0x0053  */
    /* JADX WARNING: Removed duplicated region for block: B:26:0x007e  */
    /* JADX WARNING: Removed duplicated region for block: B:29:0x0093  */
    @NonNull
    public String toString() {
        String str;
        StringBuilder sb = new StringBuilder();
        sb.append("Request[");
        if (this.mIntervalMillis != Long.MAX_VALUE) {
            sb.append("@");
            TimeUtils.formatDuration(this.mIntervalMillis, sb);
            int i7 = this.mQuality;
            if (i7 == 100) {
                str = " HIGH_ACCURACY";
            } else if (i7 != 102) {
                if (i7 == 104) {
                    str = " LOW_POWER";
                }
                if (this.mDurationMillis != Long.MAX_VALUE) {
                    sb.append(", duration=");
                    TimeUtils.formatDuration(this.mDurationMillis, sb);
                }
                if (this.mMaxUpdates != Integer.MAX_VALUE) {
                    sb.append(", maxUpdates=");
                    sb.append(this.mMaxUpdates);
                }
                long j7 = this.mMinUpdateIntervalMillis;
                if (j7 != -1 && j7 < this.mIntervalMillis) {
                    sb.append(", minUpdateInterval=");
                    TimeUtils.formatDuration(this.mMinUpdateIntervalMillis, sb);
                }
                if (((double) this.mMinUpdateDistanceMeters) > 0.0d) {
                    sb.append(", minUpdateDistance=");
                    sb.append(this.mMinUpdateDistanceMeters);
                }
                if (this.mMaxUpdateDelayMillis / 2 > this.mIntervalMillis) {
                    sb.append(", maxUpdateDelay=");
                    TimeUtils.formatDuration(this.mMaxUpdateDelayMillis, sb);
                }
                sb.append(']');
                return sb.toString();
            } else {
                str = " BALANCED";
            }
        } else {
            str = "PASSIVE";
        }
        sb.append(str);
        if (this.mDurationMillis != Long.MAX_VALUE) {
        }
        if (this.mMaxUpdates != Integer.MAX_VALUE) {
        }
        long j72 = this.mMinUpdateIntervalMillis;
        sb.append(", minUpdateInterval=");
        TimeUtils.formatDuration(this.mMinUpdateIntervalMillis, sb);
        if (((double) this.mMinUpdateDistanceMeters) > 0.0d) {
        }
        if (this.mMaxUpdateDelayMillis / 2 > this.mIntervalMillis) {
        }
        sb.append(']');
        return sb.toString();
    }

    @Nullable
    @RequiresApi(19)
    @SuppressLint({"NewApi"})
    public LocationRequest toLocationRequest(@NonNull String str) {
        return Build.VERSION.SDK_INT >= 31 ? toLocationRequest() : w.a(Api19Impl.toLocationRequest(this, str));
    }
}
