package androidx.core.math;

public class MathUtils {
    private MathUtils() {
    }

    public static int addExact(int i7, int i8) {
        int i9 = i7 + i8;
        if (((i7 ^ i9) & (i8 ^ i9)) >= 0) {
            return i9;
        }
        throw new ArithmeticException("integer overflow");
    }

    public static double clamp(double d7, double d8, double d9) {
        if (d7 < d8) {
            return d8;
        }
        return d7 > d9 ? d9 : d7;
    }

    public static int decrementExact(int i7) {
        if (i7 != Integer.MIN_VALUE) {
            return i7 - 1;
        }
        throw new ArithmeticException("integer overflow");
    }

    public static int incrementExact(int i7) {
        if (i7 != Integer.MAX_VALUE) {
            return i7 + 1;
        }
        throw new ArithmeticException("integer overflow");
    }

    public static int multiplyExact(int i7, int i8) {
        long j7 = ((long) i7) * ((long) i8);
        int i9 = (int) j7;
        if (((long) i9) == j7) {
            return i9;
        }
        throw new ArithmeticException("integer overflow");
    }

    public static int negateExact(int i7) {
        if (i7 != Integer.MIN_VALUE) {
            return -i7;
        }
        throw new ArithmeticException("integer overflow");
    }

    public static int subtractExact(int i7, int i8) {
        int i9 = i7 - i8;
        if (((i7 ^ i9) & (i8 ^ i7)) >= 0) {
            return i9;
        }
        throw new ArithmeticException("integer overflow");
    }

    public static int toIntExact(long j7) {
        int i7 = (int) j7;
        if (((long) i7) == j7) {
            return i7;
        }
        throw new ArithmeticException("integer overflow");
    }

    public static long addExact(long j7, long j8) {
        long j9 = j7 + j8;
        if (((j7 ^ j9) & (j8 ^ j9)) >= 0) {
            return j9;
        }
        throw new ArithmeticException("long overflow");
    }

    public static float clamp(float f7, float f8, float f9) {
        if (f7 < f8) {
            return f8;
        }
        return f7 > f9 ? f9 : f7;
    }

    public static long decrementExact(long j7) {
        if (j7 != Long.MIN_VALUE) {
            return j7 - 1;
        }
        throw new ArithmeticException("long overflow");
    }

    public static long incrementExact(long j7) {
        if (j7 != Long.MAX_VALUE) {
            return j7 + 1;
        }
        throw new ArithmeticException("long overflow");
    }

    public static long multiplyExact(long j7, long j8) {
        long j9 = j7 * j8;
        if (((Math.abs(j7) | Math.abs(j8)) >>> 31) == 0 || ((j8 == 0 || j9 / j8 == j7) && (j7 != Long.MIN_VALUE || j8 != -1))) {
            return j9;
        }
        throw new ArithmeticException("long overflow");
    }

    public static long negateExact(long j7) {
        if (j7 != Long.MIN_VALUE) {
            return -j7;
        }
        throw new ArithmeticException("long overflow");
    }

    public static long subtractExact(long j7, long j8) {
        long j9 = j7 - j8;
        if (((j7 ^ j9) & (j8 ^ j7)) >= 0) {
            return j9;
        }
        throw new ArithmeticException("long overflow");
    }

    public static int clamp(int i7, int i8, int i9) {
        if (i7 < i8) {
            return i8;
        }
        return i7 > i9 ? i9 : i7;
    }

    public static long clamp(long j7, long j8, long j9) {
        if (j7 < j8) {
            return j8;
        }
        return j7 > j9 ? j9 : j7;
    }
}
