package androidx.core.util;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

public final class Pools {

    public interface Pool<T> {
        @Nullable
        T acquire();

        boolean release(@NonNull T t7);
    }

    public static class SimplePool<T> implements Pool<T> {
        private final Object[] mPool;
        private int mPoolSize;

        public SimplePool(int i7) {
            if (i7 > 0) {
                this.mPool = new Object[i7];
                return;
            }
            throw new IllegalArgumentException("The max pool size must be > 0");
        }

        private boolean isInPool(@NonNull T t7) {
            for (int i7 = 0; i7 < this.mPoolSize; i7++) {
                if (this.mPool[i7] == t7) {
                    return true;
                }
            }
            return false;
        }

        @Override // androidx.core.util.Pools.Pool
        public T acquire() {
            int i7 = this.mPoolSize;
            if (i7 <= 0) {
                return null;
            }
            int i8 = i7 - 1;
            Object[] objArr = this.mPool;
            T t7 = (T) objArr[i8];
            objArr[i8] = null;
            this.mPoolSize = i7 - 1;
            return t7;
        }

        @Override // androidx.core.util.Pools.Pool
        public boolean release(@NonNull T t7) {
            if (!isInPool(t7)) {
                int i7 = this.mPoolSize;
                Object[] objArr = this.mPool;
                if (i7 >= objArr.length) {
                    return false;
                }
                objArr[i7] = t7;
                this.mPoolSize = i7 + 1;
                return true;
            }
            throw new IllegalStateException("Already in the pool!");
        }
    }

    public static class SynchronizedPool<T> extends SimplePool<T> {
        private final Object mLock = new Object();

        public SynchronizedPool(int i7) {
            super(i7);
        }

        @Override // androidx.core.util.Pools.SimplePool, androidx.core.util.Pools.Pool
        public T acquire() {
            T t7;
            synchronized (this.mLock) {
                t7 = (T) super.acquire();
            }
            return t7;
        }

        @Override // androidx.core.util.Pools.SimplePool, androidx.core.util.Pools.Pool
        public boolean release(@NonNull T t7) {
            boolean release;
            synchronized (this.mLock) {
                release = super.release(t7);
            }
            return release;
        }
    }

    private Pools() {
    }
}
