package androidx.core.util;

import android.text.TextUtils;
import androidx.annotation.IntRange;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.annotation.RestrictTo;
import java.util.Locale;

@RestrictTo({RestrictTo.Scope.LIBRARY_GROUP_PREFIX})
public final class Preconditions {
    private Preconditions() {
    }

    public static void checkArgument(boolean z7) {
        if (!z7) {
            throw new IllegalArgumentException();
        }
    }

    public static float checkArgumentFinite(float f7, @NonNull String str) {
        if (Float.isNaN(f7)) {
            throw new IllegalArgumentException(str + " must not be NaN");
        } else if (!Float.isInfinite(f7)) {
            return f7;
        } else {
            throw new IllegalArgumentException(str + " must not be infinite");
        }
    }

    public static double checkArgumentInRange(double d7, double d8, double d9, @NonNull String str) {
        if (d7 < d8) {
            throw new IllegalArgumentException(String.format(Locale.US, "%s is out of range of [%f, %f] (too low)", str, Double.valueOf(d8), Double.valueOf(d9)));
        } else if (d7 <= d9) {
            return d7;
        } else {
            throw new IllegalArgumentException(String.format(Locale.US, "%s is out of range of [%f, %f] (too high)", str, Double.valueOf(d8), Double.valueOf(d9)));
        }
    }

    @IntRange(from = 0)
    public static int checkArgumentNonnegative(int i7) {
        if (i7 >= 0) {
            return i7;
        }
        throw new IllegalArgumentException();
    }

    public static int checkFlagsArgument(int i7, int i8) {
        if ((i7 & i8) == i7) {
            return i7;
        }
        throw new IllegalArgumentException("Requested flags 0x" + Integer.toHexString(i7) + ", but only 0x" + Integer.toHexString(i8) + " are allowed");
    }

    @NonNull
    public static <T> T checkNotNull(@Nullable T t7) {
        t7.getClass();
        return t7;
    }

    public static void checkState(boolean z7) {
        checkState(z7, null);
    }

    @NonNull
    public static <T extends CharSequence> T checkStringNotEmpty(@Nullable T t7) {
        if (!TextUtils.isEmpty(t7)) {
            return t7;
        }
        throw new IllegalArgumentException();
    }

    public static void checkArgument(boolean z7, @NonNull Object obj) {
        if (!z7) {
            throw new IllegalArgumentException(String.valueOf(obj));
        }
    }

    public static float checkArgumentInRange(float f7, float f8, float f9, @NonNull String str) {
        if (f7 < f8) {
            throw new IllegalArgumentException(String.format(Locale.US, "%s is out of range of [%f, %f] (too low)", str, Float.valueOf(f8), Float.valueOf(f9)));
        } else if (f7 <= f9) {
            return f7;
        } else {
            throw new IllegalArgumentException(String.format(Locale.US, "%s is out of range of [%f, %f] (too high)", str, Float.valueOf(f8), Float.valueOf(f9)));
        }
    }

    @IntRange(from = 0)
    public static int checkArgumentNonnegative(int i7, @Nullable String str) {
        if (i7 >= 0) {
            return i7;
        }
        throw new IllegalArgumentException(str);
    }

    @NonNull
    public static <T> T checkNotNull(@Nullable T t7, @NonNull Object obj) {
        if (t7 != null) {
            return t7;
        }
        throw new NullPointerException(String.valueOf(obj));
    }

    public static void checkState(boolean z7, @Nullable String str) {
        if (!z7) {
            throw new IllegalStateException(str);
        }
    }

    @NonNull
    public static <T extends CharSequence> T checkStringNotEmpty(@Nullable T t7, @NonNull Object obj) {
        if (!TextUtils.isEmpty(t7)) {
            return t7;
        }
        throw new IllegalArgumentException(String.valueOf(obj));
    }

    public static void checkArgument(boolean z7, @NonNull String str, @NonNull Object... objArr) {
        if (!z7) {
            throw new IllegalArgumentException(String.format(str, objArr));
        }
    }

    public static int checkArgumentInRange(int i7, int i8, int i9, @NonNull String str) {
        if (i7 < i8) {
            throw new IllegalArgumentException(String.format(Locale.US, "%s is out of range of [%d, %d] (too low)", str, Integer.valueOf(i8), Integer.valueOf(i9)));
        } else if (i7 <= i9) {
            return i7;
        } else {
            throw new IllegalArgumentException(String.format(Locale.US, "%s is out of range of [%d, %d] (too high)", str, Integer.valueOf(i8), Integer.valueOf(i9)));
        }
    }

    @NonNull
    public static <T extends CharSequence> T checkStringNotEmpty(@Nullable T t7, @NonNull String str, @NonNull Object... objArr) {
        if (!TextUtils.isEmpty(t7)) {
            return t7;
        }
        throw new IllegalArgumentException(String.format(str, objArr));
    }

    public static long checkArgumentInRange(long j7, long j8, long j9, @NonNull String str) {
        if (j7 < j8) {
            throw new IllegalArgumentException(String.format(Locale.US, "%s is out of range of [%d, %d] (too low)", str, Long.valueOf(j8), Long.valueOf(j9)));
        } else if (j7 <= j9) {
            return j7;
        } else {
            throw new IllegalArgumentException(String.format(Locale.US, "%s is out of range of [%d, %d] (too high)", str, Long.valueOf(j8), Long.valueOf(j9)));
        }
    }
}
