package androidx.core.view.animation;

import android.graphics.Path;
import android.graphics.PathMeasure;
import android.view.animation.Interpolator;

class PathInterpolatorApi14 implements Interpolator {
    private static final float PRECISION = 0.002f;
    private final float[] mX;
    private final float[] mY;

    PathInterpolatorApi14(float f7, float f8) {
        this(createQuad(f7, f8));
    }

    private static Path createCubic(float f7, float f8, float f9, float f10) {
        Path path = new Path();
        path.moveTo(0.0f, 0.0f);
        path.cubicTo(f7, f8, f9, f10, 1.0f, 1.0f);
        return path;
    }

    private static Path createQuad(float f7, float f8) {
        Path path = new Path();
        path.moveTo(0.0f, 0.0f);
        path.quadTo(f7, f8, 1.0f, 1.0f);
        return path;
    }

    public float getInterpolation(float f7) {
        if (f7 <= 0.0f) {
            return 0.0f;
        }
        if (f7 >= 1.0f) {
            return 1.0f;
        }
        int length = this.mX.length - 1;
        int i7 = 0;
        while (length - i7 > 1) {
            int i8 = (i7 + length) / 2;
            if (f7 < this.mX[i8]) {
                length = i8;
            } else {
                i7 = i8;
            }
        }
        float[] fArr = this.mX;
        float f8 = fArr[length];
        float f9 = fArr[i7];
        float f10 = f8 - f9;
        if (f10 == 0.0f) {
            return this.mY[i7];
        }
        float[] fArr2 = this.mY;
        float f11 = fArr2[i7];
        return f11 + (((f7 - f9) / f10) * (fArr2[length] - f11));
    }

    PathInterpolatorApi14(float f7, float f8, float f9, float f10) {
        this(createCubic(f7, f8, f9, f10));
    }

    PathInterpolatorApi14(Path path) {
        PathMeasure pathMeasure = new PathMeasure(path, false);
        float length = pathMeasure.getLength();
        int i7 = ((int) (length / 0.002f)) + 1;
        this.mX = new float[i7];
        this.mY = new float[i7];
        float[] fArr = new float[2];
        for (int i8 = 0; i8 < i7; i8++) {
            pathMeasure.getPosTan((((float) i8) * length) / ((float) (i7 - 1)), fArr, null);
            this.mX[i8] = fArr[0];
            this.mY[i8] = fArr[1];
        }
    }
}
