package androidx.core.view.animation;

import android.graphics.Path;
import android.view.animation.Interpolator;
import android.view.animation.PathInterpolator;
import androidx.annotation.DoNotInline;
import androidx.annotation.NonNull;
import androidx.annotation.RequiresApi;

public final class PathInterpolatorCompat {

    @RequiresApi(21)
    static class Api21Impl {
        private Api21Impl() {
        }

        @DoNotInline
        static PathInterpolator createPathInterpolator(float f7, float f8) {
            return new PathInterpolator(f7, f8);
        }

        @DoNotInline
        static PathInterpolator createPathInterpolator(float f7, float f8, float f9, float f10) {
            return new PathInterpolator(f7, f8, f9, f10);
        }

        @DoNotInline
        static PathInterpolator createPathInterpolator(Path path) {
            return new PathInterpolator(path);
        }
    }

    private PathInterpolatorCompat() {
    }

    @NonNull
    public static Interpolator create(float f7, float f8) {
        return Api21Impl.createPathInterpolator(f7, f8);
    }

    @NonNull
    public static Interpolator create(float f7, float f8, float f9, float f10) {
        return Api21Impl.createPathInterpolator(f7, f8, f9, f10);
    }

    @NonNull
    public static Interpolator create(@NonNull Path path) {
        return Api21Impl.createPathInterpolator(path);
    }
}
