package androidx.dynamicanimation.animation;

import android.os.Looper;
import android.util.AndroidRuntimeException;
import android.view.View;
import androidx.annotation.FloatRange;
import androidx.annotation.RestrictTo;
import androidx.core.view.ViewCompat;
import androidx.dynamicanimation.animation.AnimationHandler;
import androidx.dynamicanimation.animation.DynamicAnimation;
import java.util.ArrayList;

public abstract class DynamicAnimation<T extends DynamicAnimation<T>> implements AnimationHandler.AnimationFrameCallback {
    public static final ViewProperty ALPHA = new ViewProperty("alpha") {
        /* class androidx.dynamicanimation.animation.DynamicAnimation.AnonymousClass12 */

        public float getValue(View view) {
            return view.getAlpha();
        }

        public void setValue(View view, float f7) {
            view.setAlpha(f7);
        }
    };
    public static final float MIN_VISIBLE_CHANGE_ALPHA = 0.00390625f;
    public static final float MIN_VISIBLE_CHANGE_PIXELS = 1.0f;
    public static final float MIN_VISIBLE_CHANGE_ROTATION_DEGREES = 0.1f;
    public static final float MIN_VISIBLE_CHANGE_SCALE = 0.002f;
    public static final ViewProperty ROTATION = new ViewProperty("rotation") {
        /* class androidx.dynamicanimation.animation.DynamicAnimation.AnonymousClass6 */

        public float getValue(View view) {
            return view.getRotation();
        }

        public void setValue(View view, float f7) {
            view.setRotation(f7);
        }
    };
    public static final ViewProperty ROTATION_X = new ViewProperty("rotationX") {
        /* class androidx.dynamicanimation.animation.DynamicAnimation.AnonymousClass7 */

        public float getValue(View view) {
            return view.getRotationX();
        }

        public void setValue(View view, float f7) {
            view.setRotationX(f7);
        }
    };
    public static final ViewProperty ROTATION_Y = new ViewProperty("rotationY") {
        /* class androidx.dynamicanimation.animation.DynamicAnimation.AnonymousClass8 */

        public float getValue(View view) {
            return view.getRotationY();
        }

        public void setValue(View view, float f7) {
            view.setRotationY(f7);
        }
    };
    public static final ViewProperty SCALE_X = new ViewProperty("scaleX") {
        /* class androidx.dynamicanimation.animation.DynamicAnimation.AnonymousClass4 */

        public float getValue(View view) {
            return view.getScaleX();
        }

        public void setValue(View view, float f7) {
            view.setScaleX(f7);
        }
    };
    public static final ViewProperty SCALE_Y = new ViewProperty("scaleY") {
        /* class androidx.dynamicanimation.animation.DynamicAnimation.AnonymousClass5 */

        public float getValue(View view) {
            return view.getScaleY();
        }

        public void setValue(View view, float f7) {
            view.setScaleY(f7);
        }
    };
    public static final ViewProperty SCROLL_X = new ViewProperty("scrollX") {
        /* class androidx.dynamicanimation.animation.DynamicAnimation.AnonymousClass13 */

        public float getValue(View view) {
            return (float) view.getScrollX();
        }

        public void setValue(View view, float f7) {
            view.setScrollX((int) f7);
        }
    };
    public static final ViewProperty SCROLL_Y = new ViewProperty("scrollY") {
        /* class androidx.dynamicanimation.animation.DynamicAnimation.AnonymousClass14 */

        public float getValue(View view) {
            return (float) view.getScrollY();
        }

        public void setValue(View view, float f7) {
            view.setScrollY((int) f7);
        }
    };
    private static final float THRESHOLD_MULTIPLIER = 0.75f;
    public static final ViewProperty TRANSLATION_X = new ViewProperty("translationX") {
        /* class androidx.dynamicanimation.animation.DynamicAnimation.AnonymousClass1 */

        public float getValue(View view) {
            return view.getTranslationX();
        }

        public void setValue(View view, float f7) {
            view.setTranslationX(f7);
        }
    };
    public static final ViewProperty TRANSLATION_Y = new ViewProperty("translationY") {
        /* class androidx.dynamicanimation.animation.DynamicAnimation.AnonymousClass2 */

        public float getValue(View view) {
            return view.getTranslationY();
        }

        public void setValue(View view, float f7) {
            view.setTranslationY(f7);
        }
    };
    public static final ViewProperty TRANSLATION_Z = new ViewProperty("translationZ") {
        /* class androidx.dynamicanimation.animation.DynamicAnimation.AnonymousClass3 */

        public float getValue(View view) {
            return ViewCompat.getTranslationZ(view);
        }

        public void setValue(View view, float f7) {
            ViewCompat.setTranslationZ(view, f7);
        }
    };
    private static final float UNSET = Float.MAX_VALUE;
    public static final ViewProperty X = new ViewProperty("x") {
        /* class androidx.dynamicanimation.animation.DynamicAnimation.AnonymousClass9 */

        public float getValue(View view) {
            return view.getX();
        }

        public void setValue(View view, float f7) {
            view.setX(f7);
        }
    };
    public static final ViewProperty Y = new ViewProperty("y") {
        /* class androidx.dynamicanimation.animation.DynamicAnimation.AnonymousClass10 */

        public float getValue(View view) {
            return view.getY();
        }

        public void setValue(View view, float f7) {
            view.setY(f7);
        }
    };
    public static final ViewProperty Z = new ViewProperty("z") {
        /* class androidx.dynamicanimation.animation.DynamicAnimation.AnonymousClass11 */

        public float getValue(View view) {
            return ViewCompat.getZ(view);
        }

        public void setValue(View view, float f7) {
            ViewCompat.setZ(view, f7);
        }
    };
    private final ArrayList<OnAnimationEndListener> mEndListeners;
    private long mLastFrameTime;
    float mMaxValue;
    float mMinValue;
    private float mMinVisibleChange;
    final FloatPropertyCompat mProperty;
    boolean mRunning;
    boolean mStartValueIsSet;
    final Object mTarget;
    private final ArrayList<OnAnimationUpdateListener> mUpdateListeners;
    float mValue;
    float mVelocity;

    static class MassState {
        float mValue;
        float mVelocity;

        MassState() {
        }
    }

    public interface OnAnimationEndListener {
        void onAnimationEnd(DynamicAnimation dynamicAnimation, boolean z7, float f7, float f8);
    }

    public interface OnAnimationUpdateListener {
        void onAnimationUpdate(DynamicAnimation dynamicAnimation, float f7, float f8);
    }

    public static abstract class ViewProperty extends FloatPropertyCompat<View> {
        private ViewProperty(String str) {
            super(str);
        }
    }

    DynamicAnimation(final FloatValueHolder floatValueHolder) {
        this.mVelocity = 0.0f;
        this.mValue = Float.MAX_VALUE;
        this.mStartValueIsSet = false;
        this.mRunning = false;
        this.mMaxValue = Float.MAX_VALUE;
        this.mMinValue = -Float.MAX_VALUE;
        this.mLastFrameTime = 0;
        this.mEndListeners = new ArrayList<>();
        this.mUpdateListeners = new ArrayList<>();
        this.mTarget = null;
        this.mProperty = new FloatPropertyCompat("FloatValueHolder") {
            /* class androidx.dynamicanimation.animation.DynamicAnimation.AnonymousClass15 */

            @Override // androidx.dynamicanimation.animation.FloatPropertyCompat
            public float getValue(Object obj) {
                return floatValueHolder.getValue();
            }

            @Override // androidx.dynamicanimation.animation.FloatPropertyCompat
            public void setValue(Object obj, float f7) {
                floatValueHolder.setValue(f7);
            }
        };
        this.mMinVisibleChange = 1.0f;
    }

    private void endAnimationInternal(boolean z7) {
        this.mRunning = false;
        AnimationHandler.getInstance().removeCallback(this);
        this.mLastFrameTime = 0;
        this.mStartValueIsSet = false;
        for (int i7 = 0; i7 < this.mEndListeners.size(); i7++) {
            if (this.mEndListeners.get(i7) != null) {
                this.mEndListeners.get(i7).onAnimationEnd(this, z7, this.mValue, this.mVelocity);
            }
        }
        removeNullEntries(this.mEndListeners);
    }

    private float getPropertyValue() {
        return this.mProperty.getValue(this.mTarget);
    }

    private static <T> void removeEntry(ArrayList<T> arrayList, T t7) {
        int indexOf = arrayList.indexOf(t7);
        if (indexOf >= 0) {
            arrayList.set(indexOf, null);
        }
    }

    private static <T> void removeNullEntries(ArrayList<T> arrayList) {
        for (int size = arrayList.size() - 1; size >= 0; size--) {
            if (arrayList.get(size) == null) {
                arrayList.remove(size);
            }
        }
    }

    private void startAnimationInternal() {
        if (!this.mRunning) {
            this.mRunning = true;
            if (!this.mStartValueIsSet) {
                this.mValue = getPropertyValue();
            }
            float f7 = this.mValue;
            if (f7 > this.mMaxValue || f7 < this.mMinValue) {
                throw new IllegalArgumentException("Starting value need to be in between min value and max value");
            }
            AnimationHandler.getInstance().addAnimationFrameCallback(this, 0);
        }
    }

    public T addEndListener(OnAnimationEndListener onAnimationEndListener) {
        if (!this.mEndListeners.contains(onAnimationEndListener)) {
            this.mEndListeners.add(onAnimationEndListener);
        }
        return this;
    }

    public T addUpdateListener(OnAnimationUpdateListener onAnimationUpdateListener) {
        if (!isRunning()) {
            if (!this.mUpdateListeners.contains(onAnimationUpdateListener)) {
                this.mUpdateListeners.add(onAnimationUpdateListener);
            }
            return this;
        }
        throw new UnsupportedOperationException("Error: Update listeners must be added beforethe animation.");
    }

    public void cancel() {
        if (Looper.myLooper() != Looper.getMainLooper()) {
            throw new AndroidRuntimeException("Animations may only be canceled on the main thread");
        } else if (this.mRunning) {
            endAnimationInternal(true);
        }
    }

    @Override // androidx.dynamicanimation.animation.AnimationHandler.AnimationFrameCallback
    @RestrictTo({RestrictTo.Scope.LIBRARY})
    public boolean doAnimationFrame(long j7) {
        long j8 = this.mLastFrameTime;
        if (j8 == 0) {
            this.mLastFrameTime = j7;
            setPropertyValue(this.mValue);
            return false;
        }
        this.mLastFrameTime = j7;
        boolean updateValueAndVelocity = updateValueAndVelocity(j7 - j8);
        float min = Math.min(this.mValue, this.mMaxValue);
        this.mValue = min;
        float max = Math.max(min, this.mMinValue);
        this.mValue = max;
        setPropertyValue(max);
        if (updateValueAndVelocity) {
            endAnimationInternal(false);
        }
        return updateValueAndVelocity;
    }

    /* access modifiers changed from: package-private */
    public abstract float getAcceleration(float f7, float f8);

    public float getMinimumVisibleChange() {
        return this.mMinVisibleChange;
    }

    /* access modifiers changed from: package-private */
    public float getValueThreshold() {
        return this.mMinVisibleChange * 0.75f;
    }

    /* access modifiers changed from: package-private */
    public abstract boolean isAtEquilibrium(float f7, float f8);

    public boolean isRunning() {
        return this.mRunning;
    }

    public void removeEndListener(OnAnimationEndListener onAnimationEndListener) {
        removeEntry(this.mEndListeners, onAnimationEndListener);
    }

    public void removeUpdateListener(OnAnimationUpdateListener onAnimationUpdateListener) {
        removeEntry(this.mUpdateListeners, onAnimationUpdateListener);
    }

    public T setMaxValue(float f7) {
        this.mMaxValue = f7;
        return this;
    }

    public T setMinValue(float f7) {
        this.mMinValue = f7;
        return this;
    }

    public T setMinimumVisibleChange(@FloatRange(from = 0.0d, fromInclusive = false) float f7) {
        if (f7 > 0.0f) {
            this.mMinVisibleChange = f7;
            setValueThreshold(f7 * 0.75f);
            return this;
        }
        throw new IllegalArgumentException("Minimum visible change must be positive.");
    }

    /* access modifiers changed from: package-private */
    public void setPropertyValue(float f7) {
        this.mProperty.setValue(this.mTarget, f7);
        for (int i7 = 0; i7 < this.mUpdateListeners.size(); i7++) {
            if (this.mUpdateListeners.get(i7) != null) {
                this.mUpdateListeners.get(i7).onAnimationUpdate(this, this.mValue, this.mVelocity);
            }
        }
        removeNullEntries(this.mUpdateListeners);
    }

    public T setStartValue(float f7) {
        this.mValue = f7;
        this.mStartValueIsSet = true;
        return this;
    }

    public T setStartVelocity(float f7) {
        this.mVelocity = f7;
        return this;
    }

    /* access modifiers changed from: package-private */
    public abstract void setValueThreshold(float f7);

    public void start() {
        if (Looper.myLooper() != Looper.getMainLooper()) {
            throw new AndroidRuntimeException("Animations may only be started on the main thread");
        } else if (!this.mRunning) {
            startAnimationInternal();
        }
    }

    /* access modifiers changed from: package-private */
    public abstract boolean updateValueAndVelocity(long j7);

    <K> DynamicAnimation(K k7, FloatPropertyCompat<K> floatPropertyCompat) {
        float f7;
        this.mVelocity = 0.0f;
        this.mValue = Float.MAX_VALUE;
        this.mStartValueIsSet = false;
        this.mRunning = false;
        this.mMaxValue = Float.MAX_VALUE;
        this.mMinValue = -Float.MAX_VALUE;
        this.mLastFrameTime = 0;
        this.mEndListeners = new ArrayList<>();
        this.mUpdateListeners = new ArrayList<>();
        this.mTarget = k7;
        this.mProperty = floatPropertyCompat;
        if (floatPropertyCompat == ROTATION || floatPropertyCompat == ROTATION_X || floatPropertyCompat == ROTATION_Y) {
            f7 = 0.1f;
        } else if (floatPropertyCompat == ALPHA || floatPropertyCompat == SCALE_X || floatPropertyCompat == SCALE_Y) {
            this.mMinVisibleChange = 0.00390625f;
            return;
        } else {
            f7 = 1.0f;
        }
        this.mMinVisibleChange = f7;
    }
}
