package androidx.dynamicanimation.animation;

import androidx.annotation.FloatRange;
import androidx.dynamicanimation.animation.DynamicAnimation;

public final class FlingAnimation extends DynamicAnimation<FlingAnimation> {
    private final DragForce mFlingForce;

    /* access modifiers changed from: package-private */
    public static final class DragForce implements Force {
        private static final float DEFAULT_FRICTION = -4.2f;
        private static final float VELOCITY_THRESHOLD_MULTIPLIER = 62.5f;
        private float mFriction = DEFAULT_FRICTION;
        private final DynamicAnimation.MassState mMassState = new DynamicAnimation.MassState();
        private float mVelocityThreshold;

        DragForce() {
        }

        @Override // androidx.dynamicanimation.animation.Force
        public float getAcceleration(float f7, float f8) {
            return f8 * this.mFriction;
        }

        /* access modifiers changed from: package-private */
        public float getFrictionScalar() {
            return this.mFriction / DEFAULT_FRICTION;
        }

        @Override // androidx.dynamicanimation.animation.Force
        public boolean isAtEquilibrium(float f7, float f8) {
            return Math.abs(f8) < this.mVelocityThreshold;
        }

        /* access modifiers changed from: package-private */
        public void setFrictionScalar(float f7) {
            this.mFriction = f7 * DEFAULT_FRICTION;
        }

        /* access modifiers changed from: package-private */
        public void setValueThreshold(float f7) {
            this.mVelocityThreshold = f7 * VELOCITY_THRESHOLD_MULTIPLIER;
        }

        /* access modifiers changed from: package-private */
        public DynamicAnimation.MassState updateValueAndVelocity(float f7, float f8, long j7) {
            float f9 = (float) j7;
            this.mMassState.mVelocity = (float) (((double) f8) * Math.exp((double) ((f9 / 1000.0f) * this.mFriction)));
            DynamicAnimation.MassState massState = this.mMassState;
            float f10 = this.mFriction;
            massState.mValue = (float) (((double) (f7 - (f8 / f10))) + (((double) (f8 / f10)) * Math.exp((double) ((f10 * f9) / 1000.0f))));
            DynamicAnimation.MassState massState2 = this.mMassState;
            if (isAtEquilibrium(massState2.mValue, massState2.mVelocity)) {
                this.mMassState.mVelocity = 0.0f;
            }
            return this.mMassState;
        }
    }

    public FlingAnimation(FloatValueHolder floatValueHolder) {
        super(floatValueHolder);
        DragForce dragForce = new DragForce();
        this.mFlingForce = dragForce;
        dragForce.setValueThreshold(getValueThreshold());
    }

    /* access modifiers changed from: package-private */
    @Override // androidx.dynamicanimation.animation.DynamicAnimation
    public float getAcceleration(float f7, float f8) {
        return this.mFlingForce.getAcceleration(f7, f8);
    }

    public float getFriction() {
        return this.mFlingForce.getFrictionScalar();
    }

    /* access modifiers changed from: package-private */
    @Override // androidx.dynamicanimation.animation.DynamicAnimation
    public boolean isAtEquilibrium(float f7, float f8) {
        return f7 >= this.mMaxValue || f7 <= this.mMinValue || this.mFlingForce.isAtEquilibrium(f7, f8);
    }

    public FlingAnimation setFriction(@FloatRange(from = 0.0d, fromInclusive = false) float f7) {
        if (f7 > 0.0f) {
            this.mFlingForce.setFrictionScalar(f7);
            return this;
        }
        throw new IllegalArgumentException("Friction must be positive");
    }

    /* access modifiers changed from: package-private */
    @Override // androidx.dynamicanimation.animation.DynamicAnimation
    public void setValueThreshold(float f7) {
        this.mFlingForce.setValueThreshold(f7);
    }

    /* access modifiers changed from: package-private */
    @Override // androidx.dynamicanimation.animation.DynamicAnimation
    public boolean updateValueAndVelocity(long j7) {
        DynamicAnimation.MassState updateValueAndVelocity = this.mFlingForce.updateValueAndVelocity(this.mValue, this.mVelocity, j7);
        float f7 = updateValueAndVelocity.mValue;
        this.mValue = f7;
        float f8 = updateValueAndVelocity.mVelocity;
        this.mVelocity = f8;
        float f9 = this.mMinValue;
        if (f7 < f9) {
            this.mValue = f9;
            return true;
        }
        float f10 = this.mMaxValue;
        if (f7 <= f10) {
            return isAtEquilibrium(f7, f8);
        }
        this.mValue = f10;
        return true;
    }

    public <K> FlingAnimation(K k7, FloatPropertyCompat<K> floatPropertyCompat) {
        super(k7, floatPropertyCompat);
        DragForce dragForce = new DragForce();
        this.mFlingForce = dragForce;
        dragForce.setValueThreshold(getValueThreshold());
    }

    @Override // androidx.dynamicanimation.animation.DynamicAnimation
    public FlingAnimation setMaxValue(float f7) {
        super.setMaxValue(f7);
        return this;
    }

    @Override // androidx.dynamicanimation.animation.DynamicAnimation
    public FlingAnimation setMinValue(float f7) {
        super.setMinValue(f7);
        return this;
    }

    @Override // androidx.dynamicanimation.animation.DynamicAnimation
    public FlingAnimation setStartVelocity(float f7) {
        super.setStartVelocity(f7);
        return this;
    }
}
