package androidx.emoji2.text.flatbuffer;

import java.io.IOException;
import java.io.InputStream;
import java.nio.BufferUnderflowException;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.util.Arrays;

public class FlatBufferBuilder {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    ByteBuffer bb;
    ByteBufferFactory bb_factory;
    boolean finished;
    boolean force_defaults;
    int minalign;
    boolean nested;
    int num_vtables;
    int object_start;
    int space;
    final Utf8 utf8;
    int vector_num_elems;
    int[] vtable;
    int vtable_in_use;
    int[] vtables;

    static class ByteBufferBackedInputStream extends InputStream {
        ByteBuffer buf;

        public ByteBufferBackedInputStream(ByteBuffer byteBuffer) {
            this.buf = byteBuffer;
        }

        @Override // java.io.InputStream
        public int read() throws IOException {
            try {
                return this.buf.get() & 255;
            } catch (BufferUnderflowException unused) {
                return -1;
            }
        }
    }

    public static abstract class ByteBufferFactory {
        public abstract ByteBuffer newByteBuffer(int i7);

        public void releaseByteBuffer(ByteBuffer byteBuffer) {
        }
    }

    public static final class HeapByteBufferFactory extends ByteBufferFactory {
        public static final HeapByteBufferFactory INSTANCE = new HeapByteBufferFactory();

        @Override // androidx.emoji2.text.flatbuffer.FlatBufferBuilder.ByteBufferFactory
        public ByteBuffer newByteBuffer(int i7) {
            return ByteBuffer.allocate(i7).order(ByteOrder.LITTLE_ENDIAN);
        }
    }

    public FlatBufferBuilder() {
        this(1024);
    }

    @Deprecated
    private int dataStart() {
        finished();
        return this.space;
    }

    static ByteBuffer growByteBuffer(ByteBuffer byteBuffer, ByteBufferFactory byteBufferFactory) {
        int capacity = byteBuffer.capacity();
        if ((-1073741824 & capacity) == 0) {
            int i7 = capacity == 0 ? 1 : capacity << 1;
            byteBuffer.position(0);
            ByteBuffer newByteBuffer = byteBufferFactory.newByteBuffer(i7);
            newByteBuffer.position(newByteBuffer.clear().capacity() - capacity);
            newByteBuffer.put(byteBuffer);
            return newByteBuffer;
        }
        throw new AssertionError("FlatBuffers: cannot grow buffer beyond 2 gigabytes.");
    }

    public static boolean isFieldPresent(Table table, int i7) {
        return table.__offset(i7) != 0;
    }

    public void Nested(int i7) {
        if (i7 != offset()) {
            throw new AssertionError("FlatBuffers: struct must be serialized inline.");
        }
    }

    public void addBoolean(int i7, boolean z7, boolean z8) {
        if (this.force_defaults || z7 != z8) {
            addBoolean(z7);
            slot(i7);
        }
    }

    public void addByte(byte b7) {
        prep(1, 0);
        putByte(b7);
    }

    public void addDouble(double d7) {
        prep(8, 0);
        putDouble(d7);
    }

    public void addFloat(float f7) {
        prep(4, 0);
        putFloat(f7);
    }

    public void addInt(int i7) {
        prep(4, 0);
        putInt(i7);
    }

    public void addLong(int i7, long j7, long j8) {
        if (this.force_defaults || j7 != j8) {
            addLong(j7);
            slot(i7);
        }
    }

    public void addOffset(int i7) {
        prep(4, 0);
        putInt((offset() - i7) + 4);
    }

    public void addShort(int i7, short s7, int i8) {
        if (this.force_defaults || s7 != i8) {
            addShort(s7);
            slot(i7);
        }
    }

    public void addStruct(int i7, int i8, int i9) {
        if (i8 != i9) {
            Nested(i8);
            slot(i7);
        }
    }

    public void clear() {
        this.space = this.bb.capacity();
        this.bb.clear();
        this.minalign = 1;
        while (true) {
            int i7 = this.vtable_in_use;
            if (i7 > 0) {
                int[] iArr = this.vtable;
                int i8 = i7 - 1;
                this.vtable_in_use = i8;
                iArr[i8] = 0;
            } else {
                this.vtable_in_use = 0;
                this.nested = false;
                this.finished = false;
                this.object_start = 0;
                this.num_vtables = 0;
                this.vector_num_elems = 0;
                return;
            }
        }
    }

    public int createByteVector(ByteBuffer byteBuffer) {
        int remaining = byteBuffer.remaining();
        startVector(1, remaining, 1);
        ByteBuffer byteBuffer2 = this.bb;
        int i7 = this.space - remaining;
        this.space = i7;
        byteBuffer2.position(i7);
        this.bb.put(byteBuffer);
        return endVector();
    }

    public <T extends Table> int createSortedVectorOfTables(T t7, int[] iArr) {
        t7.sortTables(iArr, this.bb);
        return createVectorOfTables(iArr);
    }

    public int createString(CharSequence charSequence) {
        int encodedLength = this.utf8.encodedLength(charSequence);
        addByte((byte) 0);
        startVector(1, encodedLength, 1);
        ByteBuffer byteBuffer = this.bb;
        int i7 = this.space - encodedLength;
        this.space = i7;
        byteBuffer.position(i7);
        this.utf8.encodeUtf8(charSequence, this.bb);
        return endVector();
    }

    public ByteBuffer createUnintializedVector(int i7, int i8, int i9) {
        int i10 = i7 * i8;
        startVector(i7, i8, i9);
        ByteBuffer byteBuffer = this.bb;
        int i11 = this.space - i10;
        this.space = i11;
        byteBuffer.position(i11);
        ByteBuffer order = this.bb.slice().order(ByteOrder.LITTLE_ENDIAN);
        order.limit(i10);
        return order;
    }

    public int createVectorOfTables(int[] iArr) {
        notNested();
        startVector(4, iArr.length, 4);
        for (int length = iArr.length - 1; length >= 0; length--) {
            addOffset(iArr[length]);
        }
        return endVector();
    }

    public ByteBuffer dataBuffer() {
        finished();
        return this.bb;
    }

    public int endTable() {
        int i7;
        if (this.vtable == null || !this.nested) {
            throw new AssertionError("FlatBuffers: endTable called without startTable");
        }
        addInt(0);
        int offset = offset();
        int i8 = this.vtable_in_use - 1;
        while (i8 >= 0 && this.vtable[i8] == 0) {
            i8--;
        }
        int i9 = i8 + 1;
        while (i8 >= 0) {
            int i10 = this.vtable[i8];
            addShort((short) (i10 != 0 ? offset - i10 : 0));
            i8--;
        }
        addShort((short) (offset - this.object_start));
        addShort((short) ((i9 + 2) * 2));
        int i11 = 0;
        loop2:
        while (true) {
            if (i11 >= this.num_vtables) {
                i7 = 0;
                break;
            }
            int capacity = this.bb.capacity() - this.vtables[i11];
            int i12 = this.space;
            short s7 = this.bb.getShort(capacity);
            if (s7 == this.bb.getShort(i12)) {
                for (int i13 = 2; i13 < s7; i13 += 2) {
                    if (this.bb.getShort(capacity + i13) == this.bb.getShort(i12 + i13)) {
                    }
                }
                i7 = this.vtables[i11];
                break loop2;
            }
            i11++;
        }
        if (i7 != 0) {
            int capacity2 = this.bb.capacity() - offset;
            this.space = capacity2;
            this.bb.putInt(capacity2, i7 - offset);
        } else {
            int i14 = this.num_vtables;
            int[] iArr = this.vtables;
            if (i14 == iArr.length) {
                this.vtables = Arrays.copyOf(iArr, i14 * 2);
            }
            int[] iArr2 = this.vtables;
            int i15 = this.num_vtables;
            this.num_vtables = i15 + 1;
            iArr2[i15] = offset();
            ByteBuffer byteBuffer = this.bb;
            byteBuffer.putInt(byteBuffer.capacity() - offset, offset() - offset);
        }
        this.nested = false;
        return offset;
    }

    public int endVector() {
        if (this.nested) {
            this.nested = false;
            putInt(this.vector_num_elems);
            return offset();
        }
        throw new AssertionError("FlatBuffers: endVector called without startVector");
    }

    public void finish(int i7) {
        finish(i7, false);
    }

    public void finishSizePrefixed(int i7) {
        finish(i7, true);
    }

    public void finished() {
        if (!this.finished) {
            throw new AssertionError("FlatBuffers: you can only access the serialized buffer after it has been finished by FlatBufferBuilder.finish().");
        }
    }

    public FlatBufferBuilder forceDefaults(boolean z7) {
        this.force_defaults = z7;
        return this;
    }

    public FlatBufferBuilder init(ByteBuffer byteBuffer, ByteBufferFactory byteBufferFactory) {
        this.bb_factory = byteBufferFactory;
        this.bb = byteBuffer;
        byteBuffer.clear();
        this.bb.order(ByteOrder.LITTLE_ENDIAN);
        this.minalign = 1;
        this.space = this.bb.capacity();
        this.vtable_in_use = 0;
        this.nested = false;
        this.finished = false;
        this.object_start = 0;
        this.num_vtables = 0;
        this.vector_num_elems = 0;
        return this;
    }

    public void notNested() {
        if (this.nested) {
            throw new AssertionError("FlatBuffers: object serialization must not be nested.");
        }
    }

    public int offset() {
        return this.bb.capacity() - this.space;
    }

    public void pad(int i7) {
        for (int i8 = 0; i8 < i7; i8++) {
            ByteBuffer byteBuffer = this.bb;
            int i9 = this.space - 1;
            this.space = i9;
            byteBuffer.put(i9, (byte) 0);
        }
    }

    public void prep(int i7, int i8) {
        if (i7 > this.minalign) {
            this.minalign = i7;
        }
        int i9 = ((~((this.bb.capacity() - this.space) + i8)) + 1) & (i7 - 1);
        while (this.space < i9 + i7 + i8) {
            int capacity = this.bb.capacity();
            ByteBuffer byteBuffer = this.bb;
            ByteBuffer growByteBuffer = growByteBuffer(byteBuffer, this.bb_factory);
            this.bb = growByteBuffer;
            if (byteBuffer != growByteBuffer) {
                this.bb_factory.releaseByteBuffer(byteBuffer);
            }
            this.space += this.bb.capacity() - capacity;
        }
        pad(i9);
    }

    public void putBoolean(boolean z7) {
        ByteBuffer byteBuffer = this.bb;
        int i7 = this.space - 1;
        this.space = i7;
        byteBuffer.put(i7, z7 ? (byte) 1 : 0);
    }

    public void putByte(byte b7) {
        ByteBuffer byteBuffer = this.bb;
        int i7 = this.space - 1;
        this.space = i7;
        byteBuffer.put(i7, b7);
    }

    public void putDouble(double d7) {
        ByteBuffer byteBuffer = this.bb;
        int i7 = this.space - 8;
        this.space = i7;
        byteBuffer.putDouble(i7, d7);
    }

    public void putFloat(float f7) {
        ByteBuffer byteBuffer = this.bb;
        int i7 = this.space - 4;
        this.space = i7;
        byteBuffer.putFloat(i7, f7);
    }

    public void putInt(int i7) {
        ByteBuffer byteBuffer = this.bb;
        int i8 = this.space - 4;
        this.space = i8;
        byteBuffer.putInt(i8, i7);
    }

    public void putLong(long j7) {
        ByteBuffer byteBuffer = this.bb;
        int i7 = this.space - 8;
        this.space = i7;
        byteBuffer.putLong(i7, j7);
    }

    public void putShort(short s7) {
        ByteBuffer byteBuffer = this.bb;
        int i7 = this.space - 2;
        this.space = i7;
        byteBuffer.putShort(i7, s7);
    }

    public void required(int i7, int i8) {
        int capacity = this.bb.capacity() - i7;
        if (!(this.bb.getShort((capacity - this.bb.getInt(capacity)) + i8) != 0)) {
            throw new AssertionError("FlatBuffers: field " + i8 + " must be set");
        }
    }

    public byte[] sizedByteArray() {
        return sizedByteArray(this.space, this.bb.capacity() - this.space);
    }

    public InputStream sizedInputStream() {
        finished();
        ByteBuffer duplicate = this.bb.duplicate();
        duplicate.position(this.space);
        duplicate.limit(this.bb.capacity());
        return new ByteBufferBackedInputStream(duplicate);
    }

    public void slot(int i7) {
        this.vtable[i7] = offset();
    }

    public void startTable(int i7) {
        notNested();
        int[] iArr = this.vtable;
        if (iArr == null || iArr.length < i7) {
            this.vtable = new int[i7];
        }
        this.vtable_in_use = i7;
        Arrays.fill(this.vtable, 0, i7, 0);
        this.nested = true;
        this.object_start = offset();
    }

    public void startVector(int i7, int i8, int i9) {
        notNested();
        this.vector_num_elems = i8;
        int i10 = i7 * i8;
        prep(4, i10);
        prep(i9, i10);
        this.nested = true;
    }

    public FlatBufferBuilder(int i7) {
        this(i7, HeapByteBufferFactory.INSTANCE, null, Utf8.getDefault());
    }

    public void addBoolean(boolean z7) {
        prep(1, 0);
        putBoolean(z7);
    }

    public void addByte(int i7, byte b7, int i8) {
        if (this.force_defaults || b7 != i8) {
            addByte(b7);
            slot(i7);
        }
    }

    public void addDouble(int i7, double d7, double d8) {
        if (this.force_defaults || d7 != d8) {
            addDouble(d7);
            slot(i7);
        }
    }

    public void addFloat(int i7, float f7, double d7) {
        if (this.force_defaults || ((double) f7) != d7) {
            addFloat(f7);
            slot(i7);
        }
    }

    public void addInt(int i7, int i8, int i9) {
        if (this.force_defaults || i8 != i9) {
            addInt(i8);
            slot(i7);
        }
    }

    public void addLong(long j7) {
        prep(8, 0);
        putLong(j7);
    }

    public void addOffset(int i7, int i8, int i9) {
        if (this.force_defaults || i8 != i9) {
            addOffset(i8);
            slot(i7);
        }
    }

    public void addShort(short s7) {
        prep(2, 0);
        putShort(s7);
    }

    public int createByteVector(byte[] bArr) {
        int length = bArr.length;
        startVector(1, length, 1);
        ByteBuffer byteBuffer = this.bb;
        int i7 = this.space - length;
        this.space = i7;
        byteBuffer.position(i7);
        this.bb.put(bArr);
        return endVector();
    }

    public int createString(ByteBuffer byteBuffer) {
        int remaining = byteBuffer.remaining();
        addByte((byte) 0);
        startVector(1, remaining, 1);
        ByteBuffer byteBuffer2 = this.bb;
        int i7 = this.space - remaining;
        this.space = i7;
        byteBuffer2.position(i7);
        this.bb.put(byteBuffer);
        return endVector();
    }

    public void finish(int i7, String str) {
        finish(i7, str, false);
    }

    public void finishSizePrefixed(int i7, String str) {
        finish(i7, str, true);
    }

    public byte[] sizedByteArray(int i7, int i8) {
        finished();
        byte[] bArr = new byte[i8];
        this.bb.position(i7);
        this.bb.get(bArr);
        return bArr;
    }

    public FlatBufferBuilder(int i7, ByteBufferFactory byteBufferFactory) {
        this(i7, byteBufferFactory, null, Utf8.getDefault());
    }

    public int createByteVector(byte[] bArr, int i7, int i8) {
        startVector(1, i8, 1);
        ByteBuffer byteBuffer = this.bb;
        int i9 = this.space - i8;
        this.space = i9;
        byteBuffer.position(i9);
        this.bb.put(bArr, i7, i8);
        return endVector();
    }

    /* access modifiers changed from: protected */
    public void finish(int i7, String str, boolean z7) {
        prep(this.minalign, (z7 ? 4 : 0) + 8);
        if (str.length() == 4) {
            for (int i8 = 3; i8 >= 0; i8--) {
                addByte((byte) str.charAt(i8));
            }
            finish(i7, z7);
            return;
        }
        throw new AssertionError("FlatBuffers: file identifier must be length 4");
    }

    public FlatBufferBuilder(int i7, ByteBufferFactory byteBufferFactory, ByteBuffer byteBuffer, Utf8 utf82) {
        this.minalign = 1;
        this.vtable = null;
        this.vtable_in_use = 0;
        this.nested = false;
        this.finished = false;
        this.vtables = new int[16];
        this.num_vtables = 0;
        this.vector_num_elems = 0;
        this.force_defaults = false;
        i7 = i7 <= 0 ? 1 : i7;
        this.bb_factory = byteBufferFactory;
        if (byteBuffer != null) {
            this.bb = byteBuffer;
            byteBuffer.clear();
            this.bb.order(ByteOrder.LITTLE_ENDIAN);
        } else {
            this.bb = byteBufferFactory.newByteBuffer(i7);
        }
        this.utf8 = utf82;
        this.space = this.bb.capacity();
    }

    /* access modifiers changed from: protected */
    public void finish(int i7, boolean z7) {
        prep(this.minalign, (z7 ? 4 : 0) + 4);
        addOffset(i7);
        if (z7) {
            addInt(this.bb.capacity() - this.space);
        }
        this.bb.position(this.space);
        this.finished = true;
    }

    public FlatBufferBuilder(ByteBuffer byteBuffer) {
        this(byteBuffer, new HeapByteBufferFactory());
    }

    public FlatBufferBuilder(ByteBuffer byteBuffer, ByteBufferFactory byteBufferFactory) {
        this(byteBuffer.capacity(), byteBufferFactory, byteBuffer, Utf8.getDefault());
    }
}
