package androidx.emoji2.text.flatbuffer;

import androidx.emoji2.text.flatbuffer.FlexBuffers;
import java.math.BigInteger;
import java.nio.ByteBuffer;
import java.nio.charset.StandardCharsets;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.HashMap;

public class FlexBuffersBuilder {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final int BUILDER_FLAG_NONE = 0;
    public static final int BUILDER_FLAG_SHARE_ALL = 7;
    public static final int BUILDER_FLAG_SHARE_KEYS = 1;
    public static final int BUILDER_FLAG_SHARE_KEYS_AND_STRINGS = 3;
    public static final int BUILDER_FLAG_SHARE_KEY_VECTORS = 4;
    public static final int BUILDER_FLAG_SHARE_STRINGS = 2;
    private static final int WIDTH_16 = 1;
    private static final int WIDTH_32 = 2;
    private static final int WIDTH_64 = 3;
    private static final int WIDTH_8 = 0;
    private final ReadWriteBuf bb;
    private boolean finished;
    private final int flags;
    private Comparator<Value> keyComparator;
    private final HashMap<String, Integer> keyPool;
    private final ArrayList<Value> stack;
    private final HashMap<String, Integer> stringPool;

    /* access modifiers changed from: private */
    public static class Value {
        static final /* synthetic */ boolean $assertionsDisabled = false;
        final double dValue;
        long iValue;
        int key;
        final int minBitWidth;
        final int type;

        Value(int i7, int i8, int i9, double d7) {
            this.key = i7;
            this.type = i8;
            this.minBitWidth = i9;
            this.dValue = d7;
            this.iValue = Long.MIN_VALUE;
        }

        static Value blob(int i7, int i8, int i9, int i10) {
            return new Value(i7, i9, i10, (long) i8);
        }

        static Value bool(int i7, boolean z7) {
            return new Value(i7, 26, 0, z7 ? 1 : 0);
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private int elemWidth(int i7, int i8) {
            return elemWidth(this.type, this.minBitWidth, this.iValue, i7, i8);
        }

        static Value float32(int i7, float f7) {
            return new Value(i7, 3, 2, (double) f7);
        }

        static Value float64(int i7, double d7) {
            return new Value(i7, 3, 3, d7);
        }

        static Value int16(int i7, int i8) {
            return new Value(i7, 1, 1, (long) i8);
        }

        static Value int32(int i7, int i8) {
            return new Value(i7, 1, 2, (long) i8);
        }

        static Value int64(int i7, long j7) {
            return new Value(i7, 1, 3, j7);
        }

        static Value int8(int i7, int i8) {
            return new Value(i7, 1, 0, (long) i8);
        }

        private static byte packedType(int i7, int i8) {
            return (byte) (i7 | (i8 << 2));
        }

        /* access modifiers changed from: private */
        public static int paddingBytes(int i7, int i8) {
            return ((~i7) + 1) & (i8 - 1);
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private byte storedPackedType() {
            return storedPackedType(0);
        }

        private int storedWidth(int i7) {
            boolean isTypeInline = FlexBuffers.isTypeInline(this.type);
            int i8 = this.minBitWidth;
            return isTypeInline ? Math.max(i8, i7) : i8;
        }

        static Value uInt16(int i7, int i8) {
            return new Value(i7, 2, 1, (long) i8);
        }

        static Value uInt32(int i7, int i8) {
            return new Value(i7, 2, 2, (long) i8);
        }

        static Value uInt64(int i7, long j7) {
            return new Value(i7, 2, 3, j7);
        }

        static Value uInt8(int i7, int i8) {
            return new Value(i7, 2, 0, (long) i8);
        }

        Value(int i7, int i8, int i9, long j7) {
            this.key = i7;
            this.type = i8;
            this.minBitWidth = i9;
            this.iValue = j7;
            this.dValue = Double.MIN_VALUE;
        }

        /* access modifiers changed from: private */
        public static int elemWidth(int i7, int i8, long j7, int i9, int i10) {
            if (FlexBuffers.isTypeInline(i7)) {
                return i8;
            }
            for (int i11 = 1; i11 <= 32; i11 *= 2) {
                int widthUInBits = FlexBuffersBuilder.widthUInBits((long) ((int) (((long) ((paddingBytes(i9, i11) + i9) + (i10 * i11))) - j7)));
                if ((1 << widthUInBits) == ((long) i11)) {
                    return widthUInBits;
                }
            }
            return 3;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private byte storedPackedType(int i7) {
            return packedType(storedWidth(i7), this.type);
        }
    }

    public FlexBuffersBuilder() {
        this(256);
    }

    private int align(int i7) {
        int i8 = 1 << i7;
        int paddingBytes = Value.paddingBytes(this.bb.writePosition(), i8);
        while (true) {
            int i9 = paddingBytes - 1;
            if (paddingBytes == 0) {
                return i8;
            }
            this.bb.put((byte) 0);
            paddingBytes = i9;
        }
    }

    private Value createKeyVector(int i7, int i8) {
        long j7 = (long) i8;
        int max = Math.max(0, widthUInBits(j7));
        int i9 = i7;
        while (i9 < this.stack.size()) {
            i9++;
            max = Math.max(max, Value.elemWidth(4, 0, (long) this.stack.get(i9).key, this.bb.writePosition(), i9));
        }
        int align = align(max);
        writeInt(j7, align);
        int writePosition = this.bb.writePosition();
        while (i7 < this.stack.size()) {
            int i10 = this.stack.get(i7).key;
            writeOffset((long) this.stack.get(i7).key, align);
            i7++;
        }
        return new Value(-1, FlexBuffers.toTypedVector(4, 0), max, (long) writePosition);
    }

    private Value createVector(int i7, int i8, int i9, boolean z7, boolean z8, Value value) {
        int i10;
        int i11;
        int i12 = i9;
        long j7 = (long) i12;
        int max = Math.max(0, widthUInBits(j7));
        if (value != null) {
            max = Math.max(max, value.elemWidth(this.bb.writePosition(), 0));
            i10 = 3;
        } else {
            i10 = 1;
        }
        int i13 = 4;
        int i14 = max;
        for (int i15 = i8; i15 < this.stack.size(); i15++) {
            i14 = Math.max(i14, this.stack.get(i15).elemWidth(this.bb.writePosition(), i15 + i10));
            if (z7 && i15 == i8) {
                i13 = this.stack.get(i15).type;
                if (!FlexBuffers.isTypedVectorElementType(i13)) {
                    throw new FlexBuffers.FlexBufferException("TypedVector does not support this element type");
                }
            }
        }
        int i16 = i8;
        int align = align(i14);
        if (value != null) {
            writeOffset(value.iValue, align);
            writeInt(1 << value.minBitWidth, align);
        }
        if (!z8) {
            writeInt(j7, align);
        }
        int writePosition = this.bb.writePosition();
        for (int i17 = i16; i17 < this.stack.size(); i17++) {
            writeAny(this.stack.get(i17), align);
        }
        if (!z7) {
            while (i16 < this.stack.size()) {
                this.bb.put(this.stack.get(i16).storedPackedType(i14));
                i16++;
            }
        }
        if (value != null) {
            i11 = 9;
        } else if (z7) {
            if (!z8) {
                i12 = 0;
            }
            i11 = FlexBuffers.toTypedVector(i13, i12);
        } else {
            i11 = 10;
        }
        return new Value(i7, i11, i14, (long) writePosition);
    }

    private int putKey(String str) {
        if (str == null) {
            return -1;
        }
        int writePosition = this.bb.writePosition();
        if ((this.flags & 1) != 0) {
            Integer num = this.keyPool.get(str);
            if (num != null) {
                return num.intValue();
            }
            byte[] bytes = str.getBytes(StandardCharsets.UTF_8);
            this.bb.put(bytes, 0, bytes.length);
        } else {
            byte[] bytes2 = str.getBytes(StandardCharsets.UTF_8);
            this.bb.put(bytes2, 0, bytes2.length);
        }
        this.bb.put((byte) 0);
        this.keyPool.put(str, Integer.valueOf(writePosition));
        return writePosition;
    }

    private void putUInt64(String str, long j7) {
        this.stack.add(Value.uInt64(putKey(str), j7));
    }

    static int widthUInBits(long j7) {
        if (j7 <= ((long) FlexBuffers.Unsigned.byteToUnsignedInt((byte) -1))) {
            return 0;
        }
        if (j7 <= ((long) FlexBuffers.Unsigned.shortToUnsignedInt(-1))) {
            return 1;
        }
        return j7 <= FlexBuffers.Unsigned.intToUnsignedLong(-1) ? 2 : 3;
    }

    private void writeAny(Value value, int i7) {
        int i8 = value.type;
        if (!(i8 == 0 || i8 == 1 || i8 == 2)) {
            if (i8 == 3) {
                writeDouble(value.dValue, i7);
                return;
            } else if (i8 != 26) {
                writeOffset(value.iValue, i7);
                return;
            }
        }
        writeInt(value.iValue, i7);
    }

    private Value writeBlob(int i7, byte[] bArr, int i8, boolean z7) {
        int widthUInBits = widthUInBits((long) bArr.length);
        writeInt((long) bArr.length, align(widthUInBits));
        int writePosition = this.bb.writePosition();
        this.bb.put(bArr, 0, bArr.length);
        if (z7) {
            this.bb.put((byte) 0);
        }
        return Value.blob(i7, writePosition, i8, widthUInBits);
    }

    private void writeDouble(double d7, int i7) {
        if (i7 == 4) {
            this.bb.putFloat((float) d7);
        } else if (i7 == 8) {
            this.bb.putDouble(d7);
        }
    }

    private void writeInt(long j7, int i7) {
        if (i7 == 1) {
            this.bb.put((byte) ((int) j7));
        } else if (i7 == 2) {
            this.bb.putShort((short) ((int) j7));
        } else if (i7 == 4) {
            this.bb.putInt((int) j7);
        } else if (i7 == 8) {
            this.bb.putLong(j7);
        }
    }

    private void writeOffset(long j7, int i7) {
        writeInt((long) ((int) (((long) this.bb.writePosition()) - j7)), i7);
    }

    private Value writeString(int i7, String str) {
        return writeBlob(i7, str.getBytes(StandardCharsets.UTF_8), 5, true);
    }

    public int endMap(String str, int i7) {
        int putKey = putKey(str);
        ArrayList<Value> arrayList = this.stack;
        Collections.sort(arrayList.subList(i7, arrayList.size()), this.keyComparator);
        Value createVector = createVector(putKey, i7, this.stack.size() - i7, false, false, createKeyVector(i7, this.stack.size() - i7));
        while (this.stack.size() > i7) {
            ArrayList<Value> arrayList2 = this.stack;
            arrayList2.remove(arrayList2.size() - 1);
        }
        this.stack.add(createVector);
        return (int) createVector.iValue;
    }

    public int endVector(String str, int i7, boolean z7, boolean z8) {
        Value createVector = createVector(putKey(str), i7, this.stack.size() - i7, z7, z8, null);
        while (this.stack.size() > i7) {
            ArrayList<Value> arrayList = this.stack;
            arrayList.remove(arrayList.size() - 1);
        }
        this.stack.add(createVector);
        return (int) createVector.iValue;
    }

    public ByteBuffer finish() {
        int align = align(this.stack.get(0).elemWidth(this.bb.writePosition(), 0));
        writeAny(this.stack.get(0), align);
        this.bb.put(this.stack.get(0).storedPackedType());
        this.bb.put((byte) align);
        this.finished = true;
        return ByteBuffer.wrap(this.bb.data(), 0, this.bb.writePosition());
    }

    public ReadWriteBuf getBuffer() {
        return this.bb;
    }

    public int putBlob(String str, byte[] bArr) {
        Value writeBlob = writeBlob(putKey(str), bArr, 25, false);
        this.stack.add(writeBlob);
        return (int) writeBlob.iValue;
    }

    public void putBoolean(String str, boolean z7) {
        this.stack.add(Value.bool(putKey(str), z7));
    }

    public void putFloat(double d7) {
        putFloat((String) null, d7);
    }

    public void putInt(int i7) {
        putInt((String) null, i7);
    }

    public int putString(String str) {
        return putString(null, str);
    }

    public void putUInt(int i7) {
        putUInt(null, (long) i7);
    }

    public int startMap() {
        return this.stack.size();
    }

    public int startVector() {
        return this.stack.size();
    }

    public FlexBuffersBuilder(int i7) {
        this(new ArrayReadWriteBuf(i7), 1);
    }

    public int putBlob(byte[] bArr) {
        return putBlob(null, bArr);
    }

    public void putBoolean(boolean z7) {
        putBoolean(null, z7);
    }

    public void putFloat(float f7) {
        putFloat((String) null, f7);
    }

    public void putInt(long j7) {
        putInt((String) null, j7);
    }

    public int putString(String str, String str2) {
        int putKey = putKey(str);
        if ((this.flags & 2) != 0) {
            Integer num = this.stringPool.get(str2);
            if (num == null) {
                Value writeString = writeString(putKey, str2);
                this.stringPool.put(str2, Integer.valueOf((int) writeString.iValue));
                this.stack.add(writeString);
                return (int) writeString.iValue;
            }
            this.stack.add(Value.blob(putKey, num.intValue(), 5, widthUInBits((long) str2.length())));
            return num.intValue();
        }
        Value writeString2 = writeString(putKey, str2);
        this.stack.add(writeString2);
        return (int) writeString2.iValue;
    }

    public void putUInt(long j7) {
        putUInt(null, j7);
    }

    public void putUInt64(BigInteger bigInteger) {
        putUInt64(null, bigInteger.longValue());
    }

    public FlexBuffersBuilder(ReadWriteBuf readWriteBuf, int i7) {
        this.stack = new ArrayList<>();
        this.keyPool = new HashMap<>();
        this.stringPool = new HashMap<>();
        this.finished = false;
        this.keyComparator = new Comparator<Value>() {
            /* class androidx.emoji2.text.flatbuffer.FlexBuffersBuilder.AnonymousClass1 */

            public int compare(Value value, Value value2) {
                byte b7;
                byte b8;
                int i7 = value.key;
                int i8 = value2.key;
                do {
                    b7 = FlexBuffersBuilder.this.bb.get(i7);
                    b8 = FlexBuffersBuilder.this.bb.get(i8);
                    if (b7 == 0) {
                        return b7 - b8;
                    }
                    i7++;
                    i8++;
                } while (b7 == b8);
                return b7 - b8;
            }
        };
        this.bb = readWriteBuf;
        this.flags = i7;
    }

    private void putUInt(String str, long j7) {
        int putKey = putKey(str);
        int widthUInBits = widthUInBits(j7);
        this.stack.add(widthUInBits == 0 ? Value.uInt8(putKey, (int) j7) : widthUInBits == 1 ? Value.uInt16(putKey, (int) j7) : widthUInBits == 2 ? Value.uInt32(putKey, (int) j7) : Value.uInt64(putKey, j7));
    }

    public void putFloat(String str, double d7) {
        this.stack.add(Value.float64(putKey(str), d7));
    }

    public void putInt(String str, int i7) {
        putInt(str, (long) i7);
    }

    public FlexBuffersBuilder(ByteBuffer byteBuffer) {
        this(byteBuffer, 1);
    }

    public void putFloat(String str, float f7) {
        this.stack.add(Value.float32(putKey(str), f7));
    }

    public void putInt(String str, long j7) {
        ArrayList<Value> arrayList;
        Value int64;
        int putKey = putKey(str);
        if (-128 <= j7 && j7 <= 127) {
            arrayList = this.stack;
            int64 = Value.int8(putKey, (int) j7);
        } else if (-32768 <= j7 && j7 <= 32767) {
            arrayList = this.stack;
            int64 = Value.int16(putKey, (int) j7);
        } else if (-2147483648L > j7 || j7 > 2147483647L) {
            arrayList = this.stack;
            int64 = Value.int64(putKey, j7);
        } else {
            arrayList = this.stack;
            int64 = Value.int32(putKey, (int) j7);
        }
        arrayList.add(int64);
    }

    @Deprecated
    public FlexBuffersBuilder(ByteBuffer byteBuffer, int i7) {
        this(new ArrayReadWriteBuf(byteBuffer.array()), i7);
    }
}
