package androidx.emoji2.text.flatbuffer;

import com.google.common.base.Ascii;
import java.nio.ByteBuffer;

public abstract class Utf8 {
    private static Utf8 DEFAULT;

    /* access modifiers changed from: package-private */
    public static class DecodeUtil {
        DecodeUtil() {
        }

        static void handleFourBytes(byte b7, byte b8, byte b9, byte b10, char[] cArr, int i7) throws IllegalArgumentException {
            if (isNotTrailingByte(b8) || (((b7 << Ascii.FS) + (b8 + 112)) >> 30) != 0 || isNotTrailingByte(b9) || isNotTrailingByte(b10)) {
                throw new IllegalArgumentException("Invalid UTF-8");
            }
            int trailingByteValue = ((b7 & 7) << 18) | (trailingByteValue(b8) << 12) | (trailingByteValue(b9) << 6) | trailingByteValue(b10);
            cArr[i7] = highSurrogate(trailingByteValue);
            cArr[i7 + 1] = lowSurrogate(trailingByteValue);
        }

        static void handleOneByte(byte b7, char[] cArr, int i7) {
            cArr[i7] = (char) b7;
        }

        static void handleThreeBytes(byte b7, byte b8, byte b9, char[] cArr, int i7) throws IllegalArgumentException {
            if (isNotTrailingByte(b8) || ((b7 == -32 && b8 < -96) || ((b7 == -19 && b8 >= -96) || isNotTrailingByte(b9)))) {
                throw new IllegalArgumentException("Invalid UTF-8");
            }
            cArr[i7] = (char) (((b7 & Ascii.SI) << 12) | (trailingByteValue(b8) << 6) | trailingByteValue(b9));
        }

        static void handleTwoBytes(byte b7, byte b8, char[] cArr, int i7) throws IllegalArgumentException {
            if (b7 < -62) {
                throw new IllegalArgumentException("Invalid UTF-8: Illegal leading byte in 2 bytes utf");
            } else if (!isNotTrailingByte(b8)) {
                cArr[i7] = (char) (((b7 & Ascii.US) << 6) | trailingByteValue(b8));
            } else {
                throw new IllegalArgumentException("Invalid UTF-8: Illegal trailing byte in 2 bytes utf");
            }
        }

        private static char highSurrogate(int i7) {
            return (char) ((i7 >>> 10) + 55232);
        }

        private static boolean isNotTrailingByte(byte b7) {
            return b7 > -65;
        }

        static boolean isOneByte(byte b7) {
            return b7 >= 0;
        }

        static boolean isThreeBytes(byte b7) {
            return b7 < -16;
        }

        static boolean isTwoBytes(byte b7) {
            return b7 < -32;
        }

        private static char lowSurrogate(int i7) {
            return (char) ((i7 & 1023) + 56320);
        }

        private static int trailingByteValue(byte b7) {
            return b7 & 63;
        }
    }

    static class UnpairedSurrogateException extends IllegalArgumentException {
        UnpairedSurrogateException(int i7, int i8) {
            super("Unpaired surrogate at index " + i7 + " of " + i8);
        }
    }

    public static Utf8 getDefault() {
        if (DEFAULT == null) {
            DEFAULT = new Utf8Safe();
        }
        return DEFAULT;
    }

    public static void setDefault(Utf8 utf8) {
        DEFAULT = utf8;
    }

    public abstract String decodeUtf8(ByteBuffer byteBuffer, int i7, int i8);

    public abstract void encodeUtf8(CharSequence charSequence, ByteBuffer byteBuffer);

    public abstract int encodedLength(CharSequence charSequence);
}
