package androidx.emoji2.text.flatbuffer;

import androidx.emoji2.text.flatbuffer.Utf8;
import java.nio.ByteBuffer;

public final class Utf8Safe extends Utf8 {

    /* access modifiers changed from: package-private */
    public static class UnpairedSurrogateException extends IllegalArgumentException {
        UnpairedSurrogateException(int i7, int i8) {
            super("Unpaired surrogate at index " + i7 + " of " + i8);
        }
    }

    private static int computeEncodedLength(CharSequence charSequence) {
        int length = charSequence.length();
        int i7 = 0;
        while (i7 < length && charSequence.charAt(i7) < 128) {
            i7++;
        }
        int i8 = length;
        while (true) {
            if (i7 < length) {
                char charAt = charSequence.charAt(i7);
                if (charAt >= 2048) {
                    i8 += encodedLengthGeneral(charSequence, i7);
                    break;
                }
                i8 += (127 - charAt) >>> 31;
                i7++;
            } else {
                break;
            }
        }
        if (i8 >= length) {
            return i8;
        }
        throw new IllegalArgumentException("UTF-8 length does not fit in int: " + (((long) i8) + 4294967296L));
    }

    public static String decodeUtf8Array(byte[] bArr, int i7, int i8) {
        if ((i7 | i8 | ((bArr.length - i7) - i8)) >= 0) {
            int i9 = i7 + i8;
            char[] cArr = new char[i8];
            int i10 = 0;
            while (i7 < i9) {
                byte b7 = bArr[i7];
                if (!Utf8.DecodeUtil.isOneByte(b7)) {
                    break;
                }
                i7++;
                Utf8.DecodeUtil.handleOneByte(b7, cArr, i10);
                i10++;
            }
            int i11 = i10;
            while (i7 < i9) {
                int i12 = i7 + 1;
                byte b8 = bArr[i7];
                if (Utf8.DecodeUtil.isOneByte(b8)) {
                    int i13 = i11 + 1;
                    Utf8.DecodeUtil.handleOneByte(b8, cArr, i11);
                    while (i12 < i9) {
                        byte b9 = bArr[i12];
                        if (!Utf8.DecodeUtil.isOneByte(b9)) {
                            break;
                        }
                        i12++;
                        Utf8.DecodeUtil.handleOneByte(b9, cArr, i13);
                        i13++;
                    }
                    i7 = i12;
                    i11 = i13;
                } else if (Utf8.DecodeUtil.isTwoBytes(b8)) {
                    if (i12 < i9) {
                        Utf8.DecodeUtil.handleTwoBytes(b8, bArr[i12], cArr, i11);
                        i7 = i12 + 1;
                        i11++;
                    } else {
                        throw new IllegalArgumentException("Invalid UTF-8");
                    }
                } else if (Utf8.DecodeUtil.isThreeBytes(b8)) {
                    if (i12 < i9 - 1) {
                        int i14 = i12 + 1;
                        Utf8.DecodeUtil.handleThreeBytes(b8, bArr[i12], bArr[i14], cArr, i11);
                        i7 = i14 + 1;
                        i11++;
                    } else {
                        throw new IllegalArgumentException("Invalid UTF-8");
                    }
                } else if (i12 < i9 - 2) {
                    int i15 = i12 + 1;
                    byte b10 = bArr[i12];
                    int i16 = i15 + 1;
                    Utf8.DecodeUtil.handleFourBytes(b8, b10, bArr[i15], bArr[i16], cArr, i11);
                    i7 = i16 + 1;
                    i11 = i11 + 1 + 1;
                } else {
                    throw new IllegalArgumentException("Invalid UTF-8");
                }
            }
            return new String(cArr, 0, i11);
        }
        throw new ArrayIndexOutOfBoundsException(String.format("buffer length=%d, index=%d, size=%d", Integer.valueOf(bArr.length), Integer.valueOf(i7), Integer.valueOf(i8)));
    }

    public static String decodeUtf8Buffer(ByteBuffer byteBuffer, int i7, int i8) {
        if ((i7 | i8 | ((byteBuffer.limit() - i7) - i8)) >= 0) {
            int i9 = i7 + i8;
            char[] cArr = new char[i8];
            int i10 = 0;
            while (i7 < i9) {
                byte b7 = byteBuffer.get(i7);
                if (!Utf8.DecodeUtil.isOneByte(b7)) {
                    break;
                }
                i7++;
                Utf8.DecodeUtil.handleOneByte(b7, cArr, i10);
                i10++;
            }
            int i11 = i10;
            while (i7 < i9) {
                int i12 = i7 + 1;
                byte b8 = byteBuffer.get(i7);
                if (Utf8.DecodeUtil.isOneByte(b8)) {
                    int i13 = i11 + 1;
                    Utf8.DecodeUtil.handleOneByte(b8, cArr, i11);
                    while (i12 < i9) {
                        byte b9 = byteBuffer.get(i12);
                        if (!Utf8.DecodeUtil.isOneByte(b9)) {
                            break;
                        }
                        i12++;
                        Utf8.DecodeUtil.handleOneByte(b9, cArr, i13);
                        i13++;
                    }
                    i7 = i12;
                    i11 = i13;
                } else if (Utf8.DecodeUtil.isTwoBytes(b8)) {
                    if (i12 < i9) {
                        Utf8.DecodeUtil.handleTwoBytes(b8, byteBuffer.get(i12), cArr, i11);
                        i7 = i12 + 1;
                        i11++;
                    } else {
                        throw new IllegalArgumentException("Invalid UTF-8");
                    }
                } else if (Utf8.DecodeUtil.isThreeBytes(b8)) {
                    if (i12 < i9 - 1) {
                        int i14 = i12 + 1;
                        Utf8.DecodeUtil.handleThreeBytes(b8, byteBuffer.get(i12), byteBuffer.get(i14), cArr, i11);
                        i7 = i14 + 1;
                        i11++;
                    } else {
                        throw new IllegalArgumentException("Invalid UTF-8");
                    }
                } else if (i12 < i9 - 2) {
                    int i15 = i12 + 1;
                    byte b10 = byteBuffer.get(i12);
                    int i16 = i15 + 1;
                    Utf8.DecodeUtil.handleFourBytes(b8, b10, byteBuffer.get(i15), byteBuffer.get(i16), cArr, i11);
                    i7 = i16 + 1;
                    i11 = i11 + 1 + 1;
                } else {
                    throw new IllegalArgumentException("Invalid UTF-8");
                }
            }
            return new String(cArr, 0, i11);
        }
        throw new ArrayIndexOutOfBoundsException(String.format("buffer limit=%d, index=%d, limit=%d", Integer.valueOf(byteBuffer.limit()), Integer.valueOf(i7), Integer.valueOf(i8)));
    }

    private static int encodeUtf8Array(CharSequence charSequence, byte[] bArr, int i7, int i8) {
        int i9;
        int i10;
        int i11;
        char charAt;
        int length = charSequence.length();
        int i12 = i8 + i7;
        int i13 = 0;
        while (i13 < length && (i11 = i13 + i7) < i12 && (charAt = charSequence.charAt(i13)) < 128) {
            bArr[i11] = (byte) charAt;
            i13++;
        }
        if (i13 == length) {
            return i7 + length;
        }
        int i14 = i7 + i13;
        while (i13 < length) {
            char charAt2 = charSequence.charAt(i13);
            if (charAt2 < 128 && i14 < i12) {
                i10 = i14 + 1;
                bArr[i14] = (byte) charAt2;
            } else if (charAt2 < 2048 && i14 <= i12 - 2) {
                int i15 = i14 + 1;
                bArr[i14] = (byte) ((charAt2 >>> 6) | 960);
                i14 = i15 + 1;
                bArr[i15] = (byte) ((charAt2 & '?') | 128);
                i13++;
            } else if ((charAt2 < 55296 || 57343 < charAt2) && i14 <= i12 - 3) {
                int i16 = i14 + 1;
                bArr[i14] = (byte) ((charAt2 >>> '\f') | 480);
                int i17 = i16 + 1;
                bArr[i16] = (byte) (((charAt2 >>> 6) & 63) | 128);
                i10 = i17 + 1;
                bArr[i17] = (byte) ((charAt2 & '?') | 128);
            } else if (i14 <= i12 - 4) {
                int i18 = i13 + 1;
                if (i18 != charSequence.length()) {
                    char charAt3 = charSequence.charAt(i18);
                    if (Character.isSurrogatePair(charAt2, charAt3)) {
                        int codePoint = Character.toCodePoint(charAt2, charAt3);
                        int i19 = i14 + 1;
                        bArr[i14] = (byte) ((codePoint >>> 18) | 240);
                        int i20 = i19 + 1;
                        bArr[i19] = (byte) (((codePoint >>> 12) & 63) | 128);
                        int i21 = i20 + 1;
                        bArr[i20] = (byte) (((codePoint >>> 6) & 63) | 128);
                        i14 = i21 + 1;
                        bArr[i21] = (byte) ((codePoint & 63) | 128);
                        i13 = i18;
                        i13++;
                    } else {
                        i13 = i18;
                    }
                }
                throw new UnpairedSurrogateException(i13 - 1, length);
            } else if (55296 > charAt2 || charAt2 > 57343 || ((i9 = i13 + 1) != charSequence.length() && Character.isSurrogatePair(charAt2, charSequence.charAt(i9)))) {
                throw new ArrayIndexOutOfBoundsException("Failed writing " + charAt2 + " at index " + i14);
            } else {
                throw new UnpairedSurrogateException(i13, length);
            }
            i14 = i10;
            i13++;
        }
        return i14;
    }

    private static void encodeUtf8Buffer(CharSequence charSequence, ByteBuffer byteBuffer) {
        int length = charSequence.length();
        int position = byteBuffer.position();
        int i7 = 0;
        while (i7 < length) {
            try {
                char charAt = charSequence.charAt(i7);
                if (charAt >= 128) {
                    break;
                }
                byteBuffer.put(position + i7, (byte) charAt);
                i7++;
            } catch (IndexOutOfBoundsException unused) {
                throw new ArrayIndexOutOfBoundsException("Failed writing " + charSequence.charAt(i7) + " at index " + (byteBuffer.position() + Math.max(i7, (position - byteBuffer.position()) + 1)));
            }
        }
        if (i7 == length) {
            byteBuffer.position(position + i7);
            return;
        }
        position += i7;
        while (i7 < length) {
            char charAt2 = charSequence.charAt(i7);
            if (charAt2 < 128) {
                byteBuffer.put(position, (byte) charAt2);
            } else if (charAt2 < 2048) {
                int i8 = position + 1;
                try {
                    byteBuffer.put(position, (byte) ((charAt2 >>> 6) | 192));
                    byteBuffer.put(i8, (byte) ((charAt2 & '?') | 128));
                    position = i8;
                } catch (IndexOutOfBoundsException unused2) {
                    position = i8;
                    throw new ArrayIndexOutOfBoundsException("Failed writing " + charSequence.charAt(i7) + " at index " + (byteBuffer.position() + Math.max(i7, (position - byteBuffer.position()) + 1)));
                }
            } else if (charAt2 < 55296 || 57343 < charAt2) {
                int i9 = position + 1;
                byteBuffer.put(position, (byte) ((charAt2 >>> '\f') | 224));
                position = i9 + 1;
                byteBuffer.put(i9, (byte) (((charAt2 >>> 6) & 63) | 128));
                byteBuffer.put(position, (byte) ((charAt2 & '?') | 128));
            } else {
                int i10 = i7 + 1;
                if (i10 != length) {
                    try {
                        char charAt3 = charSequence.charAt(i10);
                        if (Character.isSurrogatePair(charAt2, charAt3)) {
                            int codePoint = Character.toCodePoint(charAt2, charAt3);
                            int i11 = position + 1;
                            try {
                                byteBuffer.put(position, (byte) ((codePoint >>> 18) | 240));
                                int i12 = i11 + 1;
                                byteBuffer.put(i11, (byte) (((codePoint >>> 12) & 63) | 128));
                                int i13 = i12 + 1;
                                byteBuffer.put(i12, (byte) (((codePoint >>> 6) & 63) | 128));
                                byteBuffer.put(i13, (byte) ((codePoint & 63) | 128));
                                position = i13;
                                i7 = i10;
                            } catch (IndexOutOfBoundsException unused3) {
                                position = i11;
                                i7 = i10;
                                throw new ArrayIndexOutOfBoundsException("Failed writing " + charSequence.charAt(i7) + " at index " + (byteBuffer.position() + Math.max(i7, (position - byteBuffer.position()) + 1)));
                            }
                        } else {
                            i7 = i10;
                        }
                    } catch (IndexOutOfBoundsException unused4) {
                        i7 = i10;
                        throw new ArrayIndexOutOfBoundsException("Failed writing " + charSequence.charAt(i7) + " at index " + (byteBuffer.position() + Math.max(i7, (position - byteBuffer.position()) + 1)));
                    }
                }
                throw new UnpairedSurrogateException(i7, length);
            }
            i7++;
            position++;
        }
        byteBuffer.position(position);
    }

    private static int encodedLengthGeneral(CharSequence charSequence, int i7) {
        int length = charSequence.length();
        int i8 = 0;
        while (i7 < length) {
            char charAt = charSequence.charAt(i7);
            if (charAt < 2048) {
                i8 += (127 - charAt) >>> 31;
            } else {
                i8 += 2;
                if (55296 <= charAt && charAt <= 57343) {
                    if (Character.codePointAt(charSequence, i7) >= 65536) {
                        i7++;
                    } else {
                        throw new UnpairedSurrogateException(i7, length);
                    }
                }
            }
            i7++;
        }
        return i8;
    }

    @Override // androidx.emoji2.text.flatbuffer.Utf8
    public String decodeUtf8(ByteBuffer byteBuffer, int i7, int i8) throws IllegalArgumentException {
        return byteBuffer.hasArray() ? decodeUtf8Array(byteBuffer.array(), byteBuffer.arrayOffset() + i7, i8) : decodeUtf8Buffer(byteBuffer, i7, i8);
    }

    @Override // androidx.emoji2.text.flatbuffer.Utf8
    public void encodeUtf8(CharSequence charSequence, ByteBuffer byteBuffer) {
        if (byteBuffer.hasArray()) {
            int arrayOffset = byteBuffer.arrayOffset();
            byteBuffer.position(encodeUtf8Array(charSequence, byteBuffer.array(), byteBuffer.position() + arrayOffset, byteBuffer.remaining()) - arrayOffset);
            return;
        }
        encodeUtf8Buffer(charSequence, byteBuffer);
    }

    @Override // androidx.emoji2.text.flatbuffer.Utf8
    public int encodedLength(CharSequence charSequence) {
        return computeEncodedLength(charSequence);
    }
}
