package androidx.navigation;

import android.net.Uri;
import android.os.Bundle;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.ListIterator;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import kotlin.collections.g0;
import kotlin.collections.y;
import kotlin.d0;
import kotlin.f0;
import kotlin.jvm.internal.l0;
import kotlin.jvm.internal.w;
import kotlin.text.b0;
import kotlin.text.c0;
import kotlin.text.o;

public final class NavDeepLink {
    private static final Companion Companion = new Companion(null);
    private static final Pattern SCHEME_PATTERN = Pattern.compile("^[a-zA-Z]+[+\\w\\-.]*:");
    private final String action;
    private final List<String> arguments;
    private boolean isExactDeepLink;
    private boolean isParameterizedQuery;
    private boolean isSingleQueryParamValueOnly;
    private final String mimeType;
    private String mimeTypeFinalRegex;
    private final d0 mimeTypePattern$delegate;
    private final Map<String, ParamQuery> paramArgMap;
    private final d0 pattern$delegate;
    private String patternFinalRegex;
    private final String uriPattern;

    public static final class Builder {
        public static final Companion Companion = new Companion(null);
        private String action;
        private String mimeType;
        private String uriPattern;

        public static final class Companion {
            private Companion() {
            }

            public final Builder fromAction(String str) {
                l0.p(str, "action");
                if (str.length() > 0) {
                    Builder builder = new Builder();
                    builder.setAction(str);
                    return builder;
                }
                throw new IllegalArgumentException("The NavDeepLink cannot have an empty action.".toString());
            }

            public final Builder fromMimeType(String str) {
                l0.p(str, "mimeType");
                Builder builder = new Builder();
                builder.setMimeType(str);
                return builder;
            }

            public final Builder fromUriPattern(String str) {
                l0.p(str, "uriPattern");
                Builder builder = new Builder();
                builder.setUriPattern(str);
                return builder;
            }

            public /* synthetic */ Companion(w wVar) {
                this();
            }
        }

        public static final Builder fromAction(String str) {
            return Companion.fromAction(str);
        }

        public static final Builder fromMimeType(String str) {
            return Companion.fromMimeType(str);
        }

        public static final Builder fromUriPattern(String str) {
            return Companion.fromUriPattern(str);
        }

        public final NavDeepLink build() {
            return new NavDeepLink(this.uriPattern, this.action, this.mimeType);
        }

        public final Builder setAction(String str) {
            l0.p(str, "action");
            if (str.length() > 0) {
                this.action = str;
                return this;
            }
            throw new IllegalArgumentException("The NavDeepLink cannot have an empty action.".toString());
        }

        public final Builder setMimeType(String str) {
            l0.p(str, "mimeType");
            this.mimeType = str;
            return this;
        }

        public final Builder setUriPattern(String str) {
            l0.p(str, "uriPattern");
            this.uriPattern = str;
            return this;
        }
    }

    private static final class Companion {
        private Companion() {
        }

        public /* synthetic */ Companion(w wVar) {
            this();
        }
    }

    public static final class MimeType implements Comparable<MimeType> {
        private String subType;
        private String type;

        public MimeType(String str) {
            List list;
            boolean z7;
            l0.p(str, "mimeType");
            List<String> r7 = new o("/").r(str, 0);
            if (!r7.isEmpty()) {
                ListIterator<String> listIterator = r7.listIterator(r7.size());
                while (true) {
                    if (!listIterator.hasPrevious()) {
                        break;
                    }
                    if (listIterator.previous().length() == 0) {
                        z7 = true;
                        continue;
                    } else {
                        z7 = false;
                        continue;
                    }
                    if (!z7) {
                        list = g0.E5(r7, listIterator.nextIndex() + 1);
                        break;
                    }
                }
                this.type = (String) list.get(0);
                this.subType = (String) list.get(1);
            }
            list = y.F();
            this.type = (String) list.get(0);
            this.subType = (String) list.get(1);
        }

        public int compareTo(MimeType mimeType) {
            l0.p(mimeType, "other");
            int i7 = l0.g(this.type, mimeType.type) ? 2 : 0;
            return l0.g(this.subType, mimeType.subType) ? i7 + 1 : i7;
        }

        public final String getSubType() {
            return this.subType;
        }

        public final String getType() {
            return this.type;
        }

        public final void setSubType(String str) {
            l0.p(str, "<set-?>");
            this.subType = str;
        }

        public final void setType(String str) {
            l0.p(str, "<set-?>");
            this.type = str;
        }
    }

    public static final class ParamQuery {
        private final List<String> arguments = new ArrayList();
        private String paramRegex;

        public final void addArgumentName(String str) {
            l0.p(str, "name");
            this.arguments.add(str);
        }

        public final String getArgumentName(int i7) {
            return this.arguments.get(i7);
        }

        public final List<String> getArguments() {
            return this.arguments;
        }

        public final String getParamRegex() {
            return this.paramRegex;
        }

        public final void setParamRegex(String str) {
            this.paramRegex = str;
        }

        public final int size() {
            return this.arguments.size();
        }
    }

    /* JADX INFO: this call moved to the top of the method (can break code semantics) */
    public NavDeepLink(String str) {
        this(str, null, null);
        l0.p(str, "uri");
    }

    private final boolean buildPathRegex(String str, StringBuilder sb, Pattern pattern) {
        Matcher matcher = pattern.matcher(str);
        boolean z7 = !c0.V2(str, ".*", false, 2, null);
        int i7 = 0;
        while (matcher.find()) {
            String group = matcher.group(1);
            if (group != null) {
                this.arguments.add(group);
                String substring = str.substring(i7, matcher.start());
                l0.o(substring, "this as java.lang.String…ing(startIndex, endIndex)");
                sb.append(Pattern.quote(substring));
                sb.append("([^/]+?)");
                i7 = matcher.end();
                z7 = false;
            } else {
                throw new NullPointerException("null cannot be cast to non-null type kotlin.String");
            }
        }
        if (i7 < str.length()) {
            String substring2 = str.substring(i7);
            l0.o(substring2, "this as java.lang.String).substring(startIndex)");
            sb.append(Pattern.quote(substring2));
        }
        sb.append("($|(\\?(.)*)|(\\#(.)*))");
        return z7;
    }

    private final Pattern getMimeTypePattern() {
        return (Pattern) this.mimeTypePattern$delegate.getValue();
    }

    private final Pattern getPattern() {
        return (Pattern) this.pattern$delegate.getValue();
    }

    private final boolean matchAction(String str) {
        boolean z7 = str == null;
        String str2 = this.action;
        return z7 != (str2 != null) && (str == null || l0.g(str2, str));
    }

    private final boolean matchMimeType(String str) {
        if ((str == null) != (this.mimeType != null)) {
            if (str == null) {
                return true;
            }
            Pattern mimeTypePattern = getMimeTypePattern();
            l0.m(mimeTypePattern);
            if (mimeTypePattern.matcher(str).matches()) {
                return true;
            }
        }
        return false;
    }

    private final boolean matchUri(Uri uri) {
        if ((uri == null) != (getPattern() != null)) {
            if (uri == null) {
                return true;
            }
            Pattern pattern = getPattern();
            l0.m(pattern);
            if (pattern.matcher(uri.toString()).matches()) {
                return true;
            }
        }
        return false;
    }

    private final boolean parseArgument(Bundle bundle, String str, String str2, NavArgument navArgument) {
        if (navArgument != null) {
            navArgument.getType().parseAndPut(bundle, str, str2);
            return false;
        }
        bundle.putString(str, str2);
        return false;
    }

    public boolean equals(Object obj) {
        if (obj == null || !(obj instanceof NavDeepLink)) {
            return false;
        }
        NavDeepLink navDeepLink = (NavDeepLink) obj;
        return l0.g(this.uriPattern, navDeepLink.uriPattern) && l0.g(this.action, navDeepLink.action) && l0.g(this.mimeType, navDeepLink.mimeType);
    }

    public final String getAction() {
        return this.action;
    }

    public final List<String> getArgumentsNames$navigation_common_release() {
        List<String> list = this.arguments;
        ArrayList arrayList = new ArrayList();
        Iterator<T> it = this.paramArgMap.values().iterator();
        while (it.hasNext()) {
            boolean unused = kotlin.collections.d0.o0(arrayList, it.next().getArguments());
        }
        return g0.y4(list, arrayList);
    }

    public final Bundle getMatchingArguments(Uri uri, Map<String, NavArgument> map) {
        Matcher matcher;
        String str;
        l0.p(uri, "deepLink");
        l0.p(map, "arguments");
        Pattern pattern = getPattern();
        Matcher matcher2 = pattern != null ? pattern.matcher(uri.toString()) : null;
        if (matcher2 == null || !matcher2.matches()) {
            return null;
        }
        Bundle bundle = new Bundle();
        int size = this.arguments.size();
        int i7 = 0;
        while (i7 < size) {
            String str2 = this.arguments.get(i7);
            i7++;
            String decode = Uri.decode(matcher2.group(i7));
            NavArgument navArgument = map.get(str2);
            try {
                l0.o(decode, "value");
                if (parseArgument(bundle, str2, decode, navArgument)) {
                    return null;
                }
            } catch (IllegalArgumentException unused) {
            }
        }
        if (this.isParameterizedQuery) {
            for (String str3 : this.paramArgMap.keySet()) {
                ParamQuery paramQuery = this.paramArgMap.get(str3);
                String queryParameter = uri.getQueryParameter(str3);
                if (this.isSingleQueryParamValueOnly) {
                    String uri2 = uri.toString();
                    l0.o(uri2, "deepLink.toString()");
                    String str4 = c0.o5(uri2, '?', null, 2, null);
                    if (!l0.g(str4, uri2)) {
                        queryParameter = str4;
                    }
                }
                if (queryParameter != null) {
                    l0.m(paramQuery);
                    matcher = Pattern.compile(paramQuery.getParamRegex(), 32).matcher(queryParameter);
                    if (!matcher.matches()) {
                        return null;
                    }
                } else {
                    matcher = null;
                }
                Bundle bundle2 = new Bundle();
                try {
                    l0.m(paramQuery);
                    int size2 = paramQuery.size();
                    for (int i8 = 0; i8 < size2; i8++) {
                        if (matcher != null) {
                            str = matcher.group(i8 + 1);
                            if (str == null) {
                                str = "";
                            }
                        } else {
                            str = null;
                        }
                        String argumentName = paramQuery.getArgumentName(i8);
                        NavArgument navArgument2 = map.get(argumentName);
                        if (str != null) {
                            if (!l0.g(str, '{' + argumentName + '}') && parseArgument(bundle2, argumentName, str, navArgument2)) {
                                return null;
                            }
                        }
                    }
                    bundle.putAll(bundle2);
                } catch (IllegalArgumentException unused2) {
                }
            }
        }
        for (Map.Entry<String, NavArgument> entry : map.entrySet()) {
            String key = entry.getKey();
            NavArgument value = entry.getValue();
            if ((value != null && !value.isNullable() && !value.isDefaultValuePresent()) && !bundle.containsKey(key)) {
                return null;
            }
        }
        return bundle;
    }

    public final String getMimeType() {
        return this.mimeType;
    }

    public final int getMimeTypeMatchRating(String str) {
        l0.p(str, "mimeType");
        if (this.mimeType != null) {
            Pattern mimeTypePattern = getMimeTypePattern();
            l0.m(mimeTypePattern);
            if (mimeTypePattern.matcher(str).matches()) {
                return new MimeType(this.mimeType).compareTo(new MimeType(str));
            }
        }
        return -1;
    }

    public final String getUriPattern() {
        return this.uriPattern;
    }

    public int hashCode() {
        String str = this.uriPattern;
        int i7 = 0;
        int hashCode = ((str != null ? str.hashCode() : 0) + 0) * 31;
        String str2 = this.action;
        int hashCode2 = (hashCode + (str2 != null ? str2.hashCode() : 0)) * 31;
        String str3 = this.mimeType;
        if (str3 != null) {
            i7 = str3.hashCode();
        }
        return hashCode2 + i7;
    }

    public final boolean isExactDeepLink() {
        return this.isExactDeepLink;
    }

    public final boolean matches$navigation_common_release(Uri uri) {
        l0.p(uri, "uri");
        return matches$navigation_common_release(new NavDeepLinkRequest(uri, null, null));
    }

    public final void setExactDeepLink$navigation_common_release(boolean z7) {
        this.isExactDeepLink = z7;
    }

    public NavDeepLink(String str, String str2, String str3) {
        this.uriPattern = str;
        this.action = str2;
        this.mimeType = str3;
        this.arguments = new ArrayList();
        this.paramArgMap = new LinkedHashMap();
        this.pattern$delegate = f0.c(new NavDeepLink$pattern$2(this));
        this.mimeTypePattern$delegate = f0.c(new NavDeepLink$mimeTypePattern$2(this));
        if (str != null) {
            Uri parse = Uri.parse(str);
            this.isParameterizedQuery = parse.getQuery() != null;
            StringBuilder sb = new StringBuilder("^");
            if (!SCHEME_PATTERN.matcher(str).find()) {
                sb.append("http[s]?://");
            }
            Pattern compile = Pattern.compile("\\{(.+?)\\}");
            if (this.isParameterizedQuery) {
                Matcher matcher = Pattern.compile("(\\?)").matcher(str);
                if (matcher.find()) {
                    String substring = str.substring(0, matcher.start());
                    l0.o(substring, "this as java.lang.String…ing(startIndex, endIndex)");
                    l0.o(compile, "fillInPattern");
                    this.isExactDeepLink = buildPathRegex(substring, sb, compile);
                }
                for (String str4 : parse.getQueryParameterNames()) {
                    StringBuilder sb2 = new StringBuilder();
                    String queryParameter = parse.getQueryParameter(str4);
                    if (queryParameter == null) {
                        this.isSingleQueryParamValueOnly = true;
                        queryParameter = str4;
                    }
                    Matcher matcher2 = compile.matcher(queryParameter);
                    ParamQuery paramQuery = new ParamQuery();
                    int i7 = 0;
                    while (matcher2.find()) {
                        String group = matcher2.group(1);
                        if (group != null) {
                            paramQuery.addArgumentName(group);
                            l0.o(queryParameter, "queryParam");
                            String substring2 = queryParameter.substring(i7, matcher2.start());
                            l0.o(substring2, "this as java.lang.String…ing(startIndex, endIndex)");
                            sb2.append(Pattern.quote(substring2));
                            sb2.append("(.+?)?");
                            i7 = matcher2.end();
                        } else {
                            throw new NullPointerException("null cannot be cast to non-null type kotlin.String");
                        }
                    }
                    if (i7 < queryParameter.length()) {
                        l0.o(queryParameter, "queryParam");
                        String substring3 = queryParameter.substring(i7);
                        l0.o(substring3, "this as java.lang.String).substring(startIndex)");
                        sb2.append(Pattern.quote(substring3));
                    }
                    String sb3 = sb2.toString();
                    l0.o(sb3, "argRegex.toString()");
                    paramQuery.setParamRegex(b0.k2(sb3, ".*", "\\E.*\\Q", false, 4, null));
                    Map<String, ParamQuery> map = this.paramArgMap;
                    l0.o(str4, "paramName");
                    map.put(str4, paramQuery);
                }
            } else {
                l0.o(compile, "fillInPattern");
                this.isExactDeepLink = buildPathRegex(str, sb, compile);
            }
            String sb4 = sb.toString();
            l0.o(sb4, "uriRegex.toString()");
            this.patternFinalRegex = b0.k2(sb4, ".*", "\\E.*\\Q", false, 4, null);
        }
        if (this.mimeType == null) {
            return;
        }
        if (Pattern.compile("^[\\s\\S]+/[\\s\\S]+$").matcher(this.mimeType).matches()) {
            MimeType mimeType2 = new MimeType(this.mimeType);
            this.mimeTypeFinalRegex = b0.k2("^(" + mimeType2.getType() + "|[*]+)/(" + mimeType2.getSubType() + "|[*]+)$", "*|[*]", "[\\s\\S]", false, 4, null);
            return;
        }
        throw new IllegalArgumentException(("The given mimeType " + this.mimeType + " does not match to required \"type/subtype\" format").toString());
    }

    public final boolean matches$navigation_common_release(NavDeepLinkRequest navDeepLinkRequest) {
        l0.p(navDeepLinkRequest, "deepLinkRequest");
        if (matchUri(navDeepLinkRequest.getUri()) && matchAction(navDeepLinkRequest.getAction())) {
            return matchMimeType(navDeepLinkRequest.getMimeType());
        }
        return false;
    }
}
