package androidx.navigation;

import kotlin.jvm.internal.l0;

public final class NavOptions {
    private final int enterAnim;
    private final int exitAnim;
    private final int popEnterAnim;
    private final int popExitAnim;
    private final int popUpToId;
    private final boolean popUpToInclusive;
    private String popUpToRoute;
    private final boolean popUpToSaveState;
    private final boolean restoreState;
    private final boolean singleTop;

    public static final class Builder {
        private int enterAnim = -1;
        private int exitAnim = -1;
        private int popEnterAnim = -1;
        private int popExitAnim = -1;
        private int popUpToId = -1;
        private boolean popUpToInclusive;
        private String popUpToRoute;
        private boolean popUpToSaveState;
        private boolean restoreState;
        private boolean singleTop;

        public static /* synthetic */ Builder setPopUpTo$default(Builder builder, int i7, boolean z7, boolean z8, int i8, Object obj) {
            if ((i8 & 4) != 0) {
                z8 = false;
            }
            return builder.setPopUpTo(i7, z7, z8);
        }

        public final NavOptions build() {
            NavOptions navOptions;
            if (this.popUpToRoute != null) {
                boolean z7 = this.singleTop;
                boolean z8 = this.restoreState;
                boolean z9 = this.popUpToInclusive;
                boolean z10 = this.popUpToSaveState;
                int i7 = this.enterAnim;
                int i8 = this.exitAnim;
                int i9 = this.popEnterAnim;
                int i10 = this.popExitAnim;
            } else {
                navOptions = new NavOptions(this.singleTop, this.restoreState, this.popUpToId, this.popUpToInclusive, this.popUpToSaveState, this.enterAnim, this.exitAnim, this.popEnterAnim, this.popExitAnim);
            }
            return navOptions;
        }

        public final Builder setEnterAnim(int i7) {
            this.enterAnim = i7;
            return this;
        }

        public final Builder setExitAnim(int i7) {
            this.exitAnim = i7;
            return this;
        }

        public final Builder setLaunchSingleTop(boolean z7) {
            this.singleTop = z7;
            return this;
        }

        public final Builder setPopEnterAnim(int i7) {
            this.popEnterAnim = i7;
            return this;
        }

        public final Builder setPopExitAnim(int i7) {
            this.popExitAnim = i7;
            return this;
        }

        public final Builder setPopUpTo(int i7, boolean z7) {
            return setPopUpTo$default(this, i7, z7, false, 4, (Object) null);
        }

        public final Builder setRestoreState(boolean z7) {
            this.restoreState = z7;
            return this;
        }

        public static /* synthetic */ Builder setPopUpTo$default(Builder builder, String str, boolean z7, boolean z8, int i7, Object obj) {
            if ((i7 & 4) != 0) {
                z8 = false;
            }
            return builder.setPopUpTo(str, z7, z8);
        }

        public final Builder setPopUpTo(int i7, boolean z7, boolean z8) {
            this.popUpToId = i7;
            this.popUpToRoute = null;
            this.popUpToInclusive = z7;
            this.popUpToSaveState = z8;
            return this;
        }

        public final Builder setPopUpTo(String str, boolean z7) {
            return setPopUpTo$default(this, str, z7, false, 4, (Object) null);
        }

        public final Builder setPopUpTo(String str, boolean z7, boolean z8) {
            this.popUpToRoute = str;
            this.popUpToId = -1;
            this.popUpToInclusive = z7;
            this.popUpToSaveState = z8;
            return this;
        }
    }

    public NavOptions(boolean z7, boolean z8, int i7, boolean z9, boolean z10, int i8, int i9, int i10, int i11) {
        this.singleTop = z7;
        this.restoreState = z8;
        this.popUpToId = i7;
        this.popUpToInclusive = z9;
        this.popUpToSaveState = z10;
        this.enterAnim = i8;
        this.exitAnim = i9;
        this.popEnterAnim = i10;
        this.popExitAnim = i11;
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null || !l0.g(NavOptions.class, obj.getClass())) {
            return false;
        }
        NavOptions navOptions = (NavOptions) obj;
        return this.singleTop == navOptions.singleTop && this.restoreState == navOptions.restoreState && this.popUpToId == navOptions.popUpToId && l0.g(this.popUpToRoute, navOptions.popUpToRoute) && this.popUpToInclusive == navOptions.popUpToInclusive && this.popUpToSaveState == navOptions.popUpToSaveState && this.enterAnim == navOptions.enterAnim && this.exitAnim == navOptions.exitAnim && this.popEnterAnim == navOptions.popEnterAnim && this.popExitAnim == navOptions.popExitAnim;
    }

    public final int getEnterAnim() {
        return this.enterAnim;
    }

    public final int getExitAnim() {
        return this.exitAnim;
    }

    public final int getPopEnterAnim() {
        return this.popEnterAnim;
    }

    public final int getPopExitAnim() {
        return this.popExitAnim;
    }

    public final int getPopUpTo() {
        return this.popUpToId;
    }

    public final int getPopUpToId() {
        return this.popUpToId;
    }

    public final String getPopUpToRoute() {
        return this.popUpToRoute;
    }

    public int hashCode() {
        int i7 = (((((shouldLaunchSingleTop() ? 1 : 0) * 31) + (shouldRestoreState() ? 1 : 0)) * 31) + this.popUpToId) * 31;
        String str = this.popUpToRoute;
        return ((((((((((((i7 + (str != null ? str.hashCode() : 0)) * 31) + (isPopUpToInclusive() ? 1 : 0)) * 31) + (shouldPopUpToSaveState() ? 1 : 0)) * 31) + this.enterAnim) * 31) + this.exitAnim) * 31) + this.popEnterAnim) * 31) + this.popExitAnim;
    }

    public final boolean isPopUpToInclusive() {
        return this.popUpToInclusive;
    }

    public final boolean shouldLaunchSingleTop() {
        return this.singleTop;
    }

    public final boolean shouldPopUpToSaveState() {
        return this.popUpToSaveState;
    }

    public final boolean shouldRestoreState() {
        return this.restoreState;
    }

    public NavOptions(boolean z7, boolean z8, String str, boolean z9, boolean z10, int i7, int i8, int i9, int i10) {
        this(z7, z8, NavDestination.Companion.createRoute(str).hashCode(), z9, z10, i7, i8, i9, i10);
        this.popUpToRoute = str;
    }
}
