package androidx.recyclerview.widget;

import android.util.Log;
import android.util.SparseBooleanArray;
import android.util.SparseIntArray;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.annotation.UiThread;
import androidx.annotation.WorkerThread;
import androidx.recyclerview.widget.ThreadUtil;
import androidx.recyclerview.widget.TileList;

public class AsyncListUtil<T> {
    static final boolean DEBUG = false;
    static final String TAG = "AsyncListUtil";
    boolean mAllowScrollHints;
    private final ThreadUtil.BackgroundCallback<T> mBackgroundCallback;
    final ThreadUtil.BackgroundCallback<T> mBackgroundProxy;
    final DataCallback<T> mDataCallback;
    int mDisplayedGeneration = 0;
    int mItemCount = 0;
    private final ThreadUtil.MainThreadCallback<T> mMainThreadCallback;
    final ThreadUtil.MainThreadCallback<T> mMainThreadProxy;
    final SparseIntArray mMissingPositions = new SparseIntArray();
    final int[] mPrevRange = new int[2];
    int mRequestedGeneration = 0;
    private int mScrollHint = 0;
    final Class<T> mTClass;
    final TileList<T> mTileList;
    final int mTileSize;
    final int[] mTmpRange = new int[2];
    final int[] mTmpRangeExtended = new int[2];
    final ViewCallback mViewCallback;

    public static abstract class DataCallback<T> {
        @WorkerThread
        public abstract void fillData(@NonNull T[] tArr, int i7, int i8);

        @WorkerThread
        public int getMaxCachedTiles() {
            return 10;
        }

        @WorkerThread
        public void recycleData(@NonNull T[] tArr, int i7) {
        }

        @WorkerThread
        public abstract int refreshData();
    }

    public static abstract class ViewCallback {
        public static final int HINT_SCROLL_ASC = 2;
        public static final int HINT_SCROLL_DESC = 1;
        public static final int HINT_SCROLL_NONE = 0;

        @UiThread
        public void extendRangeInto(@NonNull int[] iArr, @NonNull int[] iArr2, int i7) {
            int i8 = iArr[1];
            int i9 = iArr[0];
            int i10 = (i8 - i9) + 1;
            int i11 = i10 / 2;
            iArr2[0] = i9 - (i7 == 1 ? i10 : i11);
            if (i7 != 2) {
                i10 = i11;
            }
            iArr2[1] = i8 + i10;
        }

        @UiThread
        public abstract void getItemRangeInto(@NonNull int[] iArr);

        @UiThread
        public abstract void onDataRefresh();

        @UiThread
        public abstract void onItemLoaded(int i7);
    }

    public AsyncListUtil(@NonNull Class<T> cls, int i7, @NonNull DataCallback<T> dataCallback, @NonNull ViewCallback viewCallback) {
        AnonymousClass1 r02 = new ThreadUtil.MainThreadCallback<T>() {
            /* class androidx.recyclerview.widget.AsyncListUtil.AnonymousClass1 */

            private boolean isRequestedGeneration(int i7) {
                return i7 == AsyncListUtil.this.mRequestedGeneration;
            }

            private void recycleAllTiles() {
                for (int i7 = 0; i7 < AsyncListUtil.this.mTileList.size(); i7++) {
                    AsyncListUtil asyncListUtil = AsyncListUtil.this;
                    asyncListUtil.mBackgroundProxy.recycleTile(asyncListUtil.mTileList.getAtIndex(i7));
                }
                AsyncListUtil.this.mTileList.clear();
            }

            @Override // androidx.recyclerview.widget.ThreadUtil.MainThreadCallback
            public void addTile(int i7, TileList.Tile<T> tile) {
                if (!isRequestedGeneration(i7)) {
                    AsyncListUtil.this.mBackgroundProxy.recycleTile(tile);
                    return;
                }
                TileList.Tile<T> addOrReplace = AsyncListUtil.this.mTileList.addOrReplace(tile);
                if (addOrReplace != null) {
                    Log.e(AsyncListUtil.TAG, "duplicate tile @" + addOrReplace.mStartPosition);
                    AsyncListUtil.this.mBackgroundProxy.recycleTile(addOrReplace);
                }
                int i8 = tile.mStartPosition + tile.mItemCount;
                int i9 = 0;
                while (i9 < AsyncListUtil.this.mMissingPositions.size()) {
                    int keyAt = AsyncListUtil.this.mMissingPositions.keyAt(i9);
                    if (tile.mStartPosition > keyAt || keyAt >= i8) {
                        i9++;
                    } else {
                        AsyncListUtil.this.mMissingPositions.removeAt(i9);
                        AsyncListUtil.this.mViewCallback.onItemLoaded(keyAt);
                    }
                }
            }

            @Override // androidx.recyclerview.widget.ThreadUtil.MainThreadCallback
            public void removeTile(int i7, int i8) {
                if (isRequestedGeneration(i7)) {
                    TileList.Tile<T> removeAtPos = AsyncListUtil.this.mTileList.removeAtPos(i8);
                    if (removeAtPos == null) {
                        Log.e(AsyncListUtil.TAG, "tile not found @" + i8);
                        return;
                    }
                    AsyncListUtil.this.mBackgroundProxy.recycleTile(removeAtPos);
                }
            }

            @Override // androidx.recyclerview.widget.ThreadUtil.MainThreadCallback
            public void updateItemCount(int i7, int i8) {
                if (isRequestedGeneration(i7)) {
                    AsyncListUtil asyncListUtil = AsyncListUtil.this;
                    asyncListUtil.mItemCount = i8;
                    asyncListUtil.mViewCallback.onDataRefresh();
                    AsyncListUtil asyncListUtil2 = AsyncListUtil.this;
                    asyncListUtil2.mDisplayedGeneration = asyncListUtil2.mRequestedGeneration;
                    recycleAllTiles();
                    AsyncListUtil asyncListUtil3 = AsyncListUtil.this;
                    asyncListUtil3.mAllowScrollHints = false;
                    asyncListUtil3.updateRange();
                }
            }
        };
        this.mMainThreadCallback = r02;
        AnonymousClass2 r12 = new ThreadUtil.BackgroundCallback<T>() {
            /* class androidx.recyclerview.widget.AsyncListUtil.AnonymousClass2 */
            private int mFirstRequiredTileStart;
            private int mGeneration;
            private int mItemCount;
            private int mLastRequiredTileStart;
            final SparseBooleanArray mLoadedTiles = new SparseBooleanArray();
            private TileList.Tile<T> mRecycledRoot;

            private TileList.Tile<T> acquireTile() {
                TileList.Tile<T> tile = this.mRecycledRoot;
                if (tile != null) {
                    this.mRecycledRoot = tile.mNext;
                    return tile;
                }
                AsyncListUtil asyncListUtil = AsyncListUtil.this;
                return new TileList.Tile<>(asyncListUtil.mTClass, asyncListUtil.mTileSize);
            }

            private void addTile(TileList.Tile<T> tile) {
                this.mLoadedTiles.put(tile.mStartPosition, true);
                AsyncListUtil.this.mMainThreadProxy.addTile(this.mGeneration, tile);
            }

            private void flushTileCache(int i7) {
                int maxCachedTiles = AsyncListUtil.this.mDataCallback.getMaxCachedTiles();
                while (this.mLoadedTiles.size() >= maxCachedTiles) {
                    int keyAt = this.mLoadedTiles.keyAt(0);
                    SparseBooleanArray sparseBooleanArray = this.mLoadedTiles;
                    int keyAt2 = sparseBooleanArray.keyAt(sparseBooleanArray.size() - 1);
                    int i8 = this.mFirstRequiredTileStart - keyAt;
                    int i9 = keyAt2 - this.mLastRequiredTileStart;
                    if (i8 > 0 && (i8 >= i9 || i7 == 2)) {
                        removeTile(keyAt);
                    } else if (i9 <= 0) {
                        return;
                    } else {
                        if (i8 < i9 || i7 == 1) {
                            removeTile(keyAt2);
                        } else {
                            return;
                        }
                    }
                }
            }

            private int getTileStart(int i7) {
                return i7 - (i7 % AsyncListUtil.this.mTileSize);
            }

            private boolean isTileLoaded(int i7) {
                return this.mLoadedTiles.get(i7);
            }

            private void log(String str, Object... objArr) {
                Log.d(AsyncListUtil.TAG, "[BKGR] " + String.format(str, objArr));
            }

            private void removeTile(int i7) {
                this.mLoadedTiles.delete(i7);
                AsyncListUtil.this.mMainThreadProxy.removeTile(this.mGeneration, i7);
            }

            private void requestTiles(int i7, int i8, int i9, boolean z7) {
                int i10 = i7;
                while (i10 <= i8) {
                    AsyncListUtil.this.mBackgroundProxy.loadTile(z7 ? (i8 + i7) - i10 : i10, i9);
                    i10 += AsyncListUtil.this.mTileSize;
                }
            }

            @Override // androidx.recyclerview.widget.ThreadUtil.BackgroundCallback
            public void loadTile(int i7, int i8) {
                if (!isTileLoaded(i7)) {
                    TileList.Tile<T> acquireTile = acquireTile();
                    acquireTile.mStartPosition = i7;
                    int min = Math.min(AsyncListUtil.this.mTileSize, this.mItemCount - i7);
                    acquireTile.mItemCount = min;
                    AsyncListUtil.this.mDataCallback.fillData(acquireTile.mItems, acquireTile.mStartPosition, min);
                    flushTileCache(i8);
                    addTile(acquireTile);
                }
            }

            @Override // androidx.recyclerview.widget.ThreadUtil.BackgroundCallback
            public void recycleTile(TileList.Tile<T> tile) {
                AsyncListUtil.this.mDataCallback.recycleData(tile.mItems, tile.mItemCount);
                tile.mNext = this.mRecycledRoot;
                this.mRecycledRoot = tile;
            }

            @Override // androidx.recyclerview.widget.ThreadUtil.BackgroundCallback
            public void refresh(int i7) {
                this.mGeneration = i7;
                this.mLoadedTiles.clear();
                int refreshData = AsyncListUtil.this.mDataCallback.refreshData();
                this.mItemCount = refreshData;
                AsyncListUtil.this.mMainThreadProxy.updateItemCount(this.mGeneration, refreshData);
            }

            @Override // androidx.recyclerview.widget.ThreadUtil.BackgroundCallback
            public void updateRange(int i7, int i8, int i9, int i10, int i11) {
                if (i7 <= i8) {
                    int tileStart = getTileStart(i7);
                    int tileStart2 = getTileStart(i8);
                    this.mFirstRequiredTileStart = getTileStart(i9);
                    int tileStart3 = getTileStart(i10);
                    this.mLastRequiredTileStart = tileStart3;
                    if (i11 == 1) {
                        requestTiles(this.mFirstRequiredTileStart, tileStart2, i11, true);
                        requestTiles(tileStart2 + AsyncListUtil.this.mTileSize, this.mLastRequiredTileStart, i11, false);
                        return;
                    }
                    requestTiles(tileStart, tileStart3, i11, false);
                    requestTiles(this.mFirstRequiredTileStart, tileStart - AsyncListUtil.this.mTileSize, i11, true);
                }
            }
        };
        this.mBackgroundCallback = r12;
        this.mTClass = cls;
        this.mTileSize = i7;
        this.mDataCallback = dataCallback;
        this.mViewCallback = viewCallback;
        this.mTileList = new TileList<>(i7);
        MessageThreadUtil messageThreadUtil = new MessageThreadUtil();
        this.mMainThreadProxy = messageThreadUtil.getMainThreadProxy(r02);
        this.mBackgroundProxy = messageThreadUtil.getBackgroundProxy(r12);
        refresh();
    }

    private boolean isRefreshPending() {
        return this.mRequestedGeneration != this.mDisplayedGeneration;
    }

    @Nullable
    public T getItem(int i7) {
        if (i7 < 0 || i7 >= this.mItemCount) {
            throw new IndexOutOfBoundsException(i7 + " is not within 0 and " + this.mItemCount);
        }
        T itemAt = this.mTileList.getItemAt(i7);
        if (itemAt == null && !isRefreshPending()) {
            this.mMissingPositions.put(i7, 0);
        }
        return itemAt;
    }

    public int getItemCount() {
        return this.mItemCount;
    }

    /* access modifiers changed from: package-private */
    public void log(String str, Object... objArr) {
        Log.d(TAG, "[MAIN] " + String.format(str, objArr));
    }

    public void onRangeChanged() {
        if (!isRefreshPending()) {
            updateRange();
            this.mAllowScrollHints = true;
        }
    }

    public void refresh() {
        this.mMissingPositions.clear();
        ThreadUtil.BackgroundCallback<T> backgroundCallback = this.mBackgroundProxy;
        int i7 = this.mRequestedGeneration + 1;
        this.mRequestedGeneration = i7;
        backgroundCallback.refresh(i7);
    }

    /* access modifiers changed from: package-private */
    public void updateRange() {
        int i7;
        this.mViewCallback.getItemRangeInto(this.mTmpRange);
        int[] iArr = this.mTmpRange;
        int i8 = iArr[0];
        int i9 = iArr[1];
        if (i8 <= i9 && i8 >= 0 && i9 < this.mItemCount) {
            if (this.mAllowScrollHints) {
                int[] iArr2 = this.mPrevRange;
                if (i8 <= iArr2[1] && (i7 = iArr2[0]) <= i9) {
                    if (i8 < i7) {
                        this.mScrollHint = 1;
                    } else if (i8 > i7) {
                        this.mScrollHint = 2;
                    }
                    int[] iArr3 = this.mPrevRange;
                    iArr3[0] = i8;
                    iArr3[1] = i9;
                    this.mViewCallback.extendRangeInto(iArr, this.mTmpRangeExtended, this.mScrollHint);
                    int[] iArr4 = this.mTmpRangeExtended;
                    iArr4[0] = Math.min(this.mTmpRange[0], Math.max(iArr4[0], 0));
                    int[] iArr5 = this.mTmpRangeExtended;
                    iArr5[1] = Math.max(this.mTmpRange[1], Math.min(iArr5[1], this.mItemCount - 1));
                    ThreadUtil.BackgroundCallback<T> backgroundCallback = this.mBackgroundProxy;
                    int[] iArr6 = this.mTmpRange;
                    int i10 = iArr6[0];
                    int i11 = iArr6[1];
                    int[] iArr7 = this.mTmpRangeExtended;
                    backgroundCallback.updateRange(i10, i11, iArr7[0], iArr7[1], this.mScrollHint);
                }
            }
            this.mScrollHint = 0;
            int[] iArr32 = this.mPrevRange;
            iArr32[0] = i8;
            iArr32[1] = i9;
            this.mViewCallback.extendRangeInto(iArr, this.mTmpRangeExtended, this.mScrollHint);
            int[] iArr42 = this.mTmpRangeExtended;
            iArr42[0] = Math.min(this.mTmpRange[0], Math.max(iArr42[0], 0));
            int[] iArr52 = this.mTmpRangeExtended;
            iArr52[1] = Math.max(this.mTmpRange[1], Math.min(iArr52[1], this.mItemCount - 1));
            ThreadUtil.BackgroundCallback<T> backgroundCallback2 = this.mBackgroundProxy;
            int[] iArr62 = this.mTmpRange;
            int i102 = iArr62[0];
            int i112 = iArr62[1];
            int[] iArr72 = this.mTmpRangeExtended;
            backgroundCallback2.updateRange(i102, i112, iArr72[0], iArr72[1], this.mScrollHint);
        }
    }
}
