package androidx.recyclerview.widget;

import android.view.View;
import android.view.ViewGroup;
import androidx.recyclerview.widget.RecyclerView;
import java.util.ArrayList;
import java.util.List;

/* access modifiers changed from: package-private */
public class ChildHelper {
    private static final boolean DEBUG = false;
    private static final String TAG = "ChildrenHelper";
    final Bucket mBucket = new Bucket();
    final Callback mCallback;
    final List<View> mHiddenViews = new ArrayList();

    /* access modifiers changed from: package-private */
    public static class Bucket {
        static final int BITS_PER_WORD = 64;
        static final long LAST_BIT = Long.MIN_VALUE;
        long mData = 0;
        Bucket mNext;

        Bucket() {
        }

        private void ensureNext() {
            if (this.mNext == null) {
                this.mNext = new Bucket();
            }
        }

        /* access modifiers changed from: package-private */
        public void clear(int i7) {
            if (i7 >= 64) {
                Bucket bucket = this.mNext;
                if (bucket != null) {
                    bucket.clear(i7 - 64);
                    return;
                }
                return;
            }
            this.mData &= ~(1 << i7);
        }

        /* access modifiers changed from: package-private */
        public int countOnesBefore(int i7) {
            long j7;
            Bucket bucket = this.mNext;
            if (bucket == null) {
                if (i7 >= 64) {
                    j7 = this.mData;
                }
                j7 = ((1 << i7) - 1) & this.mData;
            } else {
                if (i7 >= 64) {
                    return bucket.countOnesBefore(i7 - 64) + Long.bitCount(this.mData);
                }
                j7 = ((1 << i7) - 1) & this.mData;
            }
            return Long.bitCount(j7);
        }

        /* access modifiers changed from: package-private */
        public boolean get(int i7) {
            if (i7 >= 64) {
                ensureNext();
                return this.mNext.get(i7 - 64);
            }
            return ((1 << i7) & this.mData) != 0;
        }

        /* access modifiers changed from: package-private */
        public void insert(int i7, boolean z7) {
            if (i7 >= 64) {
                ensureNext();
                this.mNext.insert(i7 - 64, z7);
                return;
            }
            long j7 = this.mData;
            boolean z8 = (Long.MIN_VALUE & j7) != 0;
            long j8 = (1 << i7) - 1;
            this.mData = ((j7 & (~j8)) << 1) | (j7 & j8);
            if (z7) {
                set(i7);
            } else {
                clear(i7);
            }
            if (z8 || this.mNext != null) {
                ensureNext();
                this.mNext.insert(0, z8);
            }
        }

        /* access modifiers changed from: package-private */
        public boolean remove(int i7) {
            if (i7 >= 64) {
                ensureNext();
                return this.mNext.remove(i7 - 64);
            }
            long j7 = 1 << i7;
            long j8 = this.mData;
            boolean z7 = (j8 & j7) != 0;
            long j9 = j8 & (~j7);
            this.mData = j9;
            long j10 = j7 - 1;
            this.mData = (j9 & j10) | Long.rotateRight((~j10) & j9, 1);
            Bucket bucket = this.mNext;
            if (bucket != null) {
                if (bucket.get(0)) {
                    set(63);
                }
                this.mNext.remove(0);
            }
            return z7;
        }

        /* access modifiers changed from: package-private */
        public void reset() {
            this.mData = 0;
            Bucket bucket = this.mNext;
            if (bucket != null) {
                bucket.reset();
            }
        }

        /* access modifiers changed from: package-private */
        public void set(int i7) {
            if (i7 >= 64) {
                ensureNext();
                this.mNext.set(i7 - 64);
                return;
            }
            this.mData |= 1 << i7;
        }

        public String toString() {
            if (this.mNext == null) {
                return Long.toBinaryString(this.mData);
            }
            return this.mNext.toString() + "xx" + Long.toBinaryString(this.mData);
        }
    }

    /* access modifiers changed from: package-private */
    public interface Callback {
        void addView(View view, int i7);

        void attachViewToParent(View view, int i7, ViewGroup.LayoutParams layoutParams);

        void detachViewFromParent(int i7);

        View getChildAt(int i7);

        int getChildCount();

        RecyclerView.ViewHolder getChildViewHolder(View view);

        int indexOfChild(View view);

        void onEnteredHiddenState(View view);

        void onLeftHiddenState(View view);

        void removeAllViews();

        void removeViewAt(int i7);
    }

    ChildHelper(Callback callback) {
        this.mCallback = callback;
    }

    private int getOffset(int i7) {
        if (i7 < 0) {
            return -1;
        }
        int childCount = this.mCallback.getChildCount();
        int i8 = i7;
        while (i8 < childCount) {
            int countOnesBefore = i7 - (i8 - this.mBucket.countOnesBefore(i8));
            if (countOnesBefore == 0) {
                while (this.mBucket.get(i8)) {
                    i8++;
                }
                return i8;
            }
            i8 += countOnesBefore;
        }
        return -1;
    }

    private void hideViewInternal(View view) {
        this.mHiddenViews.add(view);
        this.mCallback.onEnteredHiddenState(view);
    }

    private boolean unhideViewInternal(View view) {
        if (!this.mHiddenViews.remove(view)) {
            return false;
        }
        this.mCallback.onLeftHiddenState(view);
        return true;
    }

    /* access modifiers changed from: package-private */
    public void addView(View view, int i7, boolean z7) {
        int childCount = i7 < 0 ? this.mCallback.getChildCount() : getOffset(i7);
        this.mBucket.insert(childCount, z7);
        if (z7) {
            hideViewInternal(view);
        }
        this.mCallback.addView(view, childCount);
    }

    /* access modifiers changed from: package-private */
    public void attachViewToParent(View view, int i7, ViewGroup.LayoutParams layoutParams, boolean z7) {
        int childCount = i7 < 0 ? this.mCallback.getChildCount() : getOffset(i7);
        this.mBucket.insert(childCount, z7);
        if (z7) {
            hideViewInternal(view);
        }
        this.mCallback.attachViewToParent(view, childCount, layoutParams);
    }

    /* access modifiers changed from: package-private */
    public void detachViewFromParent(int i7) {
        int offset = getOffset(i7);
        this.mBucket.remove(offset);
        this.mCallback.detachViewFromParent(offset);
    }

    /* access modifiers changed from: package-private */
    public View findHiddenNonRemovedView(int i7) {
        int size = this.mHiddenViews.size();
        for (int i8 = 0; i8 < size; i8++) {
            View view = this.mHiddenViews.get(i8);
            RecyclerView.ViewHolder childViewHolder = this.mCallback.getChildViewHolder(view);
            if (!(childViewHolder.getLayoutPosition() != i7 || childViewHolder.isInvalid() || childViewHolder.isRemoved())) {
                return view;
            }
        }
        return null;
    }

    /* access modifiers changed from: package-private */
    public View getChildAt(int i7) {
        return this.mCallback.getChildAt(getOffset(i7));
    }

    /* access modifiers changed from: package-private */
    public int getChildCount() {
        return this.mCallback.getChildCount() - this.mHiddenViews.size();
    }

    /* access modifiers changed from: package-private */
    public View getUnfilteredChildAt(int i7) {
        return this.mCallback.getChildAt(i7);
    }

    /* access modifiers changed from: package-private */
    public int getUnfilteredChildCount() {
        return this.mCallback.getChildCount();
    }

    /* access modifiers changed from: package-private */
    public void hide(View view) {
        int indexOfChild = this.mCallback.indexOfChild(view);
        if (indexOfChild >= 0) {
            this.mBucket.set(indexOfChild);
            hideViewInternal(view);
            return;
        }
        throw new IllegalArgumentException("view is not a child, cannot hide " + view);
    }

    /* access modifiers changed from: package-private */
    public int indexOfChild(View view) {
        int indexOfChild = this.mCallback.indexOfChild(view);
        if (indexOfChild != -1 && !this.mBucket.get(indexOfChild)) {
            return indexOfChild - this.mBucket.countOnesBefore(indexOfChild);
        }
        return -1;
    }

    /* access modifiers changed from: package-private */
    public boolean isHidden(View view) {
        return this.mHiddenViews.contains(view);
    }

    /* access modifiers changed from: package-private */
    public void removeAllViewsUnfiltered() {
        this.mBucket.reset();
        for (int size = this.mHiddenViews.size() - 1; size >= 0; size--) {
            this.mCallback.onLeftHiddenState(this.mHiddenViews.get(size));
            this.mHiddenViews.remove(size);
        }
        this.mCallback.removeAllViews();
    }

    /* access modifiers changed from: package-private */
    public void removeView(View view) {
        int indexOfChild = this.mCallback.indexOfChild(view);
        if (indexOfChild >= 0) {
            if (this.mBucket.remove(indexOfChild)) {
                unhideViewInternal(view);
            }
            this.mCallback.removeViewAt(indexOfChild);
        }
    }

    /* access modifiers changed from: package-private */
    public void removeViewAt(int i7) {
        int offset = getOffset(i7);
        View childAt = this.mCallback.getChildAt(offset);
        if (childAt != null) {
            if (this.mBucket.remove(offset)) {
                unhideViewInternal(childAt);
            }
            this.mCallback.removeViewAt(offset);
        }
    }

    /* access modifiers changed from: package-private */
    public boolean removeViewIfHidden(View view) {
        int indexOfChild = this.mCallback.indexOfChild(view);
        if (indexOfChild == -1) {
            unhideViewInternal(view);
            return true;
        } else if (!this.mBucket.get(indexOfChild)) {
            return false;
        } else {
            this.mBucket.remove(indexOfChild);
            unhideViewInternal(view);
            this.mCallback.removeViewAt(indexOfChild);
            return true;
        }
    }

    public String toString() {
        return this.mBucket.toString() + ", hidden list:" + this.mHiddenViews.size();
    }

    /* access modifiers changed from: package-private */
    public void unhide(View view) {
        int indexOfChild = this.mCallback.indexOfChild(view);
        if (indexOfChild < 0) {
            throw new IllegalArgumentException("view is not a child, cannot hide " + view);
        } else if (this.mBucket.get(indexOfChild)) {
            this.mBucket.clear(indexOfChild);
            unhideViewInternal(view);
        } else {
            throw new RuntimeException("trying to unhide a view that was not hidden" + view);
        }
    }

    /* access modifiers changed from: package-private */
    public void addView(View view, boolean z7) {
        addView(view, -1, z7);
    }
}
