package androidx.recyclerview.widget;

import androidx.annotation.IntRange;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.annotation.VisibleForTesting;
import androidx.recyclerview.widget.RecyclerView;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;

public class DiffUtil {
    private static final Comparator<Snake> SNAKE_COMPARATOR = new Comparator<Snake>() {
        /* class androidx.recyclerview.widget.DiffUtil.AnonymousClass1 */

        public int compare(Snake snake, Snake snake2) {
            int i7 = snake.f616x - snake2.f616x;
            return i7 == 0 ? snake.f617y - snake2.f617y : i7;
        }
    };

    public static abstract class Callback {
        public abstract boolean areContentsTheSame(int i7, int i8);

        public abstract boolean areItemsTheSame(int i7, int i8);

        @Nullable
        public Object getChangePayload(int i7, int i8) {
            return null;
        }

        public abstract int getNewListSize();

        public abstract int getOldListSize();
    }

    public static class DiffResult {
        private static final int FLAG_CHANGED = 2;
        private static final int FLAG_IGNORE = 16;
        private static final int FLAG_MASK = 31;
        private static final int FLAG_MOVED_CHANGED = 4;
        private static final int FLAG_MOVED_NOT_CHANGED = 8;
        private static final int FLAG_NOT_CHANGED = 1;
        private static final int FLAG_OFFSET = 5;
        public static final int NO_POSITION = -1;
        private final Callback mCallback;
        private final boolean mDetectMoves;
        private final int[] mNewItemStatuses;
        private final int mNewListSize;
        private final int[] mOldItemStatuses;
        private final int mOldListSize;
        private final List<Snake> mSnakes;

        DiffResult(Callback callback, List<Snake> list, int[] iArr, int[] iArr2, boolean z7) {
            this.mSnakes = list;
            this.mOldItemStatuses = iArr;
            this.mNewItemStatuses = iArr2;
            Arrays.fill(iArr, 0);
            Arrays.fill(iArr2, 0);
            this.mCallback = callback;
            this.mOldListSize = callback.getOldListSize();
            this.mNewListSize = callback.getNewListSize();
            this.mDetectMoves = z7;
            addRootSnake();
            findMatchingItems();
        }

        private void addRootSnake() {
            Snake snake = this.mSnakes.isEmpty() ? null : this.mSnakes.get(0);
            if (snake == null || snake.f616x != 0 || snake.f617y != 0) {
                Snake snake2 = new Snake();
                snake2.f616x = 0;
                snake2.f617y = 0;
                snake2.removal = false;
                snake2.size = 0;
                snake2.reverse = false;
                this.mSnakes.add(0, snake2);
            }
        }

        private void dispatchAdditions(List<PostponedUpdate> list, ListUpdateCallback listUpdateCallback, int i7, int i8, int i9) {
            if (!this.mDetectMoves) {
                listUpdateCallback.onInserted(i7, i8);
                return;
            }
            for (int i10 = i8 - 1; i10 >= 0; i10--) {
                int i11 = i9 + i10;
                int i12 = this.mNewItemStatuses[i11];
                int i13 = i12 & 31;
                if (i13 == 0) {
                    listUpdateCallback.onInserted(i7, 1);
                    for (PostponedUpdate postponedUpdate : list) {
                        postponedUpdate.currentPos++;
                    }
                } else if (i13 == 4 || i13 == 8) {
                    int i14 = i12 >> 5;
                    listUpdateCallback.onMoved(removePostponedUpdate(list, i14, true).currentPos, i7);
                    if (i13 == 4) {
                        listUpdateCallback.onChanged(i7, 1, this.mCallback.getChangePayload(i14, i11));
                    }
                } else if (i13 == 16) {
                    list.add(new PostponedUpdate(i11, i7, false));
                } else {
                    throw new IllegalStateException("unknown flag for pos " + i11 + " " + Long.toBinaryString((long) i13));
                }
            }
        }

        private void dispatchRemovals(List<PostponedUpdate> list, ListUpdateCallback listUpdateCallback, int i7, int i8, int i9) {
            if (!this.mDetectMoves) {
                listUpdateCallback.onRemoved(i7, i8);
                return;
            }
            for (int i10 = i8 - 1; i10 >= 0; i10--) {
                int i11 = i9 + i10;
                int i12 = this.mOldItemStatuses[i11];
                int i13 = i12 & 31;
                if (i13 == 0) {
                    listUpdateCallback.onRemoved(i7 + i10, 1);
                    for (PostponedUpdate postponedUpdate : list) {
                        postponedUpdate.currentPos--;
                    }
                } else if (i13 == 4 || i13 == 8) {
                    int i14 = i12 >> 5;
                    PostponedUpdate removePostponedUpdate = removePostponedUpdate(list, i14, false);
                    listUpdateCallback.onMoved(i7 + i10, removePostponedUpdate.currentPos - 1);
                    if (i13 == 4) {
                        listUpdateCallback.onChanged(removePostponedUpdate.currentPos - 1, 1, this.mCallback.getChangePayload(i11, i14));
                    }
                } else if (i13 == 16) {
                    list.add(new PostponedUpdate(i11, i7 + i10, true));
                } else {
                    throw new IllegalStateException("unknown flag for pos " + i11 + " " + Long.toBinaryString((long) i13));
                }
            }
        }

        private void findAddition(int i7, int i8, int i9) {
            if (this.mOldItemStatuses[i7 - 1] == 0) {
                findMatchingItem(i7, i8, i9, false);
            }
        }

        private boolean findMatchingItem(int i7, int i8, int i9, boolean z7) {
            int i10;
            int i11;
            if (z7) {
                i8--;
                i10 = i7;
                i11 = i8;
            } else {
                i11 = i7 - 1;
                i10 = i11;
            }
            while (i9 >= 0) {
                Snake snake = this.mSnakes.get(i9);
                int i12 = snake.f616x;
                int i13 = snake.size;
                int i14 = i12 + i13;
                int i15 = snake.f617y + i13;
                int i16 = 8;
                if (z7) {
                    for (int i17 = i10 - 1; i17 >= i14; i17--) {
                        if (this.mCallback.areItemsTheSame(i17, i11)) {
                            if (!this.mCallback.areContentsTheSame(i17, i11)) {
                                i16 = 4;
                            }
                            this.mNewItemStatuses[i11] = (i17 << 5) | 16;
                            this.mOldItemStatuses[i17] = (i11 << 5) | i16;
                            return true;
                        }
                    }
                    continue;
                } else {
                    for (int i18 = i8 - 1; i18 >= i15; i18--) {
                        if (this.mCallback.areItemsTheSame(i11, i18)) {
                            if (!this.mCallback.areContentsTheSame(i11, i18)) {
                                i16 = 4;
                            }
                            int i19 = i7 - 1;
                            this.mOldItemStatuses[i19] = (i18 << 5) | 16;
                            this.mNewItemStatuses[i18] = (i19 << 5) | i16;
                            return true;
                        }
                    }
                    continue;
                }
                i10 = snake.f616x;
                i8 = snake.f617y;
                i9--;
            }
            return false;
        }

        private void findMatchingItems() {
            int i7 = this.mOldListSize;
            int i8 = this.mNewListSize;
            for (int size = this.mSnakes.size() - 1; size >= 0; size--) {
                Snake snake = this.mSnakes.get(size);
                int i9 = snake.f616x;
                int i10 = snake.size;
                int i11 = i9 + i10;
                int i12 = snake.f617y + i10;
                if (this.mDetectMoves) {
                    while (i7 > i11) {
                        findAddition(i7, i8, size);
                        i7--;
                    }
                    while (i8 > i12) {
                        findRemoval(i7, i8, size);
                        i8--;
                    }
                }
                for (int i13 = 0; i13 < snake.size; i13++) {
                    int i14 = snake.f616x + i13;
                    int i15 = snake.f617y + i13;
                    int i16 = this.mCallback.areContentsTheSame(i14, i15) ? 1 : 2;
                    this.mOldItemStatuses[i14] = (i15 << 5) | i16;
                    this.mNewItemStatuses[i15] = (i14 << 5) | i16;
                }
                i7 = snake.f616x;
                i8 = snake.f617y;
            }
        }

        private void findRemoval(int i7, int i8, int i9) {
            if (this.mNewItemStatuses[i8 - 1] == 0) {
                findMatchingItem(i7, i8, i9, true);
            }
        }

        private static PostponedUpdate removePostponedUpdate(List<PostponedUpdate> list, int i7, boolean z7) {
            int size = list.size() - 1;
            while (size >= 0) {
                PostponedUpdate postponedUpdate = list.get(size);
                if (postponedUpdate.posInOwnerList == i7 && postponedUpdate.removal == z7) {
                    list.remove(size);
                    while (size < list.size()) {
                        list.get(size).currentPos += z7 ? 1 : -1;
                        size++;
                    }
                    return postponedUpdate;
                }
                size--;
            }
            return null;
        }

        public int convertNewPositionToOld(@IntRange(from = 0) int i7) {
            if (i7 < 0 || i7 >= this.mNewListSize) {
                throw new IndexOutOfBoundsException("Index out of bounds - passed position = " + i7 + ", new list size = " + this.mNewListSize);
            }
            int i8 = this.mNewItemStatuses[i7];
            if ((i8 & 31) == 0) {
                return -1;
            }
            return i8 >> 5;
        }

        public int convertOldPositionToNew(@IntRange(from = 0) int i7) {
            if (i7 < 0 || i7 >= this.mOldListSize) {
                throw new IndexOutOfBoundsException("Index out of bounds - passed position = " + i7 + ", old list size = " + this.mOldListSize);
            }
            int i8 = this.mOldItemStatuses[i7];
            if ((i8 & 31) == 0) {
                return -1;
            }
            return i8 >> 5;
        }

        public void dispatchUpdatesTo(@NonNull ListUpdateCallback listUpdateCallback) {
            BatchingListUpdateCallback batchingListUpdateCallback = listUpdateCallback instanceof BatchingListUpdateCallback ? (BatchingListUpdateCallback) listUpdateCallback : new BatchingListUpdateCallback(listUpdateCallback);
            List<PostponedUpdate> arrayList = new ArrayList<>();
            int i7 = this.mOldListSize;
            int i8 = this.mNewListSize;
            for (int size = this.mSnakes.size() - 1; size >= 0; size--) {
                Snake snake = this.mSnakes.get(size);
                int i9 = snake.size;
                int i10 = snake.f616x + i9;
                int i11 = snake.f617y + i9;
                if (i10 < i7) {
                    dispatchRemovals(arrayList, batchingListUpdateCallback, i10, i7 - i10, i10);
                }
                if (i11 < i8) {
                    dispatchAdditions(arrayList, batchingListUpdateCallback, i10, i8 - i11, i11);
                }
                for (int i12 = i9 - 1; i12 >= 0; i12--) {
                    int[] iArr = this.mOldItemStatuses;
                    int i13 = snake.f616x;
                    if ((iArr[i13 + i12] & 31) == 2) {
                        batchingListUpdateCallback.onChanged(i13 + i12, 1, this.mCallback.getChangePayload(i13 + i12, snake.f617y + i12));
                    }
                }
                i7 = snake.f616x;
                i8 = snake.f617y;
            }
            batchingListUpdateCallback.dispatchLastEvent();
        }

        /* access modifiers changed from: package-private */
        @VisibleForTesting
        public List<Snake> getSnakes() {
            return this.mSnakes;
        }

        public void dispatchUpdatesTo(@NonNull RecyclerView.Adapter adapter) {
            dispatchUpdatesTo(new AdapterListUpdateCallback(adapter));
        }
    }

    public static abstract class ItemCallback<T> {
        public abstract boolean areContentsTheSame(@NonNull T t7, @NonNull T t8);

        public abstract boolean areItemsTheSame(@NonNull T t7, @NonNull T t8);

        @Nullable
        public Object getChangePayload(@NonNull T t7, @NonNull T t8) {
            return null;
        }
    }

    /* access modifiers changed from: private */
    public static class PostponedUpdate {
        int currentPos;
        int posInOwnerList;
        boolean removal;

        public PostponedUpdate(int i7, int i8, boolean z7) {
            this.posInOwnerList = i7;
            this.currentPos = i8;
            this.removal = z7;
        }
    }

    /* access modifiers changed from: package-private */
    public static class Range {
        int newListEnd;
        int newListStart;
        int oldListEnd;
        int oldListStart;

        public Range() {
        }

        public Range(int i7, int i8, int i9, int i10) {
            this.oldListStart = i7;
            this.oldListEnd = i8;
            this.newListStart = i9;
            this.newListEnd = i10;
        }
    }

    /* access modifiers changed from: package-private */
    public static class Snake {
        boolean removal;
        boolean reverse;
        int size;

        /* renamed from: x  reason: collision with root package name */
        int f616x;

        /* renamed from: y  reason: collision with root package name */
        int f617y;

        Snake() {
        }
    }

    private DiffUtil() {
    }

    @NonNull
    public static DiffResult calculateDiff(@NonNull Callback callback) {
        return calculateDiff(callback, true);
    }

    /* JADX DEBUG: Multi-variable search result rejected for r13v0, resolved type: boolean */
    /* JADX DEBUG: Multi-variable search result rejected for r13v2, resolved type: boolean */
    /* JADX DEBUG: Multi-variable search result rejected for r14v7, resolved type: boolean */
    /* JADX DEBUG: Multi-variable search result rejected for r14v9, resolved type: boolean */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARNING: Code restructure failed: missing block: B:14:0x0042, code lost:
        if (r24[r13 - 1] < r24[r13 + r5]) goto L_0x004d;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:41:0x00b5, code lost:
        if (r25[r12 - 1] < r25[r12 + 1]) goto L_0x00c2;
     */
    private static Snake diffPartial(Callback callback, int i7, int i8, int i9, int i10, int[] iArr, int[] iArr2, int i11) {
        boolean z7;
        int i12;
        int i13;
        int i14;
        int i15;
        boolean z8;
        int i16;
        int i17;
        int i18 = i8 - i7;
        int i19 = i10 - i9;
        int i20 = 1;
        if (i18 < 1 || i19 < 1) {
            return null;
        }
        int i21 = i18 - i19;
        int i22 = ((i18 + i19) + 1) / 2;
        int i23 = (i11 - i22) - 1;
        int i24 = i11 + i22 + 1;
        boolean z9 = false;
        Arrays.fill(iArr, i23, i24, 0);
        Arrays.fill(iArr2, i23 + i21, i24 + i21, i18);
        boolean z10 = i21 % 2 != 0;
        int i25 = 0;
        while (i25 <= i22) {
            int i26 = -i25;
            int i27 = i26;
            while (i27 <= i25) {
                if (i27 != i26) {
                    if (i27 != i25) {
                        int i28 = i11 + i27;
                    }
                    i16 = iArr[(i11 + i27) - i20] + i20;
                    z8 = i20;
                    i17 = i16 - i27;
                    while (i16 < i18 && i17 < i19 && callback.areItemsTheSame(i7 + i16, i9 + i17)) {
                        i16++;
                        i17++;
                    }
                    int i29 = i11 + i27;
                    iArr[i29] = i16;
                    if (z10 || i27 < (i21 - i25) + 1 || i27 > (i21 + i25) - 1 || i16 < iArr2[i29]) {
                        i27 += 2;
                        z9 = false;
                        i20 = 1;
                    } else {
                        Snake snake = new Snake();
                        int i30 = iArr2[i29];
                        snake.f616x = i30;
                        snake.f617y = i30 - i27;
                        snake.size = iArr[i29] - i30;
                        snake.removal = z8;
                        snake.reverse = false;
                        return snake;
                    }
                }
                i16 = iArr[i11 + i27 + i20];
                z8 = z9;
                i17 = i16 - i27;
                while (i16 < i18) {
                    i16++;
                    i17++;
                }
                int i292 = i11 + i27;
                iArr[i292] = i16;
                if (z10) {
                }
                i27 += 2;
                z9 = false;
                i20 = 1;
            }
            boolean z11 = z9;
            int i31 = i26;
            while (i31 <= i25) {
                int i32 = i31 + i21;
                if (i32 != i25 + i21) {
                    if (i32 != i26 + i21) {
                        int i33 = i11 + i32;
                        i15 = 1;
                    } else {
                        i15 = 1;
                    }
                    i12 = iArr2[(i11 + i32) + i15] - i15;
                    z7 = i15;
                    i13 = i12 - i32;
                    while (true) {
                        if (i12 > 0 && i13 > 0) {
                            i14 = i18;
                            if (!callback.areItemsTheSame((i7 + i12) - 1, (i9 + i13) - 1)) {
                                break;
                            }
                            i12--;
                            i13--;
                            i18 = i14;
                        } else {
                            i14 = i18;
                        }
                    }
                    i14 = i18;
                    int i34 = i11 + i32;
                    iArr2[i34] = i12;
                    if (!z10 || i32 < i26 || i32 > i25 || iArr[i34] < i12) {
                        i31 += 2;
                        i18 = i14;
                        z11 = false;
                    } else {
                        Snake snake2 = new Snake();
                        int i35 = iArr2[i34];
                        snake2.f616x = i35;
                        snake2.f617y = i35 - i32;
                        snake2.size = iArr[i34] - i35;
                        snake2.removal = z7;
                        snake2.reverse = true;
                        return snake2;
                    }
                } else {
                    i15 = 1;
                }
                i12 = iArr2[(i11 + i32) - i15];
                z7 = z11;
                i13 = i12 - i32;
                while (true) {
                    if (i12 > 0) {
                        break;
                    }
                    break;
                    i12--;
                    i13--;
                    i18 = i14;
                }
                i14 = i18;
                int i342 = i11 + i32;
                iArr2[i342] = i12;
                if (!z10) {
                }
                i31 += 2;
                i18 = i14;
                z11 = false;
            }
            i25++;
            i20 = 1;
            i18 = i18;
            z9 = false;
        }
        throw new IllegalStateException("DiffUtil hit an unexpected case while trying to calculate the optimal path. Please make sure your data is not changing during the diff calculation.");
    }

    /* JADX WARNING: Removed duplicated region for block: B:23:0x00ae  */
    /* JADX WARNING: Removed duplicated region for block: B:27:0x00c7  */
    @NonNull
    public static DiffResult calculateDiff(@NonNull Callback callback, boolean z7) {
        int i7;
        int i8;
        int i9;
        int i10;
        int i11;
        int oldListSize = callback.getOldListSize();
        int newListSize = callback.getNewListSize();
        ArrayList arrayList = new ArrayList();
        ArrayList arrayList2 = new ArrayList();
        arrayList2.add(new Range(0, oldListSize, 0, newListSize));
        int abs = oldListSize + newListSize + Math.abs(oldListSize - newListSize);
        int i12 = abs * 2;
        int[] iArr = new int[i12];
        int[] iArr2 = new int[i12];
        ArrayList arrayList3 = new ArrayList();
        while (!arrayList2.isEmpty()) {
            Range range = (Range) arrayList2.remove(arrayList2.size() - 1);
            Snake diffPartial = diffPartial(callback, range.oldListStart, range.oldListEnd, range.newListStart, range.newListEnd, iArr, iArr2, abs);
            if (diffPartial != null) {
                if (diffPartial.size > 0) {
                    arrayList.add(diffPartial);
                }
                diffPartial.f616x += range.oldListStart;
                diffPartial.f617y += range.newListStart;
                Range range2 = arrayList3.isEmpty() ? new Range() : (Range) arrayList3.remove(arrayList3.size() - 1);
                range2.oldListStart = range.oldListStart;
                range2.newListStart = range.newListStart;
                if (diffPartial.reverse) {
                    i8 = diffPartial.f616x;
                } else if (diffPartial.removal) {
                    i8 = diffPartial.f616x - 1;
                } else {
                    range2.oldListEnd = diffPartial.f616x;
                    i7 = diffPartial.f617y - 1;
                    range2.newListEnd = i7;
                    arrayList2.add(range2);
                    if (diffPartial.reverse) {
                        int i13 = diffPartial.f616x;
                        i10 = diffPartial.size;
                        i11 = i13 + i10;
                    } else if (diffPartial.removal) {
                        int i14 = diffPartial.f616x;
                        i10 = diffPartial.size;
                        i11 = i14 + i10 + 1;
                    } else {
                        int i15 = diffPartial.f616x;
                        int i16 = diffPartial.size;
                        range.oldListStart = i15 + i16;
                        i9 = diffPartial.f617y + i16 + 1;
                        range.newListStart = i9;
                        arrayList2.add(range);
                    }
                    range.oldListStart = i11;
                    i9 = diffPartial.f617y + i10;
                    range.newListStart = i9;
                    arrayList2.add(range);
                }
                range2.oldListEnd = i8;
                i7 = diffPartial.f617y;
                range2.newListEnd = i7;
                arrayList2.add(range2);
                if (diffPartial.reverse) {
                }
                range.oldListStart = i11;
                i9 = diffPartial.f617y + i10;
                range.newListStart = i9;
                arrayList2.add(range);
            } else {
                arrayList3.add(range);
            }
        }
        Collections.sort(arrayList, SNAKE_COMPARATOR);
        return new DiffResult(callback, arrayList, iArr, iArr2, z7);
    }
}
