package androidx.recyclerview.widget;

import android.content.Context;
import android.graphics.Rect;
import android.util.AttributeSet;
import android.util.Log;
import android.util.SparseIntArray;
import android.view.View;
import android.view.ViewGroup;
import androidx.core.view.accessibility.AccessibilityNodeInfoCompat;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import java.util.Arrays;

public class GridLayoutManager extends LinearLayoutManager {
    private static final boolean DEBUG = false;
    public static final int DEFAULT_SPAN_COUNT = -1;
    private static final String TAG = "GridLayoutManager";
    int[] mCachedBorders;
    final Rect mDecorInsets = new Rect();
    boolean mPendingSpanCountChange = false;
    final SparseIntArray mPreLayoutSpanIndexCache = new SparseIntArray();
    final SparseIntArray mPreLayoutSpanSizeCache = new SparseIntArray();
    View[] mSet;
    int mSpanCount = -1;
    SpanSizeLookup mSpanSizeLookup = new DefaultSpanSizeLookup();
    private boolean mUsingSpansToEstimateScrollBarDimensions;

    public static final class DefaultSpanSizeLookup extends SpanSizeLookup {
        @Override // androidx.recyclerview.widget.GridLayoutManager.SpanSizeLookup
        public int getSpanIndex(int i7, int i8) {
            return i7 % i8;
        }

        @Override // androidx.recyclerview.widget.GridLayoutManager.SpanSizeLookup
        public int getSpanSize(int i7) {
            return 1;
        }
    }

    public static class LayoutParams extends RecyclerView.LayoutParams {
        public static final int INVALID_SPAN_ID = -1;
        int mSpanIndex = -1;
        int mSpanSize = 0;

        public LayoutParams(int i7, int i8) {
            super(i7, i8);
        }

        public int getSpanIndex() {
            return this.mSpanIndex;
        }

        public int getSpanSize() {
            return this.mSpanSize;
        }

        public LayoutParams(Context context, AttributeSet attributeSet) {
            super(context, attributeSet);
        }

        public LayoutParams(ViewGroup.LayoutParams layoutParams) {
            super(layoutParams);
        }

        public LayoutParams(ViewGroup.MarginLayoutParams marginLayoutParams) {
            super(marginLayoutParams);
        }

        public LayoutParams(RecyclerView.LayoutParams layoutParams) {
            super(layoutParams);
        }
    }

    public static abstract class SpanSizeLookup {
        private boolean mCacheSpanGroupIndices = false;
        private boolean mCacheSpanIndices = false;
        final SparseIntArray mSpanGroupIndexCache = new SparseIntArray();
        final SparseIntArray mSpanIndexCache = new SparseIntArray();

        static int findFirstKeyLessThan(SparseIntArray sparseIntArray, int i7) {
            int size = sparseIntArray.size() - 1;
            int i8 = 0;
            while (i8 <= size) {
                int i9 = (i8 + size) >>> 1;
                if (sparseIntArray.keyAt(i9) < i7) {
                    i8 = i9 + 1;
                } else {
                    size = i9 - 1;
                }
            }
            int i10 = i8 - 1;
            if (i10 < 0 || i10 >= sparseIntArray.size()) {
                return -1;
            }
            return sparseIntArray.keyAt(i10);
        }

        /* access modifiers changed from: package-private */
        public int getCachedSpanGroupIndex(int i7, int i8) {
            if (!this.mCacheSpanGroupIndices) {
                return getSpanGroupIndex(i7, i8);
            }
            int i9 = this.mSpanGroupIndexCache.get(i7, -1);
            if (i9 != -1) {
                return i9;
            }
            int spanGroupIndex = getSpanGroupIndex(i7, i8);
            this.mSpanGroupIndexCache.put(i7, spanGroupIndex);
            return spanGroupIndex;
        }

        /* access modifiers changed from: package-private */
        public int getCachedSpanIndex(int i7, int i8) {
            if (!this.mCacheSpanIndices) {
                return getSpanIndex(i7, i8);
            }
            int i9 = this.mSpanIndexCache.get(i7, -1);
            if (i9 != -1) {
                return i9;
            }
            int spanIndex = getSpanIndex(i7, i8);
            this.mSpanIndexCache.put(i7, spanIndex);
            return spanIndex;
        }

        public int getSpanGroupIndex(int i7, int i8) {
            int i9;
            int i10;
            int i11;
            int findFirstKeyLessThan;
            if (!this.mCacheSpanGroupIndices || (findFirstKeyLessThan = findFirstKeyLessThan(this.mSpanGroupIndexCache, i7)) == -1) {
                i11 = 0;
                i10 = 0;
                i9 = 0;
            } else {
                i11 = this.mSpanGroupIndexCache.get(findFirstKeyLessThan);
                i10 = findFirstKeyLessThan + 1;
                i9 = getCachedSpanIndex(findFirstKeyLessThan, i8) + getSpanSize(findFirstKeyLessThan);
                if (i9 == i8) {
                    i11++;
                    i9 = 0;
                }
            }
            int spanSize = getSpanSize(i7);
            while (i10 < i7) {
                int spanSize2 = getSpanSize(i10);
                i9 += spanSize2;
                if (i9 == i8) {
                    i11++;
                    i9 = 0;
                } else if (i9 > i8) {
                    i11++;
                    i9 = spanSize2;
                }
                i10++;
            }
            return i9 + spanSize > i8 ? i11 + 1 : i11;
        }

        /* JADX WARNING: Removed duplicated region for block: B:10:0x0024  */
        public int getSpanIndex(int i7, int i8) {
            int i9;
            int i10;
            int spanSize = getSpanSize(i7);
            if (spanSize == i8) {
                return 0;
            }
            if (!this.mCacheSpanIndices || (i10 = findFirstKeyLessThan(this.mSpanIndexCache, i7)) < 0) {
                i10 = 0;
                i9 = 0;
            } else {
                i9 = this.mSpanIndexCache.get(i10) + getSpanSize(i10);
                i10++;
            }
            if (i10 < i7) {
                int spanSize2 = getSpanSize(i10);
                i9 += spanSize2;
                if (i9 == i8) {
                    i9 = 0;
                } else if (i9 > i8) {
                    i9 = spanSize2;
                }
                i10++;
                if (i10 < i7) {
                }
            }
            if (spanSize + i9 <= i8) {
                return i9;
            }
            return 0;
        }

        public abstract int getSpanSize(int i7);

        public void invalidateSpanGroupIndexCache() {
            this.mSpanGroupIndexCache.clear();
        }

        public void invalidateSpanIndexCache() {
            this.mSpanIndexCache.clear();
        }

        public boolean isSpanGroupIndexCacheEnabled() {
            return this.mCacheSpanGroupIndices;
        }

        public boolean isSpanIndexCacheEnabled() {
            return this.mCacheSpanIndices;
        }

        public void setSpanGroupIndexCacheEnabled(boolean z7) {
            if (!z7) {
                this.mSpanGroupIndexCache.clear();
            }
            this.mCacheSpanGroupIndices = z7;
        }

        public void setSpanIndexCacheEnabled(boolean z7) {
            if (!z7) {
                this.mSpanGroupIndexCache.clear();
            }
            this.mCacheSpanIndices = z7;
        }
    }

    public GridLayoutManager(Context context, int i7) {
        super(context);
        setSpanCount(i7);
    }

    private void assignSpans(RecyclerView.Recycler recycler, RecyclerView.State state, int i7, boolean z7) {
        int i8;
        int i9;
        int i10;
        int i11 = 0;
        if (z7) {
            i10 = 1;
            i8 = i7;
            i9 = 0;
        } else {
            i9 = i7 - 1;
            i8 = -1;
            i10 = -1;
        }
        while (i9 != i8) {
            View view = this.mSet[i9];
            LayoutParams layoutParams = (LayoutParams) view.getLayoutParams();
            int spanSize = getSpanSize(recycler, state, getPosition(view));
            layoutParams.mSpanSize = spanSize;
            layoutParams.mSpanIndex = i11;
            i11 += spanSize;
            i9 += i10;
        }
    }

    private void cachePreLayoutSpanMapping() {
        int childCount = getChildCount();
        for (int i7 = 0; i7 < childCount; i7++) {
            LayoutParams layoutParams = (LayoutParams) getChildAt(i7).getLayoutParams();
            int viewLayoutPosition = layoutParams.getViewLayoutPosition();
            this.mPreLayoutSpanSizeCache.put(viewLayoutPosition, layoutParams.getSpanSize());
            this.mPreLayoutSpanIndexCache.put(viewLayoutPosition, layoutParams.getSpanIndex());
        }
    }

    private void calculateItemBorders(int i7) {
        this.mCachedBorders = calculateItemBorders(this.mCachedBorders, this.mSpanCount, i7);
    }

    private void clearPreLayoutSpanMappingCache() {
        this.mPreLayoutSpanSizeCache.clear();
        this.mPreLayoutSpanIndexCache.clear();
    }

    private int computeScrollOffsetWithSpanInfo(RecyclerView.State state) {
        if (!(getChildCount() == 0 || state.getItemCount() == 0)) {
            ensureLayoutState();
            boolean isSmoothScrollbarEnabled = isSmoothScrollbarEnabled();
            View findFirstVisibleChildClosestToStart = findFirstVisibleChildClosestToStart(!isSmoothScrollbarEnabled, true);
            View findFirstVisibleChildClosestToEnd = findFirstVisibleChildClosestToEnd(!isSmoothScrollbarEnabled, true);
            if (!(findFirstVisibleChildClosestToStart == null || findFirstVisibleChildClosestToEnd == null)) {
                int cachedSpanGroupIndex = this.mSpanSizeLookup.getCachedSpanGroupIndex(getPosition(findFirstVisibleChildClosestToStart), this.mSpanCount);
                int cachedSpanGroupIndex2 = this.mSpanSizeLookup.getCachedSpanGroupIndex(getPosition(findFirstVisibleChildClosestToEnd), this.mSpanCount);
                int min = Math.min(cachedSpanGroupIndex, cachedSpanGroupIndex2);
                int max = this.mShouldReverseLayout ? Math.max(0, ((this.mSpanSizeLookup.getCachedSpanGroupIndex(state.getItemCount() - 1, this.mSpanCount) + 1) - Math.max(cachedSpanGroupIndex, cachedSpanGroupIndex2)) - 1) : Math.max(0, min);
                if (!isSmoothScrollbarEnabled) {
                    return max;
                }
                return Math.round((((float) max) * (((float) Math.abs(this.mOrientationHelper.getDecoratedEnd(findFirstVisibleChildClosestToEnd) - this.mOrientationHelper.getDecoratedStart(findFirstVisibleChildClosestToStart))) / ((float) ((this.mSpanSizeLookup.getCachedSpanGroupIndex(getPosition(findFirstVisibleChildClosestToEnd), this.mSpanCount) - this.mSpanSizeLookup.getCachedSpanGroupIndex(getPosition(findFirstVisibleChildClosestToStart), this.mSpanCount)) + 1)))) + ((float) (this.mOrientationHelper.getStartAfterPadding() - this.mOrientationHelper.getDecoratedStart(findFirstVisibleChildClosestToStart))));
            }
        }
        return 0;
    }

    private int computeScrollRangeWithSpanInfo(RecyclerView.State state) {
        if (!(getChildCount() == 0 || state.getItemCount() == 0)) {
            ensureLayoutState();
            View findFirstVisibleChildClosestToStart = findFirstVisibleChildClosestToStart(!isSmoothScrollbarEnabled(), true);
            View findFirstVisibleChildClosestToEnd = findFirstVisibleChildClosestToEnd(!isSmoothScrollbarEnabled(), true);
            if (!(findFirstVisibleChildClosestToStart == null || findFirstVisibleChildClosestToEnd == null)) {
                if (!isSmoothScrollbarEnabled()) {
                    return this.mSpanSizeLookup.getCachedSpanGroupIndex(state.getItemCount() - 1, this.mSpanCount) + 1;
                }
                int decoratedEnd = this.mOrientationHelper.getDecoratedEnd(findFirstVisibleChildClosestToEnd) - this.mOrientationHelper.getDecoratedStart(findFirstVisibleChildClosestToStart);
                int cachedSpanGroupIndex = this.mSpanSizeLookup.getCachedSpanGroupIndex(getPosition(findFirstVisibleChildClosestToStart), this.mSpanCount);
                return (int) ((((float) decoratedEnd) / ((float) ((this.mSpanSizeLookup.getCachedSpanGroupIndex(getPosition(findFirstVisibleChildClosestToEnd), this.mSpanCount) - cachedSpanGroupIndex) + 1))) * ((float) (this.mSpanSizeLookup.getCachedSpanGroupIndex(state.getItemCount() - 1, this.mSpanCount) + 1)));
            }
        }
        return 0;
    }

    private void ensureAnchorIsInCorrectSpan(RecyclerView.Recycler recycler, RecyclerView.State state, LinearLayoutManager.AnchorInfo anchorInfo, int i7) {
        boolean z7 = i7 == 1;
        int spanIndex = getSpanIndex(recycler, state, anchorInfo.mPosition);
        if (z7) {
            while (spanIndex > 0) {
                int i8 = anchorInfo.mPosition;
                if (i8 > 0) {
                    int i9 = i8 - 1;
                    anchorInfo.mPosition = i9;
                    spanIndex = getSpanIndex(recycler, state, i9);
                } else {
                    return;
                }
            }
            return;
        }
        int itemCount = state.getItemCount() - 1;
        int i10 = anchorInfo.mPosition;
        while (i10 < itemCount) {
            int i11 = i10 + 1;
            int spanIndex2 = getSpanIndex(recycler, state, i11);
            if (spanIndex2 <= spanIndex) {
                break;
            }
            i10 = i11;
            spanIndex = spanIndex2;
        }
        anchorInfo.mPosition = i10;
    }

    private void ensureViewSet() {
        View[] viewArr = this.mSet;
        if (viewArr == null || viewArr.length != this.mSpanCount) {
            this.mSet = new View[this.mSpanCount];
        }
    }

    private int getSpanGroupIndex(RecyclerView.Recycler recycler, RecyclerView.State state, int i7) {
        if (!state.isPreLayout()) {
            return this.mSpanSizeLookup.getCachedSpanGroupIndex(i7, this.mSpanCount);
        }
        int convertPreLayoutPositionToPostLayout = recycler.convertPreLayoutPositionToPostLayout(i7);
        if (convertPreLayoutPositionToPostLayout != -1) {
            return this.mSpanSizeLookup.getCachedSpanGroupIndex(convertPreLayoutPositionToPostLayout, this.mSpanCount);
        }
        Log.w(TAG, "Cannot find span size for pre layout position. " + i7);
        return 0;
    }

    private int getSpanIndex(RecyclerView.Recycler recycler, RecyclerView.State state, int i7) {
        if (!state.isPreLayout()) {
            return this.mSpanSizeLookup.getCachedSpanIndex(i7, this.mSpanCount);
        }
        int i8 = this.mPreLayoutSpanIndexCache.get(i7, -1);
        if (i8 != -1) {
            return i8;
        }
        int convertPreLayoutPositionToPostLayout = recycler.convertPreLayoutPositionToPostLayout(i7);
        if (convertPreLayoutPositionToPostLayout != -1) {
            return this.mSpanSizeLookup.getCachedSpanIndex(convertPreLayoutPositionToPostLayout, this.mSpanCount);
        }
        Log.w(TAG, "Cannot find span size for pre layout position. It is not cached, not in the adapter. Pos:" + i7);
        return 0;
    }

    private int getSpanSize(RecyclerView.Recycler recycler, RecyclerView.State state, int i7) {
        if (!state.isPreLayout()) {
            return this.mSpanSizeLookup.getSpanSize(i7);
        }
        int i8 = this.mPreLayoutSpanSizeCache.get(i7, -1);
        if (i8 != -1) {
            return i8;
        }
        int convertPreLayoutPositionToPostLayout = recycler.convertPreLayoutPositionToPostLayout(i7);
        if (convertPreLayoutPositionToPostLayout != -1) {
            return this.mSpanSizeLookup.getSpanSize(convertPreLayoutPositionToPostLayout);
        }
        Log.w(TAG, "Cannot find span size for pre layout position. It is not cached, not in the adapter. Pos:" + i7);
        return 1;
    }

    private void guessMeasurement(float f7, int i7) {
        calculateItemBorders(Math.max(Math.round(f7 * ((float) this.mSpanCount)), i7));
    }

    private void measureChild(View view, int i7, boolean z7) {
        int i8;
        int i9;
        LayoutParams layoutParams = (LayoutParams) view.getLayoutParams();
        Rect rect = layoutParams.mDecorInsets;
        int i10 = rect.top + rect.bottom + ((ViewGroup.MarginLayoutParams) layoutParams).topMargin + ((ViewGroup.MarginLayoutParams) layoutParams).bottomMargin;
        int i11 = rect.left + rect.right + ((ViewGroup.MarginLayoutParams) layoutParams).leftMargin + ((ViewGroup.MarginLayoutParams) layoutParams).rightMargin;
        int spaceForSpanRange = getSpaceForSpanRange(layoutParams.mSpanIndex, layoutParams.mSpanSize);
        if (this.mOrientation == 1) {
            i8 = RecyclerView.LayoutManager.getChildMeasureSpec(spaceForSpanRange, i7, i11, ((ViewGroup.MarginLayoutParams) layoutParams).width, false);
            i9 = RecyclerView.LayoutManager.getChildMeasureSpec(this.mOrientationHelper.getTotalSpace(), getHeightMode(), i10, ((ViewGroup.MarginLayoutParams) layoutParams).height, true);
        } else {
            int childMeasureSpec = RecyclerView.LayoutManager.getChildMeasureSpec(spaceForSpanRange, i7, i10, ((ViewGroup.MarginLayoutParams) layoutParams).height, false);
            int childMeasureSpec2 = RecyclerView.LayoutManager.getChildMeasureSpec(this.mOrientationHelper.getTotalSpace(), getWidthMode(), i11, ((ViewGroup.MarginLayoutParams) layoutParams).width, true);
            i9 = childMeasureSpec;
            i8 = childMeasureSpec2;
        }
        measureChildWithDecorationsAndMargin(view, i8, i9, z7);
    }

    private void measureChildWithDecorationsAndMargin(View view, int i7, int i8, boolean z7) {
        RecyclerView.LayoutParams layoutParams = (RecyclerView.LayoutParams) view.getLayoutParams();
        if (z7 ? shouldReMeasureChild(view, i7, i8, layoutParams) : shouldMeasureChild(view, i7, i8, layoutParams)) {
            view.measure(i7, i8);
        }
    }

    private void updateMeasurements() {
        int i7;
        int i8;
        if (getOrientation() == 1) {
            i8 = getWidth() - getPaddingRight();
            i7 = getPaddingLeft();
        } else {
            i8 = getHeight() - getPaddingBottom();
            i7 = getPaddingTop();
        }
        calculateItemBorders(i8 - i7);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public boolean checkLayoutParams(RecyclerView.LayoutParams layoutParams) {
        return layoutParams instanceof LayoutParams;
    }

    /* access modifiers changed from: package-private */
    @Override // androidx.recyclerview.widget.LinearLayoutManager
    public void collectPrefetchPositionsForLayoutState(RecyclerView.State state, LinearLayoutManager.LayoutState layoutState, RecyclerView.LayoutManager.LayoutPrefetchRegistry layoutPrefetchRegistry) {
        int i7 = this.mSpanCount;
        for (int i8 = 0; i8 < this.mSpanCount && layoutState.hasMore(state) && i7 > 0; i8++) {
            int i9 = layoutState.mCurrentPosition;
            layoutPrefetchRegistry.addPosition(i9, Math.max(0, layoutState.mScrollingOffset));
            i7 -= this.mSpanSizeLookup.getSpanSize(i9);
            layoutState.mCurrentPosition += layoutState.mItemDirection;
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager, androidx.recyclerview.widget.LinearLayoutManager
    public int computeHorizontalScrollOffset(RecyclerView.State state) {
        return this.mUsingSpansToEstimateScrollBarDimensions ? computeScrollOffsetWithSpanInfo(state) : super.computeHorizontalScrollOffset(state);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager, androidx.recyclerview.widget.LinearLayoutManager
    public int computeHorizontalScrollRange(RecyclerView.State state) {
        return this.mUsingSpansToEstimateScrollBarDimensions ? computeScrollRangeWithSpanInfo(state) : super.computeHorizontalScrollRange(state);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager, androidx.recyclerview.widget.LinearLayoutManager
    public int computeVerticalScrollOffset(RecyclerView.State state) {
        return this.mUsingSpansToEstimateScrollBarDimensions ? computeScrollOffsetWithSpanInfo(state) : super.computeVerticalScrollOffset(state);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager, androidx.recyclerview.widget.LinearLayoutManager
    public int computeVerticalScrollRange(RecyclerView.State state) {
        return this.mUsingSpansToEstimateScrollBarDimensions ? computeScrollRangeWithSpanInfo(state) : super.computeVerticalScrollRange(state);
    }

    /* access modifiers changed from: package-private */
    @Override // androidx.recyclerview.widget.LinearLayoutManager
    public View findReferenceChild(RecyclerView.Recycler recycler, RecyclerView.State state, int i7, int i8, int i9) {
        ensureLayoutState();
        int startAfterPadding = this.mOrientationHelper.getStartAfterPadding();
        int endAfterPadding = this.mOrientationHelper.getEndAfterPadding();
        int i10 = i8 > i7 ? 1 : -1;
        View view = null;
        View view2 = null;
        while (i7 != i8) {
            View childAt = getChildAt(i7);
            int position = getPosition(childAt);
            if (position >= 0 && position < i9 && getSpanIndex(recycler, state, position) == 0) {
                if (((RecyclerView.LayoutParams) childAt.getLayoutParams()).isItemRemoved()) {
                    if (view2 == null) {
                        view2 = childAt;
                    }
                } else if (this.mOrientationHelper.getDecoratedStart(childAt) < endAfterPadding && this.mOrientationHelper.getDecoratedEnd(childAt) >= startAfterPadding) {
                    return childAt;
                } else {
                    if (view == null) {
                        view = childAt;
                    }
                }
            }
            i7 += i10;
        }
        return view != null ? view : view2;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager, androidx.recyclerview.widget.LinearLayoutManager
    public RecyclerView.LayoutParams generateDefaultLayoutParams() {
        return this.mOrientation == 0 ? new LayoutParams(-2, -1) : new LayoutParams(-1, -2);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public RecyclerView.LayoutParams generateLayoutParams(Context context, AttributeSet attributeSet) {
        return new LayoutParams(context, attributeSet);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public int getColumnCountForAccessibility(RecyclerView.Recycler recycler, RecyclerView.State state) {
        if (this.mOrientation == 1) {
            return this.mSpanCount;
        }
        if (state.getItemCount() < 1) {
            return 0;
        }
        return getSpanGroupIndex(recycler, state, state.getItemCount() - 1) + 1;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public int getRowCountForAccessibility(RecyclerView.Recycler recycler, RecyclerView.State state) {
        if (this.mOrientation == 0) {
            return this.mSpanCount;
        }
        if (state.getItemCount() < 1) {
            return 0;
        }
        return getSpanGroupIndex(recycler, state, state.getItemCount() - 1) + 1;
    }

    /* access modifiers changed from: package-private */
    public int getSpaceForSpanRange(int i7, int i8) {
        if (this.mOrientation != 1 || !isLayoutRTL()) {
            int[] iArr = this.mCachedBorders;
            return iArr[i8 + i7] - iArr[i7];
        }
        int[] iArr2 = this.mCachedBorders;
        int i9 = this.mSpanCount;
        return iArr2[i9 - i7] - iArr2[(i9 - i7) - i8];
    }

    public int getSpanCount() {
        return this.mSpanCount;
    }

    public SpanSizeLookup getSpanSizeLookup() {
        return this.mSpanSizeLookup;
    }

    public boolean isUsingSpansToEstimateScrollbarDimensions() {
        return this.mUsingSpansToEstimateScrollBarDimensions;
    }

    /* access modifiers changed from: package-private */
    @Override // androidx.recyclerview.widget.LinearLayoutManager
    public void layoutChunk(RecyclerView.Recycler recycler, RecyclerView.State state, LinearLayoutManager.LayoutState layoutState, LinearLayoutManager.LayoutChunkResult layoutChunkResult) {
        int i7;
        int i8;
        int i9;
        int i10;
        int i11;
        int i12;
        int i13;
        int i14;
        int i15;
        int i16;
        int i17;
        int i18;
        int i19;
        View next;
        int modeInOther = this.mOrientationHelper.getModeInOther();
        boolean z7 = modeInOther != 1073741824;
        int i20 = getChildCount() > 0 ? this.mCachedBorders[this.mSpanCount] : 0;
        if (z7) {
            updateMeasurements();
        }
        boolean z8 = layoutState.mItemDirection == 1;
        int i21 = this.mSpanCount;
        if (!z8) {
            i21 = getSpanIndex(recycler, state, layoutState.mCurrentPosition) + getSpanSize(recycler, state, layoutState.mCurrentPosition);
        }
        int i22 = 0;
        while (i22 < this.mSpanCount && layoutState.hasMore(state) && i21 > 0) {
            int i23 = layoutState.mCurrentPosition;
            int spanSize = getSpanSize(recycler, state, i23);
            if (spanSize <= this.mSpanCount) {
                i21 -= spanSize;
                if (i21 < 0 || (next = layoutState.next(recycler)) == null) {
                    break;
                }
                this.mSet[i22] = next;
                i22++;
            } else {
                throw new IllegalArgumentException("Item at position " + i23 + " requires " + spanSize + " spans but GridLayoutManager has only " + this.mSpanCount + " spans.");
            }
        }
        if (i22 == 0) {
            layoutChunkResult.mFinished = true;
            return;
        }
        assignSpans(recycler, state, i22, z8);
        float f7 = 0.0f;
        int i24 = 0;
        for (int i25 = 0; i25 < i22; i25++) {
            View view = this.mSet[i25];
            if (layoutState.mScrapList == null) {
                if (z8) {
                    addView(view);
                } else {
                    addView(view, 0);
                }
            } else if (z8) {
                addDisappearingView(view);
            } else {
                addDisappearingView(view, 0);
            }
            calculateItemDecorationsForChild(view, this.mDecorInsets);
            measureChild(view, modeInOther, false);
            int decoratedMeasurement = this.mOrientationHelper.getDecoratedMeasurement(view);
            if (decoratedMeasurement > i24) {
                i24 = decoratedMeasurement;
            }
            float decoratedMeasurementInOther = (((float) this.mOrientationHelper.getDecoratedMeasurementInOther(view)) * 1.0f) / ((float) ((LayoutParams) view.getLayoutParams()).mSpanSize);
            if (decoratedMeasurementInOther > f7) {
                f7 = decoratedMeasurementInOther;
            }
        }
        if (z7) {
            guessMeasurement(f7, i20);
            i24 = 0;
            for (int i26 = 0; i26 < i22; i26++) {
                View view2 = this.mSet[i26];
                measureChild(view2, 1073741824, true);
                int decoratedMeasurement2 = this.mOrientationHelper.getDecoratedMeasurement(view2);
                if (decoratedMeasurement2 > i24) {
                    i24 = decoratedMeasurement2;
                }
            }
        }
        for (int i27 = 0; i27 < i22; i27++) {
            View view3 = this.mSet[i27];
            if (this.mOrientationHelper.getDecoratedMeasurement(view3) != i24) {
                LayoutParams layoutParams = (LayoutParams) view3.getLayoutParams();
                Rect rect = layoutParams.mDecorInsets;
                int i28 = rect.top + rect.bottom + ((ViewGroup.MarginLayoutParams) layoutParams).topMargin + ((ViewGroup.MarginLayoutParams) layoutParams).bottomMargin;
                int i29 = rect.left + rect.right + ((ViewGroup.MarginLayoutParams) layoutParams).leftMargin + ((ViewGroup.MarginLayoutParams) layoutParams).rightMargin;
                int spaceForSpanRange = getSpaceForSpanRange(layoutParams.mSpanIndex, layoutParams.mSpanSize);
                if (this.mOrientation == 1) {
                    i19 = RecyclerView.LayoutManager.getChildMeasureSpec(spaceForSpanRange, 1073741824, i29, ((ViewGroup.MarginLayoutParams) layoutParams).width, false);
                    i18 = View.MeasureSpec.makeMeasureSpec(i24 - i28, 1073741824);
                } else {
                    int makeMeasureSpec = View.MeasureSpec.makeMeasureSpec(i24 - i29, 1073741824);
                    i18 = RecyclerView.LayoutManager.getChildMeasureSpec(spaceForSpanRange, 1073741824, i28, ((ViewGroup.MarginLayoutParams) layoutParams).height, false);
                    i19 = makeMeasureSpec;
                }
                measureChildWithDecorationsAndMargin(view3, i19, i18, true);
            }
        }
        layoutChunkResult.mConsumed = i24;
        if (this.mOrientation == 1) {
            if (layoutState.mLayoutDirection == -1) {
                i10 = layoutState.mOffset;
                i17 = i10 - i24;
            } else {
                i17 = layoutState.mOffset;
                i10 = i17 + i24;
            }
            i8 = i17;
            i9 = 0;
            i7 = 0;
        } else {
            if (layoutState.mLayoutDirection == -1) {
                i16 = layoutState.mOffset;
                i15 = i16 - i24;
            } else {
                i15 = layoutState.mOffset;
                i16 = i15 + i24;
            }
            i7 = i15;
            i8 = 0;
            i9 = i16;
            i10 = 0;
        }
        int i30 = 0;
        while (i30 < i22) {
            View view4 = this.mSet[i30];
            LayoutParams layoutParams2 = (LayoutParams) view4.getLayoutParams();
            if (this.mOrientation != 1) {
                int paddingTop = getPaddingTop() + this.mCachedBorders[layoutParams2.mSpanIndex];
                i12 = paddingTop;
                i13 = i9;
                i14 = this.mOrientationHelper.getDecoratedMeasurementInOther(view4) + paddingTop;
            } else if (isLayoutRTL()) {
                int paddingLeft = getPaddingLeft() + this.mCachedBorders[this.mSpanCount - layoutParams2.mSpanIndex];
                i7 = paddingLeft - this.mOrientationHelper.getDecoratedMeasurementInOther(view4);
                i14 = i10;
                i13 = paddingLeft;
                i12 = i8;
            } else {
                int paddingLeft2 = getPaddingLeft() + this.mCachedBorders[layoutParams2.mSpanIndex];
                i14 = i10;
                i11 = paddingLeft2;
                i12 = i8;
                i13 = this.mOrientationHelper.getDecoratedMeasurementInOther(view4) + paddingLeft2;
                layoutDecoratedWithMargins(view4, i11, i12, i13, i14);
                if (!layoutParams2.isItemRemoved() || layoutParams2.isItemChanged()) {
                    layoutChunkResult.mIgnoreConsumed = true;
                }
                layoutChunkResult.mFocusable |= view4.hasFocusable();
                i30++;
                i10 = i14;
                i9 = i13;
                i8 = i12;
                i7 = i11;
            }
            i11 = i7;
            layoutDecoratedWithMargins(view4, i11, i12, i13, i14);
            if (!layoutParams2.isItemRemoved()) {
            }
            layoutChunkResult.mIgnoreConsumed = true;
            layoutChunkResult.mFocusable |= view4.hasFocusable();
            i30++;
            i10 = i14;
            i9 = i13;
            i8 = i12;
            i7 = i11;
        }
        Arrays.fill(this.mSet, (Object) null);
    }

    /* access modifiers changed from: package-private */
    @Override // androidx.recyclerview.widget.LinearLayoutManager
    public void onAnchorReady(RecyclerView.Recycler recycler, RecyclerView.State state, LinearLayoutManager.AnchorInfo anchorInfo, int i7) {
        super.onAnchorReady(recycler, state, anchorInfo, i7);
        updateMeasurements();
        if (state.getItemCount() > 0 && !state.isPreLayout()) {
            ensureAnchorIsInCorrectSpan(recycler, state, anchorInfo, i7);
        }
        ensureViewSet();
    }

    /* JADX WARNING: Code restructure failed: missing block: B:54:0x00d6, code lost:
        if (r13 == (r2 > r15)) goto L_0x00b0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:65:0x00f6, code lost:
        if (r13 == r11) goto L_0x00b8;
     */
    /* JADX WARNING: Removed duplicated region for block: B:71:0x0107  */
    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager, androidx.recyclerview.widget.LinearLayoutManager
    public View onFocusSearchFailed(View view, int i7, RecyclerView.Recycler recycler, RecyclerView.State state) {
        int i8;
        int i9;
        int i10;
        int i11;
        View view2;
        View view3;
        int i12;
        int i13;
        int i14;
        boolean z7;
        RecyclerView.Recycler recycler2 = recycler;
        RecyclerView.State state2 = state;
        View findContainingItemView = findContainingItemView(view);
        View view4 = null;
        if (findContainingItemView == null) {
            return null;
        }
        LayoutParams layoutParams = (LayoutParams) findContainingItemView.getLayoutParams();
        int i15 = layoutParams.mSpanIndex;
        int i16 = layoutParams.mSpanSize + i15;
        if (super.onFocusSearchFailed(view, i7, recycler, state) == null) {
            return null;
        }
        if ((convertFocusDirectionToLayoutDirection(i7) == 1) != this.mShouldReverseLayout) {
            i10 = getChildCount() - 1;
            i9 = -1;
            i8 = -1;
        } else {
            i9 = getChildCount();
            i8 = 1;
            i10 = 0;
        }
        boolean z8 = this.mOrientation == 1 && isLayoutRTL();
        int spanGroupIndex = getSpanGroupIndex(recycler2, state2, i10);
        int i17 = -1;
        int i18 = -1;
        int i19 = 0;
        int i20 = 0;
        int i21 = i10;
        View view5 = null;
        while (i21 != i9) {
            int spanGroupIndex2 = getSpanGroupIndex(recycler2, state2, i21);
            View childAt = getChildAt(i21);
            if (childAt == findContainingItemView) {
                break;
            }
            if (!childAt.hasFocusable() || spanGroupIndex2 == spanGroupIndex) {
                LayoutParams layoutParams2 = (LayoutParams) childAt.getLayoutParams();
                int i22 = layoutParams2.mSpanIndex;
                view2 = findContainingItemView;
                int i23 = layoutParams2.mSpanSize + i22;
                if (childAt.hasFocusable() && i22 == i15 && i23 == i16) {
                    return childAt;
                }
                if ((!childAt.hasFocusable() || view4 != null) && (childAt.hasFocusable() || view5 != null)) {
                    view3 = view5;
                    int min = Math.min(i23, i16) - Math.max(i22, i15);
                    if (childAt.hasFocusable()) {
                        if (min <= i19) {
                            if (min == i19) {
                            }
                        }
                    } else if (view4 == null) {
                        i12 = i19;
                        i11 = i9;
                        z7 = true;
                        if (isViewPartiallyVisible(childAt, false, true)) {
                            i13 = i20;
                            if (min > i13) {
                                i14 = i18;
                                if (z7) {
                                    if (childAt.hasFocusable()) {
                                        i17 = layoutParams2.mSpanIndex;
                                        i18 = i14;
                                        i20 = i13;
                                        view5 = view3;
                                        view4 = childAt;
                                        i19 = Math.min(i23, i16) - Math.max(i22, i15);
                                    } else {
                                        int i24 = layoutParams2.mSpanIndex;
                                        i20 = Math.min(i23, i16) - Math.max(i22, i15);
                                        i18 = i24;
                                        i19 = i12;
                                        view5 = childAt;
                                    }
                                    i21 += i8;
                                    recycler2 = recycler;
                                    state2 = state;
                                    findContainingItemView = view2;
                                    i9 = i11;
                                }
                            } else {
                                if (min == i13) {
                                    i14 = i18;
                                    if (i22 <= i14) {
                                        z7 = false;
                                    }
                                } else {
                                    i14 = i18;
                                }
                                z7 = false;
                                if (z7) {
                                }
                            }
                        }
                        i14 = i18;
                        i13 = i20;
                        z7 = false;
                        if (z7) {
                        }
                    }
                    i12 = i19;
                    i11 = i9;
                    i14 = i18;
                    i13 = i20;
                    z7 = false;
                    if (z7) {
                    }
                } else {
                    view3 = view5;
                }
                i12 = i19;
                i11 = i9;
                i14 = i18;
                i13 = i20;
                z7 = true;
                if (z7) {
                }
            } else if (view4 != null) {
                break;
            } else {
                view2 = findContainingItemView;
                view3 = view5;
                i12 = i19;
                i11 = i9;
                i14 = i18;
                i13 = i20;
            }
            i18 = i14;
            i20 = i13;
            i19 = i12;
            view5 = view3;
            i21 += i8;
            recycler2 = recycler;
            state2 = state;
            findContainingItemView = view2;
            i9 = i11;
        }
        return view4 != null ? view4 : view5;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public void onInitializeAccessibilityNodeInfoForItem(RecyclerView.Recycler recycler, RecyclerView.State state, View view, AccessibilityNodeInfoCompat accessibilityNodeInfoCompat) {
        boolean z7;
        boolean z8;
        int i7;
        int i8;
        int i9;
        int i10;
        ViewGroup.LayoutParams layoutParams = view.getLayoutParams();
        if (!(layoutParams instanceof LayoutParams)) {
            super.onInitializeAccessibilityNodeInfoForItem(view, accessibilityNodeInfoCompat);
            return;
        }
        LayoutParams layoutParams2 = (LayoutParams) layoutParams;
        int spanGroupIndex = getSpanGroupIndex(recycler, state, layoutParams2.getViewLayoutPosition());
        if (this.mOrientation == 0) {
            i10 = layoutParams2.getSpanIndex();
            i9 = layoutParams2.getSpanSize();
            i7 = 1;
            z8 = false;
            z7 = false;
            i8 = spanGroupIndex;
        } else {
            i9 = 1;
            i8 = layoutParams2.getSpanIndex();
            i7 = layoutParams2.getSpanSize();
            z8 = false;
            z7 = false;
            i10 = spanGroupIndex;
        }
        accessibilityNodeInfoCompat.setCollectionItemInfo(AccessibilityNodeInfoCompat.CollectionItemInfoCompat.obtain(i10, i9, i8, i7, z8, z7));
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public void onItemsAdded(RecyclerView recyclerView, int i7, int i8) {
        this.mSpanSizeLookup.invalidateSpanIndexCache();
        this.mSpanSizeLookup.invalidateSpanGroupIndexCache();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public void onItemsChanged(RecyclerView recyclerView) {
        this.mSpanSizeLookup.invalidateSpanIndexCache();
        this.mSpanSizeLookup.invalidateSpanGroupIndexCache();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public void onItemsMoved(RecyclerView recyclerView, int i7, int i8, int i9) {
        this.mSpanSizeLookup.invalidateSpanIndexCache();
        this.mSpanSizeLookup.invalidateSpanGroupIndexCache();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public void onItemsRemoved(RecyclerView recyclerView, int i7, int i8) {
        this.mSpanSizeLookup.invalidateSpanIndexCache();
        this.mSpanSizeLookup.invalidateSpanGroupIndexCache();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public void onItemsUpdated(RecyclerView recyclerView, int i7, int i8, Object obj) {
        this.mSpanSizeLookup.invalidateSpanIndexCache();
        this.mSpanSizeLookup.invalidateSpanGroupIndexCache();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager, androidx.recyclerview.widget.LinearLayoutManager
    public void onLayoutChildren(RecyclerView.Recycler recycler, RecyclerView.State state) {
        if (state.isPreLayout()) {
            cachePreLayoutSpanMapping();
        }
        super.onLayoutChildren(recycler, state);
        clearPreLayoutSpanMappingCache();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager, androidx.recyclerview.widget.LinearLayoutManager
    public void onLayoutCompleted(RecyclerView.State state) {
        super.onLayoutCompleted(state);
        this.mPendingSpanCountChange = false;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager, androidx.recyclerview.widget.LinearLayoutManager
    public int scrollHorizontallyBy(int i7, RecyclerView.Recycler recycler, RecyclerView.State state) {
        updateMeasurements();
        ensureViewSet();
        return super.scrollHorizontallyBy(i7, recycler, state);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager, androidx.recyclerview.widget.LinearLayoutManager
    public int scrollVerticallyBy(int i7, RecyclerView.Recycler recycler, RecyclerView.State state) {
        updateMeasurements();
        ensureViewSet();
        return super.scrollVerticallyBy(i7, recycler, state);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public void setMeasuredDimension(Rect rect, int i7, int i8) {
        int i9;
        int i10;
        if (this.mCachedBorders == null) {
            super.setMeasuredDimension(rect, i7, i8);
        }
        int paddingLeft = getPaddingLeft() + getPaddingRight();
        int paddingTop = getPaddingTop() + getPaddingBottom();
        if (this.mOrientation == 1) {
            i10 = RecyclerView.LayoutManager.chooseSize(i8, rect.height() + paddingTop, getMinimumHeight());
            int[] iArr = this.mCachedBorders;
            i9 = RecyclerView.LayoutManager.chooseSize(i7, iArr[iArr.length - 1] + paddingLeft, getMinimumWidth());
        } else {
            i9 = RecyclerView.LayoutManager.chooseSize(i7, rect.width() + paddingLeft, getMinimumWidth());
            int[] iArr2 = this.mCachedBorders;
            i10 = RecyclerView.LayoutManager.chooseSize(i8, iArr2[iArr2.length - 1] + paddingTop, getMinimumHeight());
        }
        setMeasuredDimension(i9, i10);
    }

    public void setSpanCount(int i7) {
        if (i7 != this.mSpanCount) {
            this.mPendingSpanCountChange = true;
            if (i7 >= 1) {
                this.mSpanCount = i7;
                this.mSpanSizeLookup.invalidateSpanIndexCache();
                requestLayout();
                return;
            }
            throw new IllegalArgumentException("Span count should be at least 1. Provided " + i7);
        }
    }

    public void setSpanSizeLookup(SpanSizeLookup spanSizeLookup) {
        this.mSpanSizeLookup = spanSizeLookup;
    }

    @Override // androidx.recyclerview.widget.LinearLayoutManager
    public void setStackFromEnd(boolean z7) {
        if (!z7) {
            super.setStackFromEnd(false);
            return;
        }
        throw new UnsupportedOperationException("GridLayoutManager does not support stack from end. Consider using reverse layout");
    }

    public void setUsingSpansToEstimateScrollbarDimensions(boolean z7) {
        this.mUsingSpansToEstimateScrollBarDimensions = z7;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager, androidx.recyclerview.widget.LinearLayoutManager
    public boolean supportsPredictiveItemAnimations() {
        return this.mPendingSavedState == null && !this.mPendingSpanCountChange;
    }

    public GridLayoutManager(Context context, int i7, int i8, boolean z7) {
        super(context, i8, z7);
        setSpanCount(i7);
    }

    static int[] calculateItemBorders(int[] iArr, int i7, int i8) {
        int i9;
        if (!(iArr != null && iArr.length == i7 + 1 && iArr[iArr.length - 1] == i8)) {
            iArr = new int[(i7 + 1)];
        }
        int i10 = 0;
        iArr[0] = 0;
        int i11 = i8 / i7;
        int i12 = i8 % i7;
        int i13 = 0;
        for (int i14 = 1; i14 <= i7; i14++) {
            i10 += i12;
            if (i10 <= 0 || i7 - i10 >= i12) {
                i9 = i11;
            } else {
                i9 = i11 + 1;
                i10 -= i7;
            }
            i13 += i9;
            iArr[i14] = i13;
        }
        return iArr;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public RecyclerView.LayoutParams generateLayoutParams(ViewGroup.LayoutParams layoutParams) {
        return layoutParams instanceof ViewGroup.MarginLayoutParams ? new LayoutParams((ViewGroup.MarginLayoutParams) layoutParams) : new LayoutParams(layoutParams);
    }

    public GridLayoutManager(Context context, AttributeSet attributeSet, int i7, int i8) {
        super(context, attributeSet, i7, i8);
        setSpanCount(RecyclerView.LayoutManager.getProperties(context, attributeSet, i7, i8).spanCount);
    }
}
