package androidx.room;

import androidx.annotation.RestrictTo;
import androidx.annotation.VisibleForTesting;
import androidx.sqlite.db.SupportSQLiteProgram;
import androidx.sqlite.db.SupportSQLiteQuery;
import java.util.Arrays;
import java.util.Iterator;
import java.util.Map;
import java.util.TreeMap;

@RestrictTo({RestrictTo.Scope.LIBRARY_GROUP_PREFIX})
public class RoomSQLiteQuery implements SupportSQLiteQuery, SupportSQLiteProgram {
    private static final int BLOB = 5;
    @VisibleForTesting
    static final int DESIRED_POOL_SIZE = 10;
    private static final int DOUBLE = 3;
    private static final int LONG = 2;
    private static final int NULL = 1;
    @VisibleForTesting
    static final int POOL_LIMIT = 15;
    private static final int STRING = 4;
    @VisibleForTesting
    static final TreeMap<Integer, RoomSQLiteQuery> sQueryPool = new TreeMap<>();
    @VisibleForTesting
    int mArgCount;
    private final int[] mBindingTypes;
    @VisibleForTesting
    final byte[][] mBlobBindings;
    @VisibleForTesting
    final int mCapacity;
    @VisibleForTesting
    final double[] mDoubleBindings;
    @VisibleForTesting
    final long[] mLongBindings;
    private volatile String mQuery;
    @VisibleForTesting
    final String[] mStringBindings;

    private RoomSQLiteQuery(int i7) {
        this.mCapacity = i7;
        int i8 = i7 + 1;
        this.mBindingTypes = new int[i8];
        this.mLongBindings = new long[i8];
        this.mDoubleBindings = new double[i8];
        this.mStringBindings = new String[i8];
        this.mBlobBindings = new byte[i8][];
    }

    public static RoomSQLiteQuery acquire(String str, int i7) {
        TreeMap<Integer, RoomSQLiteQuery> treeMap = sQueryPool;
        synchronized (treeMap) {
            Map.Entry<Integer, RoomSQLiteQuery> ceilingEntry = treeMap.ceilingEntry(Integer.valueOf(i7));
            if (ceilingEntry != null) {
                treeMap.remove(ceilingEntry.getKey());
                RoomSQLiteQuery value = ceilingEntry.getValue();
                value.init(str, i7);
                return value;
            }
            RoomSQLiteQuery roomSQLiteQuery = new RoomSQLiteQuery(i7);
            roomSQLiteQuery.init(str, i7);
            return roomSQLiteQuery;
        }
    }

    public static RoomSQLiteQuery copyFrom(SupportSQLiteQuery supportSQLiteQuery) {
        RoomSQLiteQuery acquire = acquire(supportSQLiteQuery.getSql(), supportSQLiteQuery.getArgCount());
        supportSQLiteQuery.bindTo(new SupportSQLiteProgram(acquire) {
            /* class androidx.room.RoomSQLiteQuery.AnonymousClass1 */
            final /* synthetic */ RoomSQLiteQuery val$query;

            {
                this.val$query = r1;
            }

            @Override // androidx.sqlite.db.SupportSQLiteProgram
            public void bindBlob(int i7, byte[] bArr) {
                this.val$query.bindBlob(i7, bArr);
            }

            @Override // androidx.sqlite.db.SupportSQLiteProgram
            public void bindDouble(int i7, double d7) {
                this.val$query.bindDouble(i7, d7);
            }

            @Override // androidx.sqlite.db.SupportSQLiteProgram
            public void bindLong(int i7, long j7) {
                this.val$query.bindLong(i7, j7);
            }

            @Override // androidx.sqlite.db.SupportSQLiteProgram
            public void bindNull(int i7) {
                this.val$query.bindNull(i7);
            }

            @Override // androidx.sqlite.db.SupportSQLiteProgram
            public void bindString(int i7, String str) {
                this.val$query.bindString(i7, str);
            }

            @Override // androidx.sqlite.db.SupportSQLiteProgram
            public void clearBindings() {
                this.val$query.clearBindings();
            }

            @Override // java.io.Closeable, java.lang.AutoCloseable
            public void close() {
            }
        });
        return acquire;
    }

    private static void prunePoolLocked() {
        TreeMap<Integer, RoomSQLiteQuery> treeMap = sQueryPool;
        if (treeMap.size() > 15) {
            int size = treeMap.size() - 10;
            Iterator<Integer> it = treeMap.descendingKeySet().iterator();
            while (true) {
                int i7 = size - 1;
                if (size > 0) {
                    it.next();
                    it.remove();
                    size = i7;
                } else {
                    return;
                }
            }
        }
    }

    @Override // androidx.sqlite.db.SupportSQLiteProgram
    public void bindBlob(int i7, byte[] bArr) {
        this.mBindingTypes[i7] = 5;
        this.mBlobBindings[i7] = bArr;
    }

    @Override // androidx.sqlite.db.SupportSQLiteProgram
    public void bindDouble(int i7, double d7) {
        this.mBindingTypes[i7] = 3;
        this.mDoubleBindings[i7] = d7;
    }

    @Override // androidx.sqlite.db.SupportSQLiteProgram
    public void bindLong(int i7, long j7) {
        this.mBindingTypes[i7] = 2;
        this.mLongBindings[i7] = j7;
    }

    @Override // androidx.sqlite.db.SupportSQLiteProgram
    public void bindNull(int i7) {
        this.mBindingTypes[i7] = 1;
    }

    @Override // androidx.sqlite.db.SupportSQLiteProgram
    public void bindString(int i7, String str) {
        this.mBindingTypes[i7] = 4;
        this.mStringBindings[i7] = str;
    }

    @Override // androidx.sqlite.db.SupportSQLiteQuery
    public void bindTo(SupportSQLiteProgram supportSQLiteProgram) {
        for (int i7 = 1; i7 <= this.mArgCount; i7++) {
            int i8 = this.mBindingTypes[i7];
            if (i8 == 1) {
                supportSQLiteProgram.bindNull(i7);
            } else if (i8 == 2) {
                supportSQLiteProgram.bindLong(i7, this.mLongBindings[i7]);
            } else if (i8 == 3) {
                supportSQLiteProgram.bindDouble(i7, this.mDoubleBindings[i7]);
            } else if (i8 == 4) {
                supportSQLiteProgram.bindString(i7, this.mStringBindings[i7]);
            } else if (i8 == 5) {
                supportSQLiteProgram.bindBlob(i7, this.mBlobBindings[i7]);
            }
        }
    }

    @Override // androidx.sqlite.db.SupportSQLiteProgram
    public void clearBindings() {
        Arrays.fill(this.mBindingTypes, 1);
        Arrays.fill(this.mStringBindings, (Object) null);
        Arrays.fill(this.mBlobBindings, (Object) null);
        this.mQuery = null;
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() {
    }

    public void copyArgumentsFrom(RoomSQLiteQuery roomSQLiteQuery) {
        int argCount = roomSQLiteQuery.getArgCount() + 1;
        System.arraycopy(roomSQLiteQuery.mBindingTypes, 0, this.mBindingTypes, 0, argCount);
        System.arraycopy(roomSQLiteQuery.mLongBindings, 0, this.mLongBindings, 0, argCount);
        System.arraycopy(roomSQLiteQuery.mStringBindings, 0, this.mStringBindings, 0, argCount);
        System.arraycopy(roomSQLiteQuery.mBlobBindings, 0, this.mBlobBindings, 0, argCount);
        System.arraycopy(roomSQLiteQuery.mDoubleBindings, 0, this.mDoubleBindings, 0, argCount);
    }

    @Override // androidx.sqlite.db.SupportSQLiteQuery
    public int getArgCount() {
        return this.mArgCount;
    }

    @Override // androidx.sqlite.db.SupportSQLiteQuery
    public String getSql() {
        return this.mQuery;
    }

    /* access modifiers changed from: package-private */
    public void init(String str, int i7) {
        this.mQuery = str;
        this.mArgCount = i7;
    }

    public void release() {
        TreeMap<Integer, RoomSQLiteQuery> treeMap = sQueryPool;
        synchronized (treeMap) {
            treeMap.put(Integer.valueOf(this.mCapacity), this);
            prunePoolLocked();
        }
    }
}
