package androidx.swiperefreshlayout.widget;

import android.animation.Animator;
import android.animation.ValueAnimator;
import android.content.Context;
import android.content.res.Resources;
import android.graphics.Canvas;
import android.graphics.ColorFilter;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.drawable.Animatable;
import android.graphics.drawable.Drawable;
import android.view.animation.Interpolator;
import android.view.animation.LinearInterpolator;
import androidx.annotation.NonNull;
import androidx.annotation.RestrictTo;
import androidx.core.util.Preconditions;
import androidx.interpolator.view.animation.FastOutSlowInInterpolator;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

public class CircularProgressDrawable extends Drawable implements Animatable {
    private static final int ANIMATION_DURATION = 1332;
    private static final int ARROW_HEIGHT = 5;
    private static final int ARROW_HEIGHT_LARGE = 6;
    private static final int ARROW_WIDTH = 10;
    private static final int ARROW_WIDTH_LARGE = 12;
    private static final float CENTER_RADIUS = 7.5f;
    private static final float CENTER_RADIUS_LARGE = 11.0f;
    private static final int[] COLORS = {-16777216};
    private static final float COLOR_CHANGE_OFFSET = 0.75f;
    public static final int DEFAULT = 1;
    private static final float GROUP_FULL_ROTATION = 216.0f;
    public static final int LARGE = 0;
    private static final Interpolator LINEAR_INTERPOLATOR = new LinearInterpolator();
    private static final Interpolator MATERIAL_INTERPOLATOR = new FastOutSlowInInterpolator();
    private static final float MAX_PROGRESS_ARC = 0.8f;
    private static final float MIN_PROGRESS_ARC = 0.01f;
    private static final float RING_ROTATION = 0.20999998f;
    private static final float SHRINK_OFFSET = 0.5f;
    private static final float STROKE_WIDTH = 2.5f;
    private static final float STROKE_WIDTH_LARGE = 3.0f;
    private Animator mAnimator;
    boolean mFinishing;
    private Resources mResources;
    private final Ring mRing;
    private float mRotation;
    float mRotationCount;

    @Retention(RetentionPolicy.SOURCE)
    @RestrictTo({RestrictTo.Scope.LIBRARY_GROUP})
    public @interface ProgressDrawableSize {
    }

    /* access modifiers changed from: private */
    public static class Ring {
        int mAlpha;
        Path mArrow;
        int mArrowHeight;
        final Paint mArrowPaint;
        float mArrowScale;
        int mArrowWidth;
        final Paint mCirclePaint;
        int mColorIndex;
        int[] mColors;
        int mCurrentColor;
        float mEndTrim;
        final Paint mPaint;
        float mRingCenterRadius;
        float mRotation;
        boolean mShowArrow;
        float mStartTrim;
        float mStartingEndTrim;
        float mStartingRotation;
        float mStartingStartTrim;
        float mStrokeWidth;
        final RectF mTempBounds = new RectF();

        Ring() {
            Paint paint = new Paint();
            this.mPaint = paint;
            Paint paint2 = new Paint();
            this.mArrowPaint = paint2;
            Paint paint3 = new Paint();
            this.mCirclePaint = paint3;
            this.mStartTrim = 0.0f;
            this.mEndTrim = 0.0f;
            this.mRotation = 0.0f;
            this.mStrokeWidth = 5.0f;
            this.mArrowScale = 1.0f;
            this.mAlpha = 255;
            paint.setStrokeCap(Paint.Cap.SQUARE);
            paint.setAntiAlias(true);
            paint.setStyle(Paint.Style.STROKE);
            paint2.setStyle(Paint.Style.FILL);
            paint2.setAntiAlias(true);
            paint3.setColor(0);
        }

        /* access modifiers changed from: package-private */
        public void draw(Canvas canvas, Rect rect) {
            RectF rectF = this.mTempBounds;
            float f7 = this.mRingCenterRadius;
            float f8 = (this.mStrokeWidth / 2.0f) + f7;
            if (f7 <= 0.0f) {
                f8 = (((float) Math.min(rect.width(), rect.height())) / 2.0f) - Math.max((((float) this.mArrowWidth) * this.mArrowScale) / 2.0f, this.mStrokeWidth / 2.0f);
            }
            rectF.set(((float) rect.centerX()) - f8, ((float) rect.centerY()) - f8, ((float) rect.centerX()) + f8, ((float) rect.centerY()) + f8);
            float f9 = this.mStartTrim;
            float f10 = this.mRotation;
            float f11 = (f9 + f10) * 360.0f;
            float f12 = ((this.mEndTrim + f10) * 360.0f) - f11;
            this.mPaint.setColor(this.mCurrentColor);
            this.mPaint.setAlpha(this.mAlpha);
            float f13 = this.mStrokeWidth / 2.0f;
            rectF.inset(f13, f13);
            canvas.drawCircle(rectF.centerX(), rectF.centerY(), rectF.width() / 2.0f, this.mCirclePaint);
            float f14 = -f13;
            rectF.inset(f14, f14);
            canvas.drawArc(rectF, f11, f12, false, this.mPaint);
            drawTriangle(canvas, f11, f12, rectF);
        }

        /* access modifiers changed from: package-private */
        public void drawTriangle(Canvas canvas, float f7, float f8, RectF rectF) {
            if (this.mShowArrow) {
                Path path = this.mArrow;
                if (path == null) {
                    Path path2 = new Path();
                    this.mArrow = path2;
                    path2.setFillType(Path.FillType.EVEN_ODD);
                } else {
                    path.reset();
                }
                this.mArrow.moveTo(0.0f, 0.0f);
                this.mArrow.lineTo(((float) this.mArrowWidth) * this.mArrowScale, 0.0f);
                Path path3 = this.mArrow;
                float f9 = this.mArrowScale;
                path3.lineTo((((float) this.mArrowWidth) * f9) / 2.0f, ((float) this.mArrowHeight) * f9);
                this.mArrow.offset(((Math.min(rectF.width(), rectF.height()) / 2.0f) + rectF.centerX()) - ((((float) this.mArrowWidth) * this.mArrowScale) / 2.0f), rectF.centerY() + (this.mStrokeWidth / 2.0f));
                this.mArrow.close();
                this.mArrowPaint.setColor(this.mCurrentColor);
                this.mArrowPaint.setAlpha(this.mAlpha);
                canvas.save();
                canvas.rotate(f7 + f8, rectF.centerX(), rectF.centerY());
                canvas.drawPath(this.mArrow, this.mArrowPaint);
                canvas.restore();
            }
        }

        /* access modifiers changed from: package-private */
        public int getAlpha() {
            return this.mAlpha;
        }

        /* access modifiers changed from: package-private */
        public float getArrowHeight() {
            return (float) this.mArrowHeight;
        }

        /* access modifiers changed from: package-private */
        public float getArrowScale() {
            return this.mArrowScale;
        }

        /* access modifiers changed from: package-private */
        public float getArrowWidth() {
            return (float) this.mArrowWidth;
        }

        /* access modifiers changed from: package-private */
        public int getBackgroundColor() {
            return this.mCirclePaint.getColor();
        }

        /* access modifiers changed from: package-private */
        public float getCenterRadius() {
            return this.mRingCenterRadius;
        }

        /* access modifiers changed from: package-private */
        public int[] getColors() {
            return this.mColors;
        }

        /* access modifiers changed from: package-private */
        public float getEndTrim() {
            return this.mEndTrim;
        }

        /* access modifiers changed from: package-private */
        public int getNextColor() {
            return this.mColors[getNextColorIndex()];
        }

        /* access modifiers changed from: package-private */
        public int getNextColorIndex() {
            return (this.mColorIndex + 1) % this.mColors.length;
        }

        /* access modifiers changed from: package-private */
        public float getRotation() {
            return this.mRotation;
        }

        /* access modifiers changed from: package-private */
        public boolean getShowArrow() {
            return this.mShowArrow;
        }

        /* access modifiers changed from: package-private */
        public float getStartTrim() {
            return this.mStartTrim;
        }

        /* access modifiers changed from: package-private */
        public int getStartingColor() {
            return this.mColors[this.mColorIndex];
        }

        /* access modifiers changed from: package-private */
        public float getStartingEndTrim() {
            return this.mStartingEndTrim;
        }

        /* access modifiers changed from: package-private */
        public float getStartingRotation() {
            return this.mStartingRotation;
        }

        /* access modifiers changed from: package-private */
        public float getStartingStartTrim() {
            return this.mStartingStartTrim;
        }

        /* access modifiers changed from: package-private */
        public Paint.Cap getStrokeCap() {
            return this.mPaint.getStrokeCap();
        }

        /* access modifiers changed from: package-private */
        public float getStrokeWidth() {
            return this.mStrokeWidth;
        }

        /* access modifiers changed from: package-private */
        public void goToNextColor() {
            setColorIndex(getNextColorIndex());
        }

        /* access modifiers changed from: package-private */
        public void resetOriginals() {
            this.mStartingStartTrim = 0.0f;
            this.mStartingEndTrim = 0.0f;
            this.mStartingRotation = 0.0f;
            setStartTrim(0.0f);
            setEndTrim(0.0f);
            setRotation(0.0f);
        }

        /* access modifiers changed from: package-private */
        public void setAlpha(int i7) {
            this.mAlpha = i7;
        }

        /* access modifiers changed from: package-private */
        public void setArrowDimensions(float f7, float f8) {
            this.mArrowWidth = (int) f7;
            this.mArrowHeight = (int) f8;
        }

        /* access modifiers changed from: package-private */
        public void setArrowScale(float f7) {
            if (f7 != this.mArrowScale) {
                this.mArrowScale = f7;
            }
        }

        /* access modifiers changed from: package-private */
        public void setBackgroundColor(int i7) {
            this.mCirclePaint.setColor(i7);
        }

        /* access modifiers changed from: package-private */
        public void setCenterRadius(float f7) {
            this.mRingCenterRadius = f7;
        }

        /* access modifiers changed from: package-private */
        public void setColor(int i7) {
            this.mCurrentColor = i7;
        }

        /* access modifiers changed from: package-private */
        public void setColorFilter(ColorFilter colorFilter) {
            this.mPaint.setColorFilter(colorFilter);
        }

        /* access modifiers changed from: package-private */
        public void setColorIndex(int i7) {
            this.mColorIndex = i7;
            this.mCurrentColor = this.mColors[i7];
        }

        /* access modifiers changed from: package-private */
        public void setColors(@NonNull int[] iArr) {
            this.mColors = iArr;
            setColorIndex(0);
        }

        /* access modifiers changed from: package-private */
        public void setEndTrim(float f7) {
            this.mEndTrim = f7;
        }

        /* access modifiers changed from: package-private */
        public void setRotation(float f7) {
            this.mRotation = f7;
        }

        /* access modifiers changed from: package-private */
        public void setShowArrow(boolean z7) {
            if (this.mShowArrow != z7) {
                this.mShowArrow = z7;
            }
        }

        /* access modifiers changed from: package-private */
        public void setStartTrim(float f7) {
            this.mStartTrim = f7;
        }

        /* access modifiers changed from: package-private */
        public void setStrokeCap(Paint.Cap cap) {
            this.mPaint.setStrokeCap(cap);
        }

        /* access modifiers changed from: package-private */
        public void setStrokeWidth(float f7) {
            this.mStrokeWidth = f7;
            this.mPaint.setStrokeWidth(f7);
        }

        /* access modifiers changed from: package-private */
        public void storeOriginals() {
            this.mStartingStartTrim = this.mStartTrim;
            this.mStartingEndTrim = this.mEndTrim;
            this.mStartingRotation = this.mRotation;
        }
    }

    public CircularProgressDrawable(@NonNull Context context) {
        this.mResources = ((Context) Preconditions.checkNotNull(context)).getResources();
        Ring ring = new Ring();
        this.mRing = ring;
        ring.setColors(COLORS);
        setStrokeWidth(STROKE_WIDTH);
        setupAnimators();
    }

    private void applyFinishTranslation(float f7, Ring ring) {
        updateRingColor(f7, ring);
        float floor = (float) (Math.floor((double) (ring.getStartingRotation() / MAX_PROGRESS_ARC)) + 1.0d);
        ring.setStartTrim(ring.getStartingStartTrim() + (((ring.getStartingEndTrim() - MIN_PROGRESS_ARC) - ring.getStartingStartTrim()) * f7));
        ring.setEndTrim(ring.getStartingEndTrim());
        ring.setRotation(ring.getStartingRotation() + ((floor - ring.getStartingRotation()) * f7));
    }

    private int evaluateColorChange(float f7, int i7, int i8) {
        int i9 = (i7 >> 24) & 255;
        int i10 = (i7 >> 16) & 255;
        int i11 = (i7 >> 8) & 255;
        int i12 = i7 & 255;
        return ((i9 + ((int) (((float) (((i8 >> 24) & 255) - i9)) * f7))) << 24) | ((i10 + ((int) (((float) (((i8 >> 16) & 255) - i10)) * f7))) << 16) | ((i11 + ((int) (((float) (((i8 >> 8) & 255) - i11)) * f7))) << 8) | (i12 + ((int) (f7 * ((float) ((i8 & 255) - i12)))));
    }

    private float getRotation() {
        return this.mRotation;
    }

    private void setRotation(float f7) {
        this.mRotation = f7;
    }

    private void setSizeParameters(float f7, float f8, float f9, float f10) {
        Ring ring = this.mRing;
        float f11 = this.mResources.getDisplayMetrics().density;
        ring.setStrokeWidth(f8 * f11);
        ring.setCenterRadius(f7 * f11);
        ring.setColorIndex(0);
        ring.setArrowDimensions(f9 * f11, f10 * f11);
    }

    private void setupAnimators() {
        final Ring ring = this.mRing;
        ValueAnimator ofFloat = ValueAnimator.ofFloat(0.0f, 1.0f);
        ofFloat.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() {
            /* class androidx.swiperefreshlayout.widget.CircularProgressDrawable.AnonymousClass1 */

            public void onAnimationUpdate(ValueAnimator valueAnimator) {
                float floatValue = ((Float) valueAnimator.getAnimatedValue()).floatValue();
                CircularProgressDrawable.this.updateRingColor(floatValue, ring);
                CircularProgressDrawable.this.applyTransformation(floatValue, ring, false);
                CircularProgressDrawable.this.invalidateSelf();
            }
        });
        ofFloat.setRepeatCount(-1);
        ofFloat.setRepeatMode(1);
        ofFloat.setInterpolator(LINEAR_INTERPOLATOR);
        ofFloat.addListener(new Animator.AnimatorListener() {
            /* class androidx.swiperefreshlayout.widget.CircularProgressDrawable.AnonymousClass2 */

            public void onAnimationCancel(Animator animator) {
            }

            public void onAnimationEnd(Animator animator) {
            }

            public void onAnimationRepeat(Animator animator) {
                CircularProgressDrawable.this.applyTransformation(1.0f, ring, true);
                ring.storeOriginals();
                ring.goToNextColor();
                CircularProgressDrawable circularProgressDrawable = CircularProgressDrawable.this;
                if (circularProgressDrawable.mFinishing) {
                    circularProgressDrawable.mFinishing = false;
                    animator.cancel();
                    animator.setDuration(1332);
                    animator.start();
                    ring.setShowArrow(false);
                    return;
                }
                circularProgressDrawable.mRotationCount += 1.0f;
            }

            public void onAnimationStart(Animator animator) {
                CircularProgressDrawable.this.mRotationCount = 0.0f;
            }
        });
        this.mAnimator = ofFloat;
    }

    /* access modifiers changed from: package-private */
    public void applyTransformation(float f7, Ring ring, boolean z7) {
        float f8;
        float f9;
        if (this.mFinishing) {
            applyFinishTranslation(f7, ring);
        } else if (f7 != 1.0f || z7) {
            float startingRotation = ring.getStartingRotation();
            if (f7 < 0.5f) {
                f8 = ring.getStartingStartTrim();
                f9 = (MATERIAL_INTERPOLATOR.getInterpolation(f7 / 0.5f) * 0.79f) + MIN_PROGRESS_ARC + f8;
            } else {
                float startingStartTrim = ring.getStartingStartTrim() + 0.79f;
                f8 = startingStartTrim - (((1.0f - MATERIAL_INTERPOLATOR.getInterpolation((f7 - 0.5f) / 0.5f)) * 0.79f) + MIN_PROGRESS_ARC);
                f9 = startingStartTrim;
            }
            float f10 = startingRotation + (RING_ROTATION * f7);
            float f11 = (f7 + this.mRotationCount) * GROUP_FULL_ROTATION;
            ring.setStartTrim(f8);
            ring.setEndTrim(f9);
            ring.setRotation(f10);
            setRotation(f11);
        }
    }

    public void draw(Canvas canvas) {
        Rect bounds = getBounds();
        canvas.save();
        canvas.rotate(this.mRotation, bounds.exactCenterX(), bounds.exactCenterY());
        this.mRing.draw(canvas, bounds);
        canvas.restore();
    }

    public int getAlpha() {
        return this.mRing.getAlpha();
    }

    public boolean getArrowEnabled() {
        return this.mRing.getShowArrow();
    }

    public float getArrowHeight() {
        return this.mRing.getArrowHeight();
    }

    public float getArrowScale() {
        return this.mRing.getArrowScale();
    }

    public float getArrowWidth() {
        return this.mRing.getArrowWidth();
    }

    public int getBackgroundColor() {
        return this.mRing.getBackgroundColor();
    }

    public float getCenterRadius() {
        return this.mRing.getCenterRadius();
    }

    @NonNull
    public int[] getColorSchemeColors() {
        return this.mRing.getColors();
    }

    public float getEndTrim() {
        return this.mRing.getEndTrim();
    }

    public int getOpacity() {
        return -3;
    }

    public float getProgressRotation() {
        return this.mRing.getRotation();
    }

    public float getStartTrim() {
        return this.mRing.getStartTrim();
    }

    @NonNull
    public Paint.Cap getStrokeCap() {
        return this.mRing.getStrokeCap();
    }

    public float getStrokeWidth() {
        return this.mRing.getStrokeWidth();
    }

    public boolean isRunning() {
        return this.mAnimator.isRunning();
    }

    public void setAlpha(int i7) {
        this.mRing.setAlpha(i7);
        invalidateSelf();
    }

    public void setArrowDimensions(float f7, float f8) {
        this.mRing.setArrowDimensions(f7, f8);
        invalidateSelf();
    }

    public void setArrowEnabled(boolean z7) {
        this.mRing.setShowArrow(z7);
        invalidateSelf();
    }

    public void setArrowScale(float f7) {
        this.mRing.setArrowScale(f7);
        invalidateSelf();
    }

    public void setBackgroundColor(int i7) {
        this.mRing.setBackgroundColor(i7);
        invalidateSelf();
    }

    public void setCenterRadius(float f7) {
        this.mRing.setCenterRadius(f7);
        invalidateSelf();
    }

    public void setColorFilter(ColorFilter colorFilter) {
        this.mRing.setColorFilter(colorFilter);
        invalidateSelf();
    }

    public void setColorSchemeColors(@NonNull int... iArr) {
        this.mRing.setColors(iArr);
        this.mRing.setColorIndex(0);
        invalidateSelf();
    }

    public void setProgressRotation(float f7) {
        this.mRing.setRotation(f7);
        invalidateSelf();
    }

    public void setStartEndTrim(float f7, float f8) {
        this.mRing.setStartTrim(f7);
        this.mRing.setEndTrim(f8);
        invalidateSelf();
    }

    public void setStrokeCap(@NonNull Paint.Cap cap) {
        this.mRing.setStrokeCap(cap);
        invalidateSelf();
    }

    public void setStrokeWidth(float f7) {
        this.mRing.setStrokeWidth(f7);
        invalidateSelf();
    }

    public void setStyle(int i7) {
        float f7;
        float f8;
        float f9;
        float f10;
        if (i7 == 0) {
            f7 = 12.0f;
            f10 = 6.0f;
            f9 = CENTER_RADIUS_LARGE;
            f8 = STROKE_WIDTH_LARGE;
        } else {
            f7 = 10.0f;
            f10 = 5.0f;
            f9 = CENTER_RADIUS;
            f8 = STROKE_WIDTH;
        }
        setSizeParameters(f9, f8, f7, f10);
        invalidateSelf();
    }

    public void start() {
        long j7;
        Animator animator;
        this.mAnimator.cancel();
        this.mRing.storeOriginals();
        if (this.mRing.getEndTrim() != this.mRing.getStartTrim()) {
            this.mFinishing = true;
            animator = this.mAnimator;
            j7 = 666;
        } else {
            this.mRing.setColorIndex(0);
            this.mRing.resetOriginals();
            animator = this.mAnimator;
            j7 = 1332;
        }
        animator.setDuration(j7);
        this.mAnimator.start();
    }

    public void stop() {
        this.mAnimator.cancel();
        setRotation(0.0f);
        this.mRing.setShowArrow(false);
        this.mRing.setColorIndex(0);
        this.mRing.resetOriginals();
        invalidateSelf();
    }

    /* access modifiers changed from: package-private */
    public void updateRingColor(float f7, Ring ring) {
        ring.setColor(f7 > 0.75f ? evaluateColorChange((f7 - 0.75f) / 0.25f, ring.getStartingColor(), ring.getNextColor()) : ring.getStartingColor());
    }
}
