package androidx.viewpager2.widget;

import android.animation.LayoutTransition;
import android.view.View;
import android.view.ViewGroup;
import androidx.annotation.NonNull;
import androidx.recyclerview.widget.LinearLayoutManager;
import java.lang.reflect.Array;
import java.util.Arrays;
import java.util.Comparator;

final class AnimateLayoutChangeDetector {
    private static final ViewGroup.MarginLayoutParams ZERO_MARGIN_LAYOUT_PARAMS;
    private LinearLayoutManager mLayoutManager;

    static {
        ViewGroup.MarginLayoutParams marginLayoutParams = new ViewGroup.MarginLayoutParams(-1, -1);
        ZERO_MARGIN_LAYOUT_PARAMS = marginLayoutParams;
        marginLayoutParams.setMargins(0, 0, 0, 0);
    }

    AnimateLayoutChangeDetector(@NonNull LinearLayoutManager linearLayoutManager) {
        this.mLayoutManager = linearLayoutManager;
    }

    private boolean arePagesLaidOutContiguously() {
        int i7;
        int i8;
        int i9;
        int i10;
        int childCount = this.mLayoutManager.getChildCount();
        if (childCount == 0) {
            return true;
        }
        boolean z7 = this.mLayoutManager.getOrientation() == 0;
        int[] iArr = new int[2];
        iArr[1] = 2;
        iArr[0] = childCount;
        int[][] iArr2 = (int[][]) Array.newInstance(Integer.TYPE, iArr);
        for (int i11 = 0; i11 < childCount; i11++) {
            View childAt = this.mLayoutManager.getChildAt(i11);
            if (childAt != null) {
                ViewGroup.LayoutParams layoutParams = childAt.getLayoutParams();
                ViewGroup.MarginLayoutParams marginLayoutParams = layoutParams instanceof ViewGroup.MarginLayoutParams ? (ViewGroup.MarginLayoutParams) layoutParams : ZERO_MARGIN_LAYOUT_PARAMS;
                int[] iArr3 = iArr2[i11];
                if (z7) {
                    i8 = childAt.getLeft();
                    i7 = marginLayoutParams.leftMargin;
                } else {
                    i8 = childAt.getTop();
                    i7 = marginLayoutParams.topMargin;
                }
                iArr3[0] = i8 - i7;
                int[] iArr4 = iArr2[i11];
                if (z7) {
                    i10 = childAt.getRight();
                    i9 = marginLayoutParams.rightMargin;
                } else {
                    i10 = childAt.getBottom();
                    i9 = marginLayoutParams.bottomMargin;
                }
                iArr4[1] = i10 + i9;
            } else {
                throw new IllegalStateException("null view contained in the view hierarchy");
            }
        }
        Arrays.sort(iArr2, new Comparator<int[]>() {
            /* class androidx.viewpager2.widget.AnimateLayoutChangeDetector.AnonymousClass1 */

            public int compare(int[] iArr, int[] iArr2) {
                return iArr[0] - iArr2[0];
            }
        });
        for (int i12 = 1; i12 < childCount; i12++) {
            if (iArr2[i12 - 1][1] != iArr2[i12][0]) {
                return false;
            }
        }
        int[] iArr5 = iArr2[0];
        int i13 = iArr5[1];
        int i14 = iArr5[0];
        return i14 <= 0 && iArr2[childCount - 1][1] >= i13 - i14;
    }

    private boolean hasRunningChangingLayoutTransition() {
        int childCount = this.mLayoutManager.getChildCount();
        for (int i7 = 0; i7 < childCount; i7++) {
            if (hasRunningChangingLayoutTransition(this.mLayoutManager.getChildAt(i7))) {
                return true;
            }
        }
        return false;
    }

    /* access modifiers changed from: package-private */
    public boolean mayHaveInterferingAnimations() {
        return (!arePagesLaidOutContiguously() || this.mLayoutManager.getChildCount() <= 1) && hasRunningChangingLayoutTransition();
    }

    private static boolean hasRunningChangingLayoutTransition(View view) {
        if (view instanceof ViewGroup) {
            ViewGroup viewGroup = (ViewGroup) view;
            LayoutTransition layoutTransition = viewGroup.getLayoutTransition();
            if (layoutTransition != null && layoutTransition.isChangingLayout()) {
                return true;
            }
            int childCount = viewGroup.getChildCount();
            for (int i7 = 0; i7 < childCount; i7++) {
                if (hasRunningChangingLayoutTransition(viewGroup.getChildAt(i7))) {
                    return true;
                }
            }
        }
        return false;
    }
}
