package com.google.cardboard.sdk;

import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.net.Uri;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.Toast;
import androidx.annotation.NonNull;
import androidx.appcompat.app.AppCompatActivity;
import androidx.core.app.ActivityCompat;
import androidx.core.content.ContextCompat;
import com.google.android.gms.common.ConnectionResult;
import com.google.android.gms.common.e;
import com.google.android.gms.vision.barcode.Barcode;
import com.google.android.gms.vision.barcode.a;
import com.google.android.gms.vision.f;
import com.google.cardboard.sdk.qrcode.CardboardParamsUtils;
import com.google.cardboard.sdk.qrcode.QrCodeContentProcessor;
import com.google.cardboard.sdk.qrcode.QrCodeTracker;
import com.google.cardboard.sdk.qrcode.QrCodeTrackerFactory;
import com.google.cardboard.sdk.qrcode.camera.CameraSource;
import com.google.cardboard.sdk.qrcode.camera.CameraSourcePreview;
import java.io.IOException;

public class QrCodeCaptureActivity extends AppCompatActivity implements QrCodeTracker.Listener, QrCodeContentProcessor.Listener {
    private static final int MIN_SDK_VERSION = 23;
    private static final int PERMISSIONS_REQUEST_CODE = 2;
    private static final int RC_HANDLE_GMS = 9001;
    private static final String TAG = "QrCodeCaptureActivity";
    private static boolean qrCodeSaved = false;
    private CameraSource cameraSource;
    private CameraSourcePreview cameraSourcePreview;

    private void createCameraSource() {
        int i7;
        a a8 = new a.C0078a(getApplicationContext()).b(256).a();
        a8.f(new f.a(new QrCodeTrackerFactory(this)).a());
        if (!a8.b()) {
            String str = TAG;
            Log.w(str, "Detector dependencies are not yet available.");
            if (registerReceiver(null, new IntentFilter("android.intent.action.DEVICE_STORAGE_LOW")) != null) {
                Toast.makeText(this, R.string.low_storage_error, 1).show();
                i7 = R.string.low_storage_error;
            } else {
                Toast.makeText(this, R.string.missing_dependencies, 1).show();
                i7 = R.string.missing_dependencies;
            }
            Log.w(str, getString(i7));
        }
        this.cameraSource = new CameraSource(getApplicationContext(), a8);
    }

    private boolean isCameraEnabled() {
        return ContextCompat.checkSelfPermission(this, "android.permission.CAMERA") == 0;
    }

    private boolean isWriteExternalStoragePermissionsEnabled() {
        return ContextCompat.checkSelfPermission(this, "android.permission.WRITE_EXTERNAL_STORAGE") == 0;
    }

    private void launchPermissionsSettings() {
        Intent intent = new Intent();
        intent.setAction("android.settings.APPLICATION_DETAILS_SETTINGS");
        intent.setData(Uri.fromParts("package", getPackageName(), null));
        startActivity(intent);
    }

    public static native void nativeIncrementDeviceParamsChangedCount();

    private void requestPermissions() {
        ActivityCompat.requestPermissions(this, new String[]{"android.permission.CAMERA"}, 2);
    }

    private void startCameraSource() {
        int k7 = e.v().k(getApplicationContext(), 23);
        if (k7 != 0) {
            String str = TAG;
            Log.i(str, "isGooglePlayServicesAvailable() returned: " + new ConnectionResult(k7));
            e.v().s(this, k7, RC_HANDLE_GMS).show();
        }
        CameraSource cameraSource2 = this.cameraSource;
        if (cameraSource2 != null) {
            try {
                this.cameraSourcePreview.start(cameraSource2);
            } catch (IOException e7) {
                Log.e(TAG, "Unable to start camera source.", e7);
                this.cameraSource.release();
                this.cameraSource = null;
            } catch (SecurityException e8) {
                Log.e(TAG, "Security exception: ", e8);
            }
            Log.i(TAG, "cameraSourcePreview successfully started.");
        }
    }

    @Override // androidx.activity.ComponentActivity, androidx.core.app.ComponentActivity, androidx.fragment.app.FragmentActivity
    public void onCreate(Bundle bundle) {
        super.onCreate(bundle);
        setContentView(R.layout.qr_code_capture);
        this.cameraSourcePreview = (CameraSourcePreview) findViewById(R.id.preview);
    }

    /* access modifiers changed from: protected */
    @Override // androidx.fragment.app.FragmentActivity
    public void onPause() {
        super.onPause();
        CameraSourcePreview cameraSourcePreview2 = this.cameraSourcePreview;
        if (cameraSourcePreview2 != null) {
            cameraSourcePreview2.stop();
            this.cameraSourcePreview.release();
        }
    }

    @Override // com.google.cardboard.sdk.qrcode.QrCodeTracker.Listener
    public void onQrCodeDetected(Barcode barcode) {
        if (barcode != null && !qrCodeSaved) {
            qrCodeSaved = true;
            new QrCodeContentProcessor(this).processAndSaveQrCode(barcode, this);
        }
    }

    @Override // com.google.cardboard.sdk.qrcode.QrCodeContentProcessor.Listener
    public void onQrCodeSaved(boolean z7) {
        if (z7) {
            Log.d(TAG, "Device parameters saved in external storage.");
            this.cameraSourcePreview.stop();
            nativeIncrementDeviceParamsChangedCount();
            finish();
        } else {
            Log.e(TAG, "Device parameters not saved in external storage.");
        }
        qrCodeSaved = false;
    }

    @Override // androidx.activity.ComponentActivity, androidx.core.app.ActivityCompat.OnRequestPermissionsResultCallback, androidx.fragment.app.FragmentActivity
    public void onRequestPermissionsResult(int i7, @NonNull String[] strArr, @NonNull int[] iArr) {
        super.onRequestPermissionsResult(i7, strArr, iArr);
        if (!isCameraEnabled()) {
            String str = TAG;
            Log.i(str, getString(R.string.no_camera_permission));
            Toast.makeText(this, R.string.no_camera_permission, 1).show();
            if (!ActivityCompat.shouldShowRequestPermissionRationale(this, "android.permission.CAMERA")) {
                Log.i(str, "Permission denied with checking \"Do not ask again\".");
                launchPermissionsSettings();
            }
            finish();
        }
    }

    /* access modifiers changed from: protected */
    @Override // androidx.fragment.app.FragmentActivity
    public void onResume() {
        super.onResume();
        if (isCameraEnabled()) {
            createCameraSource();
            qrCodeSaved = false;
            startCameraSource();
            return;
        }
        requestPermissions();
    }

    public void skipQrCodeCapture(View view) {
        Log.d(TAG, "QR code capture skipped");
        Context applicationContext = getApplicationContext();
        if (CardboardParamsUtils.readDeviceParams(applicationContext) == null) {
            CardboardParamsUtils.saveCardboardV1DeviceParams(applicationContext);
        }
        finish();
    }
}
