package com.google.cardboard.sdk.qrcode;

import android.content.Context;
import android.os.AsyncTask;
import android.util.Log;
import android.widget.Toast;
import androidx.annotation.Nullable;
import com.google.android.gms.vision.barcode.Barcode;
import com.google.cardboard.sdk.R;
import com.google.cardboard.sdk.qrcode.CardboardParamsUtils;

public class QrCodeContentProcessor {
    private static final String TAG = "QrCodeContentProcessor";
    private final Listener listener;

    public interface Listener {
        void onQrCodeSaved(boolean z7);
    }

    public class ProcessAndSaveQrCodeTask extends AsyncTask<Barcode, Void, CardboardParamsUtils.UriToParamsStatus> {
        private final Context context;

        public ProcessAndSaveQrCodeTask(Context context2) {
            this.context = context2;
        }

        /* access modifiers changed from: protected */
        @Nullable
        public CardboardParamsUtils.UriToParamsStatus doInBackground(Barcode... barcodeArr) {
            return QrCodeContentProcessor.getParamsFromQrCode(barcodeArr[0], new UrlFactory());
        }

        /* access modifiers changed from: protected */
        public void onPostExecute(CardboardParamsUtils.UriToParamsStatus uriToParamsStatus) {
            boolean z7;
            Context context2;
            int i7;
            super.onPostExecute((Object) uriToParamsStatus);
            int i8 = uriToParamsStatus.statusCode;
            if (i8 == 1) {
                Log.d(QrCodeContentProcessor.TAG, String.valueOf(R.string.invalid_qr_code));
                context2 = this.context;
                i7 = R.string.invalid_qr_code;
            } else if (i8 == 2) {
                Log.d(QrCodeContentProcessor.TAG, String.valueOf(R.string.connection_error));
                context2 = this.context;
                i7 = R.string.connection_error;
            } else {
                byte[] bArr = uriToParamsStatus.params;
                if (bArr != null) {
                    z7 = CardboardParamsUtils.writeDeviceParams(bArr, this.context);
                    String str = QrCodeContentProcessor.TAG;
                    StringBuilder sb = new StringBuilder();
                    sb.append("Could ");
                    sb.append(!z7 ? "not " : "");
                    sb.append("write Cardboard parameters to storage.");
                    Log.d(str, sb.toString());
                    QrCodeContentProcessor.this.listener.onQrCodeSaved(z7);
                }
                z7 = false;
                QrCodeContentProcessor.this.listener.onQrCodeSaved(z7);
            }
            Toast.makeText(context2, i7, 1).show();
            z7 = false;
            QrCodeContentProcessor.this.listener.onQrCodeSaved(z7);
        }
    }

    public QrCodeContentProcessor(Listener listener2) {
        this.listener = listener2;
    }

    /* access modifiers changed from: private */
    public static CardboardParamsUtils.UriToParamsStatus getParamsFromQrCode(Barcode barcode, UrlFactory urlFactory) {
        int i7 = barcode.f6796x;
        if (i7 == 7 || i7 == 8) {
            return CardboardParamsUtils.getParamsFromUriString(barcode.f6794g, urlFactory);
        }
        String str = TAG;
        Log.e(str, "Invalid QR code format: " + barcode.f6796x);
        return CardboardParamsUtils.UriToParamsStatus.error(1);
    }

    public void processAndSaveQrCode(Barcode barcode, Context context) {
        new ProcessAndSaveQrCodeTask(context).execute(barcode);
    }
}
