package com.google.cardboard.sdk.qrcode.camera;

import android.content.Context;
import android.util.AttributeSet;
import android.util.Log;
import android.view.SurfaceHolder;
import android.view.SurfaceView;
import android.view.ViewGroup;
import androidx.annotation.RequiresPermission;
import com.google.android.gms.common.images.a;
import java.io.IOException;

public class CameraSourcePreview extends ViewGroup {
    private static final String TAG = "CameraSourcePreview";
    private CameraSource cameraSource;
    private final Context context;
    private boolean startRequested = false;
    private boolean surfaceAvailable = false;
    private final SurfaceView surfaceView;

    private class SurfaceCallback implements SurfaceHolder.Callback {
        private SurfaceCallback() {
        }

        public void surfaceChanged(SurfaceHolder surfaceHolder, int i7, int i8, int i9) {
        }

        public void surfaceCreated(SurfaceHolder surfaceHolder) {
            String str;
            Throwable e7;
            String str2;
            CameraSourcePreview.this.surfaceAvailable = true;
            try {
                CameraSourcePreview.this.startIfReady();
                return;
            } catch (SecurityException e8) {
                e7 = e8;
                str = CameraSourcePreview.TAG;
                str2 = "Do not have permission to start the camera";
            } catch (IOException e9) {
                e7 = e9;
                str = CameraSourcePreview.TAG;
                str2 = "Could not start camera source.";
            }
            Log.e(str, str2, e7);
        }

        public void surfaceDestroyed(SurfaceHolder surfaceHolder) {
            CameraSourcePreview.this.surfaceAvailable = false;
        }
    }

    public CameraSourcePreview(Context context2, AttributeSet attributeSet) {
        super(context2, attributeSet);
        this.context = context2;
        SurfaceView surfaceView2 = new SurfaceView(context2);
        this.surfaceView = surfaceView2;
        surfaceView2.getHolder().addCallback(new SurfaceCallback());
        addView(surfaceView2);
    }

    private boolean isPortraitMode() {
        int i7 = this.context.getResources().getConfiguration().orientation;
        if (i7 == 2) {
            return false;
        }
        if (i7 == 1) {
            return true;
        }
        Log.d(TAG, "isPortraitMode returning false by default");
        return false;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    @RequiresPermission("android.permission.CAMERA")
    private void startIfReady() throws IOException {
        if (this.startRequested && this.surfaceAvailable) {
            this.cameraSource.start(this.surfaceView.getHolder());
            this.startRequested = false;
        }
    }

    /* access modifiers changed from: protected */
    public void onLayout(boolean z7, int i7, int i8, int i9, int i10) {
        int i11;
        int i12;
        String str;
        String str2;
        Throwable e7;
        a previewSize;
        CameraSource cameraSource2 = this.cameraSource;
        if (cameraSource2 == null || (previewSize = cameraSource2.getPreviewSize()) == null) {
            i12 = 320;
            i11 = 240;
        } else {
            i12 = previewSize.b();
            i11 = previewSize.a();
        }
        if (!isPortraitMode()) {
            i12 = i11;
            i11 = i12;
        }
        int i13 = i9 - i7;
        int i14 = i10 - i8;
        if (isPortraitMode()) {
            i13 = (int) ((((float) i14) / ((float) i12)) * ((float) i11));
        } else {
            i14 = (int) ((((float) i13) / ((float) i11)) * ((float) i12));
        }
        for (int i15 = 0; i15 < getChildCount(); i15++) {
            getChildAt(i15).layout(0, 0, i13, i14);
        }
        try {
            startIfReady();
            return;
        } catch (SecurityException e8) {
            e7 = e8;
            str2 = TAG;
            str = "Do not have permission to start the camera";
        } catch (IOException e9) {
            e7 = e9;
            str2 = TAG;
            str = "Could not start camera source.";
        }
        Log.e(str2, str, e7);
    }

    public void release() {
        CameraSource cameraSource2 = this.cameraSource;
        if (cameraSource2 != null) {
            cameraSource2.release();
            this.cameraSource = null;
        }
    }

    @RequiresPermission("android.permission.CAMERA")
    public void start(CameraSource cameraSource2) throws IOException {
        if (cameraSource2 == null) {
            stop();
        }
        this.cameraSource = cameraSource2;
        if (cameraSource2 != null) {
            this.startRequested = true;
            startIfReady();
        }
    }

    public void stop() {
        CameraSource cameraSource2 = this.cameraSource;
        if (cameraSource2 != null) {
            cameraSource2.stop();
        }
    }
}
