package com.google.common.base;

import java.io.IOException;
import java.util.AbstractList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.Map;
import m0.a;
import m0.b;

@b
public class Joiner {
    private final String separator;

    public static final class MapJoiner {
        private final Joiner joiner;
        private final String keyValueSeparator;

        private MapJoiner(Joiner joiner2, String str) {
            this.joiner = joiner2;
            this.keyValueSeparator = (String) Preconditions.checkNotNull(str);
        }

        @a
        @p0.a
        public <A extends Appendable> A appendTo(A a8, Iterable<? extends Map.Entry<?, ?>> iterable) throws IOException {
            return (A) appendTo(a8, iterable.iterator());
        }

        @a
        public String join(Iterable<? extends Map.Entry<?, ?>> iterable) {
            return join(iterable.iterator());
        }

        public MapJoiner useForNull(String str) {
            return new MapJoiner(this.joiner.useForNull(str), this.keyValueSeparator);
        }

        @a
        @p0.a
        public <A extends Appendable> A appendTo(A a8, Iterator<? extends Map.Entry<?, ?>> it) throws IOException {
            Preconditions.checkNotNull(a8);
            if (it.hasNext()) {
                while (true) {
                    Map.Entry entry = (Map.Entry) it.next();
                    a8.append(this.joiner.toString(entry.getKey()));
                    a8.append(this.keyValueSeparator);
                    a8.append(this.joiner.toString(entry.getValue()));
                    if (!it.hasNext()) {
                        break;
                    }
                    a8.append(this.joiner.separator);
                }
            }
            return a8;
        }

        @a
        public String join(Iterator<? extends Map.Entry<?, ?>> it) {
            return appendTo(new StringBuilder(), it).toString();
        }

        @p0.a
        public <A extends Appendable> A appendTo(A a8, Map<?, ?> map) throws IOException {
            return (A) appendTo(a8, map.entrySet());
        }

        public String join(Map<?, ?> map) {
            return join(map.entrySet());
        }

        @a
        @p0.a
        public StringBuilder appendTo(StringBuilder sb, Iterable<? extends Map.Entry<?, ?>> iterable) {
            return appendTo(sb, iterable.iterator());
        }

        @a
        @p0.a
        public StringBuilder appendTo(StringBuilder sb, Iterator<? extends Map.Entry<?, ?>> it) {
            try {
                appendTo((Appendable) sb, it);
                return sb;
            } catch (IOException e7) {
                throw new AssertionError(e7);
            }
        }

        @p0.a
        public StringBuilder appendTo(StringBuilder sb, Map<?, ?> map) {
            return appendTo(sb, (Iterable<? extends Map.Entry<?, ?>>) map.entrySet());
        }
    }

    private Joiner(Joiner joiner) {
        this.separator = joiner.separator;
    }

    private static Iterable<Object> iterable(final Object obj, final Object obj2, final Object[] objArr) {
        Preconditions.checkNotNull(objArr);
        return new AbstractList<Object>() {
            /* class com.google.common.base.Joiner.AnonymousClass3 */

            @Override // java.util.List, java.util.AbstractList
            public Object get(int i7) {
                return i7 != 0 ? i7 != 1 ? objArr[i7 - 2] : obj2 : obj;
            }

            public int size() {
                return objArr.length + 2;
            }
        };
    }

    public static Joiner on(char c7) {
        return new Joiner(String.valueOf(c7));
    }

    @p0.a
    public <A extends Appendable> A appendTo(A a8, Iterable<?> iterable) throws IOException {
        return (A) appendTo(a8, iterable.iterator());
    }

    public final String join(Iterable<?> iterable) {
        return join(iterable.iterator());
    }

    public Joiner skipNulls() {
        return new Joiner(this) {
            /* class com.google.common.base.Joiner.AnonymousClass2 */

            /*  JADX ERROR: JadxOverflowException in pass: RegionMakerVisitor
                jadx.core.utils.exceptions.JadxOverflowException: Regions count limit reached
                	at jadx.core.utils.ErrorsCounter.addError(ErrorsCounter.java:57)
                	at jadx.core.utils.ErrorsCounter.error(ErrorsCounter.java:31)
                	at jadx.core.dex.attributes.nodes.NotificationAttrNode.addError(NotificationAttrNode.java:15)
                */
            /* JADX WARNING: Removed duplicated region for block: B:14:0x0035 A[SYNTHETIC] */
            /* JADX WARNING: Removed duplicated region for block: B:8:0x0025  */
            @Override // com.google.common.base.Joiner
            public <A extends java.lang.Appendable> A appendTo(A r3, java.util.Iterator<?> r4) throws java.io.IOException {
                /*
                    r2 = this;
                    java.lang.String r0 = "appendable"
                    com.google.common.base.Preconditions.checkNotNull(r3, r0)
                    java.lang.String r0 = "parts"
                    com.google.common.base.Preconditions.checkNotNull(r4, r0)
                L_0x000a:
                    boolean r0 = r4.hasNext()
                    if (r0 == 0) goto L_0x001f
                    java.lang.Object r0 = r4.next()
                    if (r0 == 0) goto L_0x000a
                L_0x0016:
                    com.google.common.base.Joiner r1 = com.google.common.base.Joiner.this
                    java.lang.CharSequence r0 = r1.toString(r0)
                    r3.append(r0)
                L_0x001f:
                    boolean r0 = r4.hasNext()
                    if (r0 == 0) goto L_0x0035
                    java.lang.Object r0 = r4.next()
                    if (r0 == 0) goto L_0x001f
                    com.google.common.base.Joiner r1 = com.google.common.base.Joiner.this
                    java.lang.String r1 = com.google.common.base.Joiner.access$100(r1)
                    r3.append(r1)
                    goto L_0x0016
                L_0x0035:
                    return r3
                */
                throw new UnsupportedOperationException("Method not decompiled: com.google.common.base.Joiner.AnonymousClass2.appendTo(java.lang.Appendable, java.util.Iterator):java.lang.Appendable");
            }

            @Override // com.google.common.base.Joiner
            public Joiner useForNull(String str) {
                throw new UnsupportedOperationException("already specified skipNulls");
            }

            @Override // com.google.common.base.Joiner
            public MapJoiner withKeyValueSeparator(String str) {
                throw new UnsupportedOperationException("can't use .skipNulls() with maps");
            }
        };
    }

    /* access modifiers changed from: package-private */
    public CharSequence toString(Object obj) {
        Preconditions.checkNotNull(obj);
        return obj instanceof CharSequence ? (CharSequence) obj : obj.toString();
    }

    public Joiner useForNull(final String str) {
        Preconditions.checkNotNull(str);
        return new Joiner(this) {
            /* class com.google.common.base.Joiner.AnonymousClass1 */

            @Override // com.google.common.base.Joiner
            public Joiner skipNulls() {
                throw new UnsupportedOperationException("already specified useForNull");
            }

            /* access modifiers changed from: package-private */
            @Override // com.google.common.base.Joiner
            public CharSequence toString(Object obj) {
                return obj == null ? str : Joiner.this.toString(obj);
            }

            @Override // com.google.common.base.Joiner
            public Joiner useForNull(String str) {
                throw new UnsupportedOperationException("already specified useForNull");
            }
        };
    }

    public MapJoiner withKeyValueSeparator(char c7) {
        return withKeyValueSeparator(String.valueOf(c7));
    }

    public static Joiner on(String str) {
        return new Joiner(str);
    }

    @p0.a
    public final <A extends Appendable> A appendTo(A a8, Object obj, Object obj2, Object... objArr) throws IOException {
        return (A) appendTo(a8, iterable(obj, obj2, objArr));
    }

    public final String join(Object obj, Object obj2, Object... objArr) {
        return join(iterable(obj, obj2, objArr));
    }

    public MapJoiner withKeyValueSeparator(String str) {
        return new MapJoiner(str);
    }

    private Joiner(String str) {
        this.separator = (String) Preconditions.checkNotNull(str);
    }

    @p0.a
    public <A extends Appendable> A appendTo(A a8, Iterator<?> it) throws IOException {
        Preconditions.checkNotNull(a8);
        if (it.hasNext()) {
            while (true) {
                a8.append(toString(it.next()));
                if (!it.hasNext()) {
                    break;
                }
                a8.append(this.separator);
            }
        }
        return a8;
    }

    public final String join(Iterator<?> it) {
        return appendTo(new StringBuilder(), it).toString();
    }

    @p0.a
    public final <A extends Appendable> A appendTo(A a8, Object[] objArr) throws IOException {
        return (A) appendTo(a8, Arrays.asList(objArr));
    }

    public final String join(Object[] objArr) {
        return join(Arrays.asList(objArr));
    }

    @p0.a
    public final StringBuilder appendTo(StringBuilder sb, Iterable<?> iterable) {
        return appendTo(sb, iterable.iterator());
    }

    @p0.a
    public final StringBuilder appendTo(StringBuilder sb, Object obj, Object obj2, Object... objArr) {
        return appendTo(sb, iterable(obj, obj2, objArr));
    }

    @p0.a
    public final StringBuilder appendTo(StringBuilder sb, Iterator<?> it) {
        try {
            appendTo((Appendable) sb, it);
            return sb;
        } catch (IOException e7) {
            throw new AssertionError(e7);
        }
    }

    @p0.a
    public final StringBuilder appendTo(StringBuilder sb, Object[] objArr) {
        return appendTo(sb, (Iterable<?>) Arrays.asList(objArr));
    }
}
