package com.google.common.base;

import java.util.Arrays;
import m0.b;
import p0.a;

@b
public final class MoreObjects {

    public static final class ToStringHelper {
        private final String className;
        private final ValueHolder holderHead;
        private ValueHolder holderTail;
        private boolean omitNullValues;

        /* access modifiers changed from: private */
        public static final class ValueHolder {
            String name;
            ValueHolder next;
            Object value;

            private ValueHolder() {
            }
        }

        private ToStringHelper(String str) {
            ValueHolder valueHolder = new ValueHolder();
            this.holderHead = valueHolder;
            this.holderTail = valueHolder;
            this.omitNullValues = false;
            this.className = (String) Preconditions.checkNotNull(str);
        }

        private ValueHolder addHolder() {
            ValueHolder valueHolder = new ValueHolder();
            this.holderTail.next = valueHolder;
            this.holderTail = valueHolder;
            return valueHolder;
        }

        @a
        public ToStringHelper add(String str, char c7) {
            return addHolder(str, String.valueOf(c7));
        }

        @a
        public ToStringHelper addValue(char c7) {
            return addHolder(String.valueOf(c7));
        }

        @a
        public ToStringHelper omitNullValues() {
            this.omitNullValues = true;
            return this;
        }

        public String toString() {
            boolean z7 = this.omitNullValues;
            StringBuilder sb = new StringBuilder(32);
            sb.append(this.className);
            sb.append('{');
            String str = "";
            for (ValueHolder valueHolder = this.holderHead.next; valueHolder != null; valueHolder = valueHolder.next) {
                Object obj = valueHolder.value;
                if (!z7 || obj != null) {
                    sb.append(str);
                    String str2 = valueHolder.name;
                    if (str2 != null) {
                        sb.append(str2);
                        sb.append('=');
                    }
                    if (obj == null || !obj.getClass().isArray()) {
                        sb.append(obj);
                    } else {
                        String deepToString = Arrays.deepToString(new Object[]{obj});
                        sb.append((CharSequence) deepToString, 1, deepToString.length() - 1);
                    }
                    str = ", ";
                }
            }
            sb.append('}');
            return sb.toString();
        }

        private ToStringHelper addHolder(Object obj) {
            addHolder().value = obj;
            return this;
        }

        @a
        public ToStringHelper add(String str, double d7) {
            return addHolder(str, String.valueOf(d7));
        }

        @a
        public ToStringHelper addValue(double d7) {
            return addHolder(String.valueOf(d7));
        }

        private ToStringHelper addHolder(String str, Object obj) {
            ValueHolder addHolder = addHolder();
            addHolder.value = obj;
            addHolder.name = (String) Preconditions.checkNotNull(str);
            return this;
        }

        @a
        public ToStringHelper add(String str, float f7) {
            return addHolder(str, String.valueOf(f7));
        }

        @a
        public ToStringHelper addValue(float f7) {
            return addHolder(String.valueOf(f7));
        }

        @a
        public ToStringHelper add(String str, int i7) {
            return addHolder(str, String.valueOf(i7));
        }

        @a
        public ToStringHelper addValue(int i7) {
            return addHolder(String.valueOf(i7));
        }

        @a
        public ToStringHelper add(String str, long j7) {
            return addHolder(str, String.valueOf(j7));
        }

        @a
        public ToStringHelper addValue(long j7) {
            return addHolder(String.valueOf(j7));
        }

        @a
        public ToStringHelper add(String str, Object obj) {
            return addHolder(str, obj);
        }

        @a
        public ToStringHelper addValue(Object obj) {
            return addHolder(obj);
        }

        @a
        public ToStringHelper add(String str, boolean z7) {
            return addHolder(str, String.valueOf(z7));
        }

        @a
        public ToStringHelper addValue(boolean z7) {
            return addHolder(String.valueOf(z7));
        }
    }

    private MoreObjects() {
    }

    public static <T> T firstNonNull(T t7, T t8) {
        if (t7 != null) {
            return t7;
        }
        if (t8 != null) {
            return t8;
        }
        throw new NullPointerException("Both parameters are null");
    }

    public static ToStringHelper toStringHelper(Class<?> cls) {
        return new ToStringHelper(cls.getSimpleName());
    }

    public static ToStringHelper toStringHelper(Object obj) {
        return new ToStringHelper(obj.getClass().getSimpleName());
    }

    public static ToStringHelper toStringHelper(String str) {
        return new ToStringHelper(str);
    }
}
