package com.google.common.base;

import m0.b;
import p0.a;

@b
public final class Preconditions {
    private Preconditions() {
    }

    private static String badElementIndex(int i7, int i8, String str) {
        if (i7 < 0) {
            return Strings.lenientFormat("%s (%s) must not be negative", str, Integer.valueOf(i7));
        } else if (i8 >= 0) {
            return Strings.lenientFormat("%s (%s) must be less than size (%s)", str, Integer.valueOf(i7), Integer.valueOf(i8));
        } else {
            throw new IllegalArgumentException("negative size: " + i8);
        }
    }

    private static String badPositionIndex(int i7, int i8, String str) {
        if (i7 < 0) {
            return Strings.lenientFormat("%s (%s) must not be negative", str, Integer.valueOf(i7));
        } else if (i8 >= 0) {
            return Strings.lenientFormat("%s (%s) must not be greater than size (%s)", str, Integer.valueOf(i7), Integer.valueOf(i8));
        } else {
            throw new IllegalArgumentException("negative size: " + i8);
        }
    }

    private static String badPositionIndexes(int i7, int i8, int i9) {
        if (i7 < 0 || i7 > i9) {
            return badPositionIndex(i7, i9, "start index");
        }
        if (i8 < 0 || i8 > i9) {
            return badPositionIndex(i8, i9, "end index");
        }
        return Strings.lenientFormat("end index (%s) must not be less than start index (%s)", Integer.valueOf(i8), Integer.valueOf(i7));
    }

    public static void checkArgument(boolean z7) {
        if (!z7) {
            throw new IllegalArgumentException();
        }
    }

    @a
    public static int checkElementIndex(int i7, int i8) {
        return checkElementIndex(i7, i8, "index");
    }

    @a
    public static <T> T checkNotNull(T t7) {
        t7.getClass();
        return t7;
    }

    @a
    public static int checkPositionIndex(int i7, int i8) {
        return checkPositionIndex(i7, i8, "index");
    }

    public static void checkPositionIndexes(int i7, int i8, int i9) {
        if (i7 < 0 || i8 < i7 || i8 > i9) {
            throw new IndexOutOfBoundsException(badPositionIndexes(i7, i8, i9));
        }
    }

    public static void checkState(boolean z7) {
        if (!z7) {
            throw new IllegalStateException();
        }
    }

    public static void checkArgument(boolean z7, Object obj) {
        if (!z7) {
            throw new IllegalArgumentException(String.valueOf(obj));
        }
    }

    @a
    public static int checkElementIndex(int i7, int i8, String str) {
        if (i7 >= 0 && i7 < i8) {
            return i7;
        }
        throw new IndexOutOfBoundsException(badElementIndex(i7, i8, str));
    }

    @a
    public static <T> T checkNotNull(T t7, Object obj) {
        if (t7 != null) {
            return t7;
        }
        throw new NullPointerException(String.valueOf(obj));
    }

    @a
    public static int checkPositionIndex(int i7, int i8, String str) {
        if (i7 >= 0 && i7 <= i8) {
            return i7;
        }
        throw new IndexOutOfBoundsException(badPositionIndex(i7, i8, str));
    }

    public static void checkState(boolean z7, Object obj) {
        if (!z7) {
            throw new IllegalStateException(String.valueOf(obj));
        }
    }

    public static void checkArgument(boolean z7, String str, char c7) {
        if (!z7) {
            throw new IllegalArgumentException(Strings.lenientFormat(str, Character.valueOf(c7)));
        }
    }

    @a
    public static <T> T checkNotNull(T t7, String str, char c7) {
        if (t7 != null) {
            return t7;
        }
        throw new NullPointerException(Strings.lenientFormat(str, Character.valueOf(c7)));
    }

    public static void checkState(boolean z7, String str, char c7) {
        if (!z7) {
            throw new IllegalStateException(Strings.lenientFormat(str, Character.valueOf(c7)));
        }
    }

    public static void checkArgument(boolean z7, String str, char c7, char c8) {
        if (!z7) {
            throw new IllegalArgumentException(Strings.lenientFormat(str, Character.valueOf(c7), Character.valueOf(c8)));
        }
    }

    @a
    public static <T> T checkNotNull(T t7, String str, char c7, char c8) {
        if (t7 != null) {
            return t7;
        }
        throw new NullPointerException(Strings.lenientFormat(str, Character.valueOf(c7), Character.valueOf(c8)));
    }

    public static void checkState(boolean z7, String str, char c7, char c8) {
        if (!z7) {
            throw new IllegalStateException(Strings.lenientFormat(str, Character.valueOf(c7), Character.valueOf(c8)));
        }
    }

    public static void checkArgument(boolean z7, String str, char c7, int i7) {
        if (!z7) {
            throw new IllegalArgumentException(Strings.lenientFormat(str, Character.valueOf(c7), Integer.valueOf(i7)));
        }
    }

    @a
    public static <T> T checkNotNull(T t7, String str, char c7, int i7) {
        if (t7 != null) {
            return t7;
        }
        throw new NullPointerException(Strings.lenientFormat(str, Character.valueOf(c7), Integer.valueOf(i7)));
    }

    public static void checkState(boolean z7, String str, char c7, int i7) {
        if (!z7) {
            throw new IllegalStateException(Strings.lenientFormat(str, Character.valueOf(c7), Integer.valueOf(i7)));
        }
    }

    public static void checkArgument(boolean z7, String str, char c7, long j7) {
        if (!z7) {
            throw new IllegalArgumentException(Strings.lenientFormat(str, Character.valueOf(c7), Long.valueOf(j7)));
        }
    }

    @a
    public static <T> T checkNotNull(T t7, String str, char c7, long j7) {
        if (t7 != null) {
            return t7;
        }
        throw new NullPointerException(Strings.lenientFormat(str, Character.valueOf(c7), Long.valueOf(j7)));
    }

    public static void checkState(boolean z7, String str, char c7, long j7) {
        if (!z7) {
            throw new IllegalStateException(Strings.lenientFormat(str, Character.valueOf(c7), Long.valueOf(j7)));
        }
    }

    public static void checkArgument(boolean z7, String str, char c7, Object obj) {
        if (!z7) {
            throw new IllegalArgumentException(Strings.lenientFormat(str, Character.valueOf(c7), obj));
        }
    }

    @a
    public static <T> T checkNotNull(T t7, String str, char c7, Object obj) {
        if (t7 != null) {
            return t7;
        }
        throw new NullPointerException(Strings.lenientFormat(str, Character.valueOf(c7), obj));
    }

    public static void checkState(boolean z7, String str, char c7, Object obj) {
        if (!z7) {
            throw new IllegalStateException(Strings.lenientFormat(str, Character.valueOf(c7), obj));
        }
    }

    public static void checkArgument(boolean z7, String str, int i7) {
        if (!z7) {
            throw new IllegalArgumentException(Strings.lenientFormat(str, Integer.valueOf(i7)));
        }
    }

    @a
    public static <T> T checkNotNull(T t7, String str, int i7) {
        if (t7 != null) {
            return t7;
        }
        throw new NullPointerException(Strings.lenientFormat(str, Integer.valueOf(i7)));
    }

    public static void checkState(boolean z7, String str, int i7) {
        if (!z7) {
            throw new IllegalStateException(Strings.lenientFormat(str, Integer.valueOf(i7)));
        }
    }

    public static void checkArgument(boolean z7, String str, int i7, char c7) {
        if (!z7) {
            throw new IllegalArgumentException(Strings.lenientFormat(str, Integer.valueOf(i7), Character.valueOf(c7)));
        }
    }

    @a
    public static <T> T checkNotNull(T t7, String str, int i7, char c7) {
        if (t7 != null) {
            return t7;
        }
        throw new NullPointerException(Strings.lenientFormat(str, Integer.valueOf(i7), Character.valueOf(c7)));
    }

    public static void checkState(boolean z7, String str, int i7, char c7) {
        if (!z7) {
            throw new IllegalStateException(Strings.lenientFormat(str, Integer.valueOf(i7), Character.valueOf(c7)));
        }
    }

    public static void checkArgument(boolean z7, String str, int i7, int i8) {
        if (!z7) {
            throw new IllegalArgumentException(Strings.lenientFormat(str, Integer.valueOf(i7), Integer.valueOf(i8)));
        }
    }

    @a
    public static <T> T checkNotNull(T t7, String str, int i7, int i8) {
        if (t7 != null) {
            return t7;
        }
        throw new NullPointerException(Strings.lenientFormat(str, Integer.valueOf(i7), Integer.valueOf(i8)));
    }

    public static void checkState(boolean z7, String str, int i7, int i8) {
        if (!z7) {
            throw new IllegalStateException(Strings.lenientFormat(str, Integer.valueOf(i7), Integer.valueOf(i8)));
        }
    }

    public static void checkArgument(boolean z7, String str, int i7, long j7) {
        if (!z7) {
            throw new IllegalArgumentException(Strings.lenientFormat(str, Integer.valueOf(i7), Long.valueOf(j7)));
        }
    }

    @a
    public static <T> T checkNotNull(T t7, String str, int i7, long j7) {
        if (t7 != null) {
            return t7;
        }
        throw new NullPointerException(Strings.lenientFormat(str, Integer.valueOf(i7), Long.valueOf(j7)));
    }

    public static void checkState(boolean z7, String str, int i7, long j7) {
        if (!z7) {
            throw new IllegalStateException(Strings.lenientFormat(str, Integer.valueOf(i7), Long.valueOf(j7)));
        }
    }

    public static void checkArgument(boolean z7, String str, int i7, Object obj) {
        if (!z7) {
            throw new IllegalArgumentException(Strings.lenientFormat(str, Integer.valueOf(i7), obj));
        }
    }

    @a
    public static <T> T checkNotNull(T t7, String str, int i7, Object obj) {
        if (t7 != null) {
            return t7;
        }
        throw new NullPointerException(Strings.lenientFormat(str, Integer.valueOf(i7), obj));
    }

    public static void checkState(boolean z7, String str, int i7, Object obj) {
        if (!z7) {
            throw new IllegalStateException(Strings.lenientFormat(str, Integer.valueOf(i7), obj));
        }
    }

    public static void checkArgument(boolean z7, String str, long j7) {
        if (!z7) {
            throw new IllegalArgumentException(Strings.lenientFormat(str, Long.valueOf(j7)));
        }
    }

    @a
    public static <T> T checkNotNull(T t7, String str, long j7) {
        if (t7 != null) {
            return t7;
        }
        throw new NullPointerException(Strings.lenientFormat(str, Long.valueOf(j7)));
    }

    public static void checkState(boolean z7, String str, long j7) {
        if (!z7) {
            throw new IllegalStateException(Strings.lenientFormat(str, Long.valueOf(j7)));
        }
    }

    public static void checkArgument(boolean z7, String str, long j7, char c7) {
        if (!z7) {
            throw new IllegalArgumentException(Strings.lenientFormat(str, Long.valueOf(j7), Character.valueOf(c7)));
        }
    }

    @a
    public static <T> T checkNotNull(T t7, String str, long j7, char c7) {
        if (t7 != null) {
            return t7;
        }
        throw new NullPointerException(Strings.lenientFormat(str, Long.valueOf(j7), Character.valueOf(c7)));
    }

    public static void checkState(boolean z7, String str, long j7, char c7) {
        if (!z7) {
            throw new IllegalStateException(Strings.lenientFormat(str, Long.valueOf(j7), Character.valueOf(c7)));
        }
    }

    public static void checkArgument(boolean z7, String str, long j7, int i7) {
        if (!z7) {
            throw new IllegalArgumentException(Strings.lenientFormat(str, Long.valueOf(j7), Integer.valueOf(i7)));
        }
    }

    @a
    public static <T> T checkNotNull(T t7, String str, long j7, int i7) {
        if (t7 != null) {
            return t7;
        }
        throw new NullPointerException(Strings.lenientFormat(str, Long.valueOf(j7), Integer.valueOf(i7)));
    }

    public static void checkState(boolean z7, String str, long j7, int i7) {
        if (!z7) {
            throw new IllegalStateException(Strings.lenientFormat(str, Long.valueOf(j7), Integer.valueOf(i7)));
        }
    }

    public static void checkArgument(boolean z7, String str, long j7, long j8) {
        if (!z7) {
            throw new IllegalArgumentException(Strings.lenientFormat(str, Long.valueOf(j7), Long.valueOf(j8)));
        }
    }

    @a
    public static <T> T checkNotNull(T t7, String str, long j7, long j8) {
        if (t7 != null) {
            return t7;
        }
        throw new NullPointerException(Strings.lenientFormat(str, Long.valueOf(j7), Long.valueOf(j8)));
    }

    public static void checkState(boolean z7, String str, long j7, long j8) {
        if (!z7) {
            throw new IllegalStateException(Strings.lenientFormat(str, Long.valueOf(j7), Long.valueOf(j8)));
        }
    }

    public static void checkArgument(boolean z7, String str, long j7, Object obj) {
        if (!z7) {
            throw new IllegalArgumentException(Strings.lenientFormat(str, Long.valueOf(j7), obj));
        }
    }

    @a
    public static <T> T checkNotNull(T t7, String str, long j7, Object obj) {
        if (t7 != null) {
            return t7;
        }
        throw new NullPointerException(Strings.lenientFormat(str, Long.valueOf(j7), obj));
    }

    public static void checkState(boolean z7, String str, long j7, Object obj) {
        if (!z7) {
            throw new IllegalStateException(Strings.lenientFormat(str, Long.valueOf(j7), obj));
        }
    }

    public static void checkArgument(boolean z7, String str, Object obj) {
        if (!z7) {
            throw new IllegalArgumentException(Strings.lenientFormat(str, obj));
        }
    }

    @a
    public static <T> T checkNotNull(T t7, String str, Object obj) {
        if (t7 != null) {
            return t7;
        }
        throw new NullPointerException(Strings.lenientFormat(str, obj));
    }

    public static void checkState(boolean z7, String str, Object obj) {
        if (!z7) {
            throw new IllegalStateException(Strings.lenientFormat(str, obj));
        }
    }

    public static void checkArgument(boolean z7, String str, Object obj, char c7) {
        if (!z7) {
            throw new IllegalArgumentException(Strings.lenientFormat(str, obj, Character.valueOf(c7)));
        }
    }

    @a
    public static <T> T checkNotNull(T t7, String str, Object obj, char c7) {
        if (t7 != null) {
            return t7;
        }
        throw new NullPointerException(Strings.lenientFormat(str, obj, Character.valueOf(c7)));
    }

    public static void checkState(boolean z7, String str, Object obj, char c7) {
        if (!z7) {
            throw new IllegalStateException(Strings.lenientFormat(str, obj, Character.valueOf(c7)));
        }
    }

    public static void checkArgument(boolean z7, String str, Object obj, int i7) {
        if (!z7) {
            throw new IllegalArgumentException(Strings.lenientFormat(str, obj, Integer.valueOf(i7)));
        }
    }

    @a
    public static <T> T checkNotNull(T t7, String str, Object obj, int i7) {
        if (t7 != null) {
            return t7;
        }
        throw new NullPointerException(Strings.lenientFormat(str, obj, Integer.valueOf(i7)));
    }

    public static void checkState(boolean z7, String str, Object obj, int i7) {
        if (!z7) {
            throw new IllegalStateException(Strings.lenientFormat(str, obj, Integer.valueOf(i7)));
        }
    }

    public static void checkArgument(boolean z7, String str, Object obj, long j7) {
        if (!z7) {
            throw new IllegalArgumentException(Strings.lenientFormat(str, obj, Long.valueOf(j7)));
        }
    }

    @a
    public static <T> T checkNotNull(T t7, String str, Object obj, long j7) {
        if (t7 != null) {
            return t7;
        }
        throw new NullPointerException(Strings.lenientFormat(str, obj, Long.valueOf(j7)));
    }

    public static void checkState(boolean z7, String str, Object obj, long j7) {
        if (!z7) {
            throw new IllegalStateException(Strings.lenientFormat(str, obj, Long.valueOf(j7)));
        }
    }

    public static void checkArgument(boolean z7, String str, Object obj, Object obj2) {
        if (!z7) {
            throw new IllegalArgumentException(Strings.lenientFormat(str, obj, obj2));
        }
    }

    @a
    public static <T> T checkNotNull(T t7, String str, Object obj, Object obj2) {
        if (t7 != null) {
            return t7;
        }
        throw new NullPointerException(Strings.lenientFormat(str, obj, obj2));
    }

    public static void checkState(boolean z7, String str, Object obj, Object obj2) {
        if (!z7) {
            throw new IllegalStateException(Strings.lenientFormat(str, obj, obj2));
        }
    }

    public static void checkArgument(boolean z7, String str, Object obj, Object obj2, Object obj3) {
        if (!z7) {
            throw new IllegalArgumentException(Strings.lenientFormat(str, obj, obj2, obj3));
        }
    }

    @a
    public static <T> T checkNotNull(T t7, String str, Object obj, Object obj2, Object obj3) {
        if (t7 != null) {
            return t7;
        }
        throw new NullPointerException(Strings.lenientFormat(str, obj, obj2, obj3));
    }

    public static void checkState(boolean z7, String str, Object obj, Object obj2, Object obj3) {
        if (!z7) {
            throw new IllegalStateException(Strings.lenientFormat(str, obj, obj2, obj3));
        }
    }

    public static void checkArgument(boolean z7, String str, Object obj, Object obj2, Object obj3, Object obj4) {
        if (!z7) {
            throw new IllegalArgumentException(Strings.lenientFormat(str, obj, obj2, obj3, obj4));
        }
    }

    @a
    public static <T> T checkNotNull(T t7, String str, Object obj, Object obj2, Object obj3, Object obj4) {
        if (t7 != null) {
            return t7;
        }
        throw new NullPointerException(Strings.lenientFormat(str, obj, obj2, obj3, obj4));
    }

    public static void checkState(boolean z7, String str, Object obj, Object obj2, Object obj3, Object obj4) {
        if (!z7) {
            throw new IllegalStateException(Strings.lenientFormat(str, obj, obj2, obj3, obj4));
        }
    }

    public static void checkArgument(boolean z7, String str, Object... objArr) {
        if (!z7) {
            throw new IllegalArgumentException(Strings.lenientFormat(str, objArr));
        }
    }

    @a
    public static <T> T checkNotNull(T t7, String str, Object... objArr) {
        if (t7 != null) {
            return t7;
        }
        throw new NullPointerException(Strings.lenientFormat(str, objArr));
    }

    public static void checkState(boolean z7, String str, Object... objArr) {
        if (!z7) {
            throw new IllegalStateException(Strings.lenientFormat(str, objArr));
        }
    }
}
