package com.google.common.base;

import com.google.common.base.CharMatcher;
import java.util.BitSet;
import m0.c;
import m0.d;

@c
final class SmallCharMatcher extends CharMatcher.NamedFastMatcher {
    private static final int C1 = -862048943;
    private static final int C2 = 461845907;
    private static final double DESIRED_LOAD_FACTOR = 0.5d;
    static final int MAX_SIZE = 1023;
    private final boolean containsZero;
    private final long filter;
    private final char[] table;

    private SmallCharMatcher(char[] cArr, long j7, boolean z7, String str) {
        super(str);
        this.table = cArr;
        this.filter = j7;
        this.containsZero = z7;
    }

    private boolean checkFilter(int i7) {
        return 1 == ((this.filter >> i7) & 1);
    }

    @d
    static int chooseTableSize(int i7) {
        if (i7 == 1) {
            return 2;
        }
        int highestOneBit = Integer.highestOneBit(i7 - 1) << 1;
        while (((double) highestOneBit) * 0.5d < ((double) i7)) {
            highestOneBit <<= 1;
        }
        return highestOneBit;
    }

    static CharMatcher from(BitSet bitSet, String str) {
        int i7;
        int cardinality = bitSet.cardinality();
        boolean z7 = bitSet.get(0);
        int chooseTableSize = chooseTableSize(cardinality);
        char[] cArr = new char[chooseTableSize];
        int i8 = chooseTableSize - 1;
        int nextSetBit = bitSet.nextSetBit(0);
        long j7 = 0;
        while (nextSetBit != -1) {
            long j8 = (1 << nextSetBit) | j7;
            int smear = smear(nextSetBit);
            while (true) {
                i7 = smear & i8;
                if (cArr[i7] == 0) {
                    break;
                }
                smear = i7 + 1;
            }
            cArr[i7] = (char) nextSetBit;
            nextSetBit = bitSet.nextSetBit(nextSetBit + 1);
            j7 = j8;
        }
        return new SmallCharMatcher(cArr, j7, z7, str);
    }

    static int smear(int i7) {
        return Integer.rotateLeft(i7 * C1, 15) * C2;
    }

    @Override // com.google.common.base.CharMatcher
    public boolean matches(char c7) {
        if (c7 == 0) {
            return this.containsZero;
        }
        if (!checkFilter(c7)) {
            return false;
        }
        int length = this.table.length - 1;
        int smear = smear(c7) & length;
        int i7 = smear;
        do {
            char c8 = this.table[i7];
            if (c8 == 0) {
                return false;
            }
            if (c8 == c7) {
                return true;
            }
            i7 = (i7 + 1) & length;
        } while (i7 != smear);
        return false;
    }

    /* access modifiers changed from: package-private */
    @Override // com.google.common.base.CharMatcher
    public void setBits(BitSet bitSet) {
        if (this.containsZero) {
            bitSet.set(0);
        }
        char[] cArr = this.table;
        for (char c7 : cArr) {
            if (c7 != 0) {
                bitSet.set(c7);
            }
        }
    }
}
