package com.google.common.collect;

import com.google.common.base.Preconditions;
import java.time.Duration;
import java.util.ArrayDeque;
import java.util.Collection;
import java.util.Deque;
import java.util.PriorityQueue;
import java.util.Queue;
import java.util.concurrent.ArrayBlockingQueue;
import java.util.concurrent.BlockingQueue;
import java.util.concurrent.ConcurrentLinkedQueue;
import java.util.concurrent.LinkedBlockingDeque;
import java.util.concurrent.LinkedBlockingQueue;
import java.util.concurrent.PriorityBlockingQueue;
import java.util.concurrent.SynchronousQueue;
import java.util.concurrent.TimeUnit;
import m0.a;
import m0.b;
import m0.c;

@b(emulated = true)
public final class nb {
    private nb() {
    }

    @a
    @p0.a
    @c
    public static <E> int a(BlockingQueue<E> blockingQueue, Collection<? super E> collection, int i7, long j7, TimeUnit timeUnit) throws InterruptedException {
        Preconditions.checkNotNull(collection);
        long nanoTime = System.nanoTime() + timeUnit.toNanos(j7);
        int i8 = 0;
        while (i8 < i7) {
            i8 += blockingQueue.drainTo(collection, i7 - i8);
            if (i8 < i7) {
                E poll = blockingQueue.poll(nanoTime - System.nanoTime(), TimeUnit.NANOSECONDS);
                if (poll == null) {
                    break;
                }
                collection.add(poll);
                i8++;
            }
        }
        return i8;
    }

    @a
    @p0.a
    @c
    public static <E> int b(BlockingQueue<E> blockingQueue, Collection<? super E> collection, int i7, Duration duration) throws InterruptedException {
        return a(blockingQueue, collection, i7, duration.toNanos(), TimeUnit.NANOSECONDS);
    }

    @a
    @p0.a
    @c
    public static <E> int c(BlockingQueue<E> blockingQueue, Collection<? super E> collection, int i7, long j7, TimeUnit timeUnit) {
        E poll;
        Preconditions.checkNotNull(collection);
        long nanoTime = System.nanoTime() + timeUnit.toNanos(j7);
        int i8 = 0;
        boolean z7 = false;
        while (i8 < i7) {
            try {
                i8 += blockingQueue.drainTo(collection, i7 - i8);
                if (i8 < i7) {
                    while (true) {
                        try {
                            poll = blockingQueue.poll(nanoTime - System.nanoTime(), TimeUnit.NANOSECONDS);
                            break;
                        } catch (InterruptedException unused) {
                            z7 = true;
                        }
                    }
                    if (poll == null) {
                        break;
                    }
                    collection.add(poll);
                    i8++;
                }
            } catch (Throwable th) {
                if (z7) {
                    Thread.currentThread().interrupt();
                }
                throw th;
            }
        }
        if (z7) {
            Thread.currentThread().interrupt();
        }
        return i8;
    }

    @a
    @p0.a
    @c
    public static <E> int d(BlockingQueue<E> blockingQueue, Collection<? super E> collection, int i7, Duration duration) {
        return c(blockingQueue, collection, i7, duration.toNanos(), TimeUnit.NANOSECONDS);
    }

    @c
    public static <E> ArrayBlockingQueue<E> e(int i7) {
        return new ArrayBlockingQueue<>(i7);
    }

    public static <E> ArrayDeque<E> f() {
        return new ArrayDeque<>();
    }

    public static <E> ArrayDeque<E> g(Iterable<? extends E> iterable) {
        if (iterable instanceof Collection) {
            return new ArrayDeque<>(f2.b(iterable));
        }
        ArrayDeque<E> arrayDeque = new ArrayDeque<>();
        t8.a(arrayDeque, iterable);
        return arrayDeque;
    }

    @c
    public static <E> ConcurrentLinkedQueue<E> h() {
        return new ConcurrentLinkedQueue<>();
    }

    @c
    public static <E> ConcurrentLinkedQueue<E> i(Iterable<? extends E> iterable) {
        if (iterable instanceof Collection) {
            return new ConcurrentLinkedQueue<>(f2.b(iterable));
        }
        ConcurrentLinkedQueue<E> concurrentLinkedQueue = new ConcurrentLinkedQueue<>();
        t8.a(concurrentLinkedQueue, iterable);
        return concurrentLinkedQueue;
    }

    @c
    public static <E> LinkedBlockingDeque<E> j() {
        return new LinkedBlockingDeque<>();
    }

    @c
    public static <E> LinkedBlockingDeque<E> k(int i7) {
        return new LinkedBlockingDeque<>(i7);
    }

    @c
    public static <E> LinkedBlockingDeque<E> l(Iterable<? extends E> iterable) {
        if (iterable instanceof Collection) {
            return new LinkedBlockingDeque<>(f2.b(iterable));
        }
        LinkedBlockingDeque<E> linkedBlockingDeque = new LinkedBlockingDeque<>();
        t8.a(linkedBlockingDeque, iterable);
        return linkedBlockingDeque;
    }

    @c
    public static <E> LinkedBlockingQueue<E> m() {
        return new LinkedBlockingQueue<>();
    }

    @c
    public static <E> LinkedBlockingQueue<E> n(int i7) {
        return new LinkedBlockingQueue<>(i7);
    }

    @c
    public static <E> LinkedBlockingQueue<E> o(Iterable<? extends E> iterable) {
        if (iterable instanceof Collection) {
            return new LinkedBlockingQueue<>(f2.b(iterable));
        }
        LinkedBlockingQueue<E> linkedBlockingQueue = new LinkedBlockingQueue<>();
        t8.a(linkedBlockingQueue, iterable);
        return linkedBlockingQueue;
    }

    @c
    public static <E extends Comparable> PriorityBlockingQueue<E> p() {
        return new PriorityBlockingQueue<>();
    }

    @c
    public static <E extends Comparable> PriorityBlockingQueue<E> q(Iterable<? extends E> iterable) {
        if (iterable instanceof Collection) {
            return new PriorityBlockingQueue<>(f2.b(iterable));
        }
        PriorityBlockingQueue<E> priorityBlockingQueue = new PriorityBlockingQueue<>();
        t8.a(priorityBlockingQueue, iterable);
        return priorityBlockingQueue;
    }

    public static <E extends Comparable> PriorityQueue<E> r() {
        return new PriorityQueue<>();
    }

    public static <E extends Comparable> PriorityQueue<E> s(Iterable<? extends E> iterable) {
        if (iterable instanceof Collection) {
            return new PriorityQueue<>(f2.b(iterable));
        }
        PriorityQueue<E> priorityQueue = new PriorityQueue<>();
        t8.a(priorityQueue, iterable);
        return priorityQueue;
    }

    @c
    public static <E> SynchronousQueue<E> t() {
        return new SynchronousQueue<>();
    }

    public static <E> Deque<E> u(Deque<E> deque) {
        return wd.i(deque, null);
    }

    public static <E> Queue<E> v(Queue<E> queue) {
        return wd.t(queue, null);
    }
}
