package org.bouncycastle2.jce.provider;

import java.math.BigInteger;
import java.security.interfaces.RSAPrivateCrtKey;
import java.security.spec.RSAPrivateCrtKeySpec;
import org.bouncycastle2.asn1.pkcs.m;
import org.bouncycastle2.asn1.pkcs.o;
import org.bouncycastle2.asn1.pkcs.r;
import org.bouncycastle2.asn1.x0;
import org.bouncycastle2.asn1.x509.b;
import org.bouncycastle2.crypto.params.v0;

public class e0 extends f0 implements RSAPrivateCrtKey {
    static final long Y5 = 7834723820638524718L;
    private BigInteger C1;
    private BigInteger C2;
    private BigInteger U5;
    private BigInteger V5;
    private BigInteger W5;
    private BigInteger X5;

    e0(RSAPrivateCrtKey rSAPrivateCrtKey) {
        this.f24321f = rSAPrivateCrtKey.getModulus();
        this.C1 = rSAPrivateCrtKey.getPublicExponent();
        this.f24322g = rSAPrivateCrtKey.getPrivateExponent();
        this.C2 = rSAPrivateCrtKey.getPrimeP();
        this.U5 = rSAPrivateCrtKey.getPrimeQ();
        this.V5 = rSAPrivateCrtKey.getPrimeExponentP();
        this.W5 = rSAPrivateCrtKey.getPrimeExponentQ();
        this.X5 = rSAPrivateCrtKey.getCrtCoefficient();
    }

    @Override // org.bouncycastle2.jce.provider.f0
    public boolean equals(Object obj) {
        if (obj == this) {
            return true;
        }
        if (!(obj instanceof RSAPrivateCrtKey)) {
            return false;
        }
        RSAPrivateCrtKey rSAPrivateCrtKey = (RSAPrivateCrtKey) obj;
        return getModulus().equals(rSAPrivateCrtKey.getModulus()) && getPublicExponent().equals(rSAPrivateCrtKey.getPublicExponent()) && getPrivateExponent().equals(rSAPrivateCrtKey.getPrivateExponent()) && getPrimeP().equals(rSAPrivateCrtKey.getPrimeP()) && getPrimeQ().equals(rSAPrivateCrtKey.getPrimeQ()) && getPrimeExponentP().equals(rSAPrivateCrtKey.getPrimeExponentP()) && getPrimeExponentQ().equals(rSAPrivateCrtKey.getPrimeExponentQ()) && getCrtCoefficient().equals(rSAPrivateCrtKey.getCrtCoefficient());
    }

    public BigInteger getCrtCoefficient() {
        return this.X5;
    }

    @Override // org.bouncycastle2.jce.provider.f0
    public byte[] getEncoded() {
        return new o(new b(m.f22532m0, new x0()), new r(getModulus(), getPublicExponent(), getPrivateExponent(), getPrimeP(), getPrimeQ(), getPrimeExponentP(), getPrimeExponentQ(), getCrtCoefficient()).d()).f();
    }

    @Override // org.bouncycastle2.jce.provider.f0
    public String getFormat() {
        return "PKCS#8";
    }

    public BigInteger getPrimeExponentP() {
        return this.V5;
    }

    public BigInteger getPrimeExponentQ() {
        return this.W5;
    }

    public BigInteger getPrimeP() {
        return this.C2;
    }

    public BigInteger getPrimeQ() {
        return this.U5;
    }

    public BigInteger getPublicExponent() {
        return this.C1;
    }

    @Override // org.bouncycastle2.jce.provider.f0
    public int hashCode() {
        return getPrivateExponent().hashCode() ^ (getModulus().hashCode() ^ getPublicExponent().hashCode());
    }

    public String toString() {
        StringBuffer stringBuffer = new StringBuffer();
        String property = System.getProperty("line.separator");
        stringBuffer.append("RSA Private CRT Key");
        stringBuffer.append(property);
        stringBuffer.append("            modulus: ");
        stringBuffer.append(getModulus().toString(16));
        stringBuffer.append(property);
        stringBuffer.append("    public exponent: ");
        stringBuffer.append(getPublicExponent().toString(16));
        stringBuffer.append(property);
        stringBuffer.append("   private exponent: ");
        stringBuffer.append(getPrivateExponent().toString(16));
        stringBuffer.append(property);
        stringBuffer.append("             primeP: ");
        stringBuffer.append(getPrimeP().toString(16));
        stringBuffer.append(property);
        stringBuffer.append("             primeQ: ");
        stringBuffer.append(getPrimeQ().toString(16));
        stringBuffer.append(property);
        stringBuffer.append("     primeExponentP: ");
        stringBuffer.append(getPrimeExponentP().toString(16));
        stringBuffer.append(property);
        stringBuffer.append("     primeExponentQ: ");
        stringBuffer.append(getPrimeExponentQ().toString(16));
        stringBuffer.append(property);
        stringBuffer.append("     crtCoefficient: ");
        stringBuffer.append(getCrtCoefficient().toString(16));
        stringBuffer.append(property);
        return stringBuffer.toString();
    }

    e0(RSAPrivateCrtKeySpec rSAPrivateCrtKeySpec) {
        this.f24321f = rSAPrivateCrtKeySpec.getModulus();
        this.C1 = rSAPrivateCrtKeySpec.getPublicExponent();
        this.f24322g = rSAPrivateCrtKeySpec.getPrivateExponent();
        this.C2 = rSAPrivateCrtKeySpec.getPrimeP();
        this.U5 = rSAPrivateCrtKeySpec.getPrimeQ();
        this.V5 = rSAPrivateCrtKeySpec.getPrimeExponentP();
        this.W5 = rSAPrivateCrtKeySpec.getPrimeExponentQ();
        this.X5 = rSAPrivateCrtKeySpec.getCrtCoefficient();
    }

    e0(o oVar) {
        this(new r((org.bouncycastle2.asn1.m) oVar.n()));
    }

    e0(r rVar) {
        this.f24321f = rVar.o();
        this.C1 = rVar.s();
        this.f24322g = rVar.r();
        this.C2 = rVar.p();
        this.U5 = rVar.q();
        this.V5 = rVar.k();
        this.W5 = rVar.l();
        this.X5 = rVar.j();
    }

    e0(v0 v0Var) {
        super(v0Var);
        this.C1 = v0Var.g();
        this.C2 = v0Var.f();
        this.U5 = v0Var.h();
        this.V5 = v0Var.d();
        this.W5 = v0Var.e();
        this.X5 = v0Var.i();
    }
}
