package pl.droidsonroids.gif;

import android.content.ContentResolver;
import android.content.res.AssetFileDescriptor;
import android.graphics.Bitmap;
import android.net.Uri;
import android.system.ErrnoException;
import android.system.Os;
import android.view.Surface;
import androidx.annotation.FloatRange;
import androidx.annotation.IntRange;
import androidx.annotation.RequiresApi;
import java.io.FileDescriptor;
import java.io.IOException;
import java.io.InputStream;
import java.nio.ByteBuffer;
import kotlin.text.h0;

/* access modifiers changed from: package-private */
public final class GifInfoHandle {
    private volatile long gifInfoPtr;

    static {
        LibraryLoader.loadLibrary();
    }

    GifInfoHandle() {
    }

    private static native void bindSurface(long j7, Surface surface, long[] jArr);

    static native int createTempNativeFileDescriptor() throws GifIOException;

    static native int extractNativeFileDescriptor(FileDescriptor fileDescriptor, boolean z7) throws GifIOException;

    private static native void free(long j7);

    private static native long getAllocationByteCount(long j7);

    private static native String getComment(long j7);

    private static native int getCurrentFrameIndex(long j7);

    private static native int getCurrentLoop(long j7);

    private static native int getCurrentPosition(long j7);

    private static native int getDuration(long j7);

    private static native int getFrameDuration(long j7, int i7);

    private static native int getHeight(long j7);

    private static native int getLoopCount(long j7);

    private static native long getMetadataByteCount(long j7);

    private static native int getNativeErrorCode(long j7);

    @RequiresApi(21)
    private static int getNativeFileDescriptor(FileDescriptor fileDescriptor, boolean z7) throws GifIOException, ErrnoException {
        try {
            int createTempNativeFileDescriptor = createTempNativeFileDescriptor();
            Os.dup2(fileDescriptor, createTempNativeFileDescriptor);
            return createTempNativeFileDescriptor;
        } finally {
            if (z7) {
                Os.close(fileDescriptor);
            }
        }
    }

    private static native int getNumberOfFrames(long j7);

    private static native long[] getSavedState(long j7);

    private static native long getSourceLength(long j7);

    private static native int getWidth(long j7);

    private static native void glTexImage2D(long j7, int i7, int i8);

    private static native void glTexSubImage2D(long j7, int i7, int i8);

    private static native void initTexImageDescriptor(long j7);

    private static native boolean isAnimationCompleted(long j7);

    private static native boolean isOpaque(long j7);

    static native long openByteArray(byte[] bArr) throws GifIOException;

    static native long openDirectByteBuffer(ByteBuffer byteBuffer) throws GifIOException;

    static native long openFile(String str) throws GifIOException;

    private static long openFileDescriptor(FileDescriptor fileDescriptor, long j7, boolean z7) throws GifIOException {
        try {
            return openNativeFileDescriptor(getNativeFileDescriptor(fileDescriptor, z7), j7);
        } catch (Exception e7) {
            throw new GifIOException(GifError.OPEN_FAILED.errorCode, e7.getMessage());
        }
    }

    static native long openNativeFileDescriptor(int i7, long j7) throws GifIOException;

    static native long openStream(InputStream inputStream) throws GifIOException;

    static GifInfoHandle openUri(ContentResolver contentResolver, Uri uri) throws IOException {
        if ("file".equals(uri.getScheme())) {
            return new GifInfoHandle(uri.getPath());
        }
        AssetFileDescriptor openAssetFileDescriptor = contentResolver.openAssetFileDescriptor(uri, "r");
        if (openAssetFileDescriptor != null) {
            return new GifInfoHandle(openAssetFileDescriptor);
        }
        throw new IOException("Could not open AssetFileDescriptor for " + uri);
    }

    private static native void postUnbindSurface(long j7);

    private static native long renderFrame(long j7, Bitmap bitmap);

    private static native boolean reset(long j7);

    private static native long restoreRemainder(long j7);

    private static native int restoreSavedState(long j7, long[] jArr, Bitmap bitmap);

    private static native void saveRemainder(long j7);

    private static native void seekToFrame(long j7, int i7, Bitmap bitmap);

    private static native void seekToFrameGL(long j7, int i7);

    private static native void seekToTime(long j7, int i7, Bitmap bitmap);

    private static native void setLoopCount(long j7, char c7);

    private static native void setOptions(long j7, char c7, boolean z7);

    private static native void setSpeedFactor(long j7, float f7);

    private static native void startDecoderThread(long j7);

    private static native void stopDecoderThread(long j7);

    private void throwIfFrameIndexOutOfBounds(@IntRange(from = 0) int i7) {
        int numberOfFrames = getNumberOfFrames(this.gifInfoPtr);
        if (i7 < 0 || i7 >= numberOfFrames) {
            throw new IndexOutOfBoundsException("Frame index is not in range <0;" + numberOfFrames + h0.f20273f);
        }
    }

    /* access modifiers changed from: package-private */
    public void bindSurface(Surface surface, long[] jArr) {
        bindSurface(this.gifInfoPtr, surface, jArr);
    }

    /* access modifiers changed from: protected */
    public void finalize() throws Throwable {
        try {
            recycle();
        } finally {
            super.finalize();
        }
    }

    /* access modifiers changed from: package-private */
    public synchronized long getAllocationByteCount() {
        return getAllocationByteCount(this.gifInfoPtr);
    }

    /* access modifiers changed from: package-private */
    public synchronized String getComment() {
        return getComment(this.gifInfoPtr);
    }

    /* access modifiers changed from: package-private */
    public synchronized int getCurrentFrameIndex() {
        return getCurrentFrameIndex(this.gifInfoPtr);
    }

    /* access modifiers changed from: package-private */
    public synchronized int getCurrentLoop() {
        return getCurrentLoop(this.gifInfoPtr);
    }

    /* access modifiers changed from: package-private */
    public synchronized int getCurrentPosition() {
        return getCurrentPosition(this.gifInfoPtr);
    }

    /* access modifiers changed from: package-private */
    public synchronized int getDuration() {
        return getDuration(this.gifInfoPtr);
    }

    /* access modifiers changed from: package-private */
    public synchronized int getFrameDuration(@IntRange(from = 0) int i7) {
        throwIfFrameIndexOutOfBounds(i7);
        return getFrameDuration(this.gifInfoPtr, i7);
    }

    /* access modifiers changed from: package-private */
    public synchronized int getHeight() {
        return getHeight(this.gifInfoPtr);
    }

    /* access modifiers changed from: package-private */
    public synchronized int getLoopCount() {
        return getLoopCount(this.gifInfoPtr);
    }

    /* access modifiers changed from: package-private */
    public synchronized long getMetadataByteCount() {
        return getMetadataByteCount(this.gifInfoPtr);
    }

    /* access modifiers changed from: package-private */
    public synchronized int getNativeErrorCode() {
        return getNativeErrorCode(this.gifInfoPtr);
    }

    /* access modifiers changed from: package-private */
    public synchronized int getNumberOfFrames() {
        return getNumberOfFrames(this.gifInfoPtr);
    }

    /* access modifiers changed from: package-private */
    public synchronized long[] getSavedState() {
        return getSavedState(this.gifInfoPtr);
    }

    /* access modifiers changed from: package-private */
    public synchronized long getSourceLength() {
        return getSourceLength(this.gifInfoPtr);
    }

    /* access modifiers changed from: package-private */
    public synchronized int getWidth() {
        return getWidth(this.gifInfoPtr);
    }

    /* access modifiers changed from: package-private */
    public void glTexImage2D(int i7, int i8) {
        glTexImage2D(this.gifInfoPtr, i7, i8);
    }

    /* access modifiers changed from: package-private */
    public void glTexSubImage2D(int i7, int i8) {
        glTexSubImage2D(this.gifInfoPtr, i7, i8);
    }

    /* access modifiers changed from: package-private */
    public void initTexImageDescriptor() {
        initTexImageDescriptor(this.gifInfoPtr);
    }

    /* access modifiers changed from: package-private */
    public synchronized boolean isAnimationCompleted() {
        return isAnimationCompleted(this.gifInfoPtr);
    }

    /* access modifiers changed from: package-private */
    public synchronized boolean isOpaque() {
        return isOpaque(this.gifInfoPtr);
    }

    /* access modifiers changed from: package-private */
    public synchronized boolean isRecycled() {
        return this.gifInfoPtr == 0;
    }

    /* access modifiers changed from: package-private */
    public synchronized void postUnbindSurface() {
        postUnbindSurface(this.gifInfoPtr);
    }

    /* access modifiers changed from: package-private */
    public synchronized void recycle() {
        free(this.gifInfoPtr);
        this.gifInfoPtr = 0;
    }

    /* access modifiers changed from: package-private */
    public synchronized long renderFrame(Bitmap bitmap) {
        return renderFrame(this.gifInfoPtr, bitmap);
    }

    /* access modifiers changed from: package-private */
    public synchronized boolean reset() {
        return reset(this.gifInfoPtr);
    }

    /* access modifiers changed from: package-private */
    public synchronized long restoreRemainder() {
        return restoreRemainder(this.gifInfoPtr);
    }

    /* access modifiers changed from: package-private */
    public synchronized int restoreSavedState(long[] jArr, Bitmap bitmap) {
        return restoreSavedState(this.gifInfoPtr, jArr, bitmap);
    }

    /* access modifiers changed from: package-private */
    public synchronized void saveRemainder() {
        saveRemainder(this.gifInfoPtr);
    }

    /* access modifiers changed from: package-private */
    public synchronized void seekToFrame(@IntRange(from = 0, to = 2147483647L) int i7, Bitmap bitmap) {
        seekToFrame(this.gifInfoPtr, i7, bitmap);
    }

    /* access modifiers changed from: package-private */
    public void seekToFrameGL(@IntRange(from = 0) int i7) {
        throwIfFrameIndexOutOfBounds(i7);
        seekToFrameGL(this.gifInfoPtr, i7);
    }

    /* access modifiers changed from: package-private */
    public synchronized void seekToTime(@IntRange(from = 0, to = 2147483647L) int i7, Bitmap bitmap) {
        seekToTime(this.gifInfoPtr, i7, bitmap);
    }

    /* access modifiers changed from: package-private */
    public void setLoopCount(@IntRange(from = 0, to = 65535) int i7) {
        if (i7 < 0 || i7 > 65535) {
            throw new IllegalArgumentException("Loop count of range <0, 65535>");
        }
        synchronized (this) {
            setLoopCount(this.gifInfoPtr, (char) i7);
        }
    }

    /* access modifiers changed from: package-private */
    public void setOptions(char c7, boolean z7) {
        setOptions(this.gifInfoPtr, c7, z7);
    }

    /* access modifiers changed from: package-private */
    public void setSpeedFactor(@FloatRange(from = 0.0d, fromInclusive = false) float f7) {
        if (f7 <= 0.0f || Float.isNaN(f7)) {
            throw new IllegalArgumentException("Speed factor is not positive");
        }
        if (f7 < 4.656613E-10f) {
            f7 = 4.656613E-10f;
        }
        synchronized (this) {
            setSpeedFactor(this.gifInfoPtr, f7);
        }
    }

    /* access modifiers changed from: package-private */
    public void startDecoderThread() {
        startDecoderThread(this.gifInfoPtr);
    }

    /* access modifiers changed from: package-private */
    public void stopDecoderThread() {
        stopDecoderThread(this.gifInfoPtr);
    }

    GifInfoHandle(AssetFileDescriptor assetFileDescriptor) throws IOException {
        try {
            this.gifInfoPtr = openFileDescriptor(assetFileDescriptor.getFileDescriptor(), assetFileDescriptor.getStartOffset(), false);
        } finally {
            try {
                assetFileDescriptor.close();
            } catch (IOException unused) {
            }
        }
    }

    GifInfoHandle(FileDescriptor fileDescriptor) throws GifIOException {
        this.gifInfoPtr = openFileDescriptor(fileDescriptor, 0, true);
    }

    GifInfoHandle(InputStream inputStream) throws GifIOException {
        if (inputStream.markSupported()) {
            this.gifInfoPtr = openStream(inputStream);
            return;
        }
        throw new IllegalArgumentException("InputStream does not support marking");
    }

    GifInfoHandle(String str) throws GifIOException {
        this.gifInfoPtr = openFile(str);
    }

    GifInfoHandle(ByteBuffer byteBuffer) throws GifIOException {
        this.gifInfoPtr = openDirectByteBuffer(byteBuffer);
    }

    GifInfoHandle(byte[] bArr) throws GifIOException {
        this.gifInfoPtr = openByteArray(bArr);
    }
}
