package pl.droidsonroids.gif;

import android.graphics.drawable.Drawable;
import android.view.View;
import androidx.annotation.NonNull;
import java.lang.ref.WeakReference;
import java.util.concurrent.CopyOnWriteArrayList;

public class MultiCallback implements Drawable.Callback {
    private final CopyOnWriteArrayList<CallbackWeakReference> mCallbacks;
    private final boolean mUseViewInvalidate;

    static final class CallbackWeakReference extends WeakReference<Drawable.Callback> {
        CallbackWeakReference(Drawable.Callback callback) {
            super(callback);
        }

        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (obj == null || CallbackWeakReference.class != obj.getClass()) {
                return false;
            }
            return get() == ((CallbackWeakReference) obj).get();
        }

        public int hashCode() {
            Drawable.Callback callback = (Drawable.Callback) get();
            if (callback != null) {
                return callback.hashCode();
            }
            return 0;
        }
    }

    public MultiCallback() {
        this(false);
    }

    public void addView(Drawable.Callback callback) {
        for (int i7 = 0; i7 < this.mCallbacks.size(); i7++) {
            CallbackWeakReference callbackWeakReference = this.mCallbacks.get(i7);
            if (((Drawable.Callback) callbackWeakReference.get()) == null) {
                this.mCallbacks.remove(callbackWeakReference);
            }
        }
        this.mCallbacks.addIfAbsent(new CallbackWeakReference(callback));
    }

    public void invalidateDrawable(@NonNull Drawable drawable) {
        for (int i7 = 0; i7 < this.mCallbacks.size(); i7++) {
            CallbackWeakReference callbackWeakReference = this.mCallbacks.get(i7);
            Drawable.Callback callback = (Drawable.Callback) callbackWeakReference.get();
            if (callback == null) {
                this.mCallbacks.remove(callbackWeakReference);
            } else if (!this.mUseViewInvalidate || !(callback instanceof View)) {
                callback.invalidateDrawable(drawable);
            } else {
                ((View) callback).invalidate();
            }
        }
    }

    public void removeView(Drawable.Callback callback) {
        for (int i7 = 0; i7 < this.mCallbacks.size(); i7++) {
            CallbackWeakReference callbackWeakReference = this.mCallbacks.get(i7);
            Drawable.Callback callback2 = (Drawable.Callback) callbackWeakReference.get();
            if (callback2 == null || callback2 == callback) {
                this.mCallbacks.remove(callbackWeakReference);
            }
        }
    }

    public void scheduleDrawable(@NonNull Drawable drawable, @NonNull Runnable runnable, long j7) {
        for (int i7 = 0; i7 < this.mCallbacks.size(); i7++) {
            CallbackWeakReference callbackWeakReference = this.mCallbacks.get(i7);
            Drawable.Callback callback = (Drawable.Callback) callbackWeakReference.get();
            if (callback != null) {
                callback.scheduleDrawable(drawable, runnable, j7);
            } else {
                this.mCallbacks.remove(callbackWeakReference);
            }
        }
    }

    public void unscheduleDrawable(@NonNull Drawable drawable, @NonNull Runnable runnable) {
        for (int i7 = 0; i7 < this.mCallbacks.size(); i7++) {
            CallbackWeakReference callbackWeakReference = this.mCallbacks.get(i7);
            Drawable.Callback callback = (Drawable.Callback) callbackWeakReference.get();
            if (callback != null) {
                callback.unscheduleDrawable(drawable, runnable);
            } else {
                this.mCallbacks.remove(callbackWeakReference);
            }
        }
    }

    public MultiCallback(boolean z7) {
        this.mCallbacks = new CopyOnWriteArrayList<>();
        this.mUseViewInvalidate = z7;
    }
}
