package androidx.appcompat.widget;

import android.content.Context;
import android.graphics.Rect;
import android.util.AttributeSet;
import android.util.DisplayMetrics;
import android.util.TypedValue;
import android.view.View;
import android.widget.FrameLayout;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.annotation.RestrictTo;
import androidx.core.view.ViewCompat;

@RestrictTo({RestrictTo.Scope.LIBRARY})
public class ContentFrameLayout extends FrameLayout {
    private OnAttachListener mAttachListener;
    private final Rect mDecorPadding;
    private TypedValue mFixedHeightMajor;
    private TypedValue mFixedHeightMinor;
    private TypedValue mFixedWidthMajor;
    private TypedValue mFixedWidthMinor;
    private TypedValue mMinWidthMajor;
    private TypedValue mMinWidthMinor;

    public interface OnAttachListener {
        void onAttachedFromWindow();

        void onDetachedFromWindow();
    }

    public ContentFrameLayout(@NonNull Context context) {
        this(context, null);
    }

    @RestrictTo({RestrictTo.Scope.LIBRARY})
    public void dispatchFitSystemWindows(Rect rect) {
        fitSystemWindows(rect);
    }

    public TypedValue getFixedHeightMajor() {
        if (this.mFixedHeightMajor == null) {
            this.mFixedHeightMajor = new TypedValue();
        }
        return this.mFixedHeightMajor;
    }

    public TypedValue getFixedHeightMinor() {
        if (this.mFixedHeightMinor == null) {
            this.mFixedHeightMinor = new TypedValue();
        }
        return this.mFixedHeightMinor;
    }

    public TypedValue getFixedWidthMajor() {
        if (this.mFixedWidthMajor == null) {
            this.mFixedWidthMajor = new TypedValue();
        }
        return this.mFixedWidthMajor;
    }

    public TypedValue getFixedWidthMinor() {
        if (this.mFixedWidthMinor == null) {
            this.mFixedWidthMinor = new TypedValue();
        }
        return this.mFixedWidthMinor;
    }

    public TypedValue getMinWidthMajor() {
        if (this.mMinWidthMajor == null) {
            this.mMinWidthMajor = new TypedValue();
        }
        return this.mMinWidthMajor;
    }

    public TypedValue getMinWidthMinor() {
        if (this.mMinWidthMinor == null) {
            this.mMinWidthMinor = new TypedValue();
        }
        return this.mMinWidthMinor;
    }

    /* access modifiers changed from: protected */
    public void onAttachedToWindow() {
        super.onAttachedToWindow();
        OnAttachListener onAttachListener = this.mAttachListener;
        if (onAttachListener != null) {
            onAttachListener.onAttachedFromWindow();
        }
    }

    /* access modifiers changed from: protected */
    public void onDetachedFromWindow() {
        super.onDetachedFromWindow();
        OnAttachListener onAttachListener = this.mAttachListener;
        if (onAttachListener != null) {
            onAttachListener.onDetachedFromWindow();
        }
    }

    /* access modifiers changed from: protected */
    /* JADX WARNING: Removed duplicated region for block: B:19:0x004a  */
    /* JADX WARNING: Removed duplicated region for block: B:22:0x0063  */
    /* JADX WARNING: Removed duplicated region for block: B:35:0x0086  */
    /* JADX WARNING: Removed duplicated region for block: B:40:0x00ab  */
    /* JADX WARNING: Removed duplicated region for block: B:41:0x00ae  */
    /* JADX WARNING: Removed duplicated region for block: B:46:0x00b8  */
    /* JADX WARNING: Removed duplicated region for block: B:48:0x00be  */
    /* JADX WARNING: Removed duplicated region for block: B:52:0x00cc  */
    /* JADX WARNING: Removed duplicated region for block: B:54:0x00d6  */
    /* JADX WARNING: Removed duplicated region for block: B:57:0x00de  */
    /* JADX WARNING: Removed duplicated region for block: B:59:? A[RETURN, SYNTHETIC] */
    public void onMeasure(int i7, int i8) {
        boolean z7;
        int measuredWidth;
        int i9;
        int i10;
        float fraction;
        int i11;
        int i12;
        float fraction2;
        int i13;
        int i14;
        float fraction3;
        DisplayMetrics displayMetrics = getContext().getResources().getDisplayMetrics();
        boolean z8 = true;
        boolean z9 = displayMetrics.widthPixels < displayMetrics.heightPixels;
        int mode = View.MeasureSpec.getMode(i7);
        int mode2 = View.MeasureSpec.getMode(i8);
        if (mode == Integer.MIN_VALUE) {
            TypedValue typedValue = z9 ? this.mFixedWidthMinor : this.mFixedWidthMajor;
            if (!(typedValue == null || (i13 = typedValue.type) == 0)) {
                if (i13 == 5) {
                    fraction3 = typedValue.getDimension(displayMetrics);
                } else if (i13 == 6) {
                    int i15 = displayMetrics.widthPixels;
                    fraction3 = typedValue.getFraction((float) i15, (float) i15);
                } else {
                    i14 = 0;
                    if (i14 > 0) {
                        Rect rect = this.mDecorPadding;
                        i7 = View.MeasureSpec.makeMeasureSpec(Math.min(i14 - (rect.left + rect.right), View.MeasureSpec.getSize(i7)), 1073741824);
                        z7 = true;
                        if (mode2 == Integer.MIN_VALUE) {
                            TypedValue typedValue2 = z9 ? this.mFixedHeightMajor : this.mFixedHeightMinor;
                            if (!(typedValue2 == null || (i11 = typedValue2.type) == 0)) {
                                if (i11 == 5) {
                                    fraction2 = typedValue2.getDimension(displayMetrics);
                                } else if (i11 == 6) {
                                    int i16 = displayMetrics.heightPixels;
                                    fraction2 = typedValue2.getFraction((float) i16, (float) i16);
                                } else {
                                    i12 = 0;
                                    if (i12 > 0) {
                                        Rect rect2 = this.mDecorPadding;
                                        i8 = View.MeasureSpec.makeMeasureSpec(Math.min(i12 - (rect2.top + rect2.bottom), View.MeasureSpec.getSize(i8)), 1073741824);
                                    }
                                }
                                i12 = (int) fraction2;
                                if (i12 > 0) {
                                }
                            }
                        }
                        super.onMeasure(i7, i8);
                        measuredWidth = getMeasuredWidth();
                        int makeMeasureSpec = View.MeasureSpec.makeMeasureSpec(measuredWidth, 1073741824);
                        if (!z7 && mode == Integer.MIN_VALUE) {
                            TypedValue typedValue3 = !z9 ? this.mMinWidthMinor : this.mMinWidthMajor;
                            if (!(typedValue3 == null || (i9 = typedValue3.type) == 0)) {
                                if (i9 != 5) {
                                    fraction = typedValue3.getDimension(displayMetrics);
                                } else if (i9 == 6) {
                                    int i17 = displayMetrics.widthPixels;
                                    fraction = typedValue3.getFraction((float) i17, (float) i17);
                                } else {
                                    i10 = 0;
                                    if (i10 > 0) {
                                        Rect rect3 = this.mDecorPadding;
                                        i10 -= rect3.left + rect3.right;
                                    }
                                    if (measuredWidth < i10) {
                                        makeMeasureSpec = View.MeasureSpec.makeMeasureSpec(i10, 1073741824);
                                        if (z8) {
                                            super.onMeasure(makeMeasureSpec, i8);
                                            return;
                                        }
                                        return;
                                    }
                                }
                                i10 = (int) fraction;
                                if (i10 > 0) {
                                }
                                if (measuredWidth < i10) {
                                }
                            }
                        }
                        z8 = false;
                        if (z8) {
                        }
                    }
                }
                i14 = (int) fraction3;
                if (i14 > 0) {
                }
            }
        }
        z7 = false;
        if (mode2 == Integer.MIN_VALUE) {
        }
        super.onMeasure(i7, i8);
        measuredWidth = getMeasuredWidth();
        int makeMeasureSpec2 = View.MeasureSpec.makeMeasureSpec(measuredWidth, 1073741824);
        if (!z9) {
        }
        if (i9 != 5) {
        }
        i10 = (int) fraction;
        if (i10 > 0) {
        }
        if (measuredWidth < i10) {
        }
        z8 = false;
        if (z8) {
        }
    }

    public void setAttachListener(OnAttachListener onAttachListener) {
        this.mAttachListener = onAttachListener;
    }

    @RestrictTo({RestrictTo.Scope.LIBRARY})
    public void setDecorPadding(int i7, int i8, int i9, int i10) {
        this.mDecorPadding.set(i7, i8, i9, i10);
        if (ViewCompat.isLaidOut(this)) {
            requestLayout();
        }
    }

    public ContentFrameLayout(@NonNull Context context, @Nullable AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    public ContentFrameLayout(@NonNull Context context, @Nullable AttributeSet attributeSet, int i7) {
        super(context, attributeSet, i7);
        this.mDecorPadding = new Rect();
    }
}
