package androidx.appcompat.widget;

import android.graphics.Insets;
import android.graphics.PorterDuff;
import android.graphics.Rect;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.DrawableContainer;
import android.graphics.drawable.ScaleDrawable;
import android.os.Build;
import androidx.annotation.DoNotInline;
import androidx.annotation.NonNull;
import androidx.annotation.RequiresApi;
import androidx.annotation.RestrictTo;
import androidx.appcompat.graphics.drawable.DrawableWrapper;
import androidx.core.graphics.drawable.WrappedDrawable;
import java.lang.reflect.Field;
import java.lang.reflect.Method;

@RestrictTo({RestrictTo.Scope.LIBRARY_GROUP_PREFIX})
public class DrawableUtils {
    private static final int[] CHECKED_STATE_SET = {16842912};
    private static final int[] EMPTY_STATE_SET = new int[0];
    public static final Rect INSETS_NONE = new Rect();

    @RequiresApi(18)
    static class Api18Impl {
        private static final Field sBottom;
        private static final Method sGetOpticalInsets;
        private static final Field sLeft;
        private static final boolean sReflectionSuccessful;
        private static final Field sRight;
        private static final Field sTop;

        /* JADX WARNING: Removed duplicated region for block: B:43:0x004b  */
        /* JADX WARNING: Removed duplicated region for block: B:44:0x0058  */
        static {
            boolean z7;
            Field field;
            Field field2;
            Field field3;
            Method method;
            Field field4;
            try {
                Class<?> cls = Class.forName("android.graphics.Insets");
                method = Drawable.class.getMethod("getOpticalInsets", new Class[0]);
                try {
                    field3 = cls.getField("left");
                } catch (NoSuchMethodException unused) {
                    field3 = null;
                    field2 = field3;
                    field = field2;
                    field4 = null;
                    z7 = false;
                    if (!z7) {
                    }
                } catch (ClassNotFoundException unused2) {
                    field3 = null;
                    field2 = field3;
                    field = field2;
                    field4 = null;
                    z7 = false;
                    if (!z7) {
                    }
                } catch (NoSuchFieldException unused3) {
                    field3 = null;
                    field2 = field3;
                    field = field2;
                    field4 = null;
                    z7 = false;
                    if (!z7) {
                    }
                }
                try {
                    field2 = cls.getField("top");
                } catch (NoSuchMethodException unused4) {
                    field2 = null;
                    field = field2;
                    field4 = null;
                    z7 = false;
                    if (!z7) {
                    }
                } catch (ClassNotFoundException unused5) {
                    field2 = null;
                    field = field2;
                    field4 = null;
                    z7 = false;
                    if (!z7) {
                    }
                } catch (NoSuchFieldException unused6) {
                    field2 = null;
                    field = field2;
                    field4 = null;
                    z7 = false;
                    if (!z7) {
                    }
                }
                try {
                    field = cls.getField("right");
                    try {
                        field4 = cls.getField("bottom");
                        z7 = true;
                    } catch (ClassNotFoundException | NoSuchFieldException | NoSuchMethodException unused7) {
                        field4 = null;
                        z7 = false;
                        if (!z7) {
                        }
                    }
                } catch (ClassNotFoundException | NoSuchFieldException | NoSuchMethodException unused8) {
                    field = null;
                    field4 = null;
                    z7 = false;
                    if (!z7) {
                    }
                }
            } catch (NoSuchMethodException unused9) {
                method = null;
                field3 = null;
                field2 = field3;
                field = field2;
                field4 = null;
                z7 = false;
                if (!z7) {
                }
            } catch (ClassNotFoundException unused10) {
                method = null;
                field3 = null;
                field2 = field3;
                field = field2;
                field4 = null;
                z7 = false;
                if (!z7) {
                }
            } catch (NoSuchFieldException unused11) {
                method = null;
                field3 = null;
                field2 = field3;
                field = field2;
                field4 = null;
                z7 = false;
                if (!z7) {
                }
            }
            if (!z7) {
                sGetOpticalInsets = method;
                sLeft = field3;
                sTop = field2;
                sRight = field;
                sBottom = field4;
                sReflectionSuccessful = true;
                return;
            }
            sGetOpticalInsets = null;
            sLeft = null;
            sTop = null;
            sRight = null;
            sBottom = null;
            sReflectionSuccessful = false;
        }

        private Api18Impl() {
        }

        @NonNull
        static Rect getOpticalInsets(@NonNull Drawable drawable) {
            return DrawableUtils.INSETS_NONE;
        }
    }

    @RequiresApi(29)
    static class Api29Impl {
        private Api29Impl() {
        }

        @DoNotInline
        static Insets getOpticalInsets(Drawable drawable) {
            return drawable.getOpticalInsets();
        }
    }

    private DrawableUtils() {
    }

    public static boolean canSafelyMutateDrawable(@NonNull Drawable drawable) {
        Drawable drawable2;
        if (drawable instanceof DrawableContainer) {
            Drawable.ConstantState constantState = drawable.getConstantState();
            if (!(constantState instanceof DrawableContainer.DrawableContainerState)) {
                return true;
            }
            for (Drawable drawable3 : ((DrawableContainer.DrawableContainerState) constantState).getChildren()) {
                if (!canSafelyMutateDrawable(drawable3)) {
                    return false;
                }
            }
            return true;
        }
        if (drawable instanceof WrappedDrawable) {
            drawable2 = ((WrappedDrawable) drawable).getWrappedDrawable();
        } else if (drawable instanceof DrawableWrapper) {
            drawable2 = ((DrawableWrapper) drawable).getWrappedDrawable();
        } else if (!(drawable instanceof ScaleDrawable)) {
            return true;
        } else {
            drawable2 = ((ScaleDrawable) drawable).getDrawable();
        }
        return canSafelyMutateDrawable(drawable2);
    }

    static void fixDrawable(@NonNull Drawable drawable) {
        String name = drawable.getClass().getName();
        if (Build.VERSION.SDK_INT < 31 && "android.graphics.drawable.ColorStateListDrawable".equals(name)) {
            forceDrawableStateChange(drawable);
        }
    }

    private static void forceDrawableStateChange(Drawable drawable) {
        int[] state = drawable.getState();
        if (state == null || state.length == 0) {
            drawable.setState(CHECKED_STATE_SET);
        } else {
            drawable.setState(EMPTY_STATE_SET);
        }
        drawable.setState(state);
    }

    @NonNull
    public static Rect getOpticalBounds(@NonNull Drawable drawable) {
        Insets opticalInsets = Api29Impl.getOpticalInsets(drawable);
        return new Rect(opticalInsets.left, opticalInsets.top, opticalInsets.right, opticalInsets.bottom);
    }

    public static PorterDuff.Mode parseTintMode(int i7, PorterDuff.Mode mode) {
        if (i7 == 3) {
            return PorterDuff.Mode.SRC_OVER;
        }
        if (i7 == 5) {
            return PorterDuff.Mode.SRC_IN;
        }
        if (i7 == 9) {
            return PorterDuff.Mode.SRC_ATOP;
        }
        switch (i7) {
            case 14:
                return PorterDuff.Mode.MULTIPLY;
            case 15:
                return PorterDuff.Mode.SCREEN;
            case 16:
                return PorterDuff.Mode.ADD;
            default:
                return mode;
        }
    }
}
