package androidx.constraintlayout.motion.widget;

import android.view.View;
import androidx.annotation.NonNull;
import androidx.constraintlayout.motion.utils.Easing;
import androidx.constraintlayout.widget.ConstraintAttribute;
import androidx.constraintlayout.widget.ConstraintSet;
import com.graphisoft.bimx.converter.FavoriteReader;
import java.util.Arrays;
import java.util.LinkedHashMap;

/* access modifiers changed from: package-private */
public class MotionPaths implements Comparable<MotionPaths> {
    static final int CARTESIAN = 2;
    public static final boolean DEBUG = false;
    static final int OFF_HEIGHT = 4;
    static final int OFF_PATH_ROTATE = 5;
    static final int OFF_POSITION = 0;
    static final int OFF_WIDTH = 3;
    static final int OFF_X = 1;
    static final int OFF_Y = 2;
    public static final boolean OLD_WAY = false;
    static final int PERPENDICULAR = 1;
    static final int SCREEN = 3;
    public static final String TAG = "MotionPaths";
    static String[] names = {FavoriteReader.HistoryItem3D.POSITION, "x", "y", "width", "height", "pathRotate"};
    LinkedHashMap<String, ConstraintAttribute> attributes;
    float height;
    int mDrawPath;
    Easing mKeyFrameEasing;
    int mMode;
    int mPathMotionArc;
    float mPathRotate;
    float mProgress;
    double[] mTempDelta;
    double[] mTempValue;
    float position;
    float time;
    float width;

    /* renamed from: x  reason: collision with root package name */
    float f502x;

    /* renamed from: y  reason: collision with root package name */
    float f503y;

    public MotionPaths() {
        this.mDrawPath = 0;
        this.mPathRotate = Float.NaN;
        this.mProgress = Float.NaN;
        this.mPathMotionArc = Key.UNSET;
        this.attributes = new LinkedHashMap<>();
        this.mMode = 0;
        this.mTempValue = new double[18];
        this.mTempDelta = new double[18];
    }

    private boolean diff(float f7, float f8) {
        return (Float.isNaN(f7) || Float.isNaN(f8)) ? Float.isNaN(f7) != Float.isNaN(f8) : Math.abs(f7 - f8) > 1.0E-6f;
    }

    private static final float xRotate(float f7, float f8, float f9, float f10, float f11, float f12) {
        return (((f11 - f9) * f8) - ((f12 - f10) * f7)) + f9;
    }

    private static final float yRotate(float f7, float f8, float f9, float f10, float f11, float f12) {
        return ((f11 - f9) * f7) + ((f12 - f10) * f8) + f10;
    }

    public void applyParameters(ConstraintSet.Constraint constraint) {
        this.mKeyFrameEasing = Easing.getInterpolator(constraint.motion.mTransitionEasing);
        ConstraintSet.Motion motion = constraint.motion;
        this.mPathMotionArc = motion.mPathMotionArc;
        this.mPathRotate = motion.mPathRotate;
        this.mDrawPath = motion.mDrawPath;
        this.mProgress = constraint.propertySet.mProgress;
        for (String str : constraint.mCustomConstraints.keySet()) {
            ConstraintAttribute constraintAttribute = constraint.mCustomConstraints.get(str);
            if (constraintAttribute.getType() != ConstraintAttribute.AttributeType.STRING_TYPE) {
                this.attributes.put(str, constraintAttribute);
            }
        }
    }

    public int compareTo(@NonNull MotionPaths motionPaths) {
        return Float.compare(this.position, motionPaths.position);
    }

    /* access modifiers changed from: package-private */
    public void different(MotionPaths motionPaths, boolean[] zArr, String[] strArr, boolean z7) {
        zArr[0] = zArr[0] | diff(this.position, motionPaths.position);
        zArr[1] = zArr[1] | diff(this.f502x, motionPaths.f502x) | z7;
        zArr[2] = z7 | diff(this.f503y, motionPaths.f503y) | zArr[2];
        zArr[3] = zArr[3] | diff(this.width, motionPaths.width);
        zArr[4] = diff(this.height, motionPaths.height) | zArr[4];
    }

    /* access modifiers changed from: package-private */
    public void fillStandard(double[] dArr, int[] iArr) {
        float[] fArr = {this.position, this.f502x, this.f503y, this.width, this.height, this.mPathRotate};
        int i7 = 0;
        for (int i8 : iArr) {
            if (i8 < 6) {
                dArr[i7] = (double) fArr[i8];
                i7++;
            }
        }
    }

    /* access modifiers changed from: package-private */
    public void getBounds(int[] iArr, double[] dArr, float[] fArr, int i7) {
        float f7 = this.width;
        float f8 = this.height;
        for (int i8 = 0; i8 < iArr.length; i8++) {
            float f9 = (float) dArr[i8];
            int i9 = iArr[i8];
            if (i9 == 3) {
                f7 = f9;
            } else if (i9 == 4) {
                f8 = f9;
            }
        }
        fArr[i7] = f7;
        fArr[i7 + 1] = f8;
    }

    /* access modifiers changed from: package-private */
    public void getCenter(int[] iArr, double[] dArr, float[] fArr, int i7) {
        float f7 = this.f502x;
        float f8 = this.f503y;
        float f9 = this.width;
        float f10 = this.height;
        for (int i8 = 0; i8 < iArr.length; i8++) {
            float f11 = (float) dArr[i8];
            int i9 = iArr[i8];
            if (i9 == 1) {
                f7 = f11;
            } else if (i9 == 2) {
                f8 = f11;
            } else if (i9 == 3) {
                f9 = f11;
            } else if (i9 == 4) {
                f10 = f11;
            }
        }
        fArr[i7] = f7 + (f9 / 2.0f) + 0.0f;
        fArr[i7 + 1] = f8 + (f10 / 2.0f) + 0.0f;
    }

    /* access modifiers changed from: package-private */
    public int getCustomData(String str, double[] dArr, int i7) {
        ConstraintAttribute constraintAttribute = this.attributes.get(str);
        if (constraintAttribute.noOfInterpValues() == 1) {
            dArr[i7] = (double) constraintAttribute.getValueToInterpolate();
            return 1;
        }
        int noOfInterpValues = constraintAttribute.noOfInterpValues();
        float[] fArr = new float[noOfInterpValues];
        constraintAttribute.getValuesToInterpolate(fArr);
        int i8 = 0;
        while (i8 < noOfInterpValues) {
            dArr[i7] = (double) fArr[i8];
            i8++;
            i7++;
        }
        return noOfInterpValues;
    }

    /* access modifiers changed from: package-private */
    public int getCustomDataCount(String str) {
        return this.attributes.get(str).noOfInterpValues();
    }

    /* access modifiers changed from: package-private */
    public void getRect(int[] iArr, double[] dArr, float[] fArr, int i7) {
        float f7 = this.f502x;
        float f8 = this.f503y;
        float f9 = this.width;
        float f10 = this.height;
        for (int i8 = 0; i8 < iArr.length; i8++) {
            float f11 = (float) dArr[i8];
            int i9 = iArr[i8];
            if (i9 == 1) {
                f7 = f11;
            } else if (i9 == 2) {
                f8 = f11;
            } else if (i9 == 3) {
                f9 = f11;
            } else if (i9 == 4) {
                f10 = f11;
            }
        }
        float f12 = f9 + f7;
        float f13 = f10 + f8;
        Float.isNaN(Float.NaN);
        Float.isNaN(Float.NaN);
        int i10 = i7 + 1;
        fArr[i7] = f7 + 0.0f;
        int i11 = i10 + 1;
        fArr[i10] = f8 + 0.0f;
        int i12 = i11 + 1;
        fArr[i11] = f12 + 0.0f;
        int i13 = i12 + 1;
        fArr[i12] = f8 + 0.0f;
        int i14 = i13 + 1;
        fArr[i13] = f12 + 0.0f;
        int i15 = i14 + 1;
        fArr[i14] = f13 + 0.0f;
        fArr[i15] = f7 + 0.0f;
        fArr[i15 + 1] = f13 + 0.0f;
    }

    /* access modifiers changed from: package-private */
    public boolean hasCustomData(String str) {
        return this.attributes.containsKey(str);
    }

    /* access modifiers changed from: package-private */
    public void initCartesian(KeyPosition keyPosition, MotionPaths motionPaths, MotionPaths motionPaths2) {
        float f7 = ((float) keyPosition.mFramePosition) / 100.0f;
        this.time = f7;
        this.mDrawPath = keyPosition.mDrawPath;
        float f8 = Float.isNaN(keyPosition.mPercentWidth) ? f7 : keyPosition.mPercentWidth;
        float f9 = Float.isNaN(keyPosition.mPercentHeight) ? f7 : keyPosition.mPercentHeight;
        float f10 = motionPaths2.width;
        float f11 = motionPaths.width;
        float f12 = motionPaths2.height;
        float f13 = motionPaths.height;
        this.position = this.time;
        float f14 = motionPaths.f502x;
        float f15 = motionPaths.f503y;
        float f16 = (motionPaths2.f502x + (f10 / 2.0f)) - ((f11 / 2.0f) + f14);
        float f17 = (motionPaths2.f503y + (f12 / 2.0f)) - (f15 + (f13 / 2.0f));
        float f18 = (f10 - f11) * f8;
        float f19 = f18 / 2.0f;
        this.f502x = (float) ((int) ((f14 + (f16 * f7)) - f19));
        float f20 = (f12 - f13) * f9;
        float f21 = f20 / 2.0f;
        this.f503y = (float) ((int) ((f15 + (f17 * f7)) - f21));
        this.width = (float) ((int) (f11 + f18));
        this.height = (float) ((int) (f13 + f20));
        float f22 = Float.isNaN(keyPosition.mPercentX) ? f7 : keyPosition.mPercentX;
        float f23 = 0.0f;
        float f24 = Float.isNaN(keyPosition.mAltPercentY) ? 0.0f : keyPosition.mAltPercentY;
        if (!Float.isNaN(keyPosition.mPercentY)) {
            f7 = keyPosition.mPercentY;
        }
        if (!Float.isNaN(keyPosition.mAltPercentX)) {
            f23 = keyPosition.mAltPercentX;
        }
        this.mMode = 2;
        this.f502x = (float) ((int) (((motionPaths.f502x + (f22 * f16)) + (f23 * f17)) - f19));
        this.f503y = (float) ((int) (((motionPaths.f503y + (f16 * f24)) + (f17 * f7)) - f21));
        this.mKeyFrameEasing = Easing.getInterpolator(keyPosition.mTransitionEasing);
        this.mPathMotionArc = keyPosition.mPathMotionArc;
    }

    /* access modifiers changed from: package-private */
    public void initPath(KeyPosition keyPosition, MotionPaths motionPaths, MotionPaths motionPaths2) {
        float f7 = ((float) keyPosition.mFramePosition) / 100.0f;
        this.time = f7;
        this.mDrawPath = keyPosition.mDrawPath;
        float f8 = Float.isNaN(keyPosition.mPercentWidth) ? f7 : keyPosition.mPercentWidth;
        float f9 = Float.isNaN(keyPosition.mPercentHeight) ? f7 : keyPosition.mPercentHeight;
        float f10 = motionPaths2.width - motionPaths.width;
        float f11 = motionPaths2.height - motionPaths.height;
        this.position = this.time;
        if (!Float.isNaN(keyPosition.mPercentX)) {
            f7 = keyPosition.mPercentX;
        }
        float f12 = motionPaths.f502x;
        float f13 = motionPaths.width;
        float f14 = motionPaths.f503y;
        float f15 = motionPaths.height;
        float f16 = (motionPaths2.f502x + (motionPaths2.width / 2.0f)) - ((f13 / 2.0f) + f12);
        float f17 = (motionPaths2.f503y + (motionPaths2.height / 2.0f)) - ((f15 / 2.0f) + f14);
        float f18 = f16 * f7;
        float f19 = f10 * f8;
        float f20 = f19 / 2.0f;
        this.f502x = (float) ((int) ((f12 + f18) - f20));
        float f21 = f7 * f17;
        float f22 = f11 * f9;
        float f23 = f22 / 2.0f;
        this.f503y = (float) ((int) ((f14 + f21) - f23));
        this.width = (float) ((int) (f13 + f19));
        this.height = (float) ((int) (f15 + f22));
        float f24 = Float.isNaN(keyPosition.mPercentY) ? 0.0f : keyPosition.mPercentY;
        this.mMode = 1;
        float f25 = (float) ((int) ((motionPaths.f502x + f18) - f20));
        float f26 = (float) ((int) ((motionPaths.f503y + f21) - f23));
        this.f502x = f25 + ((-f17) * f24);
        this.f503y = f26 + (f16 * f24);
        this.mKeyFrameEasing = Easing.getInterpolator(keyPosition.mTransitionEasing);
        this.mPathMotionArc = keyPosition.mPathMotionArc;
    }

    /* access modifiers changed from: package-private */
    public void initScreen(int i7, int i8, KeyPosition keyPosition, MotionPaths motionPaths, MotionPaths motionPaths2) {
        float f7 = ((float) keyPosition.mFramePosition) / 100.0f;
        this.time = f7;
        this.mDrawPath = keyPosition.mDrawPath;
        float f8 = Float.isNaN(keyPosition.mPercentWidth) ? f7 : keyPosition.mPercentWidth;
        float f9 = Float.isNaN(keyPosition.mPercentHeight) ? f7 : keyPosition.mPercentHeight;
        float f10 = motionPaths2.width;
        float f11 = motionPaths.width;
        float f12 = motionPaths2.height;
        float f13 = motionPaths.height;
        this.position = this.time;
        float f14 = motionPaths.f502x;
        float f15 = motionPaths.f503y;
        float f16 = motionPaths2.f502x + (f10 / 2.0f);
        float f17 = motionPaths2.f503y + (f12 / 2.0f);
        float f18 = (f10 - f11) * f8;
        this.f502x = (float) ((int) ((f14 + ((f16 - ((f11 / 2.0f) + f14)) * f7)) - (f18 / 2.0f)));
        float f19 = (f12 - f13) * f9;
        this.f503y = (float) ((int) ((f15 + ((f17 - (f15 + (f13 / 2.0f))) * f7)) - (f19 / 2.0f)));
        this.width = (float) ((int) (f11 + f18));
        this.height = (float) ((int) (f13 + f19));
        this.mMode = 3;
        if (!Float.isNaN(keyPosition.mPercentX)) {
            this.f502x = (float) ((int) (keyPosition.mPercentX * ((float) ((int) (((float) i7) - this.width)))));
        }
        if (!Float.isNaN(keyPosition.mPercentY)) {
            this.f503y = (float) ((int) (keyPosition.mPercentY * ((float) ((int) (((float) i8) - this.height)))));
        }
        this.mKeyFrameEasing = Easing.getInterpolator(keyPosition.mTransitionEasing);
        this.mPathMotionArc = keyPosition.mPathMotionArc;
    }

    /* access modifiers changed from: package-private */
    public void setBounds(float f7, float f8, float f9, float f10) {
        this.f502x = f7;
        this.f503y = f8;
        this.width = f9;
        this.height = f10;
    }

    /* access modifiers changed from: package-private */
    public void setDpDt(float f7, float f8, float[] fArr, int[] iArr, double[] dArr, double[] dArr2) {
        float f9 = 0.0f;
        float f10 = 0.0f;
        float f11 = 0.0f;
        float f12 = 0.0f;
        for (int i7 = 0; i7 < iArr.length; i7++) {
            float f13 = (float) dArr[i7];
            double d7 = dArr2[i7];
            int i8 = iArr[i7];
            if (i8 == 1) {
                f9 = f13;
            } else if (i8 == 2) {
                f11 = f13;
            } else if (i8 == 3) {
                f10 = f13;
            } else if (i8 == 4) {
                f12 = f13;
            }
        }
        float f14 = f9 - ((0.0f * f10) / 2.0f);
        float f15 = f11 - ((0.0f * f12) / 2.0f);
        fArr[0] = (f14 * (1.0f - f7)) + (((f10 * 1.0f) + f14) * f7) + 0.0f;
        fArr[1] = (f15 * (1.0f - f8)) + (((f12 * 1.0f) + f15) * f8) + 0.0f;
    }

    /* access modifiers changed from: package-private */
    /* JADX WARNING: Code restructure failed: missing block: B:42:0x00af, code lost:
        if (java.lang.Float.isNaN(Float.NaN) == false) goto L_0x00b1;
     */
    public void setView(View view, int[] iArr, double[] dArr, double[] dArr2, double[] dArr3) {
        float degrees;
        boolean z7;
        float f7 = this.f502x;
        float f8 = this.f503y;
        float f9 = this.width;
        float f10 = this.height;
        boolean z8 = true;
        if (iArr.length != 0 && this.mTempValue.length <= iArr[iArr.length - 1]) {
            int i7 = iArr[iArr.length - 1] + 1;
            this.mTempValue = new double[i7];
            this.mTempDelta = new double[i7];
        }
        Arrays.fill(this.mTempValue, Double.NaN);
        for (int i8 = 0; i8 < iArr.length; i8++) {
            double[] dArr4 = this.mTempValue;
            int i9 = iArr[i8];
            dArr4[i9] = dArr[i8];
            this.mTempDelta[i9] = dArr2[i8];
        }
        int i10 = 0;
        float f11 = Float.NaN;
        float f12 = 0.0f;
        float f13 = 0.0f;
        float f14 = 0.0f;
        float f15 = 0.0f;
        while (true) {
            double[] dArr5 = this.mTempValue;
            if (i10 >= dArr5.length) {
                break;
            }
            double d7 = 0.0d;
            if (!Double.isNaN(dArr5[i10]) || !(dArr3 == null || dArr3[i10] == 0.0d)) {
                if (dArr3 != null) {
                    d7 = dArr3[i10];
                }
                if (!Double.isNaN(this.mTempValue[i10])) {
                    d7 = this.mTempValue[i10] + d7;
                }
                float f16 = (float) d7;
                float f17 = (float) this.mTempDelta[i10];
                z7 = true;
                if (i10 == 1) {
                    f7 = f16;
                    f12 = f17;
                } else if (i10 == 2) {
                    f8 = f16;
                    f14 = f17;
                } else if (i10 == 3) {
                    f9 = f16;
                    f13 = f17;
                } else if (i10 == 4) {
                    f10 = f16;
                    f15 = f17;
                } else if (i10 == 5) {
                    f11 = f16;
                }
            } else {
                z7 = z8;
            }
            i10++;
            z8 = z7;
        }
        if (Float.isNaN(f11)) {
            degrees = Float.NaN;
        } else {
            float f18 = Float.NaN;
            if (Float.isNaN(Float.NaN)) {
                f18 = 0.0f;
            }
            degrees = (float) (((double) f18) + ((double) f11) + Math.toDegrees(Math.atan2((double) (f14 + (f15 / 2.0f)), (double) (f12 + (f13 / 2.0f)))));
        }
        view.setRotation(degrees);
        float f19 = f7 + 0.5f;
        int i11 = (int) f19;
        float f20 = f8 + 0.5f;
        int i12 = (int) f20;
        int i13 = (int) (f19 + f9);
        int i14 = (int) (f20 + f10);
        int i15 = i13 - i11;
        int i16 = i14 - i12;
        if ((i15 == view.getMeasuredWidth() && i16 == view.getMeasuredHeight()) ? false : z8) {
            view.measure(View.MeasureSpec.makeMeasureSpec(i15, 1073741824), View.MeasureSpec.makeMeasureSpec(i16, 1073741824));
        }
        view.layout(i11, i12, i13, i14);
    }

    public MotionPaths(int i7, int i8, KeyPosition keyPosition, MotionPaths motionPaths, MotionPaths motionPaths2) {
        this.mDrawPath = 0;
        this.mPathRotate = Float.NaN;
        this.mProgress = Float.NaN;
        this.mPathMotionArc = Key.UNSET;
        this.attributes = new LinkedHashMap<>();
        this.mMode = 0;
        this.mTempValue = new double[18];
        this.mTempDelta = new double[18];
        int i9 = keyPosition.mPositionType;
        if (i9 == 1) {
            initPath(keyPosition, motionPaths, motionPaths2);
        } else if (i9 != 2) {
            initCartesian(keyPosition, motionPaths, motionPaths2);
        } else {
            initScreen(i7, i8, keyPosition, motionPaths, motionPaths2);
        }
    }
}
