package androidx.constraintlayout.widget;

import android.annotation.SuppressLint;
import android.annotation.TargetApi;
import android.content.Context;
import android.content.res.Resources;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.util.AttributeSet;
import android.util.Log;
import android.util.SparseArray;
import android.util.SparseIntArray;
import android.view.View;
import android.view.ViewGroup;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.constraintlayout.solver.Metrics;
import androidx.constraintlayout.solver.widgets.ConstraintAnchor;
import androidx.constraintlayout.solver.widgets.ConstraintWidget;
import androidx.constraintlayout.solver.widgets.ConstraintWidgetContainer;
import androidx.constraintlayout.solver.widgets.Guideline;
import androidx.constraintlayout.solver.widgets.Optimizer;
import androidx.constraintlayout.solver.widgets.VirtualLayout;
import androidx.constraintlayout.solver.widgets.analyzer.BasicMeasure;
import androidx.core.internal.view.SupportMenu;
import androidx.core.view.ViewCompat;
import java.util.ArrayList;
import java.util.HashMap;

public class ConstraintLayout extends ViewGroup {
    private static final boolean DEBUG = false;
    private static final boolean DEBUG_DRAW_CONSTRAINTS = false;
    public static final int DESIGN_INFO_ID = 0;
    private static final boolean MEASURE = false;
    private static final String TAG = "ConstraintLayout";
    private static final boolean USE_CONSTRAINTS_HELPER = true;
    public static final String VERSION = "ConstraintLayout-2.0.4";
    SparseArray<View> mChildrenByIds = new SparseArray<>();
    private ArrayList<ConstraintHelper> mConstraintHelpers = new ArrayList<>(4);
    protected ConstraintLayoutStates mConstraintLayoutSpec = null;
    private ConstraintSet mConstraintSet = null;
    private int mConstraintSetId = -1;
    private ConstraintsChangedListener mConstraintsChangedListener;
    private HashMap<String, Integer> mDesignIds = new HashMap<>();
    protected boolean mDirtyHierarchy = true;
    private int mLastMeasureHeight = -1;
    int mLastMeasureHeightMode = 0;
    int mLastMeasureHeightSize = -1;
    private int mLastMeasureWidth = -1;
    int mLastMeasureWidthMode = 0;
    int mLastMeasureWidthSize = -1;
    protected ConstraintWidgetContainer mLayoutWidget = new ConstraintWidgetContainer();
    private int mMaxHeight = Integer.MAX_VALUE;
    private int mMaxWidth = Integer.MAX_VALUE;
    Measurer mMeasurer = new Measurer(this);
    private Metrics mMetrics;
    private int mMinHeight = 0;
    private int mMinWidth = 0;
    private int mOnMeasureHeightMeasureSpec = 0;
    private int mOnMeasureWidthMeasureSpec = 0;
    private int mOptimizationLevel = 257;
    private SparseArray<ConstraintWidget> mTempMapIdToWidget = new SparseArray<>();

    /* renamed from: androidx.constraintlayout.widget.ConstraintLayout$1  reason: invalid class name */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$androidx$constraintlayout$solver$widgets$ConstraintWidget$DimensionBehaviour;

        /* JADX WARNING: Can't wrap try/catch for region: R(8:0|1|2|3|4|5|6|(3:7|8|10)) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x0012 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:5:0x001d */
        /* JADX WARNING: Missing exception handler attribute for start block: B:7:0x0028 */
        static {
            int[] iArr = new int[ConstraintWidget.DimensionBehaviour.values().length];
            $SwitchMap$androidx$constraintlayout$solver$widgets$ConstraintWidget$DimensionBehaviour = iArr;
            iArr[ConstraintWidget.DimensionBehaviour.FIXED.ordinal()] = 1;
            $SwitchMap$androidx$constraintlayout$solver$widgets$ConstraintWidget$DimensionBehaviour[ConstraintWidget.DimensionBehaviour.WRAP_CONTENT.ordinal()] = 2;
            $SwitchMap$androidx$constraintlayout$solver$widgets$ConstraintWidget$DimensionBehaviour[ConstraintWidget.DimensionBehaviour.MATCH_PARENT.ordinal()] = 3;
            try {
                $SwitchMap$androidx$constraintlayout$solver$widgets$ConstraintWidget$DimensionBehaviour[ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT.ordinal()] = 4;
            } catch (NoSuchFieldError unused) {
            }
        }
    }

    public static class LayoutParams extends ViewGroup.MarginLayoutParams {
        public static final int BASELINE = 5;
        public static final int BOTTOM = 4;
        public static final int CHAIN_PACKED = 2;
        public static final int CHAIN_SPREAD = 0;
        public static final int CHAIN_SPREAD_INSIDE = 1;
        public static final int END = 7;
        public static final int HORIZONTAL = 0;
        public static final int LEFT = 1;
        public static final int MATCH_CONSTRAINT = 0;
        public static final int MATCH_CONSTRAINT_PERCENT = 2;
        public static final int MATCH_CONSTRAINT_SPREAD = 0;
        public static final int MATCH_CONSTRAINT_WRAP = 1;
        public static final int PARENT_ID = 0;
        public static final int RIGHT = 2;
        public static final int START = 6;
        public static final int TOP = 3;
        public static final int UNSET = -1;
        public static final int VERTICAL = 1;
        public int baselineToBaseline = -1;
        public int bottomToBottom = -1;
        public int bottomToTop = -1;
        public float circleAngle = 0.0f;
        public int circleConstraint = -1;
        public int circleRadius = 0;
        public boolean constrainedHeight = false;
        public boolean constrainedWidth = false;
        public String constraintTag = null;
        public String dimensionRatio = null;
        int dimensionRatioSide = 1;
        float dimensionRatioValue = 0.0f;
        public int editorAbsoluteX = -1;
        public int editorAbsoluteY = -1;
        public int endToEnd = -1;
        public int endToStart = -1;
        public int goneBottomMargin = -1;
        public int goneEndMargin = -1;
        public int goneLeftMargin = -1;
        public int goneRightMargin = -1;
        public int goneStartMargin = -1;
        public int goneTopMargin = -1;
        public int guideBegin = -1;
        public int guideEnd = -1;
        public float guidePercent = -1.0f;
        public boolean helped = false;
        public float horizontalBias = 0.5f;
        public int horizontalChainStyle = 0;
        boolean horizontalDimensionFixed = true;
        public float horizontalWeight = -1.0f;
        boolean isGuideline = false;
        boolean isHelper = false;
        boolean isInPlaceholder = false;
        boolean isVirtualGroup = false;
        public int leftToLeft = -1;
        public int leftToRight = -1;
        public int matchConstraintDefaultHeight = 0;
        public int matchConstraintDefaultWidth = 0;
        public int matchConstraintMaxHeight = 0;
        public int matchConstraintMaxWidth = 0;
        public int matchConstraintMinHeight = 0;
        public int matchConstraintMinWidth = 0;
        public float matchConstraintPercentHeight = 1.0f;
        public float matchConstraintPercentWidth = 1.0f;
        boolean needsBaseline = false;
        public int orientation = -1;
        int resolveGoneLeftMargin = -1;
        int resolveGoneRightMargin = -1;
        int resolvedGuideBegin;
        int resolvedGuideEnd;
        float resolvedGuidePercent;
        float resolvedHorizontalBias = 0.5f;
        int resolvedLeftToLeft = -1;
        int resolvedLeftToRight = -1;
        int resolvedRightToLeft = -1;
        int resolvedRightToRight = -1;
        public int rightToLeft = -1;
        public int rightToRight = -1;
        public int startToEnd = -1;
        public int startToStart = -1;
        public int topToBottom = -1;
        public int topToTop = -1;
        public float verticalBias = 0.5f;
        public int verticalChainStyle = 0;
        boolean verticalDimensionFixed = true;
        public float verticalWeight = -1.0f;
        ConstraintWidget widget = new ConstraintWidget();

        private static class Table {
            public static final int ANDROID_ORIENTATION = 1;
            public static final int LAYOUT_CONSTRAINED_HEIGHT = 28;
            public static final int LAYOUT_CONSTRAINED_WIDTH = 27;
            public static final int LAYOUT_CONSTRAINT_BASELINE_CREATOR = 43;
            public static final int LAYOUT_CONSTRAINT_BASELINE_TO_BASELINE_OF = 16;
            public static final int LAYOUT_CONSTRAINT_BOTTOM_CREATOR = 42;
            public static final int LAYOUT_CONSTRAINT_BOTTOM_TO_BOTTOM_OF = 15;
            public static final int LAYOUT_CONSTRAINT_BOTTOM_TO_TOP_OF = 14;
            public static final int LAYOUT_CONSTRAINT_CIRCLE = 2;
            public static final int LAYOUT_CONSTRAINT_CIRCLE_ANGLE = 4;
            public static final int LAYOUT_CONSTRAINT_CIRCLE_RADIUS = 3;
            public static final int LAYOUT_CONSTRAINT_DIMENSION_RATIO = 44;
            public static final int LAYOUT_CONSTRAINT_END_TO_END_OF = 20;
            public static final int LAYOUT_CONSTRAINT_END_TO_START_OF = 19;
            public static final int LAYOUT_CONSTRAINT_GUIDE_BEGIN = 5;
            public static final int LAYOUT_CONSTRAINT_GUIDE_END = 6;
            public static final int LAYOUT_CONSTRAINT_GUIDE_PERCENT = 7;
            public static final int LAYOUT_CONSTRAINT_HEIGHT_DEFAULT = 32;
            public static final int LAYOUT_CONSTRAINT_HEIGHT_MAX = 37;
            public static final int LAYOUT_CONSTRAINT_HEIGHT_MIN = 36;
            public static final int LAYOUT_CONSTRAINT_HEIGHT_PERCENT = 38;
            public static final int LAYOUT_CONSTRAINT_HORIZONTAL_BIAS = 29;
            public static final int LAYOUT_CONSTRAINT_HORIZONTAL_CHAINSTYLE = 47;
            public static final int LAYOUT_CONSTRAINT_HORIZONTAL_WEIGHT = 45;
            public static final int LAYOUT_CONSTRAINT_LEFT_CREATOR = 39;
            public static final int LAYOUT_CONSTRAINT_LEFT_TO_LEFT_OF = 8;
            public static final int LAYOUT_CONSTRAINT_LEFT_TO_RIGHT_OF = 9;
            public static final int LAYOUT_CONSTRAINT_RIGHT_CREATOR = 41;
            public static final int LAYOUT_CONSTRAINT_RIGHT_TO_LEFT_OF = 10;
            public static final int LAYOUT_CONSTRAINT_RIGHT_TO_RIGHT_OF = 11;
            public static final int LAYOUT_CONSTRAINT_START_TO_END_OF = 17;
            public static final int LAYOUT_CONSTRAINT_START_TO_START_OF = 18;
            public static final int LAYOUT_CONSTRAINT_TAG = 51;
            public static final int LAYOUT_CONSTRAINT_TOP_CREATOR = 40;
            public static final int LAYOUT_CONSTRAINT_TOP_TO_BOTTOM_OF = 13;
            public static final int LAYOUT_CONSTRAINT_TOP_TO_TOP_OF = 12;
            public static final int LAYOUT_CONSTRAINT_VERTICAL_BIAS = 30;
            public static final int LAYOUT_CONSTRAINT_VERTICAL_CHAINSTYLE = 48;
            public static final int LAYOUT_CONSTRAINT_VERTICAL_WEIGHT = 46;
            public static final int LAYOUT_CONSTRAINT_WIDTH_DEFAULT = 31;
            public static final int LAYOUT_CONSTRAINT_WIDTH_MAX = 34;
            public static final int LAYOUT_CONSTRAINT_WIDTH_MIN = 33;
            public static final int LAYOUT_CONSTRAINT_WIDTH_PERCENT = 35;
            public static final int LAYOUT_EDITOR_ABSOLUTEX = 49;
            public static final int LAYOUT_EDITOR_ABSOLUTEY = 50;
            public static final int LAYOUT_GONE_MARGIN_BOTTOM = 24;
            public static final int LAYOUT_GONE_MARGIN_END = 26;
            public static final int LAYOUT_GONE_MARGIN_LEFT = 21;
            public static final int LAYOUT_GONE_MARGIN_RIGHT = 23;
            public static final int LAYOUT_GONE_MARGIN_START = 25;
            public static final int LAYOUT_GONE_MARGIN_TOP = 22;
            public static final int UNUSED = 0;
            public static final SparseIntArray map;

            static {
                SparseIntArray sparseIntArray = new SparseIntArray();
                map = sparseIntArray;
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintLeft_toLeftOf, 8);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintLeft_toRightOf, 9);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintRight_toLeftOf, 10);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintRight_toRightOf, 11);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintTop_toTopOf, 12);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintTop_toBottomOf, 13);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintBottom_toTopOf, 14);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintBottom_toBottomOf, 15);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintBaseline_toBaselineOf, 16);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintCircle, 2);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintCircleRadius, 3);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintCircleAngle, 4);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_editor_absoluteX, 49);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_editor_absoluteY, 50);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintGuide_begin, 5);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintGuide_end, 6);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintGuide_percent, 7);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_android_orientation, 1);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintStart_toEndOf, 17);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintStart_toStartOf, 18);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintEnd_toStartOf, 19);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintEnd_toEndOf, 20);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_goneMarginLeft, 21);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_goneMarginTop, 22);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_goneMarginRight, 23);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_goneMarginBottom, 24);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_goneMarginStart, 25);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_goneMarginEnd, 26);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintHorizontal_bias, 29);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintVertical_bias, 30);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintDimensionRatio, 44);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintHorizontal_weight, 45);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintVertical_weight, 46);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintHorizontal_chainStyle, 47);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintVertical_chainStyle, 48);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constrainedWidth, 27);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constrainedHeight, 28);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintWidth_default, 31);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintHeight_default, 32);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintWidth_min, 33);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintWidth_max, 34);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintWidth_percent, 35);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintHeight_min, 36);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintHeight_max, 37);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintHeight_percent, 38);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintLeft_creator, 39);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintTop_creator, 40);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintRight_creator, 41);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintBottom_creator, 42);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintBaseline_creator, 43);
                sparseIntArray.append(R.styleable.ConstraintLayout_Layout_layout_constraintTag, 51);
            }

            private Table() {
            }
        }

        public LayoutParams(int i7, int i8) {
            super(i7, i8);
        }

        public String getConstraintTag() {
            return this.constraintTag;
        }

        public ConstraintWidget getConstraintWidget() {
            return this.widget;
        }

        public void reset() {
            ConstraintWidget constraintWidget = this.widget;
            if (constraintWidget != null) {
                constraintWidget.reset();
            }
        }

        /* JADX WARNING: Code restructure failed: missing block: B:70:0x00ca, code lost:
            if (r1 > 0) goto L_0x00cc;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:76:0x00d9, code lost:
            if (r1 > 0) goto L_0x00cc;
         */
        /* JADX WARNING: Removed duplicated region for block: B:15:0x0048  */
        /* JADX WARNING: Removed duplicated region for block: B:18:0x004f  */
        /* JADX WARNING: Removed duplicated region for block: B:21:0x0056  */
        /* JADX WARNING: Removed duplicated region for block: B:24:0x005c  */
        /* JADX WARNING: Removed duplicated region for block: B:27:0x0062  */
        /* JADX WARNING: Removed duplicated region for block: B:34:0x0074  */
        /* JADX WARNING: Removed duplicated region for block: B:35:0x007c  */
        /* JADX WARNING: Removed duplicated region for block: B:79:0x00e0  */
        /* JADX WARNING: Removed duplicated region for block: B:83:0x00eb  */
        @TargetApi(17)
        public void resolveLayoutDirection(int i7) {
            int i8;
            int i9;
            int i10;
            int i11;
            int i12;
            int i13 = ((ViewGroup.MarginLayoutParams) this).leftMargin;
            int i14 = ((ViewGroup.MarginLayoutParams) this).rightMargin;
            super.resolveLayoutDirection(i7);
            boolean z7 = false;
            boolean z8 = 1 == getLayoutDirection();
            this.resolvedRightToLeft = -1;
            this.resolvedRightToRight = -1;
            this.resolvedLeftToLeft = -1;
            this.resolvedLeftToRight = -1;
            this.resolveGoneLeftMargin = this.goneLeftMargin;
            this.resolveGoneRightMargin = this.goneRightMargin;
            float f7 = this.horizontalBias;
            this.resolvedHorizontalBias = f7;
            int i15 = this.guideBegin;
            this.resolvedGuideBegin = i15;
            int i16 = this.guideEnd;
            this.resolvedGuideEnd = i16;
            float f8 = this.guidePercent;
            this.resolvedGuidePercent = f8;
            if (z8) {
                int i17 = this.startToEnd;
                if (i17 != -1) {
                    this.resolvedRightToLeft = i17;
                } else {
                    int i18 = this.startToStart;
                    if (i18 != -1) {
                        this.resolvedRightToRight = i18;
                    }
                    i9 = this.endToStart;
                    if (i9 != -1) {
                        this.resolvedLeftToRight = i9;
                        z7 = true;
                    }
                    i10 = this.endToEnd;
                    if (i10 != -1) {
                        this.resolvedLeftToLeft = i10;
                        z7 = true;
                    }
                    i11 = this.goneStartMargin;
                    if (i11 != -1) {
                        this.resolveGoneRightMargin = i11;
                    }
                    i12 = this.goneEndMargin;
                    if (i12 != -1) {
                        this.resolveGoneLeftMargin = i12;
                    }
                    if (z7) {
                        this.resolvedHorizontalBias = 1.0f - f7;
                    }
                    if (this.isGuideline && this.orientation == 1) {
                        if (f8 == -1.0f) {
                            this.resolvedGuidePercent = 1.0f - f8;
                            this.resolvedGuideBegin = -1;
                            this.resolvedGuideEnd = -1;
                        } else {
                            if (i15 != -1) {
                                this.resolvedGuideEnd = i15;
                                this.resolvedGuideBegin = -1;
                            } else if (i16 != -1) {
                                this.resolvedGuideBegin = i16;
                                this.resolvedGuideEnd = -1;
                            }
                            this.resolvedGuidePercent = -1.0f;
                        }
                    }
                }
                z7 = true;
                i9 = this.endToStart;
                if (i9 != -1) {
                }
                i10 = this.endToEnd;
                if (i10 != -1) {
                }
                i11 = this.goneStartMargin;
                if (i11 != -1) {
                }
                i12 = this.goneEndMargin;
                if (i12 != -1) {
                }
                if (z7) {
                }
                if (f8 == -1.0f) {
                }
            } else {
                int i19 = this.startToEnd;
                if (i19 != -1) {
                    this.resolvedLeftToRight = i19;
                }
                int i20 = this.startToStart;
                if (i20 != -1) {
                    this.resolvedLeftToLeft = i20;
                }
                int i21 = this.endToStart;
                if (i21 != -1) {
                    this.resolvedRightToLeft = i21;
                }
                int i22 = this.endToEnd;
                if (i22 != -1) {
                    this.resolvedRightToRight = i22;
                }
                int i23 = this.goneStartMargin;
                if (i23 != -1) {
                    this.resolveGoneLeftMargin = i23;
                }
                int i24 = this.goneEndMargin;
                if (i24 != -1) {
                    this.resolveGoneRightMargin = i24;
                }
            }
            if (this.endToStart == -1 && this.endToEnd == -1 && this.startToStart == -1 && this.startToEnd == -1) {
                int i25 = this.rightToLeft;
                if (i25 != -1) {
                    this.resolvedRightToLeft = i25;
                    if (((ViewGroup.MarginLayoutParams) this).rightMargin <= 0) {
                    }
                    i8 = this.leftToLeft;
                    if (i8 != -1) {
                        this.resolvedLeftToLeft = i8;
                        if (((ViewGroup.MarginLayoutParams) this).leftMargin > 0 || i13 <= 0) {
                            return;
                        }
                    } else {
                        int i26 = this.leftToRight;
                        if (i26 != -1) {
                            this.resolvedLeftToRight = i26;
                            if (((ViewGroup.MarginLayoutParams) this).leftMargin > 0 || i13 <= 0) {
                                return;
                            }
                        } else {
                            return;
                        }
                    }
                    ((ViewGroup.MarginLayoutParams) this).leftMargin = i13;
                }
                int i27 = this.rightToRight;
                if (i27 != -1) {
                    this.resolvedRightToRight = i27;
                    if (((ViewGroup.MarginLayoutParams) this).rightMargin <= 0) {
                    }
                }
                i8 = this.leftToLeft;
                if (i8 != -1) {
                }
                ((ViewGroup.MarginLayoutParams) this).leftMargin = i13;
                ((ViewGroup.MarginLayoutParams) this).rightMargin = i14;
                i8 = this.leftToLeft;
                if (i8 != -1) {
                }
                ((ViewGroup.MarginLayoutParams) this).leftMargin = i13;
            }
        }

        public void setWidgetDebugName(String str) {
            this.widget.setDebugName(str);
        }

        public void validate() {
            this.isGuideline = false;
            this.horizontalDimensionFixed = true;
            this.verticalDimensionFixed = true;
            int i7 = ((ViewGroup.MarginLayoutParams) this).width;
            if (i7 == -2 && this.constrainedWidth) {
                this.horizontalDimensionFixed = false;
                if (this.matchConstraintDefaultWidth == 0) {
                    this.matchConstraintDefaultWidth = 1;
                }
            }
            int i8 = ((ViewGroup.MarginLayoutParams) this).height;
            if (i8 == -2 && this.constrainedHeight) {
                this.verticalDimensionFixed = false;
                if (this.matchConstraintDefaultHeight == 0) {
                    this.matchConstraintDefaultHeight = 1;
                }
            }
            if (i7 == 0 || i7 == -1) {
                this.horizontalDimensionFixed = false;
                if (i7 == 0 && this.matchConstraintDefaultWidth == 1) {
                    ((ViewGroup.MarginLayoutParams) this).width = -2;
                    this.constrainedWidth = true;
                }
            }
            if (i8 == 0 || i8 == -1) {
                this.verticalDimensionFixed = false;
                if (i8 == 0 && this.matchConstraintDefaultHeight == 1) {
                    ((ViewGroup.MarginLayoutParams) this).height = -2;
                    this.constrainedHeight = true;
                }
            }
            if (this.guidePercent != -1.0f || this.guideBegin != -1 || this.guideEnd != -1) {
                this.isGuideline = true;
                this.horizontalDimensionFixed = true;
                this.verticalDimensionFixed = true;
                if (!(this.widget instanceof Guideline)) {
                    this.widget = new Guideline();
                }
                ((Guideline) this.widget).setOrientation(this.orientation);
            }
        }

        public LayoutParams(Context context, AttributeSet attributeSet) {
            super(context, attributeSet);
            String str;
            int i7;
            float parseFloat;
            TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, R.styleable.ConstraintLayout_Layout);
            int indexCount = obtainStyledAttributes.getIndexCount();
            for (int i8 = 0; i8 < indexCount; i8++) {
                int index = obtainStyledAttributes.getIndex(i8);
                int i9 = Table.map.get(index);
                switch (i9) {
                    case 1:
                        this.orientation = obtainStyledAttributes.getInt(index, this.orientation);
                        continue;
                    case 2:
                        int resourceId = obtainStyledAttributes.getResourceId(index, this.circleConstraint);
                        this.circleConstraint = resourceId;
                        if (resourceId == -1) {
                            this.circleConstraint = obtainStyledAttributes.getInt(index, -1);
                        } else {
                            continue;
                        }
                    case 3:
                        this.circleRadius = obtainStyledAttributes.getDimensionPixelSize(index, this.circleRadius);
                        continue;
                    case 4:
                        float f7 = obtainStyledAttributes.getFloat(index, this.circleAngle) % 360.0f;
                        this.circleAngle = f7;
                        if (f7 < 0.0f) {
                            this.circleAngle = (360.0f - f7) % 360.0f;
                        } else {
                            continue;
                        }
                    case 5:
                        this.guideBegin = obtainStyledAttributes.getDimensionPixelOffset(index, this.guideBegin);
                        continue;
                    case 6:
                        this.guideEnd = obtainStyledAttributes.getDimensionPixelOffset(index, this.guideEnd);
                        continue;
                    case 7:
                        this.guidePercent = obtainStyledAttributes.getFloat(index, this.guidePercent);
                        continue;
                    case 8:
                        int resourceId2 = obtainStyledAttributes.getResourceId(index, this.leftToLeft);
                        this.leftToLeft = resourceId2;
                        if (resourceId2 == -1) {
                            this.leftToLeft = obtainStyledAttributes.getInt(index, -1);
                        } else {
                            continue;
                        }
                    case 9:
                        int resourceId3 = obtainStyledAttributes.getResourceId(index, this.leftToRight);
                        this.leftToRight = resourceId3;
                        if (resourceId3 == -1) {
                            this.leftToRight = obtainStyledAttributes.getInt(index, -1);
                        } else {
                            continue;
                        }
                    case 10:
                        int resourceId4 = obtainStyledAttributes.getResourceId(index, this.rightToLeft);
                        this.rightToLeft = resourceId4;
                        if (resourceId4 == -1) {
                            this.rightToLeft = obtainStyledAttributes.getInt(index, -1);
                        } else {
                            continue;
                        }
                    case 11:
                        int resourceId5 = obtainStyledAttributes.getResourceId(index, this.rightToRight);
                        this.rightToRight = resourceId5;
                        if (resourceId5 == -1) {
                            this.rightToRight = obtainStyledAttributes.getInt(index, -1);
                        } else {
                            continue;
                        }
                    case 12:
                        int resourceId6 = obtainStyledAttributes.getResourceId(index, this.topToTop);
                        this.topToTop = resourceId6;
                        if (resourceId6 == -1) {
                            this.topToTop = obtainStyledAttributes.getInt(index, -1);
                        } else {
                            continue;
                        }
                    case 13:
                        int resourceId7 = obtainStyledAttributes.getResourceId(index, this.topToBottom);
                        this.topToBottom = resourceId7;
                        if (resourceId7 == -1) {
                            this.topToBottom = obtainStyledAttributes.getInt(index, -1);
                        } else {
                            continue;
                        }
                    case 14:
                        int resourceId8 = obtainStyledAttributes.getResourceId(index, this.bottomToTop);
                        this.bottomToTop = resourceId8;
                        if (resourceId8 == -1) {
                            this.bottomToTop = obtainStyledAttributes.getInt(index, -1);
                        } else {
                            continue;
                        }
                    case 15:
                        int resourceId9 = obtainStyledAttributes.getResourceId(index, this.bottomToBottom);
                        this.bottomToBottom = resourceId9;
                        if (resourceId9 == -1) {
                            this.bottomToBottom = obtainStyledAttributes.getInt(index, -1);
                        } else {
                            continue;
                        }
                    case 16:
                        int resourceId10 = obtainStyledAttributes.getResourceId(index, this.baselineToBaseline);
                        this.baselineToBaseline = resourceId10;
                        if (resourceId10 == -1) {
                            this.baselineToBaseline = obtainStyledAttributes.getInt(index, -1);
                        } else {
                            continue;
                        }
                    case 17:
                        int resourceId11 = obtainStyledAttributes.getResourceId(index, this.startToEnd);
                        this.startToEnd = resourceId11;
                        if (resourceId11 == -1) {
                            this.startToEnd = obtainStyledAttributes.getInt(index, -1);
                        } else {
                            continue;
                        }
                    case 18:
                        int resourceId12 = obtainStyledAttributes.getResourceId(index, this.startToStart);
                        this.startToStart = resourceId12;
                        if (resourceId12 == -1) {
                            this.startToStart = obtainStyledAttributes.getInt(index, -1);
                        } else {
                            continue;
                        }
                    case 19:
                        int resourceId13 = obtainStyledAttributes.getResourceId(index, this.endToStart);
                        this.endToStart = resourceId13;
                        if (resourceId13 == -1) {
                            this.endToStart = obtainStyledAttributes.getInt(index, -1);
                        } else {
                            continue;
                        }
                    case 20:
                        int resourceId14 = obtainStyledAttributes.getResourceId(index, this.endToEnd);
                        this.endToEnd = resourceId14;
                        if (resourceId14 == -1) {
                            this.endToEnd = obtainStyledAttributes.getInt(index, -1);
                        } else {
                            continue;
                        }
                    case 21:
                        this.goneLeftMargin = obtainStyledAttributes.getDimensionPixelSize(index, this.goneLeftMargin);
                        continue;
                    case 22:
                        this.goneTopMargin = obtainStyledAttributes.getDimensionPixelSize(index, this.goneTopMargin);
                        continue;
                    case 23:
                        this.goneRightMargin = obtainStyledAttributes.getDimensionPixelSize(index, this.goneRightMargin);
                        continue;
                    case 24:
                        this.goneBottomMargin = obtainStyledAttributes.getDimensionPixelSize(index, this.goneBottomMargin);
                        continue;
                    case 25:
                        this.goneStartMargin = obtainStyledAttributes.getDimensionPixelSize(index, this.goneStartMargin);
                        continue;
                    case 26:
                        this.goneEndMargin = obtainStyledAttributes.getDimensionPixelSize(index, this.goneEndMargin);
                        continue;
                    case 27:
                        this.constrainedWidth = obtainStyledAttributes.getBoolean(index, this.constrainedWidth);
                        continue;
                    case 28:
                        this.constrainedHeight = obtainStyledAttributes.getBoolean(index, this.constrainedHeight);
                        continue;
                    case 29:
                        this.horizontalBias = obtainStyledAttributes.getFloat(index, this.horizontalBias);
                        continue;
                    case 30:
                        this.verticalBias = obtainStyledAttributes.getFloat(index, this.verticalBias);
                        continue;
                    case 31:
                        int i10 = obtainStyledAttributes.getInt(index, 0);
                        this.matchConstraintDefaultWidth = i10;
                        if (i10 == 1) {
                            str = "layout_constraintWidth_default=\"wrap\" is deprecated.\nUse layout_width=\"WRAP_CONTENT\" and layout_constrainedWidth=\"true\" instead.";
                            break;
                        } else {
                            continue;
                        }
                    case 32:
                        int i11 = obtainStyledAttributes.getInt(index, 0);
                        this.matchConstraintDefaultHeight = i11;
                        if (i11 == 1) {
                            str = "layout_constraintHeight_default=\"wrap\" is deprecated.\nUse layout_height=\"WRAP_CONTENT\" and layout_constrainedHeight=\"true\" instead.";
                            break;
                        } else {
                            continue;
                        }
                    case 33:
                        try {
                            this.matchConstraintMinWidth = obtainStyledAttributes.getDimensionPixelSize(index, this.matchConstraintMinWidth);
                            continue;
                        } catch (Exception unused) {
                            if (obtainStyledAttributes.getInt(index, this.matchConstraintMinWidth) == -2) {
                                this.matchConstraintMinWidth = -2;
                            }
                        }
                    case 34:
                        try {
                            this.matchConstraintMaxWidth = obtainStyledAttributes.getDimensionPixelSize(index, this.matchConstraintMaxWidth);
                            continue;
                        } catch (Exception unused2) {
                            if (obtainStyledAttributes.getInt(index, this.matchConstraintMaxWidth) == -2) {
                                this.matchConstraintMaxWidth = -2;
                            }
                        }
                    case 35:
                        this.matchConstraintPercentWidth = Math.max(0.0f, obtainStyledAttributes.getFloat(index, this.matchConstraintPercentWidth));
                        this.matchConstraintDefaultWidth = 2;
                        continue;
                    case 36:
                        try {
                            this.matchConstraintMinHeight = obtainStyledAttributes.getDimensionPixelSize(index, this.matchConstraintMinHeight);
                            continue;
                        } catch (Exception unused3) {
                            if (obtainStyledAttributes.getInt(index, this.matchConstraintMinHeight) == -2) {
                                this.matchConstraintMinHeight = -2;
                            }
                        }
                    case 37:
                        try {
                            this.matchConstraintMaxHeight = obtainStyledAttributes.getDimensionPixelSize(index, this.matchConstraintMaxHeight);
                            continue;
                        } catch (Exception unused4) {
                            if (obtainStyledAttributes.getInt(index, this.matchConstraintMaxHeight) == -2) {
                                this.matchConstraintMaxHeight = -2;
                            }
                        }
                    case 38:
                        this.matchConstraintPercentHeight = Math.max(0.0f, obtainStyledAttributes.getFloat(index, this.matchConstraintPercentHeight));
                        this.matchConstraintDefaultHeight = 2;
                        continue;
                    default:
                        switch (i9) {
                            case 44:
                                String string = obtainStyledAttributes.getString(index);
                                this.dimensionRatio = string;
                                this.dimensionRatioValue = Float.NaN;
                                this.dimensionRatioSide = -1;
                                if (string != null) {
                                    int length = string.length();
                                    int indexOf = this.dimensionRatio.indexOf(44);
                                    if (indexOf <= 0 || indexOf >= length - 1) {
                                        i7 = 0;
                                    } else {
                                        String substring = this.dimensionRatio.substring(0, indexOf);
                                        if (substring.equalsIgnoreCase("W")) {
                                            this.dimensionRatioSide = 0;
                                        } else if (substring.equalsIgnoreCase("H")) {
                                            this.dimensionRatioSide = 1;
                                        }
                                        i7 = indexOf + 1;
                                    }
                                    int indexOf2 = this.dimensionRatio.indexOf(58);
                                    if (indexOf2 >= 0 && indexOf2 < length - 1) {
                                        String substring2 = this.dimensionRatio.substring(i7, indexOf2);
                                        String substring3 = this.dimensionRatio.substring(indexOf2 + 1);
                                        if (substring2.length() > 0 && substring3.length() > 0) {
                                            try {
                                                float parseFloat2 = Float.parseFloat(substring2);
                                                float parseFloat3 = Float.parseFloat(substring3);
                                                parseFloat = (parseFloat2 > 0.0f && parseFloat3 > 0.0f) ? this.dimensionRatioSide == 1 ? Math.abs(parseFloat3 / parseFloat2) : Math.abs(parseFloat2 / parseFloat3) : parseFloat;
                                            } catch (NumberFormatException unused5) {
                                                break;
                                            }
                                        }
                                    } else {
                                        String substring4 = this.dimensionRatio.substring(i7);
                                        if (substring4.length() <= 0) {
                                            break;
                                        } else {
                                            parseFloat = Float.parseFloat(substring4);
                                        }
                                    }
                                    this.dimensionRatioValue = parseFloat;
                                    break;
                                } else {
                                    continue;
                                }
                            case 45:
                                this.horizontalWeight = obtainStyledAttributes.getFloat(index, this.horizontalWeight);
                                continue;
                            case 46:
                                this.verticalWeight = obtainStyledAttributes.getFloat(index, this.verticalWeight);
                                continue;
                            case 47:
                                this.horizontalChainStyle = obtainStyledAttributes.getInt(index, 0);
                                continue;
                            case 48:
                                this.verticalChainStyle = obtainStyledAttributes.getInt(index, 0);
                                continue;
                            case Table.LAYOUT_EDITOR_ABSOLUTEX /*{ENCODED_INT: 49}*/:
                                this.editorAbsoluteX = obtainStyledAttributes.getDimensionPixelOffset(index, this.editorAbsoluteX);
                                continue;
                            case 50:
                                this.editorAbsoluteY = obtainStyledAttributes.getDimensionPixelOffset(index, this.editorAbsoluteY);
                                continue;
                            case Table.LAYOUT_CONSTRAINT_TAG /*{ENCODED_INT: 51}*/:
                                this.constraintTag = obtainStyledAttributes.getString(index);
                                continue;
                                continue;
                        }
                        break;
                }
                Log.e(ConstraintLayout.TAG, str);
            }
            obtainStyledAttributes.recycle();
            validate();
        }

        public LayoutParams(ViewGroup.LayoutParams layoutParams) {
            super(layoutParams);
        }

        public LayoutParams(LayoutParams layoutParams) {
            super((ViewGroup.MarginLayoutParams) layoutParams);
            this.guideBegin = layoutParams.guideBegin;
            this.guideEnd = layoutParams.guideEnd;
            this.guidePercent = layoutParams.guidePercent;
            this.leftToLeft = layoutParams.leftToLeft;
            this.leftToRight = layoutParams.leftToRight;
            this.rightToLeft = layoutParams.rightToLeft;
            this.rightToRight = layoutParams.rightToRight;
            this.topToTop = layoutParams.topToTop;
            this.topToBottom = layoutParams.topToBottom;
            this.bottomToTop = layoutParams.bottomToTop;
            this.bottomToBottom = layoutParams.bottomToBottom;
            this.baselineToBaseline = layoutParams.baselineToBaseline;
            this.circleConstraint = layoutParams.circleConstraint;
            this.circleRadius = layoutParams.circleRadius;
            this.circleAngle = layoutParams.circleAngle;
            this.startToEnd = layoutParams.startToEnd;
            this.startToStart = layoutParams.startToStart;
            this.endToStart = layoutParams.endToStart;
            this.endToEnd = layoutParams.endToEnd;
            this.goneLeftMargin = layoutParams.goneLeftMargin;
            this.goneTopMargin = layoutParams.goneTopMargin;
            this.goneRightMargin = layoutParams.goneRightMargin;
            this.goneBottomMargin = layoutParams.goneBottomMargin;
            this.goneStartMargin = layoutParams.goneStartMargin;
            this.goneEndMargin = layoutParams.goneEndMargin;
            this.horizontalBias = layoutParams.horizontalBias;
            this.verticalBias = layoutParams.verticalBias;
            this.dimensionRatio = layoutParams.dimensionRatio;
            this.dimensionRatioValue = layoutParams.dimensionRatioValue;
            this.dimensionRatioSide = layoutParams.dimensionRatioSide;
            this.horizontalWeight = layoutParams.horizontalWeight;
            this.verticalWeight = layoutParams.verticalWeight;
            this.horizontalChainStyle = layoutParams.horizontalChainStyle;
            this.verticalChainStyle = layoutParams.verticalChainStyle;
            this.constrainedWidth = layoutParams.constrainedWidth;
            this.constrainedHeight = layoutParams.constrainedHeight;
            this.matchConstraintDefaultWidth = layoutParams.matchConstraintDefaultWidth;
            this.matchConstraintDefaultHeight = layoutParams.matchConstraintDefaultHeight;
            this.matchConstraintMinWidth = layoutParams.matchConstraintMinWidth;
            this.matchConstraintMaxWidth = layoutParams.matchConstraintMaxWidth;
            this.matchConstraintMinHeight = layoutParams.matchConstraintMinHeight;
            this.matchConstraintMaxHeight = layoutParams.matchConstraintMaxHeight;
            this.matchConstraintPercentWidth = layoutParams.matchConstraintPercentWidth;
            this.matchConstraintPercentHeight = layoutParams.matchConstraintPercentHeight;
            this.editorAbsoluteX = layoutParams.editorAbsoluteX;
            this.editorAbsoluteY = layoutParams.editorAbsoluteY;
            this.orientation = layoutParams.orientation;
            this.horizontalDimensionFixed = layoutParams.horizontalDimensionFixed;
            this.verticalDimensionFixed = layoutParams.verticalDimensionFixed;
            this.needsBaseline = layoutParams.needsBaseline;
            this.isGuideline = layoutParams.isGuideline;
            this.resolvedLeftToLeft = layoutParams.resolvedLeftToLeft;
            this.resolvedLeftToRight = layoutParams.resolvedLeftToRight;
            this.resolvedRightToLeft = layoutParams.resolvedRightToLeft;
            this.resolvedRightToRight = layoutParams.resolvedRightToRight;
            this.resolveGoneLeftMargin = layoutParams.resolveGoneLeftMargin;
            this.resolveGoneRightMargin = layoutParams.resolveGoneRightMargin;
            this.resolvedHorizontalBias = layoutParams.resolvedHorizontalBias;
            this.constraintTag = layoutParams.constraintTag;
            this.widget = layoutParams.widget;
        }
    }

    /* access modifiers changed from: package-private */
    public class Measurer implements BasicMeasure.Measurer {
        ConstraintLayout layout;
        int layoutHeightSpec;
        int layoutWidthSpec;
        int paddingBottom;
        int paddingHeight;
        int paddingTop;
        int paddingWidth;

        public Measurer(ConstraintLayout constraintLayout) {
            this.layout = constraintLayout;
        }

        private boolean isSimilarSpec(int i7, int i8, int i9) {
            if (i7 == i8) {
                return true;
            }
            int mode = View.MeasureSpec.getMode(i7);
            View.MeasureSpec.getSize(i7);
            int mode2 = View.MeasureSpec.getMode(i8);
            int size = View.MeasureSpec.getSize(i8);
            if (mode2 == 1073741824) {
                return (mode == Integer.MIN_VALUE || mode == 0) && i9 == size;
            }
            return false;
        }

        public void captureLayoutInfos(int i7, int i8, int i9, int i10, int i11, int i12) {
            this.paddingTop = i9;
            this.paddingBottom = i10;
            this.paddingWidth = i11;
            this.paddingHeight = i12;
            this.layoutWidthSpec = i7;
            this.layoutHeightSpec = i8;
        }

        @Override // androidx.constraintlayout.solver.widgets.analyzer.BasicMeasure.Measurer
        public final void didMeasures() {
            int childCount = this.layout.getChildCount();
            for (int i7 = 0; i7 < childCount; i7++) {
                View childAt = this.layout.getChildAt(i7);
                if (childAt instanceof Placeholder) {
                    ((Placeholder) childAt).updatePostMeasure(this.layout);
                }
            }
            int size = this.layout.mConstraintHelpers.size();
            if (size > 0) {
                for (int i8 = 0; i8 < size; i8++) {
                    ((ConstraintHelper) this.layout.mConstraintHelpers.get(i8)).updatePostMeasure(this.layout);
                }
            }
        }

        /* JADX WARNING: Removed duplicated region for block: B:102:0x0179  */
        /* JADX WARNING: Removed duplicated region for block: B:107:0x018c  */
        /* JADX WARNING: Removed duplicated region for block: B:111:0x01a3  */
        /* JADX WARNING: Removed duplicated region for block: B:112:0x01a5  */
        /* JADX WARNING: Removed duplicated region for block: B:114:0x01a8  */
        /* JADX WARNING: Removed duplicated region for block: B:115:0x01aa  */
        /* JADX WARNING: Removed duplicated region for block: B:118:0x01af  */
        /* JADX WARNING: Removed duplicated region for block: B:123:0x01b9  */
        /* JADX WARNING: Removed duplicated region for block: B:129:0x01c4  */
        /* JADX WARNING: Removed duplicated region for block: B:134:0x01cf  */
        /* JADX WARNING: Removed duplicated region for block: B:139:0x01da A[RETURN] */
        /* JADX WARNING: Removed duplicated region for block: B:140:0x01db  */
        /* JADX WARNING: Removed duplicated region for block: B:49:0x00b6  */
        @Override // androidx.constraintlayout.solver.widgets.analyzer.BasicMeasure.Measurer
        @SuppressLint({"WrongCall"})
        public final void measure(ConstraintWidget constraintWidget, BasicMeasure.Measure measure) {
            int i7;
            int i8;
            int i9;
            int i10;
            int i11;
            int i12;
            int i13;
            int i14;
            int i15;
            int i16;
            int i17;
            int i18;
            if (constraintWidget != null) {
                if (constraintWidget.getVisibility() == 8 && !constraintWidget.isInPlaceholder()) {
                    measure.measuredWidth = 0;
                    measure.measuredHeight = 0;
                    measure.measuredBaseline = 0;
                } else if (constraintWidget.getParent() != null) {
                    ConstraintWidget.DimensionBehaviour dimensionBehaviour = measure.horizontalBehavior;
                    ConstraintWidget.DimensionBehaviour dimensionBehaviour2 = measure.verticalBehavior;
                    int i19 = measure.horizontalDimension;
                    int i20 = measure.verticalDimension;
                    int i21 = this.paddingTop + this.paddingBottom;
                    int i22 = this.paddingWidth;
                    View view = (View) constraintWidget.getCompanionWidget();
                    int[] iArr = AnonymousClass1.$SwitchMap$androidx$constraintlayout$solver$widgets$ConstraintWidget$DimensionBehaviour;
                    int i23 = iArr[dimensionBehaviour.ordinal()];
                    if (i23 != 1) {
                        if (i23 == 2) {
                            i18 = this.layoutWidthSpec;
                            i17 = -2;
                        } else if (i23 != 3) {
                            if (i23 != 4) {
                                i7 = 0;
                            } else {
                                i7 = ViewGroup.getChildMeasureSpec(this.layoutWidthSpec, i22, -2);
                                boolean z7 = constraintWidget.mMatchConstraintDefaultWidth == 1;
                                int i24 = measure.measureStrategy;
                                if (i24 == BasicMeasure.Measure.TRY_GIVEN_DIMENSIONS || i24 == BasicMeasure.Measure.USE_GIVEN_DIMENSIONS) {
                                    if (measure.measureStrategy == BasicMeasure.Measure.USE_GIVEN_DIMENSIONS || !z7 || (z7 && (view.getMeasuredHeight() == constraintWidget.getHeight())) || (view instanceof Placeholder) || constraintWidget.isResolvedHorizontally()) {
                                        i19 = constraintWidget.getWidth();
                                    }
                                }
                            }
                            i8 = iArr[dimensionBehaviour2.ordinal()];
                            if (i8 != 1) {
                                if (i8 == 2) {
                                    i16 = this.layoutHeightSpec;
                                    i15 = -2;
                                } else if (i8 != 3) {
                                    if (i8 != 4) {
                                        i9 = 0;
                                    } else {
                                        i9 = ViewGroup.getChildMeasureSpec(this.layoutHeightSpec, i21, -2);
                                        boolean z8 = constraintWidget.mMatchConstraintDefaultHeight == 1;
                                        int i25 = measure.measureStrategy;
                                        if (i25 == BasicMeasure.Measure.TRY_GIVEN_DIMENSIONS || i25 == BasicMeasure.Measure.USE_GIVEN_DIMENSIONS) {
                                            if (measure.measureStrategy == BasicMeasure.Measure.USE_GIVEN_DIMENSIONS || !z8 || (z8 && (view.getMeasuredWidth() == constraintWidget.getWidth())) || (view instanceof Placeholder) || constraintWidget.isResolvedVertically()) {
                                                i20 = constraintWidget.getHeight();
                                            }
                                        }
                                    }
                                    ConstraintWidgetContainer constraintWidgetContainer = (ConstraintWidgetContainer) constraintWidget.getParent();
                                    if (constraintWidgetContainer != null && Optimizer.enabled(ConstraintLayout.this.mOptimizationLevel, 256) && view.getMeasuredWidth() == constraintWidget.getWidth() && view.getMeasuredWidth() < constraintWidgetContainer.getWidth() && view.getMeasuredHeight() == constraintWidget.getHeight() && view.getMeasuredHeight() < constraintWidgetContainer.getHeight() && view.getBaseline() == constraintWidget.getBaselineDistance() && !constraintWidget.isMeasureRequested()) {
                                        if (!isSimilarSpec(constraintWidget.getLastHorizontalMeasureSpec(), i7, constraintWidget.getWidth()) && isSimilarSpec(constraintWidget.getLastVerticalMeasureSpec(), i9, constraintWidget.getHeight())) {
                                            measure.measuredWidth = constraintWidget.getWidth();
                                            measure.measuredHeight = constraintWidget.getHeight();
                                            measure.measuredBaseline = constraintWidget.getBaselineDistance();
                                            return;
                                        }
                                    }
                                    ConstraintWidget.DimensionBehaviour dimensionBehaviour3 = ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT;
                                    boolean z9 = dimensionBehaviour == dimensionBehaviour3;
                                    boolean z10 = dimensionBehaviour2 == dimensionBehaviour3;
                                    ConstraintWidget.DimensionBehaviour dimensionBehaviour4 = ConstraintWidget.DimensionBehaviour.MATCH_PARENT;
                                    boolean z11 = dimensionBehaviour2 != dimensionBehaviour4 || dimensionBehaviour2 == ConstraintWidget.DimensionBehaviour.FIXED;
                                    boolean z12 = dimensionBehaviour != dimensionBehaviour4 || dimensionBehaviour == ConstraintWidget.DimensionBehaviour.FIXED;
                                    boolean z13 = !z9 && constraintWidget.mDimensionRatio > 0.0f;
                                    boolean z14 = !z10 && constraintWidget.mDimensionRatio > 0.0f;
                                    if (view != null) {
                                        LayoutParams layoutParams = (LayoutParams) view.getLayoutParams();
                                        int i26 = measure.measureStrategy;
                                        if (i26 == BasicMeasure.Measure.TRY_GIVEN_DIMENSIONS || i26 == BasicMeasure.Measure.USE_GIVEN_DIMENSIONS || !z9 || constraintWidget.mMatchConstraintDefaultWidth != 0 || !z10 || constraintWidget.mMatchConstraintDefaultHeight != 0) {
                                            if (!(view instanceof VirtualLayout) || !(constraintWidget instanceof VirtualLayout)) {
                                                view.measure(i7, i9);
                                            } else {
                                                ((VirtualLayout) view).onMeasure((VirtualLayout) constraintWidget, i7, i9);
                                            }
                                            constraintWidget.setLastMeasureSpec(i7, i9);
                                            int measuredWidth = view.getMeasuredWidth();
                                            int measuredHeight = view.getMeasuredHeight();
                                            i11 = view.getBaseline();
                                            int i27 = constraintWidget.mMatchConstraintMinWidth;
                                            i10 = i27 > 0 ? Math.max(i27, measuredWidth) : measuredWidth;
                                            int i28 = constraintWidget.mMatchConstraintMaxWidth;
                                            if (i28 > 0) {
                                                i10 = Math.min(i28, i10);
                                            }
                                            int i29 = constraintWidget.mMatchConstraintMinHeight;
                                            if (i29 > 0) {
                                                i12 = Math.max(i29, measuredHeight);
                                                i14 = i7;
                                            } else {
                                                i14 = i7;
                                                i12 = measuredHeight;
                                            }
                                            int i30 = constraintWidget.mMatchConstraintMaxHeight;
                                            if (i30 > 0) {
                                                i12 = Math.min(i30, i12);
                                            }
                                            if (!Optimizer.enabled(ConstraintLayout.this.mOptimizationLevel, 1)) {
                                                if (z13 && z11) {
                                                    i10 = (int) ((((float) i12) * constraintWidget.mDimensionRatio) + 0.5f);
                                                } else if (z14 && z12) {
                                                    i12 = (int) ((((float) i10) / constraintWidget.mDimensionRatio) + 0.5f);
                                                }
                                            }
                                            if (!(measuredWidth == i10 && measuredHeight == i12)) {
                                                int makeMeasureSpec = measuredWidth != i10 ? View.MeasureSpec.makeMeasureSpec(i10, 1073741824) : i14;
                                                if (measuredHeight != i12) {
                                                    i9 = View.MeasureSpec.makeMeasureSpec(i12, 1073741824);
                                                }
                                                view.measure(makeMeasureSpec, i9);
                                                constraintWidget.setLastMeasureSpec(makeMeasureSpec, i9);
                                                i10 = view.getMeasuredWidth();
                                                i12 = view.getMeasuredHeight();
                                                i11 = view.getBaseline();
                                            }
                                            i13 = -1;
                                        } else {
                                            i13 = -1;
                                            i12 = 0;
                                            i11 = 0;
                                            i10 = 0;
                                        }
                                        boolean z15 = i11 != i13;
                                        measure.measuredNeedsSolverPass = (i10 == measure.horizontalDimension && i12 == measure.verticalDimension) ? false : true;
                                        if (layoutParams.needsBaseline) {
                                            z15 = true;
                                        }
                                        if (!(!z15 || i11 == -1 || constraintWidget.getBaselineDistance() == i11)) {
                                            measure.measuredNeedsSolverPass = true;
                                        }
                                        measure.measuredWidth = i10;
                                        measure.measuredHeight = i12;
                                        measure.measuredHasBaseline = z15;
                                        measure.measuredBaseline = i11;
                                        return;
                                    }
                                    return;
                                } else {
                                    i16 = this.layoutHeightSpec;
                                    i21 += constraintWidget.getVerticalMargin();
                                    i15 = -1;
                                }
                                i9 = ViewGroup.getChildMeasureSpec(i16, i21, i15);
                                ConstraintWidgetContainer constraintWidgetContainer2 = (ConstraintWidgetContainer) constraintWidget.getParent();
                                if (!isSimilarSpec(constraintWidget.getLastHorizontalMeasureSpec(), i7, constraintWidget.getWidth()) && isSimilarSpec(constraintWidget.getLastVerticalMeasureSpec(), i9, constraintWidget.getHeight())) {
                                }
                                ConstraintWidget.DimensionBehaviour dimensionBehaviour32 = ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT;
                                if (dimensionBehaviour == dimensionBehaviour32) {
                                }
                                if (dimensionBehaviour2 == dimensionBehaviour32) {
                                }
                                ConstraintWidget.DimensionBehaviour dimensionBehaviour42 = ConstraintWidget.DimensionBehaviour.MATCH_PARENT;
                                if (dimensionBehaviour2 != dimensionBehaviour42) {
                                }
                                if (dimensionBehaviour != dimensionBehaviour42) {
                                }
                                if (!z9) {
                                }
                                if (!z10) {
                                }
                                if (view != null) {
                                }
                            }
                            i9 = View.MeasureSpec.makeMeasureSpec(i20, 1073741824);
                            ConstraintWidgetContainer constraintWidgetContainer22 = (ConstraintWidgetContainer) constraintWidget.getParent();
                            if (!isSimilarSpec(constraintWidget.getLastHorizontalMeasureSpec(), i7, constraintWidget.getWidth()) && isSimilarSpec(constraintWidget.getLastVerticalMeasureSpec(), i9, constraintWidget.getHeight())) {
                            }
                            ConstraintWidget.DimensionBehaviour dimensionBehaviour322 = ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT;
                            if (dimensionBehaviour == dimensionBehaviour322) {
                            }
                            if (dimensionBehaviour2 == dimensionBehaviour322) {
                            }
                            ConstraintWidget.DimensionBehaviour dimensionBehaviour422 = ConstraintWidget.DimensionBehaviour.MATCH_PARENT;
                            if (dimensionBehaviour2 != dimensionBehaviour422) {
                            }
                            if (dimensionBehaviour != dimensionBehaviour422) {
                            }
                            if (!z9) {
                            }
                            if (!z10) {
                            }
                            if (view != null) {
                            }
                        } else {
                            i18 = this.layoutWidthSpec;
                            i22 += constraintWidget.getHorizontalMargin();
                            i17 = -1;
                        }
                        i7 = ViewGroup.getChildMeasureSpec(i18, i22, i17);
                        i8 = iArr[dimensionBehaviour2.ordinal()];
                        if (i8 != 1) {
                        }
                        i9 = View.MeasureSpec.makeMeasureSpec(i20, 1073741824);
                        ConstraintWidgetContainer constraintWidgetContainer222 = (ConstraintWidgetContainer) constraintWidget.getParent();
                        if (!isSimilarSpec(constraintWidget.getLastHorizontalMeasureSpec(), i7, constraintWidget.getWidth()) && isSimilarSpec(constraintWidget.getLastVerticalMeasureSpec(), i9, constraintWidget.getHeight())) {
                        }
                        ConstraintWidget.DimensionBehaviour dimensionBehaviour3222 = ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT;
                        if (dimensionBehaviour == dimensionBehaviour3222) {
                        }
                        if (dimensionBehaviour2 == dimensionBehaviour3222) {
                        }
                        ConstraintWidget.DimensionBehaviour dimensionBehaviour4222 = ConstraintWidget.DimensionBehaviour.MATCH_PARENT;
                        if (dimensionBehaviour2 != dimensionBehaviour4222) {
                        }
                        if (dimensionBehaviour != dimensionBehaviour4222) {
                        }
                        if (!z9) {
                        }
                        if (!z10) {
                        }
                        if (view != null) {
                        }
                    }
                    i7 = View.MeasureSpec.makeMeasureSpec(i19, 1073741824);
                    i8 = iArr[dimensionBehaviour2.ordinal()];
                    if (i8 != 1) {
                    }
                    i9 = View.MeasureSpec.makeMeasureSpec(i20, 1073741824);
                    ConstraintWidgetContainer constraintWidgetContainer2222 = (ConstraintWidgetContainer) constraintWidget.getParent();
                    if (!isSimilarSpec(constraintWidget.getLastHorizontalMeasureSpec(), i7, constraintWidget.getWidth()) && isSimilarSpec(constraintWidget.getLastVerticalMeasureSpec(), i9, constraintWidget.getHeight())) {
                    }
                    ConstraintWidget.DimensionBehaviour dimensionBehaviour32222 = ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT;
                    if (dimensionBehaviour == dimensionBehaviour32222) {
                    }
                    if (dimensionBehaviour2 == dimensionBehaviour32222) {
                    }
                    ConstraintWidget.DimensionBehaviour dimensionBehaviour42222 = ConstraintWidget.DimensionBehaviour.MATCH_PARENT;
                    if (dimensionBehaviour2 != dimensionBehaviour42222) {
                    }
                    if (dimensionBehaviour != dimensionBehaviour42222) {
                    }
                    if (!z9) {
                    }
                    if (!z10) {
                    }
                    if (view != null) {
                    }
                }
            }
        }
    }

    public ConstraintLayout(@NonNull Context context) {
        super(context);
        init(null, 0, 0);
    }

    private int getPaddingWidth() {
        int max = Math.max(0, getPaddingLeft()) + Math.max(0, getPaddingRight());
        int max2 = Math.max(0, getPaddingStart()) + Math.max(0, getPaddingEnd());
        return max2 > 0 ? max2 : max;
    }

    private final ConstraintWidget getTargetWidget(int i7) {
        if (i7 == 0) {
            return this.mLayoutWidget;
        }
        View view = this.mChildrenByIds.get(i7);
        if (view == null && (view = findViewById(i7)) != null && view != this && view.getParent() == this) {
            onViewAdded(view);
        }
        if (view == this) {
            return this.mLayoutWidget;
        }
        if (view == null) {
            return null;
        }
        return ((LayoutParams) view.getLayoutParams()).widget;
    }

    private void init(AttributeSet attributeSet, int i7, int i8) {
        this.mLayoutWidget.setCompanionWidget(this);
        this.mLayoutWidget.setMeasurer(this.mMeasurer);
        this.mChildrenByIds.put(getId(), this);
        this.mConstraintSet = null;
        if (attributeSet != null) {
            TypedArray obtainStyledAttributes = getContext().obtainStyledAttributes(attributeSet, R.styleable.ConstraintLayout_Layout, i7, i8);
            int indexCount = obtainStyledAttributes.getIndexCount();
            for (int i9 = 0; i9 < indexCount; i9++) {
                int index = obtainStyledAttributes.getIndex(i9);
                if (index == R.styleable.ConstraintLayout_Layout_android_minWidth) {
                    this.mMinWidth = obtainStyledAttributes.getDimensionPixelOffset(index, this.mMinWidth);
                } else if (index == R.styleable.ConstraintLayout_Layout_android_minHeight) {
                    this.mMinHeight = obtainStyledAttributes.getDimensionPixelOffset(index, this.mMinHeight);
                } else if (index == R.styleable.ConstraintLayout_Layout_android_maxWidth) {
                    this.mMaxWidth = obtainStyledAttributes.getDimensionPixelOffset(index, this.mMaxWidth);
                } else if (index == R.styleable.ConstraintLayout_Layout_android_maxHeight) {
                    this.mMaxHeight = obtainStyledAttributes.getDimensionPixelOffset(index, this.mMaxHeight);
                } else if (index == R.styleable.ConstraintLayout_Layout_layout_optimizationLevel) {
                    this.mOptimizationLevel = obtainStyledAttributes.getInt(index, this.mOptimizationLevel);
                } else if (index == R.styleable.ConstraintLayout_Layout_layoutDescription) {
                    int resourceId = obtainStyledAttributes.getResourceId(index, 0);
                    if (resourceId != 0) {
                        try {
                            parseLayoutDescription(resourceId);
                        } catch (Resources.NotFoundException unused) {
                            this.mConstraintLayoutSpec = null;
                        }
                    }
                } else if (index == R.styleable.ConstraintLayout_Layout_constraintSet) {
                    int resourceId2 = obtainStyledAttributes.getResourceId(index, 0);
                    try {
                        ConstraintSet constraintSet = new ConstraintSet();
                        this.mConstraintSet = constraintSet;
                        constraintSet.load(getContext(), resourceId2);
                    } catch (Resources.NotFoundException unused2) {
                        this.mConstraintSet = null;
                    }
                    this.mConstraintSetId = resourceId2;
                }
            }
            obtainStyledAttributes.recycle();
        }
        this.mLayoutWidget.setOptimizationLevel(this.mOptimizationLevel);
    }

    private void markHierarchyDirty() {
        this.mDirtyHierarchy = true;
        this.mLastMeasureWidth = -1;
        this.mLastMeasureHeight = -1;
        this.mLastMeasureWidthSize = -1;
        this.mLastMeasureHeightSize = -1;
        this.mLastMeasureWidthMode = 0;
        this.mLastMeasureHeightMode = 0;
    }

    private void setChildrenConstraints() {
        boolean isInEditMode = isInEditMode();
        int childCount = getChildCount();
        for (int i7 = 0; i7 < childCount; i7++) {
            ConstraintWidget viewWidget = getViewWidget(getChildAt(i7));
            if (viewWidget != null) {
                viewWidget.reset();
            }
        }
        if (isInEditMode) {
            for (int i8 = 0; i8 < childCount; i8++) {
                View childAt = getChildAt(i8);
                try {
                    String resourceName = getResources().getResourceName(childAt.getId());
                    setDesignInformation(0, resourceName, Integer.valueOf(childAt.getId()));
                    int indexOf = resourceName.indexOf(47);
                    if (indexOf != -1) {
                        resourceName = resourceName.substring(indexOf + 1);
                    }
                    getTargetWidget(childAt.getId()).setDebugName(resourceName);
                } catch (Resources.NotFoundException unused) {
                }
            }
        }
        if (this.mConstraintSetId != -1) {
            for (int i9 = 0; i9 < childCount; i9++) {
                View childAt2 = getChildAt(i9);
                if (childAt2.getId() == this.mConstraintSetId && (childAt2 instanceof Constraints)) {
                    this.mConstraintSet = ((Constraints) childAt2).getConstraintSet();
                }
            }
        }
        ConstraintSet constraintSet = this.mConstraintSet;
        if (constraintSet != null) {
            constraintSet.applyToInternal(this, true);
        }
        this.mLayoutWidget.removeAllChildren();
        int size = this.mConstraintHelpers.size();
        if (size > 0) {
            for (int i10 = 0; i10 < size; i10++) {
                this.mConstraintHelpers.get(i10).updatePreLayout(this);
            }
        }
        for (int i11 = 0; i11 < childCount; i11++) {
            View childAt3 = getChildAt(i11);
            if (childAt3 instanceof Placeholder) {
                ((Placeholder) childAt3).updatePreLayout(this);
            }
        }
        this.mTempMapIdToWidget.clear();
        this.mTempMapIdToWidget.put(0, this.mLayoutWidget);
        this.mTempMapIdToWidget.put(getId(), this.mLayoutWidget);
        for (int i12 = 0; i12 < childCount; i12++) {
            View childAt4 = getChildAt(i12);
            this.mTempMapIdToWidget.put(childAt4.getId(), getViewWidget(childAt4));
        }
        for (int i13 = 0; i13 < childCount; i13++) {
            View childAt5 = getChildAt(i13);
            ConstraintWidget viewWidget2 = getViewWidget(childAt5);
            if (viewWidget2 != null) {
                LayoutParams layoutParams = (LayoutParams) childAt5.getLayoutParams();
                this.mLayoutWidget.add(viewWidget2);
                applyConstraintsFromLayoutParams(isInEditMode, childAt5, viewWidget2, layoutParams, this.mTempMapIdToWidget);
            }
        }
    }

    private boolean updateHierarchy() {
        int childCount = getChildCount();
        boolean z7 = false;
        int i7 = 0;
        while (true) {
            if (i7 >= childCount) {
                break;
            } else if (getChildAt(i7).isLayoutRequested()) {
                z7 = true;
                break;
            } else {
                i7++;
            }
        }
        if (z7) {
            setChildrenConstraints();
        }
        return z7;
    }

    @Override // android.view.ViewGroup
    public void addView(View view, int i7, ViewGroup.LayoutParams layoutParams) {
        super.addView(view, i7, layoutParams);
    }

    /* access modifiers changed from: protected */
    /* JADX WARNING: Removed duplicated region for block: B:32:0x00b6  */
    /* JADX WARNING: Removed duplicated region for block: B:35:0x00c8 A[ADDED_TO_REGION] */
    /* JADX WARNING: Removed duplicated region for block: B:42:0x00e2  */
    /* JADX WARNING: Removed duplicated region for block: B:45:0x00f5  */
    /* JADX WARNING: Removed duplicated region for block: B:53:0x0113  */
    /* JADX WARNING: Removed duplicated region for block: B:56:0x0127  */
    /* JADX WARNING: Removed duplicated region for block: B:64:0x0144  */
    /* JADX WARNING: Removed duplicated region for block: B:72:0x0198  */
    /* JADX WARNING: Removed duplicated region for block: B:75:0x01a1  */
    public void applyConstraintsFromLayoutParams(boolean z7, View view, ConstraintWidget constraintWidget, LayoutParams layoutParams, SparseArray<ConstraintWidget> sparseArray) {
        int i7;
        float f7;
        int i8;
        int i9;
        int i10;
        float f8;
        int i11;
        int i12;
        ConstraintAnchor.Type type;
        ConstraintWidget constraintWidget2;
        ConstraintAnchor.Type type2;
        ConstraintWidget constraintWidget3;
        int i13;
        int i14;
        ConstraintAnchor.Type type3;
        ConstraintWidget constraintWidget4;
        ConstraintAnchor.Type type4;
        ConstraintWidget constraintWidget5;
        int i15;
        ConstraintAnchor.Type type5;
        ConstraintWidget constraintWidget6;
        ConstraintAnchor.Type type6;
        ConstraintWidget constraintWidget7;
        int i16;
        ConstraintAnchor.Type type7;
        ConstraintWidget constraintWidget8;
        ConstraintAnchor.Type type8;
        ConstraintWidget constraintWidget9;
        layoutParams.validate();
        layoutParams.helped = false;
        constraintWidget.setVisibility(view.getVisibility());
        if (layoutParams.isInPlaceholder) {
            constraintWidget.setInPlaceholder(true);
            constraintWidget.setVisibility(8);
        }
        constraintWidget.setCompanionWidget(view);
        if (view instanceof ConstraintHelper) {
            ((ConstraintHelper) view).resolveRtl(constraintWidget, this.mLayoutWidget.isRtl());
        }
        if (layoutParams.isGuideline) {
            Guideline guideline = (Guideline) constraintWidget;
            int i17 = layoutParams.resolvedGuideBegin;
            int i18 = layoutParams.resolvedGuideEnd;
            float f9 = layoutParams.resolvedGuidePercent;
            if (f9 != -1.0f) {
                guideline.setGuidePercent(f9);
            } else if (i17 != -1) {
                guideline.setGuideBegin(i17);
            } else if (i18 != -1) {
                guideline.setGuideEnd(i18);
            }
        } else {
            int i19 = layoutParams.resolvedLeftToLeft;
            int i20 = layoutParams.resolvedLeftToRight;
            int i21 = layoutParams.resolvedRightToLeft;
            int i22 = layoutParams.resolvedRightToRight;
            int i23 = layoutParams.resolveGoneLeftMargin;
            int i24 = layoutParams.resolveGoneRightMargin;
            float f10 = layoutParams.resolvedHorizontalBias;
            int i25 = layoutParams.circleConstraint;
            if (i25 != -1) {
                ConstraintWidget constraintWidget10 = sparseArray.get(i25);
                if (constraintWidget10 != null) {
                    constraintWidget.connectCircularConstraint(constraintWidget10, layoutParams.circleAngle, layoutParams.circleRadius);
                }
            } else {
                if (i19 != -1) {
                    constraintWidget8 = sparseArray.get(i19);
                    if (constraintWidget8 != null) {
                        type7 = ConstraintAnchor.Type.LEFT;
                        constraintWidget9 = constraintWidget;
                        type8 = type7;
                        f7 = f10;
                        i16 = ((ViewGroup.MarginLayoutParams) layoutParams).leftMargin;
                    } else {
                        f7 = f10;
                        if (i21 != -1) {
                            constraintWidget6 = sparseArray.get(i21);
                            if (constraintWidget6 != null) {
                                type6 = ConstraintAnchor.Type.RIGHT;
                                type5 = ConstraintAnchor.Type.LEFT;
                                i15 = ((ViewGroup.MarginLayoutParams) layoutParams).rightMargin;
                                constraintWidget7 = constraintWidget;
                            }
                            i8 = layoutParams.topToTop;
                            if (i8 != -1) {
                                constraintWidget4 = sparseArray.get(i8);
                                if (constraintWidget4 != null) {
                                    type3 = ConstraintAnchor.Type.TOP;
                                    i14 = ((ViewGroup.MarginLayoutParams) layoutParams).topMargin;
                                    i13 = layoutParams.goneTopMargin;
                                    constraintWidget5 = constraintWidget;
                                    type4 = type3;
                                }
                                i9 = layoutParams.bottomToTop;
                                if (i9 != -1) {
                                    constraintWidget2 = sparseArray.get(i9);
                                    if (constraintWidget2 != null) {
                                        type2 = ConstraintAnchor.Type.BOTTOM;
                                        type = ConstraintAnchor.Type.TOP;
                                        i12 = ((ViewGroup.MarginLayoutParams) layoutParams).bottomMargin;
                                        i11 = layoutParams.goneBottomMargin;
                                        constraintWidget3 = constraintWidget;
                                    }
                                    i10 = layoutParams.baselineToBaseline;
                                    if (i10 != -1) {
                                        View view2 = this.mChildrenByIds.get(i10);
                                        ConstraintWidget constraintWidget11 = sparseArray.get(layoutParams.baselineToBaseline);
                                        if (!(constraintWidget11 == null || view2 == null || !(view2.getLayoutParams() instanceof LayoutParams))) {
                                            LayoutParams layoutParams2 = (LayoutParams) view2.getLayoutParams();
                                            layoutParams.needsBaseline = true;
                                            layoutParams2.needsBaseline = true;
                                            ConstraintAnchor.Type type9 = ConstraintAnchor.Type.BASELINE;
                                            constraintWidget.getAnchor(type9).connect(constraintWidget11.getAnchor(type9), 0, -1, true);
                                            constraintWidget.setHasBaseline(true);
                                            layoutParams2.widget.setHasBaseline(true);
                                            constraintWidget.getAnchor(ConstraintAnchor.Type.TOP).reset();
                                            constraintWidget.getAnchor(ConstraintAnchor.Type.BOTTOM).reset();
                                        }
                                    }
                                    if (f7 >= 0.0f) {
                                        constraintWidget.setHorizontalBiasPercent(f7);
                                    }
                                    f8 = layoutParams.verticalBias;
                                    if (f8 >= 0.0f) {
                                        constraintWidget.setVerticalBiasPercent(f8);
                                    }
                                } else {
                                    int i26 = layoutParams.bottomToBottom;
                                    if (!(i26 == -1 || (constraintWidget2 = sparseArray.get(i26)) == null)) {
                                        type = ConstraintAnchor.Type.BOTTOM;
                                        i12 = ((ViewGroup.MarginLayoutParams) layoutParams).bottomMargin;
                                        i11 = layoutParams.goneBottomMargin;
                                        constraintWidget3 = constraintWidget;
                                        type2 = type;
                                    }
                                    i10 = layoutParams.baselineToBaseline;
                                    if (i10 != -1) {
                                    }
                                    if (f7 >= 0.0f) {
                                    }
                                    f8 = layoutParams.verticalBias;
                                    if (f8 >= 0.0f) {
                                    }
                                }
                                constraintWidget3.immediateConnect(type2, constraintWidget2, type, i12, i11);
                                i10 = layoutParams.baselineToBaseline;
                                if (i10 != -1) {
                                }
                                if (f7 >= 0.0f) {
                                }
                                f8 = layoutParams.verticalBias;
                                if (f8 >= 0.0f) {
                                }
                            } else {
                                int i27 = layoutParams.topToBottom;
                                if (!(i27 == -1 || (constraintWidget4 = sparseArray.get(i27)) == null)) {
                                    type4 = ConstraintAnchor.Type.TOP;
                                    type3 = ConstraintAnchor.Type.BOTTOM;
                                    i14 = ((ViewGroup.MarginLayoutParams) layoutParams).topMargin;
                                    i13 = layoutParams.goneTopMargin;
                                    constraintWidget5 = constraintWidget;
                                }
                                i9 = layoutParams.bottomToTop;
                                if (i9 != -1) {
                                }
                                constraintWidget3.immediateConnect(type2, constraintWidget2, type, i12, i11);
                                i10 = layoutParams.baselineToBaseline;
                                if (i10 != -1) {
                                }
                                if (f7 >= 0.0f) {
                                }
                                f8 = layoutParams.verticalBias;
                                if (f8 >= 0.0f) {
                                }
                            }
                            constraintWidget5.immediateConnect(type4, constraintWidget4, type3, i14, i13);
                            i9 = layoutParams.bottomToTop;
                            if (i9 != -1) {
                            }
                            constraintWidget3.immediateConnect(type2, constraintWidget2, type, i12, i11);
                            i10 = layoutParams.baselineToBaseline;
                            if (i10 != -1) {
                            }
                            if (f7 >= 0.0f) {
                            }
                            f8 = layoutParams.verticalBias;
                            if (f8 >= 0.0f) {
                            }
                        } else {
                            if (!(i22 == -1 || (constraintWidget6 = sparseArray.get(i22)) == null)) {
                                type5 = ConstraintAnchor.Type.RIGHT;
                                i15 = ((ViewGroup.MarginLayoutParams) layoutParams).rightMargin;
                                constraintWidget7 = constraintWidget;
                                type6 = type5;
                            }
                            i8 = layoutParams.topToTop;
                            if (i8 != -1) {
                            }
                            constraintWidget5.immediateConnect(type4, constraintWidget4, type3, i14, i13);
                            i9 = layoutParams.bottomToTop;
                            if (i9 != -1) {
                            }
                            constraintWidget3.immediateConnect(type2, constraintWidget2, type, i12, i11);
                            i10 = layoutParams.baselineToBaseline;
                            if (i10 != -1) {
                            }
                            if (f7 >= 0.0f) {
                            }
                            f8 = layoutParams.verticalBias;
                            if (f8 >= 0.0f) {
                            }
                        }
                        constraintWidget7.immediateConnect(type6, constraintWidget6, type5, i15, i24);
                        i8 = layoutParams.topToTop;
                        if (i8 != -1) {
                        }
                        constraintWidget5.immediateConnect(type4, constraintWidget4, type3, i14, i13);
                        i9 = layoutParams.bottomToTop;
                        if (i9 != -1) {
                        }
                        constraintWidget3.immediateConnect(type2, constraintWidget2, type, i12, i11);
                        i10 = layoutParams.baselineToBaseline;
                        if (i10 != -1) {
                        }
                        if (f7 >= 0.0f) {
                        }
                        f8 = layoutParams.verticalBias;
                        if (f8 >= 0.0f) {
                        }
                    }
                } else {
                    f7 = f10;
                    if (!(i20 == -1 || (constraintWidget8 = sparseArray.get(i20)) == null)) {
                        type8 = ConstraintAnchor.Type.LEFT;
                        type7 = ConstraintAnchor.Type.RIGHT;
                        i16 = ((ViewGroup.MarginLayoutParams) layoutParams).leftMargin;
                        constraintWidget9 = constraintWidget;
                    }
                    if (i21 != -1) {
                    }
                    constraintWidget7.immediateConnect(type6, constraintWidget6, type5, i15, i24);
                    i8 = layoutParams.topToTop;
                    if (i8 != -1) {
                    }
                    constraintWidget5.immediateConnect(type4, constraintWidget4, type3, i14, i13);
                    i9 = layoutParams.bottomToTop;
                    if (i9 != -1) {
                    }
                    constraintWidget3.immediateConnect(type2, constraintWidget2, type, i12, i11);
                    i10 = layoutParams.baselineToBaseline;
                    if (i10 != -1) {
                    }
                    if (f7 >= 0.0f) {
                    }
                    f8 = layoutParams.verticalBias;
                    if (f8 >= 0.0f) {
                    }
                }
                constraintWidget9.immediateConnect(type8, constraintWidget8, type7, i16, i23);
                if (i21 != -1) {
                }
                constraintWidget7.immediateConnect(type6, constraintWidget6, type5, i15, i24);
                i8 = layoutParams.topToTop;
                if (i8 != -1) {
                }
                constraintWidget5.immediateConnect(type4, constraintWidget4, type3, i14, i13);
                i9 = layoutParams.bottomToTop;
                if (i9 != -1) {
                }
                constraintWidget3.immediateConnect(type2, constraintWidget2, type, i12, i11);
                i10 = layoutParams.baselineToBaseline;
                if (i10 != -1) {
                }
                if (f7 >= 0.0f) {
                }
                f8 = layoutParams.verticalBias;
                if (f8 >= 0.0f) {
                }
            }
            if (z7 && !((i7 = layoutParams.editorAbsoluteX) == -1 && layoutParams.editorAbsoluteY == -1)) {
                constraintWidget.setOrigin(i7, layoutParams.editorAbsoluteY);
            }
            if (layoutParams.horizontalDimensionFixed) {
                constraintWidget.setHorizontalDimensionBehaviour(ConstraintWidget.DimensionBehaviour.FIXED);
                constraintWidget.setWidth(((ViewGroup.MarginLayoutParams) layoutParams).width);
                if (((ViewGroup.MarginLayoutParams) layoutParams).width == -2) {
                    constraintWidget.setHorizontalDimensionBehaviour(ConstraintWidget.DimensionBehaviour.WRAP_CONTENT);
                }
            } else if (((ViewGroup.MarginLayoutParams) layoutParams).width == -1) {
                constraintWidget.setHorizontalDimensionBehaviour(layoutParams.constrainedWidth ? ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT : ConstraintWidget.DimensionBehaviour.MATCH_PARENT);
                constraintWidget.getAnchor(ConstraintAnchor.Type.LEFT).mMargin = ((ViewGroup.MarginLayoutParams) layoutParams).leftMargin;
                constraintWidget.getAnchor(ConstraintAnchor.Type.RIGHT).mMargin = ((ViewGroup.MarginLayoutParams) layoutParams).rightMargin;
            } else {
                constraintWidget.setHorizontalDimensionBehaviour(ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT);
                constraintWidget.setWidth(0);
            }
            if (layoutParams.verticalDimensionFixed) {
                constraintWidget.setVerticalDimensionBehaviour(ConstraintWidget.DimensionBehaviour.FIXED);
                constraintWidget.setHeight(((ViewGroup.MarginLayoutParams) layoutParams).height);
                if (((ViewGroup.MarginLayoutParams) layoutParams).height == -2) {
                    constraintWidget.setVerticalDimensionBehaviour(ConstraintWidget.DimensionBehaviour.WRAP_CONTENT);
                }
            } else if (((ViewGroup.MarginLayoutParams) layoutParams).height == -1) {
                constraintWidget.setVerticalDimensionBehaviour(layoutParams.constrainedHeight ? ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT : ConstraintWidget.DimensionBehaviour.MATCH_PARENT);
                constraintWidget.getAnchor(ConstraintAnchor.Type.TOP).mMargin = ((ViewGroup.MarginLayoutParams) layoutParams).topMargin;
                constraintWidget.getAnchor(ConstraintAnchor.Type.BOTTOM).mMargin = ((ViewGroup.MarginLayoutParams) layoutParams).bottomMargin;
            } else {
                constraintWidget.setVerticalDimensionBehaviour(ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT);
                constraintWidget.setHeight(0);
            }
            constraintWidget.setDimensionRatio(layoutParams.dimensionRatio);
            constraintWidget.setHorizontalWeight(layoutParams.horizontalWeight);
            constraintWidget.setVerticalWeight(layoutParams.verticalWeight);
            constraintWidget.setHorizontalChainStyle(layoutParams.horizontalChainStyle);
            constraintWidget.setVerticalChainStyle(layoutParams.verticalChainStyle);
            constraintWidget.setHorizontalMatchStyle(layoutParams.matchConstraintDefaultWidth, layoutParams.matchConstraintMinWidth, layoutParams.matchConstraintMaxWidth, layoutParams.matchConstraintPercentWidth);
            constraintWidget.setVerticalMatchStyle(layoutParams.matchConstraintDefaultHeight, layoutParams.matchConstraintMinHeight, layoutParams.matchConstraintMaxHeight, layoutParams.matchConstraintPercentHeight);
        }
    }

    /* access modifiers changed from: protected */
    public boolean checkLayoutParams(ViewGroup.LayoutParams layoutParams) {
        return layoutParams instanceof LayoutParams;
    }

    /* access modifiers changed from: protected */
    public void dispatchDraw(Canvas canvas) {
        Object tag;
        int size;
        ArrayList<ConstraintHelper> arrayList = this.mConstraintHelpers;
        if (arrayList != null && (size = arrayList.size()) > 0) {
            for (int i7 = 0; i7 < size; i7++) {
                this.mConstraintHelpers.get(i7).updatePreDraw(this);
            }
        }
        super.dispatchDraw(canvas);
        if (isInEditMode()) {
            int childCount = getChildCount();
            float width = (float) getWidth();
            float height = (float) getHeight();
            for (int i8 = 0; i8 < childCount; i8++) {
                View childAt = getChildAt(i8);
                if (!(childAt.getVisibility() == 8 || (tag = childAt.getTag()) == null || !(tag instanceof String))) {
                    String[] split = ((String) tag).split(",");
                    if (split.length == 4) {
                        int parseInt = Integer.parseInt(split[0]);
                        int parseInt2 = Integer.parseInt(split[1]);
                        int parseInt3 = Integer.parseInt(split[2]);
                        int i9 = (int) ((((float) parseInt) / 1080.0f) * width);
                        int i10 = (int) ((((float) parseInt2) / 1920.0f) * height);
                        Paint paint = new Paint();
                        paint.setColor(SupportMenu.CATEGORY_MASK);
                        float f7 = (float) i9;
                        float f8 = (float) i10;
                        float f9 = (float) (i9 + ((int) ((((float) parseInt3) / 1080.0f) * width)));
                        canvas.drawLine(f7, f8, f9, f8, paint);
                        float parseInt4 = (float) (i10 + ((int) ((((float) Integer.parseInt(split[3])) / 1920.0f) * height)));
                        canvas.drawLine(f9, f8, f9, parseInt4, paint);
                        canvas.drawLine(f9, parseInt4, f7, parseInt4, paint);
                        canvas.drawLine(f7, parseInt4, f7, f8, paint);
                        paint.setColor(-16711936);
                        canvas.drawLine(f7, f8, f9, parseInt4, paint);
                        canvas.drawLine(f7, parseInt4, f9, f8, paint);
                    }
                }
            }
        }
    }

    public void fillMetrics(Metrics metrics) {
        this.mMetrics = metrics;
        this.mLayoutWidget.fillMetrics(metrics);
    }

    public void forceLayout() {
        markHierarchyDirty();
        super.forceLayout();
    }

    public Object getDesignInformation(int i7, Object obj) {
        if (i7 != 0 || !(obj instanceof String)) {
            return null;
        }
        String str = (String) obj;
        HashMap<String, Integer> hashMap = this.mDesignIds;
        if (hashMap == null || !hashMap.containsKey(str)) {
            return null;
        }
        return this.mDesignIds.get(str);
    }

    public int getMaxHeight() {
        return this.mMaxHeight;
    }

    public int getMaxWidth() {
        return this.mMaxWidth;
    }

    public int getMinHeight() {
        return this.mMinHeight;
    }

    public int getMinWidth() {
        return this.mMinWidth;
    }

    public int getOptimizationLevel() {
        return this.mLayoutWidget.getOptimizationLevel();
    }

    public View getViewById(int i7) {
        return this.mChildrenByIds.get(i7);
    }

    public final ConstraintWidget getViewWidget(View view) {
        if (view == this) {
            return this.mLayoutWidget;
        }
        if (view == null) {
            return null;
        }
        return ((LayoutParams) view.getLayoutParams()).widget;
    }

    /* access modifiers changed from: protected */
    public boolean isRtl() {
        return ((getContext().getApplicationInfo().flags & 4194304) != 0) && 1 == getLayoutDirection();
    }

    public void loadLayoutDescription(int i7) {
        if (i7 != 0) {
            try {
                this.mConstraintLayoutSpec = new ConstraintLayoutStates(getContext(), this, i7);
                return;
            } catch (Resources.NotFoundException unused) {
            }
        }
        this.mConstraintLayoutSpec = null;
    }

    /* access modifiers changed from: protected */
    public void onLayout(boolean z7, int i7, int i8, int i9, int i10) {
        View content;
        int childCount = getChildCount();
        boolean isInEditMode = isInEditMode();
        for (int i11 = 0; i11 < childCount; i11++) {
            View childAt = getChildAt(i11);
            LayoutParams layoutParams = (LayoutParams) childAt.getLayoutParams();
            ConstraintWidget constraintWidget = layoutParams.widget;
            if ((childAt.getVisibility() != 8 || layoutParams.isGuideline || layoutParams.isHelper || layoutParams.isVirtualGroup || isInEditMode) && !layoutParams.isInPlaceholder) {
                int x7 = constraintWidget.getX();
                int y7 = constraintWidget.getY();
                int width = constraintWidget.getWidth() + x7;
                int height = constraintWidget.getHeight() + y7;
                childAt.layout(x7, y7, width, height);
                if ((childAt instanceof Placeholder) && (content = ((Placeholder) childAt).getContent()) != null) {
                    content.setVisibility(0);
                    content.layout(x7, y7, width, height);
                }
            }
        }
        int size = this.mConstraintHelpers.size();
        if (size > 0) {
            for (int i12 = 0; i12 < size; i12++) {
                this.mConstraintHelpers.get(i12).updatePostLayout(this);
            }
        }
    }

    /* access modifiers changed from: protected */
    public void onMeasure(int i7, int i8) {
        if (!this.mDirtyHierarchy) {
            int childCount = getChildCount();
            int i9 = 0;
            while (true) {
                if (i9 >= childCount) {
                    break;
                } else if (getChildAt(i9).isLayoutRequested()) {
                    this.mDirtyHierarchy = true;
                    break;
                } else {
                    i9++;
                }
            }
        }
        if (!this.mDirtyHierarchy) {
            int i10 = this.mOnMeasureWidthMeasureSpec;
            if (!(i10 == i7 && this.mOnMeasureHeightMeasureSpec == i8)) {
                if (i10 == i7 && View.MeasureSpec.getMode(i7) == 1073741824 && View.MeasureSpec.getMode(i8) == Integer.MIN_VALUE && View.MeasureSpec.getMode(this.mOnMeasureHeightMeasureSpec) == Integer.MIN_VALUE && View.MeasureSpec.getSize(i8) >= this.mLayoutWidget.getHeight()) {
                    this.mOnMeasureWidthMeasureSpec = i7;
                    this.mOnMeasureHeightMeasureSpec = i8;
                }
            }
            resolveMeasuredDimension(i7, i8, this.mLayoutWidget.getWidth(), this.mLayoutWidget.getHeight(), this.mLayoutWidget.isWidthMeasuredTooSmall(), this.mLayoutWidget.isHeightMeasuredTooSmall());
        }
        this.mOnMeasureWidthMeasureSpec = i7;
        this.mOnMeasureHeightMeasureSpec = i8;
        this.mLayoutWidget.setRtl(isRtl());
        if (this.mDirtyHierarchy) {
            this.mDirtyHierarchy = false;
            if (updateHierarchy()) {
                this.mLayoutWidget.updateHierarchy();
            }
        }
        resolveSystem(this.mLayoutWidget, this.mOptimizationLevel, i7, i8);
        resolveMeasuredDimension(i7, i8, this.mLayoutWidget.getWidth(), this.mLayoutWidget.getHeight(), this.mLayoutWidget.isWidthMeasuredTooSmall(), this.mLayoutWidget.isHeightMeasuredTooSmall());
    }

    public void onViewAdded(View view) {
        super.onViewAdded(view);
        ConstraintWidget viewWidget = getViewWidget(view);
        if ((view instanceof Guideline) && !(viewWidget instanceof Guideline)) {
            LayoutParams layoutParams = (LayoutParams) view.getLayoutParams();
            Guideline guideline = new Guideline();
            layoutParams.widget = guideline;
            layoutParams.isGuideline = true;
            guideline.setOrientation(layoutParams.orientation);
        }
        if (view instanceof ConstraintHelper) {
            ConstraintHelper constraintHelper = (ConstraintHelper) view;
            constraintHelper.validateParams();
            ((LayoutParams) view.getLayoutParams()).isHelper = true;
            if (!this.mConstraintHelpers.contains(constraintHelper)) {
                this.mConstraintHelpers.add(constraintHelper);
            }
        }
        this.mChildrenByIds.put(view.getId(), view);
        this.mDirtyHierarchy = true;
    }

    public void onViewRemoved(View view) {
        super.onViewRemoved(view);
        this.mChildrenByIds.remove(view.getId());
        this.mLayoutWidget.remove(getViewWidget(view));
        this.mConstraintHelpers.remove(view);
        this.mDirtyHierarchy = true;
    }

    /* access modifiers changed from: protected */
    public void parseLayoutDescription(int i7) {
        this.mConstraintLayoutSpec = new ConstraintLayoutStates(getContext(), this, i7);
    }

    public void removeView(View view) {
        super.removeView(view);
    }

    public void requestLayout() {
        markHierarchyDirty();
        super.requestLayout();
    }

    /* access modifiers changed from: protected */
    public void resolveMeasuredDimension(int i7, int i8, int i9, int i10, boolean z7, boolean z8) {
        Measurer measurer = this.mMeasurer;
        int i11 = measurer.paddingHeight;
        int resolveSizeAndState = View.resolveSizeAndState(i9 + measurer.paddingWidth, i7, 0);
        int resolveSizeAndState2 = View.resolveSizeAndState(i10 + i11, i8, 0);
        int i12 = resolveSizeAndState & ViewCompat.MEASURED_SIZE_MASK;
        int i13 = resolveSizeAndState2 & ViewCompat.MEASURED_SIZE_MASK;
        int min = Math.min(this.mMaxWidth, i12);
        int min2 = Math.min(this.mMaxHeight, i13);
        if (z7) {
            min |= 16777216;
        }
        if (z8) {
            min2 |= 16777216;
        }
        setMeasuredDimension(min, min2);
        this.mLastMeasureWidth = min;
        this.mLastMeasureHeight = min2;
    }

    /* access modifiers changed from: protected */
    public void resolveSystem(ConstraintWidgetContainer constraintWidgetContainer, int i7, int i8, int i9) {
        int mode = View.MeasureSpec.getMode(i8);
        int size = View.MeasureSpec.getSize(i8);
        int mode2 = View.MeasureSpec.getMode(i9);
        int size2 = View.MeasureSpec.getSize(i9);
        int max = Math.max(0, getPaddingTop());
        int max2 = Math.max(0, getPaddingBottom());
        int i10 = max + max2;
        int paddingWidth = getPaddingWidth();
        this.mMeasurer.captureLayoutInfos(i8, i9, max, max2, paddingWidth, i10);
        int max3 = Math.max(0, getPaddingStart());
        int max4 = Math.max(0, getPaddingEnd());
        if (max3 <= 0 && max4 <= 0) {
            max4 = Math.max(0, getPaddingLeft());
        } else if (!isRtl()) {
            max4 = max3;
        }
        int i11 = size - paddingWidth;
        int i12 = size2 - i10;
        setSelfDimensionBehaviour(constraintWidgetContainer, mode, i11, mode2, i12);
        constraintWidgetContainer.measure(i7, mode, i11, mode2, i12, this.mLastMeasureWidth, this.mLastMeasureHeight, max4, max);
    }

    public void setConstraintSet(ConstraintSet constraintSet) {
        this.mConstraintSet = constraintSet;
    }

    public void setDesignInformation(int i7, Object obj, Object obj2) {
        if (i7 == 0 && (obj instanceof String) && (obj2 instanceof Integer)) {
            if (this.mDesignIds == null) {
                this.mDesignIds = new HashMap<>();
            }
            String str = (String) obj;
            int indexOf = str.indexOf("/");
            if (indexOf != -1) {
                str = str.substring(indexOf + 1);
            }
            this.mDesignIds.put(str, Integer.valueOf(((Integer) obj2).intValue()));
        }
    }

    public void setId(int i7) {
        this.mChildrenByIds.remove(getId());
        super.setId(i7);
        this.mChildrenByIds.put(getId(), this);
    }

    public void setMaxHeight(int i7) {
        if (i7 != this.mMaxHeight) {
            this.mMaxHeight = i7;
            requestLayout();
        }
    }

    public void setMaxWidth(int i7) {
        if (i7 != this.mMaxWidth) {
            this.mMaxWidth = i7;
            requestLayout();
        }
    }

    public void setMinHeight(int i7) {
        if (i7 != this.mMinHeight) {
            this.mMinHeight = i7;
            requestLayout();
        }
    }

    public void setMinWidth(int i7) {
        if (i7 != this.mMinWidth) {
            this.mMinWidth = i7;
            requestLayout();
        }
    }

    public void setOnConstraintsChanged(ConstraintsChangedListener constraintsChangedListener) {
        this.mConstraintsChangedListener = constraintsChangedListener;
        ConstraintLayoutStates constraintLayoutStates = this.mConstraintLayoutSpec;
        if (constraintLayoutStates != null) {
            constraintLayoutStates.setOnConstraintsChanged(constraintsChangedListener);
        }
    }

    public void setOptimizationLevel(int i7) {
        this.mOptimizationLevel = i7;
        this.mLayoutWidget.setOptimizationLevel(i7);
    }

    /* access modifiers changed from: protected */
    /* JADX WARNING: Code restructure failed: missing block: B:10:0x002a, code lost:
        if (r3 == 0) goto L_0x002c;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:18:0x0044, code lost:
        if (r3 == 0) goto L_0x004b;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:20:0x0049, code lost:
        if (r3 == 0) goto L_0x004b;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:8:0x0025, code lost:
        if (r3 == 0) goto L_0x002c;
     */
    /* JADX WARNING: Removed duplicated region for block: B:13:0x0034  */
    /* JADX WARNING: Removed duplicated region for block: B:19:0x0047  */
    public void setSelfDimensionBehaviour(ConstraintWidgetContainer constraintWidgetContainer, int i7, int i8, int i9, int i10) {
        ConstraintWidget.DimensionBehaviour dimensionBehaviour;
        Measurer measurer = this.mMeasurer;
        int i11 = measurer.paddingHeight;
        int i12 = measurer.paddingWidth;
        ConstraintWidget.DimensionBehaviour dimensionBehaviour2 = ConstraintWidget.DimensionBehaviour.FIXED;
        int childCount = getChildCount();
        if (i7 != Integer.MIN_VALUE) {
            if (i7 == 0) {
                dimensionBehaviour = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
            } else if (i7 != 1073741824) {
                dimensionBehaviour = dimensionBehaviour2;
            } else {
                i8 = Math.min(this.mMaxWidth - i12, i8);
                dimensionBehaviour = dimensionBehaviour2;
                if (i9 != Integer.MIN_VALUE) {
                    if (i9 == 0) {
                        dimensionBehaviour2 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
                    } else if (i9 == 1073741824) {
                        i10 = Math.min(this.mMaxHeight - i11, i10);
                        if (!(i8 == constraintWidgetContainer.getWidth() && i10 == constraintWidgetContainer.getHeight())) {
                            constraintWidgetContainer.invalidateMeasures();
                        }
                        constraintWidgetContainer.setX(0);
                        constraintWidgetContainer.setY(0);
                        constraintWidgetContainer.setMaxWidth(this.mMaxWidth - i12);
                        constraintWidgetContainer.setMaxHeight(this.mMaxHeight - i11);
                        constraintWidgetContainer.setMinWidth(0);
                        constraintWidgetContainer.setMinHeight(0);
                        constraintWidgetContainer.setHorizontalDimensionBehaviour(dimensionBehaviour);
                        constraintWidgetContainer.setWidth(i8);
                        constraintWidgetContainer.setVerticalDimensionBehaviour(dimensionBehaviour2);
                        constraintWidgetContainer.setHeight(i10);
                        constraintWidgetContainer.setMinWidth(this.mMinWidth - i12);
                        constraintWidgetContainer.setMinHeight(this.mMinHeight - i11);
                    }
                    i10 = 0;
                    constraintWidgetContainer.invalidateMeasures();
                    constraintWidgetContainer.setX(0);
                    constraintWidgetContainer.setY(0);
                    constraintWidgetContainer.setMaxWidth(this.mMaxWidth - i12);
                    constraintWidgetContainer.setMaxHeight(this.mMaxHeight - i11);
                    constraintWidgetContainer.setMinWidth(0);
                    constraintWidgetContainer.setMinHeight(0);
                    constraintWidgetContainer.setHorizontalDimensionBehaviour(dimensionBehaviour);
                    constraintWidgetContainer.setWidth(i8);
                    constraintWidgetContainer.setVerticalDimensionBehaviour(dimensionBehaviour2);
                    constraintWidgetContainer.setHeight(i10);
                    constraintWidgetContainer.setMinWidth(this.mMinWidth - i12);
                    constraintWidgetContainer.setMinHeight(this.mMinHeight - i11);
                }
                dimensionBehaviour2 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
                i10 = Math.max(0, this.mMinHeight);
                constraintWidgetContainer.invalidateMeasures();
                constraintWidgetContainer.setX(0);
                constraintWidgetContainer.setY(0);
                constraintWidgetContainer.setMaxWidth(this.mMaxWidth - i12);
                constraintWidgetContainer.setMaxHeight(this.mMaxHeight - i11);
                constraintWidgetContainer.setMinWidth(0);
                constraintWidgetContainer.setMinHeight(0);
                constraintWidgetContainer.setHorizontalDimensionBehaviour(dimensionBehaviour);
                constraintWidgetContainer.setWidth(i8);
                constraintWidgetContainer.setVerticalDimensionBehaviour(dimensionBehaviour2);
                constraintWidgetContainer.setHeight(i10);
                constraintWidgetContainer.setMinWidth(this.mMinWidth - i12);
                constraintWidgetContainer.setMinHeight(this.mMinHeight - i11);
            }
            i8 = 0;
            if (i9 != Integer.MIN_VALUE) {
            }
            i10 = Math.max(0, this.mMinHeight);
            constraintWidgetContainer.invalidateMeasures();
            constraintWidgetContainer.setX(0);
            constraintWidgetContainer.setY(0);
            constraintWidgetContainer.setMaxWidth(this.mMaxWidth - i12);
            constraintWidgetContainer.setMaxHeight(this.mMaxHeight - i11);
            constraintWidgetContainer.setMinWidth(0);
            constraintWidgetContainer.setMinHeight(0);
            constraintWidgetContainer.setHorizontalDimensionBehaviour(dimensionBehaviour);
            constraintWidgetContainer.setWidth(i8);
            constraintWidgetContainer.setVerticalDimensionBehaviour(dimensionBehaviour2);
            constraintWidgetContainer.setHeight(i10);
            constraintWidgetContainer.setMinWidth(this.mMinWidth - i12);
            constraintWidgetContainer.setMinHeight(this.mMinHeight - i11);
        }
        dimensionBehaviour = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
        i8 = Math.max(0, this.mMinWidth);
        if (i9 != Integer.MIN_VALUE) {
        }
        i10 = Math.max(0, this.mMinHeight);
        constraintWidgetContainer.invalidateMeasures();
        constraintWidgetContainer.setX(0);
        constraintWidgetContainer.setY(0);
        constraintWidgetContainer.setMaxWidth(this.mMaxWidth - i12);
        constraintWidgetContainer.setMaxHeight(this.mMaxHeight - i11);
        constraintWidgetContainer.setMinWidth(0);
        constraintWidgetContainer.setMinHeight(0);
        constraintWidgetContainer.setHorizontalDimensionBehaviour(dimensionBehaviour);
        constraintWidgetContainer.setWidth(i8);
        constraintWidgetContainer.setVerticalDimensionBehaviour(dimensionBehaviour2);
        constraintWidgetContainer.setHeight(i10);
        constraintWidgetContainer.setMinWidth(this.mMinWidth - i12);
        constraintWidgetContainer.setMinHeight(this.mMinHeight - i11);
    }

    public void setState(int i7, int i8, int i9) {
        ConstraintLayoutStates constraintLayoutStates = this.mConstraintLayoutSpec;
        if (constraintLayoutStates != null) {
            constraintLayoutStates.updateConstraints(i7, (float) i8, (float) i9);
        }
    }

    public boolean shouldDelayChildPressedState() {
        return false;
    }

    public ConstraintLayout(@NonNull Context context, @Nullable AttributeSet attributeSet) {
        super(context, attributeSet);
        init(attributeSet, 0, 0);
    }

    /* access modifiers changed from: protected */
    public LayoutParams generateDefaultLayoutParams() {
        return new LayoutParams(-2, -2);
    }

    /* access modifiers changed from: protected */
    @Override // android.view.ViewGroup
    public ViewGroup.LayoutParams generateLayoutParams(ViewGroup.LayoutParams layoutParams) {
        return new LayoutParams(layoutParams);
    }

    public ConstraintLayout(@NonNull Context context, @Nullable AttributeSet attributeSet, int i7) {
        super(context, attributeSet, i7);
        init(attributeSet, i7, 0);
    }

    @Override // android.view.ViewGroup
    public LayoutParams generateLayoutParams(AttributeSet attributeSet) {
        return new LayoutParams(getContext(), attributeSet);
    }

    @TargetApi(21)
    public ConstraintLayout(@NonNull Context context, @Nullable AttributeSet attributeSet, int i7, int i8) {
        super(context, attributeSet, i7, i8);
        init(attributeSet, i7, i8);
    }
}
