package androidx.core.graphics;

import android.graphics.Path;
import android.util.Log;
import androidx.annotation.Nullable;
import java.util.ArrayList;

public class PathParser {
    private static final String LOGTAG = "PathParser";

    /* access modifiers changed from: private */
    public static class ExtractFloatResult {
        int mEndPosition;
        boolean mEndWithNegOrDot;

        ExtractFloatResult() {
        }
    }

    public static class PathDataNode {
        public float[] mParams;
        public char mType;

        PathDataNode(char c7, float[] fArr) {
            this.mType = c7;
            this.mParams = fArr;
        }

        /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
        private static void addCommand(Path path, float[] fArr, char c7, char c8, float[] fArr2) {
            int i7;
            int i8;
            float f7;
            float f8;
            float f9;
            float f10;
            float f11;
            float f12;
            float f13;
            float f14;
            int i9;
            char c9 = c8;
            char c10 = 0;
            float f15 = fArr[0];
            float f16 = fArr[1];
            float f17 = fArr[2];
            float f18 = fArr[3];
            float f19 = fArr[4];
            float f20 = fArr[5];
            switch (c9) {
                case 'A':
                case 'a':
                    i9 = 7;
                    i7 = i9;
                    break;
                case 'C':
                case 'c':
                    i9 = 6;
                    i7 = i9;
                    break;
                case 'H':
                case 'V':
                case 'h':
                case 'v':
                    i7 = 1;
                    break;
                case 'L':
                case 'M':
                case 'T':
                case 'l':
                case 'm':
                case 't':
                default:
                    i7 = 2;
                    break;
                case 'Q':
                case 'S':
                case 'q':
                case 's':
                    i7 = 4;
                    break;
                case 'Z':
                case 'z':
                    path.close();
                    path.moveTo(f19, f20);
                    f15 = f19;
                    f17 = f15;
                    f16 = f20;
                    f18 = f16;
                    i7 = 2;
                    break;
            }
            float f21 = f15;
            float f22 = f16;
            float f23 = f19;
            float f24 = f20;
            int i10 = 0;
            char c11 = c7;
            while (i10 < fArr2.length) {
                if (c9 != 'A') {
                    if (c9 == 'C') {
                        i8 = i10;
                        int i11 = i8 + 2;
                        int i12 = i8 + 3;
                        int i13 = i8 + 4;
                        int i14 = i8 + 5;
                        path.cubicTo(fArr2[i8 + 0], fArr2[i8 + 1], fArr2[i11], fArr2[i12], fArr2[i13], fArr2[i14]);
                        f21 = fArr2[i13];
                        float f25 = fArr2[i14];
                        float f26 = fArr2[i11];
                        float f27 = fArr2[i12];
                        f22 = f25;
                        f18 = f27;
                        f17 = f26;
                    } else if (c9 == 'H') {
                        i8 = i10;
                        int i15 = i8 + 0;
                        path.lineTo(fArr2[i15], f22);
                        f21 = fArr2[i15];
                    } else if (c9 == 'Q') {
                        i8 = i10;
                        int i16 = i8 + 0;
                        int i17 = i8 + 1;
                        int i18 = i8 + 2;
                        int i19 = i8 + 3;
                        path.quadTo(fArr2[i16], fArr2[i17], fArr2[i18], fArr2[i19]);
                        float f28 = fArr2[i16];
                        float f29 = fArr2[i17];
                        f21 = fArr2[i18];
                        f22 = fArr2[i19];
                        f17 = f28;
                        f18 = f29;
                    } else if (c9 == 'V') {
                        i8 = i10;
                        int i20 = i8 + 0;
                        path.lineTo(f21, fArr2[i20]);
                        f22 = fArr2[i20];
                    } else if (c9 != 'a') {
                        if (c9 == 'c') {
                            int i21 = i10 + 2;
                            int i22 = i10 + 3;
                            int i23 = i10 + 4;
                            int i24 = i10 + 5;
                            path.rCubicTo(fArr2[i10 + 0], fArr2[i10 + 1], fArr2[i21], fArr2[i22], fArr2[i23], fArr2[i24]);
                            f8 = fArr2[i21] + f21;
                            f7 = fArr2[i22] + f22;
                            f21 += fArr2[i23];
                            f9 = fArr2[i24];
                            f22 += f9;
                            f17 = f8;
                            f18 = f7;
                        } else if (c9 != 'h') {
                            if (c9 != 'q') {
                                if (c9 == 'v') {
                                    int i25 = i10 + 0;
                                    path.rLineTo(0.0f, fArr2[i25]);
                                    f10 = fArr2[i25];
                                } else if (c9 != 'L') {
                                    if (c9 == 'M') {
                                        f21 = fArr2[i10 + 0];
                                        f22 = fArr2[i10 + 1];
                                        if (i10 > 0) {
                                            path.lineTo(f21, f22);
                                        } else {
                                            path.moveTo(f21, f22);
                                        }
                                    } else if (c9 == 'S') {
                                        if (c11 == 'c' || c11 == 's' || c11 == 'C' || c11 == 'S') {
                                            f21 = (f21 * 2.0f) - f17;
                                            f22 = (f22 * 2.0f) - f18;
                                        }
                                        int i26 = i10 + 0;
                                        int i27 = i10 + 1;
                                        int i28 = i10 + 2;
                                        int i29 = i10 + 3;
                                        path.cubicTo(f21, f22, fArr2[i26], fArr2[i27], fArr2[i28], fArr2[i29]);
                                        f8 = fArr2[i26];
                                        f7 = fArr2[i27];
                                        f21 = fArr2[i28];
                                        f22 = fArr2[i29];
                                        f17 = f8;
                                        f18 = f7;
                                    } else if (c9 == 'T') {
                                        if (c11 == 'q' || c11 == 't' || c11 == 'Q' || c11 == 'T') {
                                            f21 = (f21 * 2.0f) - f17;
                                            f22 = (f22 * 2.0f) - f18;
                                        }
                                        int i30 = i10 + 0;
                                        int i31 = i10 + 1;
                                        path.quadTo(f21, f22, fArr2[i30], fArr2[i31]);
                                        float f30 = fArr2[i30];
                                        float f31 = fArr2[i31];
                                        i8 = i10;
                                        f18 = f22;
                                        f17 = f21;
                                        f21 = f30;
                                        f22 = f31;
                                    } else if (c9 == 'l') {
                                        int i32 = i10 + 0;
                                        int i33 = i10 + 1;
                                        path.rLineTo(fArr2[i32], fArr2[i33]);
                                        f21 += fArr2[i32];
                                        f10 = fArr2[i33];
                                    } else if (c9 == 'm') {
                                        float f32 = fArr2[i10 + 0];
                                        f21 += f32;
                                        float f33 = fArr2[i10 + 1];
                                        f22 += f33;
                                        if (i10 > 0) {
                                            path.rLineTo(f32, f33);
                                        } else {
                                            path.rMoveTo(f32, f33);
                                        }
                                    } else if (c9 == 's') {
                                        if (c11 == 'c' || c11 == 's' || c11 == 'C' || c11 == 'S') {
                                            float f34 = f21 - f17;
                                            f11 = f22 - f18;
                                            f12 = f34;
                                        } else {
                                            f12 = 0.0f;
                                            f11 = 0.0f;
                                        }
                                        int i34 = i10 + 0;
                                        int i35 = i10 + 1;
                                        int i36 = i10 + 2;
                                        int i37 = i10 + 3;
                                        path.rCubicTo(f12, f11, fArr2[i34], fArr2[i35], fArr2[i36], fArr2[i37]);
                                        f8 = fArr2[i34] + f21;
                                        f7 = fArr2[i35] + f22;
                                        f21 += fArr2[i36];
                                        f9 = fArr2[i37];
                                    } else if (c9 == 't') {
                                        if (c11 == 'q' || c11 == 't' || c11 == 'Q' || c11 == 'T') {
                                            f13 = f21 - f17;
                                            f14 = f22 - f18;
                                        } else {
                                            f14 = 0.0f;
                                            f13 = 0.0f;
                                        }
                                        int i38 = i10 + 0;
                                        int i39 = i10 + 1;
                                        path.rQuadTo(f13, f14, fArr2[i38], fArr2[i39]);
                                        float f35 = f13 + f21;
                                        float f36 = f14 + f22;
                                        f21 += fArr2[i38];
                                        f22 += fArr2[i39];
                                        f18 = f36;
                                        f17 = f35;
                                    }
                                    i8 = i10;
                                    f24 = f22;
                                    f23 = f21;
                                } else {
                                    int i40 = i10 + 0;
                                    int i41 = i10 + 1;
                                    path.lineTo(fArr2[i40], fArr2[i41]);
                                    f21 = fArr2[i40];
                                    f22 = fArr2[i41];
                                }
                                f22 += f10;
                            } else {
                                int i42 = i10 + 0;
                                int i43 = i10 + 1;
                                int i44 = i10 + 2;
                                int i45 = i10 + 3;
                                path.rQuadTo(fArr2[i42], fArr2[i43], fArr2[i44], fArr2[i45]);
                                f8 = fArr2[i42] + f21;
                                f7 = fArr2[i43] + f22;
                                f21 += fArr2[i44];
                                f9 = fArr2[i45];
                            }
                            f22 += f9;
                            f17 = f8;
                            f18 = f7;
                        } else {
                            int i46 = i10 + 0;
                            path.rLineTo(fArr2[i46], 0.0f);
                            f21 += fArr2[i46];
                        }
                        i8 = i10;
                    } else {
                        int i47 = i10 + 5;
                        int i48 = i10 + 6;
                        i8 = i10;
                        drawArc(path, f21, f22, fArr2[i47] + f21, fArr2[i48] + f22, fArr2[i10 + 0], fArr2[i10 + 1], fArr2[i10 + 2], fArr2[i10 + 3] != 0.0f, fArr2[i10 + 4] != 0.0f);
                        f21 += fArr2[i47];
                        f22 += fArr2[i48];
                    }
                    i10 = i8 + i7;
                    c11 = c8;
                    c9 = c11;
                    c10 = 0;
                } else {
                    i8 = i10;
                    int i49 = i8 + 5;
                    int i50 = i8 + 6;
                    drawArc(path, f21, f22, fArr2[i49], fArr2[i50], fArr2[i8 + 0], fArr2[i8 + 1], fArr2[i8 + 2], fArr2[i8 + 3] != 0.0f, fArr2[i8 + 4] != 0.0f);
                    f21 = fArr2[i49];
                    f22 = fArr2[i50];
                }
                f18 = f22;
                f17 = f21;
                i10 = i8 + i7;
                c11 = c8;
                c9 = c11;
                c10 = 0;
            }
            fArr[c10] = f21;
            fArr[1] = f22;
            fArr[2] = f17;
            fArr[3] = f18;
            fArr[4] = f23;
            fArr[5] = f24;
        }

        private static void arcToBezier(Path path, double d7, double d8, double d9, double d10, double d11, double d12, double d13, double d14, double d15) {
            double d16 = d9;
            int ceil = (int) Math.ceil(Math.abs((d15 * 4.0d) / 3.141592653589793d));
            double cos = Math.cos(d13);
            double sin = Math.sin(d13);
            double cos2 = Math.cos(d14);
            double sin2 = Math.sin(d14);
            double d17 = -d16;
            double d18 = d17 * cos;
            double d19 = d10 * sin;
            double d20 = (d18 * sin2) - (d19 * cos2);
            double d21 = d17 * sin;
            double d22 = d10 * cos;
            double d23 = (sin2 * d21) + (cos2 * d22);
            double d24 = d15 / ((double) ceil);
            double d25 = d23;
            double d26 = d20;
            int i7 = 0;
            double d27 = d11;
            double d28 = d12;
            double d29 = d14;
            while (i7 < ceil) {
                double d30 = d29 + d24;
                double sin3 = Math.sin(d30);
                double cos3 = Math.cos(d30);
                double d31 = (d7 + ((d16 * cos) * cos3)) - (d19 * sin3);
                double d32 = d8 + (d16 * sin * cos3) + (d22 * sin3);
                double d33 = (d18 * sin3) - (d19 * cos3);
                double d34 = (sin3 * d21) + (cos3 * d22);
                double d35 = d30 - d29;
                double tan = Math.tan(d35 / 2.0d);
                double sin4 = (Math.sin(d35) * (Math.sqrt(((tan * 3.0d) * tan) + 4.0d) - 1.0d)) / 3.0d;
                path.rLineTo(0.0f, 0.0f);
                path.cubicTo((float) (d27 + (d26 * sin4)), (float) (d28 + (d25 * sin4)), (float) (d31 - (sin4 * d33)), (float) (d32 - (sin4 * d34)), (float) d31, (float) d32);
                i7++;
                d24 = d24;
                sin = sin;
                d27 = d31;
                d21 = d21;
                cos = cos;
                d29 = d30;
                d25 = d34;
                d26 = d33;
                ceil = ceil;
                d28 = d32;
                d16 = d9;
            }
        }

        private static void drawArc(Path path, float f7, float f8, float f9, float f10, float f11, float f12, float f13, boolean z7, boolean z8) {
            double d7;
            double d8;
            double radians = Math.toRadians((double) f13);
            double cos = Math.cos(radians);
            double sin = Math.sin(radians);
            double d9 = (double) f7;
            double d10 = d9 * cos;
            double d11 = (double) f8;
            double d12 = (double) f11;
            double d13 = (d10 + (d11 * sin)) / d12;
            double d14 = (double) f12;
            double d15 = ((((double) (-f7)) * sin) + (d11 * cos)) / d14;
            double d16 = (double) f10;
            double d17 = ((((double) f9) * cos) + (d16 * sin)) / d12;
            double d18 = ((((double) (-f9)) * sin) + (d16 * cos)) / d14;
            double d19 = d13 - d17;
            double d20 = d15 - d18;
            double d21 = (d13 + d17) / 2.0d;
            double d22 = (d15 + d18) / 2.0d;
            double d23 = (d19 * d19) + (d20 * d20);
            if (d23 == 0.0d) {
                Log.w(PathParser.LOGTAG, " Points are coincident");
                return;
            }
            double d24 = (1.0d / d23) - 0.25d;
            if (d24 < 0.0d) {
                Log.w(PathParser.LOGTAG, "Points are too far apart " + d23);
                float sqrt = (float) (Math.sqrt(d23) / 1.99999d);
                drawArc(path, f7, f8, f9, f10, f11 * sqrt, f12 * sqrt, f13, z7, z8);
                return;
            }
            double sqrt2 = Math.sqrt(d24);
            double d25 = d19 * sqrt2;
            double d26 = sqrt2 * d20;
            if (z7 == z8) {
                d8 = d21 - d26;
                d7 = d22 + d25;
            } else {
                d8 = d21 + d26;
                d7 = d22 - d25;
            }
            double atan2 = Math.atan2(d15 - d7, d13 - d8);
            double atan22 = Math.atan2(d18 - d7, d17 - d8) - atan2;
            int i7 = (atan22 > 0.0d ? 1 : (atan22 == 0.0d ? 0 : -1));
            if (z8 != (i7 >= 0)) {
                atan22 = i7 > 0 ? atan22 - 6.283185307179586d : atan22 + 6.283185307179586d;
            }
            double d27 = d8 * d12;
            double d28 = d7 * d14;
            arcToBezier(path, (d27 * cos) - (d28 * sin), (d27 * sin) + (d28 * cos), d12, d14, d9, d11, radians, atan2, atan22);
        }

        public static void nodesToPath(PathDataNode[] pathDataNodeArr, Path path) {
            float[] fArr = new float[6];
            char c7 = 'm';
            for (int i7 = 0; i7 < pathDataNodeArr.length; i7++) {
                PathDataNode pathDataNode = pathDataNodeArr[i7];
                addCommand(path, fArr, c7, pathDataNode.mType, pathDataNode.mParams);
                c7 = pathDataNodeArr[i7].mType;
            }
        }

        public void interpolatePathDataNode(PathDataNode pathDataNode, PathDataNode pathDataNode2, float f7) {
            this.mType = pathDataNode.mType;
            int i7 = 0;
            while (true) {
                float[] fArr = pathDataNode.mParams;
                if (i7 < fArr.length) {
                    this.mParams[i7] = (fArr[i7] * (1.0f - f7)) + (pathDataNode2.mParams[i7] * f7);
                    i7++;
                } else {
                    return;
                }
            }
        }

        PathDataNode(PathDataNode pathDataNode) {
            this.mType = pathDataNode.mType;
            float[] fArr = pathDataNode.mParams;
            this.mParams = PathParser.copyOfRange(fArr, 0, fArr.length);
        }
    }

    private PathParser() {
    }

    private static void addNode(ArrayList<PathDataNode> arrayList, char c7, float[] fArr) {
        arrayList.add(new PathDataNode(c7, fArr));
    }

    public static boolean canMorph(@Nullable PathDataNode[] pathDataNodeArr, @Nullable PathDataNode[] pathDataNodeArr2) {
        if (pathDataNodeArr == null || pathDataNodeArr2 == null || pathDataNodeArr.length != pathDataNodeArr2.length) {
            return false;
        }
        for (int i7 = 0; i7 < pathDataNodeArr.length; i7++) {
            PathDataNode pathDataNode = pathDataNodeArr[i7];
            char c7 = pathDataNode.mType;
            PathDataNode pathDataNode2 = pathDataNodeArr2[i7];
            if (!(c7 == pathDataNode2.mType && pathDataNode.mParams.length == pathDataNode2.mParams.length)) {
                return false;
            }
        }
        return true;
    }

    static float[] copyOfRange(float[] fArr, int i7, int i8) {
        if (i7 <= i8) {
            int length = fArr.length;
            if (i7 < 0 || i7 > length) {
                throw new ArrayIndexOutOfBoundsException();
            }
            int i9 = i8 - i7;
            int min = Math.min(i9, length - i7);
            float[] fArr2 = new float[i9];
            System.arraycopy(fArr, i7, fArr2, 0, min);
            return fArr2;
        }
        throw new IllegalArgumentException();
    }

    public static PathDataNode[] createNodesFromPathData(String str) {
        if (str == null) {
            return null;
        }
        ArrayList arrayList = new ArrayList();
        int i7 = 1;
        int i8 = 0;
        while (i7 < str.length()) {
            int nextStart = nextStart(str, i7);
            String trim = str.substring(i8, nextStart).trim();
            if (trim.length() > 0) {
                addNode(arrayList, trim.charAt(0), getFloats(trim));
            }
            i8 = nextStart;
            i7 = nextStart + 1;
        }
        if (i7 - i8 == 1 && i8 < str.length()) {
            addNode(arrayList, str.charAt(i8), new float[0]);
        }
        return (PathDataNode[]) arrayList.toArray(new PathDataNode[arrayList.size()]);
    }

    public static Path createPathFromPathData(String str) {
        Path path = new Path();
        PathDataNode[] createNodesFromPathData = createNodesFromPathData(str);
        if (createNodesFromPathData == null) {
            return null;
        }
        try {
            PathDataNode.nodesToPath(createNodesFromPathData, path);
            return path;
        } catch (RuntimeException e7) {
            throw new RuntimeException("Error in parsing " + str, e7);
        }
    }

    public static PathDataNode[] deepCopyNodes(PathDataNode[] pathDataNodeArr) {
        if (pathDataNodeArr == null) {
            return null;
        }
        PathDataNode[] pathDataNodeArr2 = new PathDataNode[pathDataNodeArr.length];
        for (int i7 = 0; i7 < pathDataNodeArr.length; i7++) {
            pathDataNodeArr2[i7] = new PathDataNode(pathDataNodeArr[i7]);
        }
        return pathDataNodeArr2;
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* JADX WARNING: Code restructure failed: missing block: B:14:0x002c, code lost:
        if (r2 == false) goto L_0x0027;
     */
    /* JADX WARNING: Removed duplicated region for block: B:19:0x0038 A[LOOP:0: B:1:0x0007->B:19:0x0038, LOOP_END] */
    /* JADX WARNING: Removed duplicated region for block: B:23:0x003b A[SYNTHETIC] */
    private static void extract(String str, int i7, ExtractFloatResult extractFloatResult) {
        extractFloatResult.mEndWithNegOrDot = false;
        boolean z7 = false;
        boolean z8 = false;
        boolean z9 = false;
        for (int i8 = i7; i8 < str.length(); i8++) {
            char charAt = str.charAt(i8);
            if (charAt != ' ') {
                if (charAt == 'E' || charAt == 'e') {
                    z7 = true;
                    if (z9) {
                        extractFloatResult.mEndPosition = i8;
                    }
                } else {
                    switch (charAt) {
                        case ',':
                            break;
                        case '-':
                            if (i8 != i7) {
                            }
                            z7 = false;
                            break;
                        case '.':
                            if (!z8) {
                                z7 = false;
                                z8 = true;
                                break;
                            }
                            extractFloatResult.mEndWithNegOrDot = true;
                            break;
                        default:
                            z7 = false;
                            break;
                    }
                    if (z9) {
                    }
                }
            }
            z7 = false;
            z9 = true;
            if (z9) {
            }
        }
        extractFloatResult.mEndPosition = i8;
    }

    private static float[] getFloats(String str) {
        if (str.charAt(0) == 'z' || str.charAt(0) == 'Z') {
            return new float[0];
        }
        try {
            float[] fArr = new float[str.length()];
            ExtractFloatResult extractFloatResult = new ExtractFloatResult();
            int length = str.length();
            int i7 = 1;
            int i8 = 0;
            while (i7 < length) {
                extract(str, i7, extractFloatResult);
                int i9 = extractFloatResult.mEndPosition;
                if (i7 < i9) {
                    fArr[i8] = Float.parseFloat(str.substring(i7, i9));
                    i8++;
                }
                i7 = extractFloatResult.mEndWithNegOrDot ? i9 : i9 + 1;
            }
            return copyOfRange(fArr, 0, i8);
        } catch (NumberFormatException e7) {
            throw new RuntimeException("error in parsing \"" + str + "\"", e7);
        }
    }

    public static boolean interpolatePathDataNodes(PathDataNode[] pathDataNodeArr, PathDataNode[] pathDataNodeArr2, PathDataNode[] pathDataNodeArr3, float f7) {
        if (pathDataNodeArr == null || pathDataNodeArr2 == null || pathDataNodeArr3 == null) {
            throw new IllegalArgumentException("The nodes to be interpolated and resulting nodes cannot be null");
        } else if (pathDataNodeArr.length == pathDataNodeArr2.length && pathDataNodeArr2.length == pathDataNodeArr3.length) {
            if (!canMorph(pathDataNodeArr2, pathDataNodeArr3)) {
                return false;
            }
            for (int i7 = 0; i7 < pathDataNodeArr.length; i7++) {
                pathDataNodeArr[i7].interpolatePathDataNode(pathDataNodeArr2[i7], pathDataNodeArr3[i7], f7);
            }
            return true;
        } else {
            throw new IllegalArgumentException("The nodes to be interpolated and resulting nodes must have the same length");
        }
    }

    private static int nextStart(String str, int i7) {
        while (i7 < str.length()) {
            char charAt = str.charAt(i7);
            if (((charAt - 'A') * (charAt - 'Z') <= 0 || (charAt - 'a') * (charAt - 'z') <= 0) && charAt != 'e' && charAt != 'E') {
                return i7;
            }
            i7++;
        }
        return i7;
    }

    public static void updateNodes(PathDataNode[] pathDataNodeArr, PathDataNode[] pathDataNodeArr2) {
        for (int i7 = 0; i7 < pathDataNodeArr2.length; i7++) {
            pathDataNodeArr[i7].mType = pathDataNodeArr2[i7].mType;
            int i8 = 0;
            while (true) {
                float[] fArr = pathDataNodeArr2[i7].mParams;
                if (i8 >= fArr.length) {
                    break;
                }
                pathDataNodeArr[i7].mParams[i8] = fArr[i8];
                i8++;
            }
        }
    }
}
