package androidx.customview.widget;

import android.graphics.Rect;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;

class FocusStrategy {

    public interface BoundsAdapter<T> {
        void obtainBounds(T t7, Rect rect);
    }

    public interface CollectionAdapter<T, V> {
        V get(T t7, int i7);

        int size(T t7);
    }

    private static class SequentialComparator<T> implements Comparator<T> {
        private final BoundsAdapter<T> mAdapter;
        private final boolean mIsLayoutRtl;
        private final Rect mTemp1 = new Rect();
        private final Rect mTemp2 = new Rect();

        SequentialComparator(boolean z7, BoundsAdapter<T> boundsAdapter) {
            this.mIsLayoutRtl = z7;
            this.mAdapter = boundsAdapter;
        }

        @Override // java.util.Comparator
        public int compare(T t7, T t8) {
            Rect rect = this.mTemp1;
            Rect rect2 = this.mTemp2;
            this.mAdapter.obtainBounds(t7, rect);
            this.mAdapter.obtainBounds(t8, rect2);
            int i7 = rect.top;
            int i8 = rect2.top;
            if (i7 < i8) {
                return -1;
            }
            if (i7 > i8) {
                return 1;
            }
            int i9 = rect.left;
            int i10 = rect2.left;
            if (i9 < i10) {
                return this.mIsLayoutRtl ? 1 : -1;
            }
            if (i9 > i10) {
                return this.mIsLayoutRtl ? -1 : 1;
            }
            int i11 = rect.bottom;
            int i12 = rect2.bottom;
            if (i11 < i12) {
                return -1;
            }
            if (i11 > i12) {
                return 1;
            }
            int i13 = rect.right;
            int i14 = rect2.right;
            if (i13 < i14) {
                return this.mIsLayoutRtl ? 1 : -1;
            }
            if (i13 > i14) {
                return this.mIsLayoutRtl ? -1 : 1;
            }
            return 0;
        }
    }

    private FocusStrategy() {
    }

    private static boolean beamBeats(int i7, @NonNull Rect rect, @NonNull Rect rect2, @NonNull Rect rect3) {
        boolean beamsOverlap = beamsOverlap(i7, rect, rect2);
        if (beamsOverlap(i7, rect, rect3) || !beamsOverlap) {
            return false;
        }
        if (!isToDirectionOf(i7, rect, rect3) || i7 == 17 || i7 == 66) {
            return true;
        }
        return majorAxisDistance(i7, rect, rect2) < majorAxisDistanceToFarEdge(i7, rect, rect3);
    }

    private static boolean beamsOverlap(int i7, @NonNull Rect rect, @NonNull Rect rect2) {
        if (i7 != 17) {
            if (i7 != 33) {
                if (i7 != 66) {
                    if (i7 != 130) {
                        throw new IllegalArgumentException("direction must be one of {FOCUS_UP, FOCUS_DOWN, FOCUS_LEFT, FOCUS_RIGHT}.");
                    }
                }
            }
            return rect2.right >= rect.left && rect2.left <= rect.right;
        }
        return rect2.bottom >= rect.top && rect2.top <= rect.bottom;
    }

    /* JADX WARNING: Removed duplicated region for block: B:18:0x004d  */
    public static <L, T> T findNextFocusInAbsoluteDirection(@NonNull L l7, @NonNull CollectionAdapter<L, T> collectionAdapter, @NonNull BoundsAdapter<T> boundsAdapter, @Nullable T t7, @NonNull Rect rect, int i7) {
        int size;
        int i8;
        int i9;
        Rect rect2 = new Rect(rect);
        if (i7 != 17) {
            if (i7 == 33) {
                i9 = rect.height() + 1;
            } else if (i7 == 66) {
                i8 = -(rect.width() + 1);
            } else if (i7 == 130) {
                i9 = -(rect.height() + 1);
            } else {
                throw new IllegalArgumentException("direction must be one of {FOCUS_UP, FOCUS_DOWN, FOCUS_LEFT, FOCUS_RIGHT}.");
            }
            rect2.offset(0, i9);
            size = collectionAdapter.size(l7);
            Rect rect3 = new Rect();
            T t8 = null;
            for (int i10 = 0; i10 < size; i10++) {
                T t9 = collectionAdapter.get(l7, i10);
                if (t9 != t7) {
                    boundsAdapter.obtainBounds(t9, rect3);
                    if (isBetterCandidate(i7, rect, rect3, rect2)) {
                        rect2.set(rect3);
                        t8 = t9;
                    }
                }
            }
            return t8;
        }
        i8 = rect.width() + 1;
        rect2.offset(i8, 0);
        size = collectionAdapter.size(l7);
        Rect rect32 = new Rect();
        T t82 = null;
        while (i10 < size) {
        }
        return t82;
    }

    public static <L, T> T findNextFocusInRelativeDirection(@NonNull L l7, @NonNull CollectionAdapter<L, T> collectionAdapter, @NonNull BoundsAdapter<T> boundsAdapter, @Nullable T t7, int i7, boolean z7, boolean z8) {
        int size = collectionAdapter.size(l7);
        ArrayList arrayList = new ArrayList(size);
        for (int i8 = 0; i8 < size; i8++) {
            arrayList.add(collectionAdapter.get(l7, i8));
        }
        Collections.sort(arrayList, new SequentialComparator(z7, boundsAdapter));
        if (i7 == 1) {
            return (T) getPreviousFocusable(t7, arrayList, z8);
        }
        if (i7 == 2) {
            return (T) getNextFocusable(t7, arrayList, z8);
        }
        throw new IllegalArgumentException("direction must be one of {FOCUS_FORWARD, FOCUS_BACKWARD}.");
    }

    private static <T> T getNextFocusable(T t7, ArrayList<T> arrayList, boolean z7) {
        int size = arrayList.size();
        int lastIndexOf = (t7 == null ? -1 : arrayList.lastIndexOf(t7)) + 1;
        if (lastIndexOf < size) {
            return arrayList.get(lastIndexOf);
        }
        if (!z7 || size <= 0) {
            return null;
        }
        return arrayList.get(0);
    }

    private static <T> T getPreviousFocusable(T t7, ArrayList<T> arrayList, boolean z7) {
        int size = arrayList.size();
        int indexOf = (t7 == null ? size : arrayList.indexOf(t7)) - 1;
        if (indexOf >= 0) {
            return arrayList.get(indexOf);
        }
        if (!z7 || size <= 0) {
            return null;
        }
        return arrayList.get(size - 1);
    }

    private static int getWeightedDistanceFor(int i7, int i8) {
        return (i7 * 13 * i7) + (i8 * i8);
    }

    private static boolean isBetterCandidate(int i7, @NonNull Rect rect, @NonNull Rect rect2, @NonNull Rect rect3) {
        if (!isCandidate(rect, rect2, i7)) {
            return false;
        }
        if (isCandidate(rect, rect3, i7) && !beamBeats(i7, rect, rect2, rect3)) {
            return !beamBeats(i7, rect, rect3, rect2) && getWeightedDistanceFor(majorAxisDistance(i7, rect, rect2), minorAxisDistance(i7, rect, rect2)) < getWeightedDistanceFor(majorAxisDistance(i7, rect, rect3), minorAxisDistance(i7, rect, rect3));
        }
        return true;
    }

    private static boolean isCandidate(@NonNull Rect rect, @NonNull Rect rect2, int i7) {
        if (i7 == 17) {
            int i8 = rect.right;
            int i9 = rect2.right;
            return (i8 > i9 || rect.left >= i9) && rect.left > rect2.left;
        } else if (i7 == 33) {
            int i10 = rect.bottom;
            int i11 = rect2.bottom;
            return (i10 > i11 || rect.top >= i11) && rect.top > rect2.top;
        } else if (i7 == 66) {
            int i12 = rect.left;
            int i13 = rect2.left;
            return (i12 < i13 || rect.right <= i13) && rect.right < rect2.right;
        } else if (i7 == 130) {
            int i14 = rect.top;
            int i15 = rect2.top;
            return (i14 < i15 || rect.bottom <= i15) && rect.bottom < rect2.bottom;
        } else {
            throw new IllegalArgumentException("direction must be one of {FOCUS_UP, FOCUS_DOWN, FOCUS_LEFT, FOCUS_RIGHT}.");
        }
    }

    private static boolean isToDirectionOf(int i7, @NonNull Rect rect, @NonNull Rect rect2) {
        if (i7 == 17) {
            return rect.left >= rect2.right;
        }
        if (i7 == 33) {
            return rect.top >= rect2.bottom;
        }
        if (i7 == 66) {
            return rect.right <= rect2.left;
        }
        if (i7 == 130) {
            return rect.bottom <= rect2.top;
        }
        throw new IllegalArgumentException("direction must be one of {FOCUS_UP, FOCUS_DOWN, FOCUS_LEFT, FOCUS_RIGHT}.");
    }

    private static int majorAxisDistance(int i7, @NonNull Rect rect, @NonNull Rect rect2) {
        return Math.max(0, majorAxisDistanceRaw(i7, rect, rect2));
    }

    private static int majorAxisDistanceRaw(int i7, @NonNull Rect rect, @NonNull Rect rect2) {
        int i8;
        int i9;
        if (i7 == 17) {
            i8 = rect.left;
            i9 = rect2.right;
        } else if (i7 == 33) {
            i8 = rect.top;
            i9 = rect2.bottom;
        } else if (i7 == 66) {
            i8 = rect2.left;
            i9 = rect.right;
        } else if (i7 == 130) {
            i8 = rect2.top;
            i9 = rect.bottom;
        } else {
            throw new IllegalArgumentException("direction must be one of {FOCUS_UP, FOCUS_DOWN, FOCUS_LEFT, FOCUS_RIGHT}.");
        }
        return i8 - i9;
    }

    private static int majorAxisDistanceToFarEdge(int i7, @NonNull Rect rect, @NonNull Rect rect2) {
        return Math.max(1, majorAxisDistanceToFarEdgeRaw(i7, rect, rect2));
    }

    private static int majorAxisDistanceToFarEdgeRaw(int i7, @NonNull Rect rect, @NonNull Rect rect2) {
        int i8;
        int i9;
        if (i7 == 17) {
            i8 = rect.left;
            i9 = rect2.left;
        } else if (i7 == 33) {
            i8 = rect.top;
            i9 = rect2.top;
        } else if (i7 == 66) {
            i8 = rect2.right;
            i9 = rect.right;
        } else if (i7 == 130) {
            i8 = rect2.bottom;
            i9 = rect.bottom;
        } else {
            throw new IllegalArgumentException("direction must be one of {FOCUS_UP, FOCUS_DOWN, FOCUS_LEFT, FOCUS_RIGHT}.");
        }
        return i8 - i9;
    }

    private static int minorAxisDistance(int i7, @NonNull Rect rect, @NonNull Rect rect2) {
        int height;
        int i8;
        int height2;
        if (i7 != 17) {
            if (i7 != 33) {
                if (i7 != 66) {
                    if (i7 != 130) {
                        throw new IllegalArgumentException("direction must be one of {FOCUS_UP, FOCUS_DOWN, FOCUS_LEFT, FOCUS_RIGHT}.");
                    }
                }
            }
            height = rect.left + (rect.width() / 2);
            i8 = rect2.left;
            height2 = rect2.width();
            return Math.abs(height - (i8 + (height2 / 2)));
        }
        height = rect.top + (rect.height() / 2);
        i8 = rect2.top;
        height2 = rect2.height();
        return Math.abs(height - (i8 + (height2 / 2)));
    }
}
