package androidx.room;

import androidx.annotation.RestrictTo;
import androidx.sqlite.db.SupportSQLiteStatement;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

@RestrictTo({RestrictTo.Scope.LIBRARY_GROUP_PREFIX})
public abstract class EntityInsertionAdapter<T> extends SharedSQLiteStatement {
    public EntityInsertionAdapter(RoomDatabase roomDatabase) {
        super(roomDatabase);
    }

    /* access modifiers changed from: protected */
    public abstract void bind(SupportSQLiteStatement supportSQLiteStatement, T t7);

    /* JADX DEBUG: Multi-variable search result rejected for r2v0, resolved type: androidx.room.EntityInsertionAdapter<T> */
    /* JADX WARN: Multi-variable type inference failed */
    public final void insert(Iterable<? extends T> iterable) {
        SupportSQLiteStatement acquire = acquire();
        try {
            Iterator<? extends T> it = iterable.iterator();
            while (it.hasNext()) {
                bind(acquire, it.next());
                acquire.executeInsert();
            }
        } finally {
            release(acquire);
        }
    }

    public final long insertAndReturnId(T t7) {
        SupportSQLiteStatement acquire = acquire();
        try {
            bind(acquire, t7);
            return acquire.executeInsert();
        } finally {
            release(acquire);
        }
    }

    /* JADX DEBUG: Multi-variable search result rejected for r5v0, resolved type: androidx.room.EntityInsertionAdapter<T> */
    /* JADX WARN: Multi-variable type inference failed */
    public final long[] insertAndReturnIdsArray(Collection<? extends T> collection) {
        SupportSQLiteStatement acquire = acquire();
        try {
            long[] jArr = new long[collection.size()];
            Iterator<? extends T> it = collection.iterator();
            int i7 = 0;
            while (it.hasNext()) {
                bind(acquire, it.next());
                jArr[i7] = acquire.executeInsert();
                i7++;
            }
            return jArr;
        } finally {
            release(acquire);
        }
    }

    /* JADX DEBUG: Multi-variable search result rejected for r5v0, resolved type: androidx.room.EntityInsertionAdapter<T> */
    /* JADX WARN: Multi-variable type inference failed */
    public final Long[] insertAndReturnIdsArrayBox(Collection<? extends T> collection) {
        SupportSQLiteStatement acquire = acquire();
        try {
            Long[] lArr = new Long[collection.size()];
            Iterator<? extends T> it = collection.iterator();
            int i7 = 0;
            while (it.hasNext()) {
                bind(acquire, it.next());
                lArr[i7] = Long.valueOf(acquire.executeInsert());
                i7++;
            }
            return lArr;
        } finally {
            release(acquire);
        }
    }

    /* JADX DEBUG: Multi-variable search result rejected for r5v0, resolved type: androidx.room.EntityInsertionAdapter<T> */
    /* JADX WARN: Multi-variable type inference failed */
    public final List<Long> insertAndReturnIdsList(Collection<? extends T> collection) {
        SupportSQLiteStatement acquire = acquire();
        try {
            ArrayList arrayList = new ArrayList(collection.size());
            Iterator<? extends T> it = collection.iterator();
            int i7 = 0;
            while (it.hasNext()) {
                bind(acquire, it.next());
                arrayList.add(i7, Long.valueOf(acquire.executeInsert()));
                i7++;
            }
            return arrayList;
        } finally {
            release(acquire);
        }
    }

    public final void insert(T t7) {
        SupportSQLiteStatement acquire = acquire();
        try {
            bind(acquire, t7);
            acquire.executeInsert();
        } finally {
            release(acquire);
        }
    }

    public final long[] insertAndReturnIdsArray(T[] tArr) {
        SupportSQLiteStatement acquire = acquire();
        try {
            long[] jArr = new long[tArr.length];
            int i7 = 0;
            for (T t7 : tArr) {
                bind(acquire, t7);
                jArr[i7] = acquire.executeInsert();
                i7++;
            }
            return jArr;
        } finally {
            release(acquire);
        }
    }

    public final Long[] insertAndReturnIdsArrayBox(T[] tArr) {
        SupportSQLiteStatement acquire = acquire();
        try {
            Long[] lArr = new Long[tArr.length];
            int i7 = 0;
            for (T t7 : tArr) {
                bind(acquire, t7);
                lArr[i7] = Long.valueOf(acquire.executeInsert());
                i7++;
            }
            return lArr;
        } finally {
            release(acquire);
        }
    }

    public final List<Long> insertAndReturnIdsList(T[] tArr) {
        SupportSQLiteStatement acquire = acquire();
        try {
            ArrayList arrayList = new ArrayList(tArr.length);
            int i7 = 0;
            for (T t7 : tArr) {
                bind(acquire, t7);
                arrayList.add(i7, Long.valueOf(acquire.executeInsert()));
                i7++;
            }
            return arrayList;
        } finally {
            release(acquire);
        }
    }

    public final void insert(T[] tArr) {
        SupportSQLiteStatement acquire = acquire();
        try {
            for (T t7 : tArr) {
                bind(acquire, t7);
                acquire.executeInsert();
            }
        } finally {
            release(acquire);
        }
    }
}
