package androidx.work.impl.utils;

import android.text.TextUtils;
import androidx.annotation.NonNull;
import androidx.annotation.RestrictTo;
import androidx.annotation.VisibleForTesting;
import androidx.work.Constraints;
import androidx.work.Data;
import androidx.work.ExistingWorkPolicy;
import androidx.work.Logger;
import androidx.work.Operation;
import androidx.work.WorkInfo;
import androidx.work.WorkRequest;
import androidx.work.impl.OperationImpl;
import androidx.work.impl.Scheduler;
import androidx.work.impl.Schedulers;
import androidx.work.impl.WorkContinuationImpl;
import androidx.work.impl.WorkDatabase;
import androidx.work.impl.WorkManagerImpl;
import androidx.work.impl.background.systemalarm.RescheduleReceiver;
import androidx.work.impl.model.Dependency;
import androidx.work.impl.model.DependencyDao;
import androidx.work.impl.model.WorkName;
import androidx.work.impl.model.WorkSpec;
import androidx.work.impl.model.WorkSpecDao;
import androidx.work.impl.model.WorkTag;
import androidx.work.impl.workers.ConstraintTrackingWorker;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;

@RestrictTo({RestrictTo.Scope.LIBRARY_GROUP})
public class EnqueueRunnable implements Runnable {
    private static final String TAG = Logger.tagWithPrefix("EnqueueRunnable");
    private final OperationImpl mOperation = new OperationImpl();
    private final WorkContinuationImpl mWorkContinuation;

    public EnqueueRunnable(@NonNull WorkContinuationImpl workContinuationImpl) {
        this.mWorkContinuation = workContinuationImpl;
    }

    private static boolean enqueueContinuation(@NonNull WorkContinuationImpl workContinuationImpl) {
        boolean enqueueWorkWithPrerequisites = enqueueWorkWithPrerequisites(workContinuationImpl.getWorkManagerImpl(), workContinuationImpl.getWork(), (String[]) WorkContinuationImpl.prerequisitesFor(workContinuationImpl).toArray(new String[0]), workContinuationImpl.getName(), workContinuationImpl.getExistingWorkPolicy());
        workContinuationImpl.markEnqueued();
        return enqueueWorkWithPrerequisites;
    }

    /* JADX WARNING: Removed duplicated region for block: B:42:0x0091  */
    /* JADX WARNING: Removed duplicated region for block: B:85:0x0147  */
    private static boolean enqueueWorkWithPrerequisites(WorkManagerImpl workManagerImpl, @NonNull List<? extends WorkRequest> list, String[] strArr, String str, ExistingWorkPolicy existingWorkPolicy) {
        boolean z7;
        boolean z8;
        boolean z9;
        Iterator<? extends WorkRequest> it;
        String[] strArr2 = strArr;
        long currentTimeMillis = System.currentTimeMillis();
        WorkDatabase workDatabase = workManagerImpl.getWorkDatabase();
        boolean z10 = true;
        boolean z11 = strArr2 != null && strArr2.length > 0;
        if (z11) {
            z9 = true;
            z8 = false;
            z7 = false;
            for (String str2 : strArr2) {
                WorkSpec workSpec = workDatabase.workSpecDao().getWorkSpec(str2);
                if (workSpec == null) {
                    Logger.get().error(TAG, String.format("Prerequisite %s doesn't exist; not enqueuing", str2), new Throwable[0]);
                    return false;
                }
                WorkInfo.State state = workSpec.state;
                z9 &= state == WorkInfo.State.SUCCEEDED;
                if (state == WorkInfo.State.FAILED) {
                    z7 = true;
                } else if (state == WorkInfo.State.CANCELLED) {
                    z8 = true;
                }
            }
        } else {
            z9 = true;
            z8 = false;
            z7 = false;
        }
        boolean z12 = !TextUtils.isEmpty(str);
        if (z12 && !z11) {
            List<WorkSpec.IdAndState> workSpecIdAndStatesForName = workDatabase.workSpecDao().getWorkSpecIdAndStatesForName(str);
            if (!workSpecIdAndStatesForName.isEmpty()) {
                if (existingWorkPolicy == ExistingWorkPolicy.APPEND || existingWorkPolicy == ExistingWorkPolicy.APPEND_OR_REPLACE) {
                    DependencyDao dependencyDao = workDatabase.dependencyDao();
                    List arrayList = new ArrayList();
                    for (WorkSpec.IdAndState idAndState : workSpecIdAndStatesForName) {
                        if (!dependencyDao.hasDependents(idAndState.id)) {
                            WorkInfo.State state2 = idAndState.state;
                            boolean z13 = (state2 == WorkInfo.State.SUCCEEDED) & z9;
                            if (state2 == WorkInfo.State.FAILED) {
                                z7 = true;
                            } else if (state2 == WorkInfo.State.CANCELLED) {
                                z8 = true;
                            }
                            arrayList.add(idAndState.id);
                            z9 = z13;
                        }
                    }
                    if (existingWorkPolicy == ExistingWorkPolicy.APPEND_OR_REPLACE && (z8 || z7)) {
                        WorkSpecDao workSpecDao = workDatabase.workSpecDao();
                        for (WorkSpec.IdAndState idAndState2 : workSpecDao.getWorkSpecIdAndStatesForName(str)) {
                            workSpecDao.delete(idAndState2.id);
                        }
                        arrayList = Collections.emptyList();
                        z8 = false;
                        z7 = false;
                    }
                    strArr2 = (String[]) arrayList.toArray(strArr2);
                    z11 = strArr2.length > 0;
                } else {
                    if (existingWorkPolicy == ExistingWorkPolicy.KEEP) {
                        for (WorkSpec.IdAndState idAndState3 : workSpecIdAndStatesForName) {
                            WorkInfo.State state3 = idAndState3.state;
                            if (state3 == WorkInfo.State.ENQUEUED || state3 == WorkInfo.State.RUNNING) {
                                return false;
                            }
                            while (r2.hasNext()) {
                            }
                        }
                    }
                    CancelWorkRunnable.forName(str, workManagerImpl, false).run();
                    WorkSpecDao workSpecDao2 = workDatabase.workSpecDao();
                    for (WorkSpec.IdAndState idAndState4 : workSpecIdAndStatesForName) {
                        workSpecDao2.delete(idAndState4.id);
                    }
                    it = list.iterator();
                    while (it.hasNext()) {
                        WorkRequest workRequest = (WorkRequest) it.next();
                        WorkSpec workSpec2 = workRequest.getWorkSpec();
                        if (z11 && !z9) {
                            workSpec2.state = z7 ? WorkInfo.State.FAILED : z8 ? WorkInfo.State.CANCELLED : WorkInfo.State.BLOCKED;
                        } else if (!workSpec2.isPeriodic()) {
                            workSpec2.periodStartTime = currentTimeMillis;
                        } else {
                            workSpec2.periodStartTime = 0;
                        }
                        if (workSpec2.state == WorkInfo.State.ENQUEUED) {
                            z10 = true;
                        }
                        workDatabase.workSpecDao().insertWorkSpec(workSpec2);
                        if (z11) {
                            int length = strArr2.length;
                            int i7 = 0;
                            while (i7 < length) {
                                workDatabase.dependencyDao().insertDependency(new Dependency(workRequest.getStringId(), strArr2[i7]));
                                i7++;
                                strArr2 = strArr2;
                                it = it;
                            }
                        }
                        for (String str3 : workRequest.getTags()) {
                            workDatabase.workTagDao().insert(new WorkTag(str3, workRequest.getStringId()));
                        }
                        if (z12) {
                            workDatabase.workNameDao().insert(new WorkName(str, workRequest.getStringId()));
                        }
                        strArr2 = strArr2;
                        it = it;
                    }
                    return z10;
                }
            }
        }
        z10 = false;
        it = list.iterator();
        while (it.hasNext()) {
        }
        return z10;
    }

    private static boolean processContinuation(@NonNull WorkContinuationImpl workContinuationImpl) {
        List<WorkContinuationImpl> parents = workContinuationImpl.getParents();
        boolean z7 = false;
        if (parents != null) {
            boolean z8 = false;
            for (WorkContinuationImpl workContinuationImpl2 : parents) {
                if (!workContinuationImpl2.isEnqueued()) {
                    z8 |= processContinuation(workContinuationImpl2);
                } else {
                    Logger.get().warning(TAG, String.format("Already enqueued work ids (%s).", TextUtils.join(", ", workContinuationImpl2.getIds())), new Throwable[0]);
                }
            }
            z7 = z8;
        }
        return enqueueContinuation(workContinuationImpl) | z7;
    }

    private static void tryDelegateConstrainedWorkSpec(WorkSpec workSpec) {
        Constraints constraints = workSpec.constraints;
        String str = workSpec.workerClassName;
        if (str.equals(ConstraintTrackingWorker.class.getName())) {
            return;
        }
        if (constraints.requiresBatteryNotLow() || constraints.requiresStorageNotLow()) {
            Data.Builder builder = new Data.Builder();
            builder.putAll(workSpec.input).putString(ConstraintTrackingWorker.ARGUMENT_CLASS_NAME, str);
            workSpec.workerClassName = ConstraintTrackingWorker.class.getName();
            workSpec.input = builder.build();
        }
    }

    private static boolean usesScheduler(@NonNull WorkManagerImpl workManagerImpl, @NonNull String str) {
        try {
            Class<?> cls = Class.forName(str);
            for (Scheduler scheduler : workManagerImpl.getSchedulers()) {
                if (cls.isAssignableFrom(scheduler.getClass())) {
                    return true;
                }
            }
        } catch (ClassNotFoundException unused) {
        }
        return false;
    }

    @VisibleForTesting
    public boolean addToDatabase() {
        WorkDatabase workDatabase = this.mWorkContinuation.getWorkManagerImpl().getWorkDatabase();
        workDatabase.beginTransaction();
        try {
            boolean processContinuation = processContinuation(this.mWorkContinuation);
            workDatabase.setTransactionSuccessful();
            return processContinuation;
        } finally {
            workDatabase.endTransaction();
        }
    }

    @NonNull
    public Operation getOperation() {
        return this.mOperation;
    }

    public void run() {
        try {
            if (!this.mWorkContinuation.hasCycles()) {
                if (addToDatabase()) {
                    PackageManagerHelper.setComponentEnabled(this.mWorkContinuation.getWorkManagerImpl().getApplicationContext(), RescheduleReceiver.class, true);
                    scheduleWorkInBackground();
                }
                this.mOperation.setState(Operation.SUCCESS);
                return;
            }
            throw new IllegalStateException(String.format("WorkContinuation has cycles (%s)", this.mWorkContinuation));
        } catch (Throwable th) {
            this.mOperation.setState(new Operation.State.FAILURE(th));
        }
    }

    @VisibleForTesting
    public void scheduleWorkInBackground() {
        WorkManagerImpl workManagerImpl = this.mWorkContinuation.getWorkManagerImpl();
        Schedulers.schedule(workManagerImpl.getConfiguration(), workManagerImpl.getWorkDatabase(), workManagerImpl.getSchedulers());
    }
}
