package com.google.android.gms.common.images;

import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.drawable.Drawable;
import android.net.Uri;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.os.ParcelFileDescriptor;
import android.os.ResultReceiver;
import android.os.SystemClock;
import android.util.Log;
import android.widget.ImageView;
import androidx.collection.LruCache;
import com.google.android.gms.common.annotation.KeepName;
import com.google.android.gms.common.internal.h;
import com.google.android.gms.internal.base.k;
import com.google.android.gms.internal.base.p;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.concurrent.CountDownLatch;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

public final class ImageManager {

    /* renamed from: i  reason: collision with root package name */
    private static final Object f5122i = new Object();

    /* renamed from: j  reason: collision with root package name */
    private static HashSet<Uri> f5123j = new HashSet<>();

    /* renamed from: k  reason: collision with root package name */
    private static ImageManager f5124k;

    /* renamed from: a  reason: collision with root package name */
    private final Context f5125a;

    /* renamed from: b  reason: collision with root package name */
    private final Handler f5126b = new p(Looper.getMainLooper());

    /* renamed from: c  reason: collision with root package name */
    private final ExecutorService f5127c = Executors.newFixedThreadPool(4);

    /* renamed from: d  reason: collision with root package name */
    private final b f5128d = null;

    /* renamed from: e  reason: collision with root package name */
    private final k f5129e = new k();

    /* renamed from: f  reason: collision with root package name */
    private final Map<b, ImageReceiver> f5130f = new HashMap();

    /* renamed from: g  reason: collision with root package name */
    private final Map<Uri, ImageReceiver> f5131g = new HashMap();

    /* renamed from: h  reason: collision with root package name */
    private final Map<Uri, Long> f5132h = new HashMap();

    /* access modifiers changed from: private */
    @KeepName
    public final class ImageReceiver extends ResultReceiver {

        /* renamed from: f  reason: collision with root package name */
        private final Uri f5133f;

        /* renamed from: g  reason: collision with root package name */
        private final ArrayList<b> f5134g = new ArrayList<>();

        ImageReceiver(Uri uri) {
            super(new p(Looper.getMainLooper()));
            this.f5133f = uri;
        }

        public final void b(b bVar) {
            com.google.android.gms.common.internal.d.a("ImageReceiver.addImageRequest() must be called in the main thread");
            this.f5134g.add(bVar);
        }

        public final void j(b bVar) {
            com.google.android.gms.common.internal.d.a("ImageReceiver.removeImageRequest() must be called in the main thread");
            this.f5134g.remove(bVar);
        }

        public final void l() {
            Intent intent = new Intent(h.f5288c);
            intent.putExtra(h.f5289d, this.f5133f);
            intent.putExtra(h.f5290e, this);
            intent.putExtra(h.f5291f, 3);
            ImageManager.this.f5125a.sendBroadcast(intent);
        }

        public final void onReceiveResult(int i7, Bundle bundle) {
            ImageManager.this.f5127c.execute(new c(this.f5133f, (ParcelFileDescriptor) bundle.getParcelable("com.google.android.gms.extra.fileDescriptor")));
        }
    }

    public interface a {
        void a(Uri uri, Drawable drawable, boolean z7);
    }

    /* access modifiers changed from: private */
    public static final class b extends LruCache<c, Bitmap> {
        /* JADX DEBUG: Method arguments types fixed to match base method, original types: [boolean, java.lang.Object, java.lang.Object, java.lang.Object] */
        /* access modifiers changed from: protected */
        @Override // androidx.collection.LruCache
        public final /* synthetic */ void entryRemoved(boolean z7, c cVar, Bitmap bitmap, Bitmap bitmap2) {
            super.entryRemoved(z7, cVar, bitmap, bitmap2);
        }

        /* JADX DEBUG: Method arguments types fixed to match base method, original types: [java.lang.Object, java.lang.Object] */
        /* access modifiers changed from: protected */
        @Override // androidx.collection.LruCache
        public final /* synthetic */ int sizeOf(c cVar, Bitmap bitmap) {
            Bitmap bitmap2 = bitmap;
            return bitmap2.getHeight() * bitmap2.getRowBytes();
        }
    }

    private final class c implements Runnable {

        /* renamed from: f  reason: collision with root package name */
        private final Uri f5136f;

        /* renamed from: g  reason: collision with root package name */
        private final ParcelFileDescriptor f5137g;

        public c(Uri uri, ParcelFileDescriptor parcelFileDescriptor) {
            this.f5136f = uri;
            this.f5137g = parcelFileDescriptor;
        }

        public final void run() {
            com.google.android.gms.common.internal.d.b("LoadBitmapFromDiskRunnable can't be executed in the main thread");
            ParcelFileDescriptor parcelFileDescriptor = this.f5137g;
            boolean z7 = false;
            Bitmap bitmap = null;
            if (parcelFileDescriptor != null) {
                try {
                    bitmap = BitmapFactory.decodeFileDescriptor(parcelFileDescriptor.getFileDescriptor());
                } catch (OutOfMemoryError e7) {
                    String valueOf = String.valueOf(this.f5136f);
                    StringBuilder sb = new StringBuilder(valueOf.length() + 34);
                    sb.append("OOM while loading bitmap for uri: ");
                    sb.append(valueOf);
                    Log.e("ImageManager", sb.toString(), e7);
                    z7 = true;
                }
                try {
                    this.f5137g.close();
                } catch (IOException e8) {
                    Log.e("ImageManager", "closed failed", e8);
                }
            }
            CountDownLatch countDownLatch = new CountDownLatch(1);
            ImageManager.this.f5126b.post(new e(this.f5136f, bitmap, z7, countDownLatch));
            try {
                countDownLatch.await();
            } catch (InterruptedException unused) {
                String valueOf2 = String.valueOf(this.f5136f);
                StringBuilder sb2 = new StringBuilder(valueOf2.length() + 32);
                sb2.append("Latch interrupted while posting ");
                sb2.append(valueOf2);
                Log.w("ImageManager", sb2.toString());
            }
        }
    }

    /* access modifiers changed from: private */
    public final class d implements Runnable {

        /* renamed from: f  reason: collision with root package name */
        private final b f5139f;

        public d(b bVar) {
            this.f5139f = bVar;
        }

        public final void run() {
            com.google.android.gms.common.internal.d.a("LoadImageRunnable must be executed on the main thread");
            ImageReceiver imageReceiver = (ImageReceiver) ImageManager.this.f5130f.get(this.f5139f);
            if (imageReceiver != null) {
                ImageManager.this.f5130f.remove(this.f5139f);
                imageReceiver.j(this.f5139f);
            }
            b bVar = this.f5139f;
            c cVar = bVar.f5152a;
            if (cVar.f5159a == null) {
                bVar.c(ImageManager.this.f5125a, ImageManager.this.f5129e, true);
                return;
            }
            Bitmap h7 = ImageManager.this.h(cVar);
            if (h7 != null) {
                this.f5139f.a(ImageManager.this.f5125a, h7, true);
                return;
            }
            Long l7 = (Long) ImageManager.this.f5132h.get(cVar.f5159a);
            if (l7 != null) {
                if (SystemClock.elapsedRealtime() - l7.longValue() < 3600000) {
                    this.f5139f.c(ImageManager.this.f5125a, ImageManager.this.f5129e, true);
                    return;
                }
                ImageManager.this.f5132h.remove(cVar.f5159a);
            }
            this.f5139f.b(ImageManager.this.f5125a, ImageManager.this.f5129e);
            ImageReceiver imageReceiver2 = (ImageReceiver) ImageManager.this.f5131g.get(cVar.f5159a);
            if (imageReceiver2 == null) {
                imageReceiver2 = new ImageReceiver(cVar.f5159a);
                ImageManager.this.f5131g.put(cVar.f5159a, imageReceiver2);
            }
            imageReceiver2.b(this.f5139f);
            if (!(this.f5139f instanceof e)) {
                ImageManager.this.f5130f.put(this.f5139f, imageReceiver2);
            }
            synchronized (ImageManager.f5122i) {
                if (!ImageManager.f5123j.contains(cVar.f5159a)) {
                    ImageManager.f5123j.add(cVar.f5159a);
                    imageReceiver2.l();
                }
            }
        }
    }

    private final class e implements Runnable {

        /* renamed from: f  reason: collision with root package name */
        private final Uri f5141f;

        /* renamed from: g  reason: collision with root package name */
        private final Bitmap f5142g;

        /* renamed from: p  reason: collision with root package name */
        private final CountDownLatch f5143p;

        /* renamed from: x  reason: collision with root package name */
        private boolean f5144x;

        public e(Uri uri, Bitmap bitmap, boolean z7, CountDownLatch countDownLatch) {
            this.f5141f = uri;
            this.f5142g = bitmap;
            this.f5144x = z7;
            this.f5143p = countDownLatch;
        }

        public final void run() {
            com.google.android.gms.common.internal.d.a("OnBitmapLoadedRunnable must be executed in the main thread");
            boolean z7 = this.f5142g != null;
            if (ImageManager.this.f5128d != null) {
                if (this.f5144x) {
                    ImageManager.this.f5128d.evictAll();
                    System.gc();
                    this.f5144x = false;
                    ImageManager.this.f5126b.post(this);
                    return;
                } else if (z7) {
                    ImageManager.this.f5128d.put(new c(this.f5141f), this.f5142g);
                }
            }
            ImageReceiver imageReceiver = (ImageReceiver) ImageManager.this.f5131g.remove(this.f5141f);
            if (imageReceiver != null) {
                ArrayList arrayList = imageReceiver.f5134g;
                int size = arrayList.size();
                for (int i7 = 0; i7 < size; i7++) {
                    b bVar = (b) arrayList.get(i7);
                    ImageManager imageManager = ImageManager.this;
                    if (z7) {
                        bVar.a(imageManager.f5125a, this.f5142g, false);
                    } else {
                        imageManager.f5132h.put(this.f5141f, Long.valueOf(SystemClock.elapsedRealtime()));
                        bVar.c(ImageManager.this.f5125a, ImageManager.this.f5129e, false);
                    }
                    if (!(bVar instanceof e)) {
                        ImageManager.this.f5130f.remove(bVar);
                    }
                }
            }
            this.f5143p.countDown();
            synchronized (ImageManager.f5122i) {
                ImageManager.f5123j.remove(this.f5141f);
            }
        }
    }

    private ImageManager(Context context, boolean z7) {
        this.f5125a = context.getApplicationContext();
    }

    public static ImageManager a(Context context) {
        if (f5124k == null) {
            f5124k = new ImageManager(context, false);
        }
        return f5124k;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private final Bitmap h(c cVar) {
        b bVar = this.f5128d;
        if (bVar == null) {
            return null;
        }
        return (Bitmap) bVar.get(cVar);
    }

    private final void j(b bVar) {
        com.google.android.gms.common.internal.d.a("ImageManager.loadImage() must be called in the main thread");
        new d(bVar).run();
    }

    public final void b(ImageView imageView, int i7) {
        j(new d(imageView, i7));
    }

    public final void c(ImageView imageView, Uri uri) {
        j(new d(imageView, uri));
    }

    public final void d(ImageView imageView, Uri uri, int i7) {
        d dVar = new d(imageView, uri);
        dVar.f5154c = i7;
        j(dVar);
    }

    public final void e(a aVar, Uri uri) {
        j(new e(aVar, uri));
    }

    public final void f(a aVar, Uri uri, int i7) {
        e eVar = new e(aVar, uri);
        eVar.f5154c = i7;
        j(eVar);
    }
}
