package com.google.android.material.slider;

import android.animation.Animator;
import android.animation.AnimatorListenerAdapter;
import android.animation.ValueAnimator;
import android.content.Context;
import android.content.res.ColorStateList;
import android.content.res.Resources;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.PorterDuff;
import android.graphics.PorterDuffXfermode;
import android.graphics.Rect;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.RippleDrawable;
import android.os.Bundle;
import android.os.Parcel;
import android.os.Parcelable;
import android.util.AttributeSet;
import android.util.Log;
import android.view.KeyEvent;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewConfiguration;
import android.view.ViewGroup;
import android.view.ViewParent;
import android.view.accessibility.AccessibilityManager;
import android.widget.SeekBar;
import androidx.annotation.ColorInt;
import androidx.annotation.ColorRes;
import androidx.annotation.DimenRes;
import androidx.annotation.Dimension;
import androidx.annotation.IntRange;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.annotation.VisibleForTesting;
import androidx.appcompat.content.res.AppCompatResources;
import androidx.core.graphics.drawable.DrawableCompat;
import androidx.core.math.MathUtils;
import androidx.core.view.ViewCompat;
import androidx.core.view.accessibility.AccessibilityNodeInfoCompat;
import androidx.customview.widget.ExploreByTouchHelper;
import b0.a;
import com.google.android.material.internal.q;
import com.google.android.material.internal.x;
import com.google.android.material.internal.y;
import com.google.android.material.shape.j;
import com.google.android.material.shape.o;
import com.google.android.material.slider.BaseSlider;
import com.google.android.material.slider.a;
import com.google.android.material.slider.b;
import java.math.BigDecimal;
import java.math.MathContext;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;

/* access modifiers changed from: package-private */
public abstract class BaseSlider<S extends BaseSlider<S, L, T>, L extends a<S>, T extends b<S>> extends View {

    /* renamed from: c0  reason: collision with root package name */
    private static final String f8512c0 = "BaseSlider";

    /* renamed from: d0  reason: collision with root package name */
    private static final String f8513d0 = "Slider value(%s) must be greater or equal to valueFrom(%s), and lower or equal to valueTo(%s)";

    /* renamed from: e0  reason: collision with root package name */
    private static final String f8514e0 = "Value(%s) must be equal to valueFrom(%s) plus a multiple of stepSize(%s) when using stepSize(%s)";

    /* renamed from: f0  reason: collision with root package name */
    private static final String f8515f0 = "valueFrom(%s) must be smaller than valueTo(%s)";

    /* renamed from: g0  reason: collision with root package name */
    private static final String f8516g0 = "valueTo(%s) must be greater than valueFrom(%s)";

    /* renamed from: h0  reason: collision with root package name */
    private static final String f8517h0 = "The stepSize(%s) must be 0, or a factor of the valueFrom(%s)-valueTo(%s) range";

    /* renamed from: i0  reason: collision with root package name */
    private static final String f8518i0 = "Floating point value used for %s(%s). Using floats can have rounding errors which may result in incorrect values. Instead, consider using integers with a custom LabelFormatter to display the  value correctly.";

    /* renamed from: j0  reason: collision with root package name */
    private static final int f8519j0 = 200;

    /* renamed from: k0  reason: collision with root package name */
    private static final int f8520k0 = 63;

    /* renamed from: l0  reason: collision with root package name */
    private static final double f8521l0 = 1.0E-4d;

    /* renamed from: m0  reason: collision with root package name */
    static final int f8522m0 = a.n.mc;

    /* renamed from: n0  reason: collision with root package name */
    static final int f8523n0 = 1;

    /* renamed from: o0  reason: collision with root package name */
    static final int f8524o0 = 0;

    /* renamed from: p0  reason: collision with root package name */
    private static final long f8525p0 = 83;

    /* renamed from: q0  reason: collision with root package name */
    private static final long f8526q0 = 117;
    private int A;
    private float B;
    private MotionEvent C;
    private d D;
    private boolean E;
    private float F;
    private float G;
    private ArrayList<Float> H;
    private int I;
    private int J;
    private float K;
    private float[] L;
    private boolean M;
    private int N;
    private boolean O;
    private boolean P;
    private boolean Q;
    @NonNull
    private ColorStateList R;
    @NonNull
    private ColorStateList S;
    @NonNull
    private ColorStateList T;
    @NonNull
    private ColorStateList U;
    @NonNull
    private ColorStateList V;
    @NonNull
    private final j W;
    @NonNull

    /* renamed from: a  reason: collision with root package name */
    private final Paint f8527a;

    /* renamed from: a0  reason: collision with root package name */
    private float f8528a0;
    @NonNull

    /* renamed from: b  reason: collision with root package name */
    private final Paint f8529b;

    /* renamed from: b0  reason: collision with root package name */
    private int f8530b0;
    @NonNull

    /* renamed from: c  reason: collision with root package name */
    private final Paint f8531c;
    @NonNull

    /* renamed from: d  reason: collision with root package name */
    private final Paint f8532d;
    @NonNull

    /* renamed from: e  reason: collision with root package name */
    private final Paint f8533e;
    @NonNull

    /* renamed from: f  reason: collision with root package name */
    private final Paint f8534f;
    @NonNull

    /* renamed from: g  reason: collision with root package name */
    private final e f8535g;

    /* renamed from: h  reason: collision with root package name */
    private final AccessibilityManager f8536h;

    /* renamed from: i  reason: collision with root package name */
    private BaseSlider<S, L, T>.d f8537i;
    @NonNull

    /* renamed from: j  reason: collision with root package name */
    private final f f8538j;
    @NonNull

    /* renamed from: k  reason: collision with root package name */
    private final List<com.google.android.material.tooltip.a> f8539k;
    @NonNull

    /* renamed from: l  reason: collision with root package name */
    private final List<L> f8540l;
    @NonNull

    /* renamed from: m  reason: collision with root package name */
    private final List<T> f8541m;

    /* renamed from: n  reason: collision with root package name */
    private boolean f8542n;

    /* renamed from: o  reason: collision with root package name */
    private ValueAnimator f8543o;

    /* renamed from: p  reason: collision with root package name */
    private ValueAnimator f8544p;

    /* renamed from: q  reason: collision with root package name */
    private final int f8545q;

    /* renamed from: r  reason: collision with root package name */
    private int f8546r;

    /* renamed from: s  reason: collision with root package name */
    private int f8547s;

    /* renamed from: t  reason: collision with root package name */
    private int f8548t;

    /* renamed from: u  reason: collision with root package name */
    private int f8549u;

    /* renamed from: v  reason: collision with root package name */
    private int f8550v;

    /* renamed from: w  reason: collision with root package name */
    private int f8551w;

    /* renamed from: x  reason: collision with root package name */
    private int f8552x;

    /* renamed from: y  reason: collision with root package name */
    private int f8553y;

    /* renamed from: z  reason: collision with root package name */
    private int f8554z;

    /* access modifiers changed from: package-private */
    public static class SliderState extends View.BaseSavedState {
        public static final Parcelable.Creator<SliderState> CREATOR = new a();

        /* renamed from: f  reason: collision with root package name */
        float f8555f;

        /* renamed from: g  reason: collision with root package name */
        float f8556g;

        /* renamed from: p  reason: collision with root package name */
        ArrayList<Float> f8557p;

        /* renamed from: x  reason: collision with root package name */
        float f8558x;

        /* renamed from: y  reason: collision with root package name */
        boolean f8559y;

        static class a implements Parcelable.Creator<SliderState> {
            a() {
            }

            @NonNull
            /* renamed from: a */
            public SliderState createFromParcel(@NonNull Parcel parcel) {
                return new SliderState(parcel, null);
            }

            @NonNull
            /* renamed from: b */
            public SliderState[] newArray(int i7) {
                return new SliderState[i7];
            }
        }

        private SliderState(@NonNull Parcel parcel) {
            super(parcel);
            this.f8555f = parcel.readFloat();
            this.f8556g = parcel.readFloat();
            ArrayList<Float> arrayList = new ArrayList<>();
            this.f8557p = arrayList;
            parcel.readList(arrayList, Float.class.getClassLoader());
            this.f8558x = parcel.readFloat();
            this.f8559y = parcel.createBooleanArray()[0];
        }

        public void writeToParcel(@NonNull Parcel parcel, int i7) {
            super.writeToParcel(parcel, i7);
            parcel.writeFloat(this.f8555f);
            parcel.writeFloat(this.f8556g);
            parcel.writeList(this.f8557p);
            parcel.writeFloat(this.f8558x);
            parcel.writeBooleanArray(new boolean[]{this.f8559y});
        }

        /* synthetic */ SliderState(Parcel parcel, a aVar) {
            this(parcel);
        }

        SliderState(Parcelable parcelable) {
            super(parcelable);
        }
    }

    /* access modifiers changed from: package-private */
    public class a implements f {

        /* renamed from: a  reason: collision with root package name */
        final /* synthetic */ AttributeSet f8560a;

        /* renamed from: b  reason: collision with root package name */
        final /* synthetic */ int f8561b;

        a(AttributeSet attributeSet, int i7) {
            this.f8560a = attributeSet;
            this.f8561b = i7;
        }

        @Override // com.google.android.material.slider.BaseSlider.f
        public com.google.android.material.tooltip.a a() {
            TypedArray j7 = q.j(BaseSlider.this.getContext(), this.f8560a, a.o.Fo, this.f8561b, BaseSlider.f8522m0, new int[0]);
            com.google.android.material.tooltip.a a02 = BaseSlider.a0(BaseSlider.this.getContext(), j7);
            j7.recycle();
            return a02;
        }
    }

    /* access modifiers changed from: package-private */
    public class b implements ValueAnimator.AnimatorUpdateListener {
        b() {
        }

        public void onAnimationUpdate(ValueAnimator valueAnimator) {
            float floatValue = ((Float) valueAnimator.getAnimatedValue()).floatValue();
            for (com.google.android.material.tooltip.a aVar : BaseSlider.this.f8539k) {
                aVar.k1(floatValue);
            }
            ViewCompat.postInvalidateOnAnimation(BaseSlider.this);
        }
    }

    /* access modifiers changed from: package-private */
    public class c extends AnimatorListenerAdapter {
        c() {
        }

        public void onAnimationEnd(Animator animator) {
            super.onAnimationEnd(animator);
            for (com.google.android.material.tooltip.a aVar : BaseSlider.this.f8539k) {
                y.g(BaseSlider.this).remove(aVar);
            }
        }
    }

    /* access modifiers changed from: private */
    public class d implements Runnable {

        /* renamed from: f  reason: collision with root package name */
        int f8565f;

        private d() {
            this.f8565f = -1;
        }

        /* access modifiers changed from: package-private */
        public void a(int i7) {
            this.f8565f = i7;
        }

        public void run() {
            BaseSlider.this.f8535g.sendEventForVirtualView(this.f8565f, 4);
        }

        /* synthetic */ d(BaseSlider baseSlider, a aVar) {
            this();
        }
    }

    /* access modifiers changed from: private */
    public static class e extends ExploreByTouchHelper {

        /* renamed from: a  reason: collision with root package name */
        private final BaseSlider<?, ?, ?> f8567a;

        /* renamed from: b  reason: collision with root package name */
        Rect f8568b = new Rect();

        e(BaseSlider<?, ?, ?> baseSlider) {
            super(baseSlider);
            this.f8567a = baseSlider;
        }

        @NonNull
        private String a(int i7) {
            Context context;
            int i8;
            if (i7 == this.f8567a.getValues().size() - 1) {
                context = this.f8567a.getContext();
                i8 = a.m.f1567b0;
            } else if (i7 != 0) {
                return "";
            } else {
                context = this.f8567a.getContext();
                i8 = a.m.f1569c0;
            }
            return context.getString(i8);
        }

        /* access modifiers changed from: protected */
        @Override // androidx.customview.widget.ExploreByTouchHelper
        public int getVirtualViewAt(float f7, float f8) {
            for (int i7 = 0; i7 < this.f8567a.getValues().size(); i7++) {
                this.f8567a.o0(i7, this.f8568b);
                if (this.f8568b.contains((int) f7, (int) f8)) {
                    return i7;
                }
            }
            return -1;
        }

        /* access modifiers changed from: protected */
        @Override // androidx.customview.widget.ExploreByTouchHelper
        public void getVisibleVirtualViews(List<Integer> list) {
            for (int i7 = 0; i7 < this.f8567a.getValues().size(); i7++) {
                list.add(Integer.valueOf(i7));
            }
        }

        /* access modifiers changed from: protected */
        /* JADX WARNING: Code restructure failed: missing block: B:13:0x002e, code lost:
            if (r4.f8567a.m0(r5, r7.getFloat(androidx.core.view.accessibility.AccessibilityNodeInfoCompat.ACTION_ARGUMENT_PROGRESS_VALUE)) != false) goto L_0x0030;
         */
        @Override // androidx.customview.widget.ExploreByTouchHelper
        public boolean onPerformActionForVirtualView(int i7, int i8, Bundle bundle) {
            if (!this.f8567a.isEnabled()) {
                return false;
            }
            if (i8 == 4096 || i8 == 8192) {
                float m7 = this.f8567a.m(20);
                if (i8 == 8192) {
                    m7 = -m7;
                }
                if (this.f8567a.N()) {
                    m7 = -m7;
                }
                if (!this.f8567a.m0(i7, MathUtils.clamp(this.f8567a.getValues().get(i7).floatValue() + m7, this.f8567a.getValueFrom(), this.f8567a.getValueTo()))) {
                    return false;
                }
            } else {
                if (i8 == 16908349 && bundle != null && bundle.containsKey(AccessibilityNodeInfoCompat.ACTION_ARGUMENT_PROGRESS_VALUE)) {
                }
                return false;
            }
            this.f8567a.p0();
            this.f8567a.postInvalidate();
            invalidateVirtualView(i7);
            return true;
        }

        /* access modifiers changed from: protected */
        @Override // androidx.customview.widget.ExploreByTouchHelper
        public void onPopulateNodeForVirtualView(int i7, AccessibilityNodeInfoCompat accessibilityNodeInfoCompat) {
            accessibilityNodeInfoCompat.addAction(AccessibilityNodeInfoCompat.AccessibilityActionCompat.ACTION_SET_PROGRESS);
            List<Float> values = this.f8567a.getValues();
            float floatValue = values.get(i7).floatValue();
            float valueFrom = this.f8567a.getValueFrom();
            float valueTo = this.f8567a.getValueTo();
            if (this.f8567a.isEnabled()) {
                if (floatValue > valueFrom) {
                    accessibilityNodeInfoCompat.addAction(8192);
                }
                if (floatValue < valueTo) {
                    accessibilityNodeInfoCompat.addAction(4096);
                }
            }
            accessibilityNodeInfoCompat.setRangeInfo(AccessibilityNodeInfoCompat.RangeInfoCompat.obtain(1, valueFrom, valueTo, floatValue));
            accessibilityNodeInfoCompat.setClassName(SeekBar.class.getName());
            StringBuilder sb = new StringBuilder();
            if (this.f8567a.getContentDescription() != null) {
                sb.append(this.f8567a.getContentDescription());
                sb.append(",");
            }
            if (values.size() > 1) {
                sb.append(a(i7));
                sb.append(this.f8567a.D(floatValue));
            }
            accessibilityNodeInfoCompat.setContentDescription(sb.toString());
            this.f8567a.o0(i7, this.f8568b);
            accessibilityNodeInfoCompat.setBoundsInParent(this.f8568b);
        }
    }

    /* access modifiers changed from: private */
    public interface f {
        com.google.android.material.tooltip.a a();
    }

    public BaseSlider(@NonNull Context context) {
        this(context, null);
    }

    private void A() {
        if (this.f8542n) {
            this.f8542n = false;
            ValueAnimator q7 = q(false);
            this.f8544p = q7;
            this.f8543o = null;
            q7.addListener(new c());
            this.f8544p.start();
        }
    }

    private void B(int i7) {
        if (i7 == 1) {
            U(Integer.MAX_VALUE);
        } else if (i7 == 2) {
            U(Integer.MIN_VALUE);
        } else if (i7 == 17) {
            V(Integer.MAX_VALUE);
        } else if (i7 == 66) {
            V(Integer.MIN_VALUE);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String D(float f7) {
        if (K()) {
            return this.D.a(f7);
        }
        return String.format(((float) ((int) f7)) == f7 ? "%.0f" : "%.2f", Float.valueOf(f7));
    }

    private float[] E() {
        float floatValue = ((Float) Collections.max(getValues())).floatValue();
        float floatValue2 = ((Float) Collections.min(getValues())).floatValue();
        if (this.H.size() == 1) {
            floatValue2 = this.F;
        }
        float W2 = W(floatValue2);
        float W3 = W(floatValue);
        if (N()) {
            return new float[]{W3, W2};
        }
        return new float[]{W2, W3};
    }

    private static float F(ValueAnimator valueAnimator, float f7) {
        if (valueAnimator == null || !valueAnimator.isRunning()) {
            return f7;
        }
        float floatValue = ((Float) valueAnimator.getAnimatedValue()).floatValue();
        valueAnimator.cancel();
        return floatValue;
    }

    private float G(int i7, float f7) {
        float f8 = 0.0f;
        if (this.K == 0.0f) {
            f8 = getMinSeparation();
        }
        if (this.f8530b0 == 0) {
            f8 = t(f8);
        }
        if (N()) {
            f8 = -f8;
        }
        int i8 = i7 + 1;
        int i9 = i7 - 1;
        return MathUtils.clamp(f7, i9 < 0 ? this.F : this.H.get(i9).floatValue() + f8, i8 >= this.H.size() ? this.G : this.H.get(i8).floatValue() - f8);
    }

    @ColorInt
    private int H(@NonNull ColorStateList colorStateList) {
        return colorStateList.getColorForState(getDrawableState(), colorStateList.getDefaultColor());
    }

    private float I() {
        double l02 = l0(this.f8528a0);
        if (N()) {
            l02 = 1.0d - l02;
        }
        float f7 = this.G;
        float f8 = this.F;
        return (float) ((l02 * ((double) (f7 - f8))) + ((double) f8));
    }

    private float J() {
        float f7 = this.f8528a0;
        if (N()) {
            f7 = 1.0f - f7;
        }
        float f8 = this.G;
        float f9 = this.F;
        return (f7 * (f8 - f9)) + f9;
    }

    private void L() {
        this.f8527a.setStrokeWidth((float) this.f8550v);
        this.f8529b.setStrokeWidth((float) this.f8550v);
        this.f8533e.setStrokeWidth(((float) this.f8550v) / 2.0f);
        this.f8534f.setStrokeWidth(((float) this.f8550v) / 2.0f);
    }

    private boolean M() {
        ViewParent parent = getParent();
        while (true) {
            boolean z7 = false;
            if (!(parent instanceof ViewGroup)) {
                return false;
            }
            ViewGroup viewGroup = (ViewGroup) parent;
            if (viewGroup.canScrollVertically(1) || viewGroup.canScrollVertically(-1)) {
                z7 = true;
            }
            if (z7 && viewGroup.shouldDelayChildPressedState()) {
                return true;
            }
            parent = parent.getParent();
        }
    }

    private void P(@NonNull Resources resources) {
        this.f8548t = resources.getDimensionPixelSize(a.f.W5);
        int dimensionPixelOffset = resources.getDimensionPixelOffset(a.f.U5);
        this.f8546r = dimensionPixelOffset;
        this.f8551w = dimensionPixelOffset;
        this.f8547s = resources.getDimensionPixelSize(a.f.S5);
        this.f8552x = resources.getDimensionPixelOffset(a.f.V5);
        this.A = resources.getDimensionPixelSize(a.f.O5);
    }

    private void Q() {
        if (this.K > 0.0f) {
            r0();
            int min = Math.min((int) (((this.G - this.F) / this.K) + 1.0f), (this.N / (this.f8550v * 2)) + 1);
            float[] fArr = this.L;
            if (fArr == null || fArr.length != min * 2) {
                this.L = new float[(min * 2)];
            }
            float f7 = ((float) this.N) / ((float) (min - 1));
            for (int i7 = 0; i7 < min * 2; i7 += 2) {
                float[] fArr2 = this.L;
                fArr2[i7] = ((float) this.f8551w) + (((float) (i7 / 2)) * f7);
                fArr2[i7 + 1] = (float) n();
            }
        }
    }

    private void R(@NonNull Canvas canvas, int i7, int i8) {
        if (j0()) {
            canvas.drawCircle((float) ((int) (((float) this.f8551w) + (W(this.H.get(this.J).floatValue()) * ((float) i7)))), (float) i8, (float) this.f8554z, this.f8532d);
        }
    }

    private void S(@NonNull Canvas canvas) {
        if (this.M && this.K > 0.0f) {
            float[] E2 = E();
            int c02 = c0(this.L, E2[0]);
            int c03 = c0(this.L, E2[1]);
            int i7 = c02 * 2;
            canvas.drawPoints(this.L, 0, i7, this.f8533e);
            int i8 = c03 * 2;
            canvas.drawPoints(this.L, i7, i8 - i7, this.f8534f);
            float[] fArr = this.L;
            canvas.drawPoints(fArr, i8, fArr.length - i8, this.f8533e);
        }
    }

    private void T() {
        this.f8551w = this.f8546r + Math.max(this.f8553y - this.f8547s, 0);
        if (ViewCompat.isLaidOut(this)) {
            q0(getWidth());
        }
    }

    private boolean U(int i7) {
        int i8 = this.J;
        int clamp = (int) MathUtils.clamp(((long) i8) + ((long) i7), 0L, (long) (this.H.size() - 1));
        this.J = clamp;
        if (clamp == i8) {
            return false;
        }
        if (this.I != -1) {
            this.I = clamp;
        }
        p0();
        postInvalidate();
        return true;
    }

    private boolean V(int i7) {
        if (N()) {
            i7 = i7 == Integer.MIN_VALUE ? Integer.MAX_VALUE : -i7;
        }
        return U(i7);
    }

    private float W(float f7) {
        float f8 = this.F;
        float f9 = (f7 - f8) / (this.G - f8);
        return N() ? 1.0f - f9 : f9;
    }

    private Boolean X(int i7, @NonNull KeyEvent keyEvent) {
        if (i7 == 61) {
            return keyEvent.hasNoModifiers() ? Boolean.valueOf(U(1)) : keyEvent.isShiftPressed() ? Boolean.valueOf(U(-1)) : Boolean.FALSE;
        }
        if (i7 != 66) {
            if (i7 != 81) {
                if (i7 == 69) {
                    U(-1);
                    return Boolean.TRUE;
                } else if (i7 != 70) {
                    switch (i7) {
                        case 21:
                            V(-1);
                            return Boolean.TRUE;
                        case 22:
                            V(1);
                            return Boolean.TRUE;
                        case 23:
                            break;
                        default:
                            return null;
                    }
                }
            }
            U(1);
            return Boolean.TRUE;
        }
        this.I = this.J;
        postInvalidate();
        return Boolean.TRUE;
    }

    private void Y() {
        for (T t7 : this.f8541m) {
            t7.a(this);
        }
    }

    private void Z() {
        for (T t7 : this.f8541m) {
            t7.b(this);
        }
    }

    /* access modifiers changed from: private */
    @NonNull
    public static com.google.android.material.tooltip.a a0(@NonNull Context context, @NonNull TypedArray typedArray) {
        return com.google.android.material.tooltip.a.U0(context, null, 0, typedArray.getResourceId(a.o.Oo, a.n.Rc));
    }

    private static int c0(float[] fArr, float f7) {
        return Math.round(f7 * ((float) ((fArr.length / 2) - 1)));
    }

    private void d0(Context context, AttributeSet attributeSet, int i7) {
        TypedArray j7 = q.j(context, attributeSet, a.o.Fo, i7, f8522m0, new int[0]);
        this.F = j7.getFloat(a.o.Jo, 0.0f);
        this.G = j7.getFloat(a.o.Ko, 1.0f);
        setValues(Float.valueOf(this.F));
        this.K = j7.getFloat(a.o.Io, 0.0f);
        boolean hasValue = j7.hasValue(a.o.Yo);
        int i8 = hasValue ? a.o.Yo : a.o.ap;
        int i9 = hasValue ? a.o.Yo : a.o.Zo;
        ColorStateList a8 = com.google.android.material.resources.c.a(context, j7, i8);
        if (a8 == null) {
            a8 = AppCompatResources.getColorStateList(context, a.e.f963r1);
        }
        setTrackInactiveTintList(a8);
        ColorStateList a9 = com.google.android.material.resources.c.a(context, j7, i9);
        if (a9 == null) {
            a9 = AppCompatResources.getColorStateList(context, a.e.f951o1);
        }
        setTrackActiveTintList(a9);
        this.W.n0(com.google.android.material.resources.c.a(context, j7, a.o.Po));
        if (j7.hasValue(a.o.So)) {
            setThumbStrokeColor(com.google.android.material.resources.c.a(context, j7, a.o.So));
        }
        setThumbStrokeWidth(j7.getDimension(a.o.To, 0.0f));
        ColorStateList a10 = com.google.android.material.resources.c.a(context, j7, a.o.Lo);
        if (a10 == null) {
            a10 = AppCompatResources.getColorStateList(context, a.e.f955p1);
        }
        setHaloTintList(a10);
        this.M = j7.getBoolean(a.o.Xo, true);
        boolean hasValue2 = j7.hasValue(a.o.Uo);
        int i10 = hasValue2 ? a.o.Uo : a.o.Wo;
        int i11 = hasValue2 ? a.o.Uo : a.o.Vo;
        ColorStateList a11 = com.google.android.material.resources.c.a(context, j7, i10);
        if (a11 == null) {
            a11 = AppCompatResources.getColorStateList(context, a.e.f959q1);
        }
        setTickInactiveTintList(a11);
        ColorStateList a12 = com.google.android.material.resources.c.a(context, j7, i11);
        if (a12 == null) {
            a12 = AppCompatResources.getColorStateList(context, a.e.f947n1);
        }
        setTickActiveTintList(a12);
        setThumbRadius(j7.getDimensionPixelSize(a.o.Ro, 0));
        setHaloRadius(j7.getDimensionPixelSize(a.o.Mo, 0));
        setThumbElevation(j7.getDimension(a.o.Qo, 0.0f));
        setTrackHeight(j7.getDimensionPixelSize(a.o.bp, 0));
        this.f8549u = j7.getInt(a.o.No, 0);
        if (!j7.getBoolean(a.o.Go, true)) {
            setEnabled(false);
        }
        j7.recycle();
    }

    private void g0(int i7) {
        BaseSlider<S, L, T>.d dVar = this.f8537i;
        if (dVar == null) {
            this.f8537i = new d(this, null);
        } else {
            removeCallbacks(dVar);
        }
        this.f8537i.a(i7);
        postDelayed(this.f8537i, 200);
    }

    private void h0(com.google.android.material.tooltip.a aVar, float f7) {
        aVar.l1(D(f7));
        int W2 = (this.f8551w + ((int) (W(f7) * ((float) this.N)))) - (aVar.getIntrinsicWidth() / 2);
        int n7 = n() - (this.A + this.f8553y);
        aVar.setBounds(W2, n7 - aVar.getIntrinsicHeight(), aVar.getIntrinsicWidth() + W2, n7);
        Rect rect = new Rect(aVar.getBounds());
        com.google.android.material.internal.c.c(y.f(this), this, rect);
        aVar.setBounds(rect);
        y.g(this).add(aVar);
    }

    private void i0(@NonNull ArrayList<Float> arrayList) {
        if (!arrayList.isEmpty()) {
            Collections.sort(arrayList);
            if (this.H.size() != arrayList.size() || !this.H.equals(arrayList)) {
                this.H = arrayList;
                this.Q = true;
                this.J = 0;
                p0();
                r();
                v();
                postInvalidate();
                return;
            }
            return;
        }
        throw new IllegalArgumentException("At least one value must be set");
    }

    private void j(com.google.android.material.tooltip.a aVar) {
        aVar.j1(y.f(this));
    }

    private boolean j0() {
        return this.O || !(getBackground() instanceof RippleDrawable);
    }

    private Float k(int i7) {
        float m7 = this.P ? m(20) : l();
        if (i7 == 21) {
            if (!N()) {
                m7 = -m7;
            }
            return Float.valueOf(m7);
        } else if (i7 == 22) {
            if (N()) {
                m7 = -m7;
            }
            return Float.valueOf(m7);
        } else if (i7 == 69) {
            return Float.valueOf(-m7);
        } else {
            if (i7 == 70 || i7 == 81) {
                return Float.valueOf(m7);
            }
            return null;
        }
    }

    private boolean k0(float f7) {
        return m0(this.I, f7);
    }

    private float l() {
        float f7 = this.K;
        if (f7 == 0.0f) {
            return 1.0f;
        }
        return f7;
    }

    private double l0(float f7) {
        float f8 = this.K;
        if (f8 <= 0.0f) {
            return (double) f7;
        }
        int i7 = (int) ((this.G - this.F) / f8);
        return ((double) Math.round(f7 * ((float) i7))) / ((double) i7);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private float m(int i7) {
        float l7 = l();
        float f7 = (this.G - this.F) / l7;
        float f8 = (float) i7;
        return f7 <= f8 ? l7 : ((float) Math.round(f7 / f8)) * l7;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean m0(int i7, float f7) {
        if (((double) Math.abs(f7 - this.H.get(i7).floatValue())) < f8521l0) {
            return false;
        }
        this.H.set(i7, Float.valueOf(G(i7, f7)));
        this.J = i7;
        u(i7);
        return true;
    }

    private int n() {
        int i7 = this.f8552x;
        int i8 = 0;
        if (this.f8549u == 1) {
            i8 = this.f8539k.get(0).getIntrinsicHeight();
        }
        return i7 + i8;
    }

    private boolean n0() {
        return k0(I());
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void p0() {
        if (!j0() && getMeasuredWidth() > 0) {
            Drawable background = getBackground();
            if (background instanceof RippleDrawable) {
                int W2 = (int) ((W(this.H.get(this.J).floatValue()) * ((float) this.N)) + ((float) this.f8551w));
                int n7 = n();
                int i7 = this.f8554z;
                DrawableCompat.setHotspotBounds(background, W2 - i7, n7 - i7, W2 + i7, n7 + i7);
            }
        }
    }

    private ValueAnimator q(boolean z7) {
        float f7 = 0.0f;
        float F2 = F(z7 ? this.f8544p : this.f8543o, z7 ? 0.0f : 1.0f);
        if (z7) {
            f7 = 1.0f;
        }
        ValueAnimator ofFloat = ValueAnimator.ofFloat(F2, f7);
        ofFloat.setDuration(z7 ? f8525p0 : f8526q0);
        ofFloat.setInterpolator(z7 ? com.google.android.material.animation.a.f6958e : com.google.android.material.animation.a.f6956c);
        ofFloat.addUpdateListener(new b());
        return ofFloat;
    }

    private void q0(int i7) {
        this.N = Math.max(i7 - (this.f8551w * 2), 0);
        Q();
    }

    private void r() {
        if (this.f8539k.size() > this.H.size()) {
            List<com.google.android.material.tooltip.a> subList = this.f8539k.subList(this.H.size(), this.f8539k.size());
            for (com.google.android.material.tooltip.a aVar : subList) {
                if (ViewCompat.isAttachedToWindow(this)) {
                    s(aVar);
                }
            }
            subList.clear();
        }
        while (this.f8539k.size() < this.H.size()) {
            com.google.android.material.tooltip.a a8 = this.f8538j.a();
            this.f8539k.add(a8);
            if (ViewCompat.isAttachedToWindow(this)) {
                j(a8);
            }
        }
        int i7 = 1;
        if (this.f8539k.size() == 1) {
            i7 = 0;
        }
        for (com.google.android.material.tooltip.a aVar2 : this.f8539k) {
            aVar2.H0((float) i7);
        }
    }

    private void r0() {
        if (this.Q) {
            t0();
            u0();
            s0();
            v0();
            y0();
            this.Q = false;
        }
    }

    private void s(com.google.android.material.tooltip.a aVar) {
        x g7 = y.g(this);
        if (g7 != null) {
            g7.remove(aVar);
            aVar.W0(y.f(this));
        }
    }

    private void s0() {
        if (this.K > 0.0f && !w0(this.G)) {
            throw new IllegalStateException(String.format(f8517h0, Float.toString(this.K), Float.toString(this.F), Float.toString(this.G)));
        }
    }

    private float t(float f7) {
        if (f7 == 0.0f) {
            return 0.0f;
        }
        float f8 = (f7 - ((float) this.f8551w)) / ((float) this.N);
        float f9 = this.F;
        return (f8 * (f9 - this.G)) + f9;
    }

    private void t0() {
        if (this.F >= this.G) {
            throw new IllegalStateException(String.format(f8515f0, Float.toString(this.F), Float.toString(this.G)));
        }
    }

    private void u(int i7) {
        for (L l7 : this.f8540l) {
            l7.a(this, this.H.get(i7).floatValue(), true);
        }
        AccessibilityManager accessibilityManager = this.f8536h;
        if (accessibilityManager != null && accessibilityManager.isEnabled()) {
            g0(i7);
        }
    }

    private void u0() {
        if (this.G <= this.F) {
            throw new IllegalStateException(String.format(f8516g0, Float.toString(this.G), Float.toString(this.F)));
        }
    }

    private void v() {
        for (L l7 : this.f8540l) {
            Iterator<Float> it = this.H.iterator();
            while (it.hasNext()) {
                l7.a(this, it.next().floatValue(), false);
            }
        }
    }

    private void v0() {
        Iterator<Float> it = this.H.iterator();
        while (it.hasNext()) {
            Float next = it.next();
            if (next.floatValue() < this.F || next.floatValue() > this.G) {
                throw new IllegalStateException(String.format(f8513d0, Float.toString(next.floatValue()), Float.toString(this.F), Float.toString(this.G)));
            } else if (this.K > 0.0f && !w0(next.floatValue())) {
                throw new IllegalStateException(String.format(f8514e0, Float.toString(next.floatValue()), Float.toString(this.F), Float.toString(this.K), Float.toString(this.K)));
            }
        }
    }

    private void w(@NonNull Canvas canvas, int i7, int i8) {
        float[] E2 = E();
        int i9 = this.f8551w;
        float f7 = (float) i7;
        float f8 = (float) i8;
        canvas.drawLine(((float) i9) + (E2[0] * f7), f8, ((float) i9) + (E2[1] * f7), f8, this.f8529b);
    }

    private boolean w0(float f7) {
        double doubleValue = new BigDecimal(Float.toString(f7)).subtract(new BigDecimal(Float.toString(this.F))).divide(new BigDecimal(Float.toString(this.K)), MathContext.DECIMAL64).doubleValue();
        return Math.abs(((double) Math.round(doubleValue)) - doubleValue) < f8521l0;
    }

    private void x(@NonNull Canvas canvas, int i7, int i8) {
        float[] E2 = E();
        int i9 = this.f8551w;
        float f7 = (float) i7;
        float f8 = ((float) i9) + (E2[1] * f7);
        if (f8 < ((float) (i9 + i7))) {
            float f9 = (float) i8;
            canvas.drawLine(f8, f9, (float) (i9 + i7), f9, this.f8527a);
        }
        int i10 = this.f8551w;
        float f10 = ((float) i10) + (E2[0] * f7);
        if (f10 > ((float) i10)) {
            float f11 = (float) i8;
            canvas.drawLine((float) i10, f11, f10, f11, this.f8527a);
        }
    }

    private float x0(float f7) {
        return (W(f7) * ((float) this.N)) + ((float) this.f8551w);
    }

    private void y(@NonNull Canvas canvas, int i7, int i8) {
        if (!isEnabled()) {
            Iterator<Float> it = this.H.iterator();
            while (it.hasNext()) {
                canvas.drawCircle(((float) this.f8551w) + (W(it.next().floatValue()) * ((float) i7)), (float) i8, (float) this.f8553y, this.f8531c);
            }
        }
        Iterator<Float> it2 = this.H.iterator();
        while (it2.hasNext()) {
            canvas.save();
            int W2 = this.f8551w + ((int) (W(it2.next().floatValue()) * ((float) i7)));
            int i9 = this.f8553y;
            canvas.translate((float) (W2 - i9), (float) (i8 - i9));
            this.W.draw(canvas);
            canvas.restore();
        }
    }

    private void y0() {
        float f7 = this.K;
        if (f7 != 0.0f) {
            if (((float) ((int) f7)) != f7) {
                Log.w(f8512c0, String.format(f8518i0, "stepSize", Float.valueOf(f7)));
            }
            float f8 = this.F;
            if (((float) ((int) f8)) != f8) {
                Log.w(f8512c0, String.format(f8518i0, "valueFrom", Float.valueOf(f8)));
            }
            float f9 = this.G;
            if (((float) ((int) f9)) != f9) {
                Log.w(f8512c0, String.format(f8518i0, "valueTo", Float.valueOf(f9)));
            }
        }
    }

    private void z() {
        if (this.f8549u != 2) {
            if (!this.f8542n) {
                this.f8542n = true;
                ValueAnimator q7 = q(true);
                this.f8543o = q7;
                this.f8544p = null;
                q7.start();
            }
            Iterator<com.google.android.material.tooltip.a> it = this.f8539k.iterator();
            for (int i7 = 0; i7 < this.H.size() && it.hasNext(); i7++) {
                if (i7 != this.J) {
                    h0(it.next(), this.H.get(i7).floatValue());
                }
            }
            if (it.hasNext()) {
                h0(it.next(), this.H.get(this.J).floatValue());
            } else {
                throw new IllegalStateException(String.format("Not enough labels(%d) to display all the values(%d)", Integer.valueOf(this.f8539k.size()), Integer.valueOf(this.H.size())));
            }
        }
    }

    /* access modifiers changed from: package-private */
    @VisibleForTesting
    public void C(boolean z7) {
        this.O = z7;
    }

    public boolean K() {
        return this.D != null;
    }

    /* access modifiers changed from: package-private */
    public final boolean N() {
        return ViewCompat.getLayoutDirection(this) == 1;
    }

    public boolean O() {
        return this.M;
    }

    /* access modifiers changed from: protected */
    public boolean b0() {
        if (this.I != -1) {
            return true;
        }
        float J2 = J();
        float x02 = x0(J2);
        this.I = 0;
        float abs = Math.abs(this.H.get(0).floatValue() - J2);
        for (int i7 = 1; i7 < this.H.size(); i7++) {
            float abs2 = Math.abs(this.H.get(i7).floatValue() - J2);
            float x03 = x0(this.H.get(i7).floatValue());
            if (Float.compare(abs2, abs) > 1) {
                break;
            }
            boolean z7 = !N() ? x03 - x02 < 0.0f : x03 - x02 > 0.0f;
            if (Float.compare(abs2, abs) >= 0) {
                if (Float.compare(abs2, abs) != 0) {
                    continue;
                } else if (Math.abs(x03 - x02) < ((float) this.f8545q)) {
                    this.I = -1;
                    return false;
                } else if (!z7) {
                }
            }
            this.I = i7;
            abs = abs2;
        }
        return this.I != -1;
    }

    public boolean dispatchHoverEvent(@NonNull MotionEvent motionEvent) {
        return this.f8535g.dispatchHoverEvent(motionEvent) || super.dispatchHoverEvent(motionEvent);
    }

    public boolean dispatchKeyEvent(@NonNull KeyEvent keyEvent) {
        return super.dispatchKeyEvent(keyEvent);
    }

    /* access modifiers changed from: protected */
    public void drawableStateChanged() {
        super.drawableStateChanged();
        this.f8527a.setColor(H(this.V));
        this.f8529b.setColor(H(this.U));
        this.f8533e.setColor(H(this.T));
        this.f8534f.setColor(H(this.S));
        for (com.google.android.material.tooltip.a aVar : this.f8539k) {
            if (aVar.isStateful()) {
                aVar.setState(getDrawableState());
            }
        }
        if (this.W.isStateful()) {
            this.W.setState(getDrawableState());
        }
        this.f8532d.setColor(H(this.R));
        this.f8532d.setAlpha(63);
    }

    public void e0(@NonNull L l7) {
        this.f8540l.remove(l7);
    }

    public void f0(@NonNull T t7) {
        this.f8541m.remove(t7);
    }

    @NonNull
    public CharSequence getAccessibilityClassName() {
        return SeekBar.class.getName();
    }

    /* access modifiers changed from: package-private */
    @VisibleForTesting
    public final int getAccessibilityFocusedVirtualViewId() {
        return this.f8535g.getAccessibilityFocusedVirtualViewId();
    }

    public int getActiveThumbIndex() {
        return this.I;
    }

    public int getFocusedThumbIndex() {
        return this.J;
    }

    @Dimension
    public int getHaloRadius() {
        return this.f8554z;
    }

    @NonNull
    public ColorStateList getHaloTintList() {
        return this.R;
    }

    public int getLabelBehavior() {
        return this.f8549u;
    }

    /* access modifiers changed from: protected */
    public float getMinSeparation() {
        return 0.0f;
    }

    public float getStepSize() {
        return this.K;
    }

    public float getThumbElevation() {
        return this.W.x();
    }

    @Dimension
    public int getThumbRadius() {
        return this.f8553y;
    }

    public ColorStateList getThumbStrokeColor() {
        return this.W.M();
    }

    public float getThumbStrokeWidth() {
        return this.W.P();
    }

    @NonNull
    public ColorStateList getThumbTintList() {
        return this.W.y();
    }

    @NonNull
    public ColorStateList getTickActiveTintList() {
        return this.S;
    }

    @NonNull
    public ColorStateList getTickInactiveTintList() {
        return this.T;
    }

    @NonNull
    public ColorStateList getTickTintList() {
        if (this.T.equals(this.S)) {
            return this.S;
        }
        throw new IllegalStateException("The inactive and active ticks are different colors. Use the getTickColorInactive() and getTickColorActive() methods instead.");
    }

    @NonNull
    public ColorStateList getTrackActiveTintList() {
        return this.U;
    }

    @Dimension
    public int getTrackHeight() {
        return this.f8550v;
    }

    @NonNull
    public ColorStateList getTrackInactiveTintList() {
        return this.V;
    }

    @Dimension
    public int getTrackSidePadding() {
        return this.f8551w;
    }

    @NonNull
    public ColorStateList getTrackTintList() {
        if (this.V.equals(this.U)) {
            return this.U;
        }
        throw new IllegalStateException("The inactive and active parts of the track are different colors. Use the getInactiveTrackColor() and getActiveTrackColor() methods instead.");
    }

    @Dimension
    public int getTrackWidth() {
        return this.N;
    }

    public float getValueFrom() {
        return this.F;
    }

    public float getValueTo() {
        return this.G;
    }

    /* access modifiers changed from: package-private */
    @NonNull
    public List<Float> getValues() {
        return new ArrayList(this.H);
    }

    public void h(@Nullable L l7) {
        this.f8540l.add(l7);
    }

    public void i(@NonNull T t7) {
        this.f8541m.add(t7);
    }

    public void o() {
        this.f8540l.clear();
    }

    /* access modifiers changed from: package-private */
    public void o0(int i7, Rect rect) {
        int W2 = this.f8551w + ((int) (W(getValues().get(i7).floatValue()) * ((float) this.N)));
        int n7 = n();
        int i8 = this.f8553y;
        rect.set(W2 - i8, n7 - i8, W2 + i8, n7 + i8);
    }

    /* access modifiers changed from: protected */
    public void onAttachedToWindow() {
        super.onAttachedToWindow();
        for (com.google.android.material.tooltip.a aVar : this.f8539k) {
            j(aVar);
        }
    }

    /* access modifiers changed from: protected */
    public void onDetachedFromWindow() {
        BaseSlider<S, L, T>.d dVar = this.f8537i;
        if (dVar != null) {
            removeCallbacks(dVar);
        }
        this.f8542n = false;
        for (com.google.android.material.tooltip.a aVar : this.f8539k) {
            s(aVar);
        }
        super.onDetachedFromWindow();
    }

    /* access modifiers changed from: protected */
    public void onDraw(@NonNull Canvas canvas) {
        if (this.Q) {
            r0();
            Q();
        }
        super.onDraw(canvas);
        int n7 = n();
        x(canvas, this.N, n7);
        if (((Float) Collections.max(getValues())).floatValue() > this.F) {
            w(canvas, this.N, n7);
        }
        S(canvas);
        if ((this.E || isFocused()) && isEnabled()) {
            R(canvas, this.N, n7);
            if (this.I != -1) {
                z();
            }
        }
        y(canvas, this.N, n7);
    }

    /* access modifiers changed from: protected */
    public void onFocusChanged(boolean z7, int i7, @Nullable Rect rect) {
        super.onFocusChanged(z7, i7, rect);
        if (!z7) {
            this.I = -1;
            A();
            this.f8535g.clearKeyboardFocusForVirtualView(this.J);
            return;
        }
        B(i7);
        this.f8535g.requestKeyboardFocusForVirtualView(this.J);
    }

    public boolean onKeyDown(int i7, @NonNull KeyEvent keyEvent) {
        if (!isEnabled()) {
            return super.onKeyDown(i7, keyEvent);
        }
        if (this.H.size() == 1) {
            this.I = 0;
        }
        if (this.I == -1) {
            Boolean X = X(i7, keyEvent);
            return X != null ? X.booleanValue() : super.onKeyDown(i7, keyEvent);
        }
        this.P |= keyEvent.isLongPress();
        Float k7 = k(i7);
        if (k7 != null) {
            if (k0(this.H.get(this.I).floatValue() + k7.floatValue())) {
                p0();
                postInvalidate();
            }
            return true;
        }
        if (i7 != 23) {
            if (i7 != 61) {
                if (i7 != 66) {
                    return super.onKeyDown(i7, keyEvent);
                }
            } else if (keyEvent.hasNoModifiers()) {
                return U(1);
            } else {
                if (keyEvent.isShiftPressed()) {
                    return U(-1);
                }
                return false;
            }
        }
        this.I = -1;
        A();
        postInvalidate();
        return true;
    }

    public boolean onKeyUp(int i7, @NonNull KeyEvent keyEvent) {
        this.P = false;
        return super.onKeyUp(i7, keyEvent);
    }

    /* access modifiers changed from: protected */
    public void onMeasure(int i7, int i8) {
        int i9 = this.f8548t;
        int i10 = 0;
        if (this.f8549u == 1) {
            i10 = this.f8539k.get(0).getIntrinsicHeight();
        }
        super.onMeasure(i7, View.MeasureSpec.makeMeasureSpec(i9 + i10, 1073741824));
    }

    /* access modifiers changed from: protected */
    public void onRestoreInstanceState(Parcelable parcelable) {
        SliderState sliderState = (SliderState) parcelable;
        super.onRestoreInstanceState(sliderState.getSuperState());
        this.F = sliderState.f8555f;
        this.G = sliderState.f8556g;
        i0(sliderState.f8557p);
        this.K = sliderState.f8558x;
        if (sliderState.f8559y) {
            requestFocus();
        }
        v();
    }

    /* access modifiers changed from: protected */
    public Parcelable onSaveInstanceState() {
        SliderState sliderState = new SliderState(super.onSaveInstanceState());
        sliderState.f8555f = this.F;
        sliderState.f8556g = this.G;
        sliderState.f8557p = new ArrayList<>(this.H);
        sliderState.f8558x = this.K;
        sliderState.f8559y = hasFocus();
        return sliderState;
    }

    /* access modifiers changed from: protected */
    public void onSizeChanged(int i7, int i8, int i9, int i10) {
        q0(i7);
        p0();
    }

    public boolean onTouchEvent(@NonNull MotionEvent motionEvent) {
        if (!isEnabled()) {
            return false;
        }
        float x7 = motionEvent.getX();
        float f7 = (x7 - ((float) this.f8551w)) / ((float) this.N);
        this.f8528a0 = f7;
        float max = Math.max(0.0f, f7);
        this.f8528a0 = max;
        this.f8528a0 = Math.min(1.0f, max);
        int actionMasked = motionEvent.getActionMasked();
        if (actionMasked != 0) {
            if (actionMasked == 1) {
                this.E = false;
                MotionEvent motionEvent2 = this.C;
                if (motionEvent2 != null && motionEvent2.getActionMasked() == 0 && Math.abs(this.C.getX() - motionEvent.getX()) <= ((float) this.f8545q) && Math.abs(this.C.getY() - motionEvent.getY()) <= ((float) this.f8545q) && b0()) {
                    Y();
                }
                if (this.I != -1) {
                    n0();
                    this.I = -1;
                    Z();
                }
                A();
            } else if (actionMasked == 2) {
                if (!this.E) {
                    if (M() && Math.abs(x7 - this.B) < ((float) this.f8545q)) {
                        return false;
                    }
                    getParent().requestDisallowInterceptTouchEvent(true);
                    Y();
                }
                if (b0()) {
                    this.E = true;
                    n0();
                    p0();
                }
            }
            invalidate();
        } else {
            this.B = x7;
            if (!M()) {
                getParent().requestDisallowInterceptTouchEvent(true);
                if (b0()) {
                    requestFocus();
                    this.E = true;
                    n0();
                    p0();
                    invalidate();
                    Y();
                }
            }
        }
        setPressed(this.E);
        this.C = MotionEvent.obtain(motionEvent);
        return true;
    }

    public void p() {
        this.f8541m.clear();
    }

    /* access modifiers changed from: protected */
    public void setActiveThumbIndex(int i7) {
        this.I = i7;
    }

    public void setEnabled(boolean z7) {
        super.setEnabled(z7);
        setLayerType(z7 ? 0 : 2, null);
    }

    public void setFocusedThumbIndex(int i7) {
        if (i7 < 0 || i7 >= this.H.size()) {
            throw new IllegalArgumentException("index out of range");
        }
        this.J = i7;
        this.f8535g.requestKeyboardFocusForVirtualView(i7);
        postInvalidate();
    }

    public void setHaloRadius(@IntRange(from = 0) @Dimension int i7) {
        if (i7 != this.f8554z) {
            this.f8554z = i7;
            Drawable background = getBackground();
            if (j0() || !(background instanceof RippleDrawable)) {
                postInvalidate();
            } else {
                h0.a.b((RippleDrawable) background, this.f8554z);
            }
        }
    }

    public void setHaloRadiusResource(@DimenRes int i7) {
        setHaloRadius(getResources().getDimensionPixelSize(i7));
    }

    public void setHaloTintList(@NonNull ColorStateList colorStateList) {
        if (!colorStateList.equals(this.R)) {
            this.R = colorStateList;
            Drawable background = getBackground();
            if (j0() || !(background instanceof RippleDrawable)) {
                this.f8532d.setColor(H(colorStateList));
                this.f8532d.setAlpha(63);
                invalidate();
                return;
            }
            ((RippleDrawable) background).setColor(colorStateList);
        }
    }

    public void setLabelBehavior(int i7) {
        if (this.f8549u != i7) {
            this.f8549u = i7;
            requestLayout();
        }
    }

    public void setLabelFormatter(@Nullable d dVar) {
        this.D = dVar;
    }

    /* access modifiers changed from: protected */
    public void setSeparationUnit(int i7) {
        this.f8530b0 = i7;
    }

    public void setStepSize(float f7) {
        if (f7 < 0.0f) {
            throw new IllegalArgumentException(String.format(f8517h0, Float.toString(f7), Float.toString(this.F), Float.toString(this.G)));
        } else if (this.K != f7) {
            this.K = f7;
            this.Q = true;
            postInvalidate();
        }
    }

    public void setThumbElevation(float f7) {
        this.W.m0(f7);
    }

    public void setThumbElevationResource(@DimenRes int i7) {
        setThumbElevation(getResources().getDimension(i7));
    }

    public void setThumbRadius(@IntRange(from = 0) @Dimension int i7) {
        if (i7 != this.f8553y) {
            this.f8553y = i7;
            T();
            this.W.setShapeAppearanceModel(o.a().q(0, (float) this.f8553y).m());
            j jVar = this.W;
            int i8 = this.f8553y;
            jVar.setBounds(0, 0, i8 * 2, i8 * 2);
            postInvalidate();
        }
    }

    public void setThumbRadiusResource(@DimenRes int i7) {
        setThumbRadius(getResources().getDimensionPixelSize(i7));
    }

    public void setThumbStrokeColor(@Nullable ColorStateList colorStateList) {
        this.W.E0(colorStateList);
        postInvalidate();
    }

    public void setThumbStrokeColorResource(@ColorRes int i7) {
        if (i7 != 0) {
            setThumbStrokeColor(AppCompatResources.getColorStateList(getContext(), i7));
        }
    }

    public void setThumbStrokeWidth(float f7) {
        this.W.H0(f7);
        postInvalidate();
    }

    public void setThumbStrokeWidthResource(@DimenRes int i7) {
        if (i7 != 0) {
            setThumbStrokeWidth(getResources().getDimension(i7));
        }
    }

    public void setThumbTintList(@NonNull ColorStateList colorStateList) {
        if (!colorStateList.equals(this.W.y())) {
            this.W.n0(colorStateList);
            invalidate();
        }
    }

    public void setTickActiveTintList(@NonNull ColorStateList colorStateList) {
        if (!colorStateList.equals(this.S)) {
            this.S = colorStateList;
            this.f8534f.setColor(H(colorStateList));
            invalidate();
        }
    }

    public void setTickInactiveTintList(@NonNull ColorStateList colorStateList) {
        if (!colorStateList.equals(this.T)) {
            this.T = colorStateList;
            this.f8533e.setColor(H(colorStateList));
            invalidate();
        }
    }

    public void setTickTintList(@NonNull ColorStateList colorStateList) {
        setTickInactiveTintList(colorStateList);
        setTickActiveTintList(colorStateList);
    }

    public void setTickVisible(boolean z7) {
        if (this.M != z7) {
            this.M = z7;
            postInvalidate();
        }
    }

    public void setTrackActiveTintList(@NonNull ColorStateList colorStateList) {
        if (!colorStateList.equals(this.U)) {
            this.U = colorStateList;
            this.f8529b.setColor(H(colorStateList));
            invalidate();
        }
    }

    public void setTrackHeight(@IntRange(from = 0) @Dimension int i7) {
        if (this.f8550v != i7) {
            this.f8550v = i7;
            L();
            postInvalidate();
        }
    }

    public void setTrackInactiveTintList(@NonNull ColorStateList colorStateList) {
        if (!colorStateList.equals(this.V)) {
            this.V = colorStateList;
            this.f8527a.setColor(H(colorStateList));
            invalidate();
        }
    }

    public void setTrackTintList(@NonNull ColorStateList colorStateList) {
        setTrackInactiveTintList(colorStateList);
        setTrackActiveTintList(colorStateList);
    }

    public void setValueFrom(float f7) {
        this.F = f7;
        this.Q = true;
        postInvalidate();
    }

    public void setValueTo(float f7) {
        this.G = f7;
        this.Q = true;
        postInvalidate();
    }

    /* access modifiers changed from: package-private */
    public void setValues(@NonNull List<Float> list) {
        i0(new ArrayList<>(list));
    }

    public BaseSlider(@NonNull Context context, @Nullable AttributeSet attributeSet) {
        this(context, attributeSet, a.c.Ic);
    }

    /* access modifiers changed from: package-private */
    public void setValues(@NonNull Float... fArr) {
        ArrayList<Float> arrayList = new ArrayList<>();
        Collections.addAll(arrayList, fArr);
        i0(arrayList);
    }

    public BaseSlider(@NonNull Context context, @Nullable AttributeSet attributeSet, int i7) {
        super(l0.a.c(context, attributeSet, i7, f8522m0), attributeSet, i7);
        this.f8539k = new ArrayList();
        this.f8540l = new ArrayList();
        this.f8541m = new ArrayList();
        this.f8542n = false;
        this.E = false;
        this.H = new ArrayList<>();
        this.I = -1;
        this.J = -1;
        this.K = 0.0f;
        this.M = true;
        this.P = false;
        j jVar = new j();
        this.W = jVar;
        this.f8530b0 = 0;
        Context context2 = getContext();
        Paint paint = new Paint();
        this.f8527a = paint;
        paint.setStyle(Paint.Style.STROKE);
        paint.setStrokeCap(Paint.Cap.ROUND);
        Paint paint2 = new Paint();
        this.f8529b = paint2;
        paint2.setStyle(Paint.Style.STROKE);
        paint2.setStrokeCap(Paint.Cap.ROUND);
        Paint paint3 = new Paint(1);
        this.f8531c = paint3;
        paint3.setStyle(Paint.Style.FILL);
        paint3.setXfermode(new PorterDuffXfermode(PorterDuff.Mode.CLEAR));
        Paint paint4 = new Paint(1);
        this.f8532d = paint4;
        paint4.setStyle(Paint.Style.FILL);
        Paint paint5 = new Paint();
        this.f8533e = paint5;
        paint5.setStyle(Paint.Style.STROKE);
        paint5.setStrokeCap(Paint.Cap.ROUND);
        Paint paint6 = new Paint();
        this.f8534f = paint6;
        paint6.setStyle(Paint.Style.STROKE);
        paint6.setStrokeCap(Paint.Cap.ROUND);
        P(context2.getResources());
        this.f8538j = new a(attributeSet, i7);
        d0(context2, attributeSet, i7);
        setFocusable(true);
        setClickable(true);
        jVar.w0(2);
        this.f8545q = ViewConfiguration.get(context2).getScaledTouchSlop();
        e eVar = new e(this);
        this.f8535g = eVar;
        ViewCompat.setAccessibilityDelegate(this, eVar);
        this.f8536h = (AccessibilityManager) getContext().getSystemService("accessibility");
    }
}
