package com.google.cardboard.sdk.qrcode.camera;

import android.annotation.SuppressLint;
import android.content.Context;
import android.graphics.ImageFormat;
import android.hardware.Camera;
import android.os.SystemClock;
import android.util.Log;
import android.view.SurfaceHolder;
import android.view.WindowManager;
import androidx.annotation.RequiresPermission;
import com.google.android.gms.common.images.a;
import com.google.android.gms.vision.b;
import com.google.android.gms.vision.d;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

public class CameraSource {
    private static final float ASPECT_RATIO_TOLERANCE = 0.01f;
    @SuppressLint({"InlinedApi"})
    public static final int CAMERA_FACING_BACK = 0;
    @SuppressLint({"InlinedApi"})
    public static final int CAMERA_FACING_FRONT = 1;
    private static final float FPS = 15.0f;
    private static final int HEIGHT = 1200;
    private static final String TAG = "CameraSource";
    private static final int WIDTH = 1600;
    private final Map<byte[], ByteBuffer> bytesToByteBuffer = new HashMap();
    private Camera camera;
    private final Object cameraLock = new Object();
    private final Context context;
    private final FrameProcessingRunnable frameProcessor;
    private a previewSize;
    private Thread processingThread;
    private int rotation;

    /* access modifiers changed from: private */
    public class CameraPreviewCallback implements Camera.PreviewCallback {
        private CameraPreviewCallback() {
        }

        public void onPreviewFrame(byte[] bArr, Camera camera) {
            CameraSource.this.frameProcessor.setNextFrame(bArr, camera);
        }
    }

    /* access modifiers changed from: private */
    public class FrameProcessingRunnable implements Runnable {
        static final /* synthetic */ boolean $assertionsDisabled = false;
        private boolean active = true;
        private b<?> detector;
        private final Object lock = new Object();
        private ByteBuffer pendingFrameData;
        private int pendingFrameId = 0;
        private long pendingTimeMillis;
        private final long startTimeMillis = SystemClock.elapsedRealtime();

        FrameProcessingRunnable(b<?> bVar) {
            this.detector = bVar;
        }

        /* access modifiers changed from: package-private */
        @SuppressLint({"Assert"})
        public void release() {
            b<?> bVar = this.detector;
            if (bVar != null) {
                bVar.d();
                this.detector = null;
            }
        }

        /* JADX WARNING: Code restructure failed: missing block: B:19:?, code lost:
            r6.detector.c(r1);
         */
        /* JADX WARNING: Code restructure failed: missing block: B:21:0x0075, code lost:
            r0 = move-exception;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:23:?, code lost:
            android.util.Log.e(com.google.cardboard.sdk.qrcode.camera.CameraSource.TAG, "Exception thrown from receiver.", r0);
         */
        /* JADX WARNING: Code restructure failed: missing block: B:25:0x008e, code lost:
            r0 = move-exception;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:26:0x008f, code lost:
            r6.this$0.camera.addCallbackBuffer(r2.array());
         */
        /* JADX WARNING: Code restructure failed: missing block: B:27:0x009c, code lost:
            throw r0;
         */
        /* JADX WARNING: Removed duplicated region for block: B:16:0x0021  */
        /* JADX WARNING: Removed duplicated region for block: B:32:0x001f A[SYNTHETIC] */
        public void run() {
            boolean z7;
            while (true) {
                synchronized (this.lock) {
                    while (true) {
                        z7 = this.active;
                        if (z7 && this.pendingFrameData == null) {
                            try {
                                this.lock.wait();
                            } catch (InterruptedException e7) {
                                Log.d(CameraSource.TAG, "Frame processing loop terminated.", e7);
                                return;
                            }
                        } else if (!z7) {
                            d a8 = new d.a().d(this.pendingFrameData, CameraSource.this.previewSize.b(), CameraSource.this.previewSize.a(), 17).c(this.pendingFrameId).f(this.pendingTimeMillis).e(CameraSource.this.rotation).a();
                            ByteBuffer byteBuffer = this.pendingFrameData;
                            this.pendingFrameData = null;
                        } else {
                            return;
                        }
                    }
                    if (!z7) {
                    }
                }
            }
        }

        /* access modifiers changed from: package-private */
        public void setActive(boolean z7) {
            synchronized (this.lock) {
                this.active = z7;
                this.lock.notifyAll();
            }
        }

        /* access modifiers changed from: package-private */
        public void setNextFrame(byte[] bArr, Camera camera) {
            synchronized (this.lock) {
                ByteBuffer byteBuffer = this.pendingFrameData;
                if (byteBuffer != null) {
                    camera.addCallbackBuffer(byteBuffer.array());
                    this.pendingFrameData = null;
                }
                if (!CameraSource.this.bytesToByteBuffer.containsKey(bArr)) {
                    Log.d(CameraSource.TAG, "Skipping frame.  Could not find ByteBuffer associated with the image data from the camera.");
                    return;
                }
                this.pendingTimeMillis = SystemClock.elapsedRealtime() - this.startTimeMillis;
                this.pendingFrameId++;
                this.pendingFrameData = (ByteBuffer) CameraSource.this.bytesToByteBuffer.get(bArr);
                this.lock.notifyAll();
            }
        }
    }

    /* access modifiers changed from: private */
    public static class SizePair {
        private a picture;
        private final a preview;

        public SizePair(Camera.Size size, Camera.Size size2) {
            this.preview = new a(size.width, size.height);
            if (size2 != null) {
                this.picture = new a(size2.width, size2.height);
            }
        }

        public a pictureSize() {
            return this.picture;
        }

        public a previewSize() {
            return this.preview;
        }
    }

    public CameraSource(Context context2, b<?> bVar) {
        if (context2 == null) {
            Log.e(TAG, "context is null.");
            throw new IllegalArgumentException("No context supplied.");
        } else if (bVar != null) {
            this.context = context2;
            this.frameProcessor = new FrameProcessingRunnable(bVar);
            Log.i(TAG, "Successful CameraSource creation.");
        } else {
            Log.e(TAG, "detector is null.");
            throw new IllegalArgumentException("No detector supplied.");
        }
    }

    @SuppressLint({"InlinedApi"})
    private Camera createCamera() {
        int idForRequestedCamera = getIdForRequestedCamera(0);
        if (idForRequestedCamera != -1) {
            Camera open = Camera.open(idForRequestedCamera);
            SizePair selectSizePair = selectSizePair(open, WIDTH, HEIGHT);
            if (selectSizePair != null) {
                a pictureSize = selectSizePair.pictureSize();
                this.previewSize = selectSizePair.previewSize();
                int[] selectPreviewFpsRange = selectPreviewFpsRange(open, FPS);
                if (selectPreviewFpsRange != null) {
                    Camera.Parameters parameters = open.getParameters();
                    if (pictureSize != null) {
                        parameters.setPictureSize(pictureSize.b(), pictureSize.a());
                    }
                    parameters.setPreviewSize(this.previewSize.b(), this.previewSize.a());
                    parameters.setPreviewFpsRange(selectPreviewFpsRange[0], selectPreviewFpsRange[1]);
                    parameters.setPreviewFormat(17);
                    setRotation(open, parameters, idForRequestedCamera);
                    if (parameters.getSupportedFocusModes().contains("continuous-picture")) {
                        parameters.setFocusMode("continuous-picture");
                    } else {
                        Log.i(TAG, "Camera focus mode: FOCUS_MODE_CONTINUOUS_PICTURE is not supported on this device.");
                    }
                    open.setParameters(parameters);
                    open.setPreviewCallbackWithBuffer(new CameraPreviewCallback());
                    open.addCallbackBuffer(createPreviewBuffer(this.previewSize));
                    open.addCallbackBuffer(createPreviewBuffer(this.previewSize));
                    open.addCallbackBuffer(createPreviewBuffer(this.previewSize));
                    open.addCallbackBuffer(createPreviewBuffer(this.previewSize));
                    Log.i(TAG, "Successful camera creation.");
                    return open;
                }
                Log.e(TAG, "Could not find suitable preview frames per second range.");
                throw new RuntimeException("Could not find suitable preview frames per second range.");
            }
            Log.e(TAG, "Could not find suitable preview size.");
            throw new RuntimeException("Could not find suitable preview size.");
        }
        Log.e(TAG, "Could not find requested camera.");
        throw new RuntimeException("Could not find requested camera.");
    }

    private byte[] createPreviewBuffer(a aVar) {
        byte[] bArr = new byte[(((int) Math.ceil(((double) ((((long) aVar.a()) * ((long) aVar.b())) * ((long) ImageFormat.getBitsPerPixel(17)))) / 8.0d)) + 1)];
        this.bytesToByteBuffer.put(bArr, ByteBuffer.wrap(bArr));
        return bArr;
    }

    private static List<SizePair> generateValidPreviewSizeList(Camera camera2) {
        Camera.Parameters parameters = camera2.getParameters();
        List<Camera.Size> supportedPreviewSizes = parameters.getSupportedPreviewSizes();
        List<Camera.Size> supportedPictureSizes = parameters.getSupportedPictureSizes();
        ArrayList arrayList = new ArrayList();
        for (Camera.Size size : supportedPreviewSizes) {
            float f7 = ((float) size.width) / ((float) size.height);
            Iterator<Camera.Size> it = supportedPictureSizes.iterator();
            while (true) {
                if (!it.hasNext()) {
                    break;
                }
                Camera.Size next = it.next();
                if (Math.abs(f7 - (((float) next.width) / ((float) next.height))) < ASPECT_RATIO_TOLERANCE) {
                    arrayList.add(new SizePair(size, next));
                    break;
                }
            }
        }
        if (arrayList.isEmpty()) {
            Log.w(TAG, "No preview sizes have a corresponding same-aspect-ratio picture size");
            for (Camera.Size size2 : supportedPreviewSizes) {
                arrayList.add(new SizePair(size2, null));
            }
        }
        return arrayList;
    }

    private static int getIdForRequestedCamera(int i7) {
        Camera.CameraInfo cameraInfo = new Camera.CameraInfo();
        for (int i8 = 0; i8 < Camera.getNumberOfCameras(); i8++) {
            Camera.getCameraInfo(i8, cameraInfo);
            if (cameraInfo.facing == i7) {
                return i8;
            }
        }
        return -1;
    }

    private static int[] selectPreviewFpsRange(Camera camera2, float f7) {
        int i7 = (int) (f7 * 1000.0f);
        int[] iArr = null;
        int i8 = Integer.MAX_VALUE;
        for (int[] iArr2 : camera2.getParameters().getSupportedPreviewFpsRange()) {
            int abs = Math.abs(i7 - iArr2[0]) + Math.abs(i7 - iArr2[1]);
            if (abs < i8) {
                iArr = iArr2;
                i8 = abs;
            }
        }
        return iArr;
    }

    private static SizePair selectSizePair(Camera camera2, int i7, int i8) {
        SizePair sizePair = null;
        int i9 = Integer.MAX_VALUE;
        for (SizePair sizePair2 : generateValidPreviewSizeList(camera2)) {
            a previewSize2 = sizePair2.previewSize();
            int abs = Math.abs(previewSize2.b() - i7) + Math.abs(previewSize2.a() - i8);
            if (abs < i9) {
                sizePair = sizePair2;
                i9 = abs;
            }
        }
        return sizePair;
    }

    private void setRotation(Camera camera2, Camera.Parameters parameters, int i7) {
        int i8;
        int i9;
        int rotation2 = ((WindowManager) this.context.getSystemService("window")).getDefaultDisplay().getRotation();
        int i10 = 0;
        if (rotation2 != 0) {
            if (rotation2 == 1) {
                i10 = 90;
            } else if (rotation2 == 2) {
                i10 = 180;
            } else if (rotation2 != 3) {
                String str = TAG;
                Log.e(str, "Bad rotation value: " + rotation2);
            } else {
                i10 = 270;
            }
        }
        Camera.CameraInfo cameraInfo = new Camera.CameraInfo();
        Camera.getCameraInfo(i7, cameraInfo);
        if (cameraInfo.facing == 1) {
            i8 = (cameraInfo.orientation + i10) % 360;
            i9 = (360 - i8) % 360;
        } else {
            i8 = ((cameraInfo.orientation - i10) + 360) % 360;
            i9 = i8;
        }
        this.rotation = i8 / 90;
        camera2.setDisplayOrientation(i9);
        parameters.setRotation(i8);
    }

    public a getPreviewSize() {
        return this.previewSize;
    }

    public void release() {
        synchronized (this.cameraLock) {
            stop();
            this.frameProcessor.release();
        }
    }

    @RequiresPermission("android.permission.CAMERA")
    public CameraSource start(SurfaceHolder surfaceHolder) throws IOException {
        synchronized (this.cameraLock) {
            if (this.camera != null) {
                return this;
            }
            Camera createCamera = createCamera();
            this.camera = createCamera;
            createCamera.setPreviewDisplay(surfaceHolder);
            this.camera.startPreview();
            this.processingThread = new Thread(this.frameProcessor);
            this.frameProcessor.setActive(true);
            this.processingThread.start();
            return this;
        }
    }

    public void stop() {
        synchronized (this.cameraLock) {
            this.frameProcessor.setActive(false);
            Thread thread = this.processingThread;
            if (thread != null) {
                try {
                    thread.join();
                } catch (InterruptedException unused) {
                    Log.d(TAG, "Frame processing thread interrupted on release.");
                }
                this.processingThread = null;
            }
            this.bytesToByteBuffer.clear();
            Camera camera2 = this.camera;
            if (camera2 != null) {
                camera2.stopPreview();
                this.camera.setPreviewCallbackWithBuffer(null);
                try {
                    this.camera.setPreviewTexture(null);
                } catch (Exception e7) {
                    String str = TAG;
                    Log.e(str, "Failed to clear camera preview: " + e7);
                }
                this.camera.release();
                this.camera = null;
            }
        }
    }
}
