package com.google.common.io;

import com.google.common.base.Ascii;
import com.google.common.base.Optional;
import com.google.common.base.Preconditions;
import com.google.common.collect.t5;
import com.google.common.hash.p;
import com.google.common.hash.q;
import com.google.common.hash.r;
import com.google.common.hash.s;
import java.io.BufferedInputStream;
import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.Reader;
import java.nio.charset.Charset;
import java.util.Arrays;
import java.util.Collection;
import java.util.Iterator;

@m0.c
public abstract class g {

    /* access modifiers changed from: package-private */
    public class a extends l {

        /* renamed from: a  reason: collision with root package name */
        final Charset f11418a;

        a(Charset charset) {
            this.f11418a = (Charset) Preconditions.checkNotNull(charset);
        }

        @Override // com.google.common.io.l
        public g b(Charset charset) {
            return charset.equals(this.f11418a) ? g.this : super.b(charset);
        }

        @Override // com.google.common.io.l
        public Reader q() throws IOException {
            return new InputStreamReader(g.this.m(), this.f11418a);
        }

        @Override // com.google.common.io.l
        public String r() throws IOException {
            return new String(g.this.o(), this.f11418a);
        }

        public String toString() {
            return g.this.toString() + ".asCharSource(" + this.f11418a + ")";
        }
    }

    private static class b extends g {

        /* renamed from: a  reason: collision with root package name */
        final byte[] f11420a;

        /* renamed from: b  reason: collision with root package name */
        final int f11421b;

        /* renamed from: c  reason: collision with root package name */
        final int f11422c;

        b(byte[] bArr) {
            this(bArr, 0, bArr.length);
        }

        @Override // com.google.common.io.g
        public long g(OutputStream outputStream) throws IOException {
            outputStream.write(this.f11420a, this.f11421b, this.f11422c);
            return (long) this.f11422c;
        }

        @Override // com.google.common.io.g
        public q j(r rVar) throws IOException {
            return rVar.j(this.f11420a, this.f11421b, this.f11422c);
        }

        @Override // com.google.common.io.g
        public boolean k() {
            return this.f11422c == 0;
        }

        @Override // com.google.common.io.g
        public InputStream l() throws IOException {
            return m();
        }

        @Override // com.google.common.io.g
        public InputStream m() {
            return new ByteArrayInputStream(this.f11420a, this.f11421b, this.f11422c);
        }

        @Override // com.google.common.io.g
        public <T> T n(e<T> eVar) throws IOException {
            eVar.a(this.f11420a, this.f11421b, this.f11422c);
            return eVar.getResult();
        }

        @Override // com.google.common.io.g
        public byte[] o() {
            byte[] bArr = this.f11420a;
            int i7 = this.f11421b;
            return Arrays.copyOfRange(bArr, i7, this.f11422c + i7);
        }

        @Override // com.google.common.io.g
        public long p() {
            return (long) this.f11422c;
        }

        @Override // com.google.common.io.g
        public Optional<Long> q() {
            return Optional.of(Long.valueOf((long) this.f11422c));
        }

        @Override // com.google.common.io.g
        public g r(long j7, long j8) {
            boolean z7 = true;
            Preconditions.checkArgument(j7 >= 0, "offset (%s) may not be negative", j7);
            if (j8 < 0) {
                z7 = false;
            }
            Preconditions.checkArgument(z7, "length (%s) may not be negative", j8);
            long min = Math.min(j7, (long) this.f11422c);
            return new b(this.f11420a, this.f11421b + ((int) min), (int) Math.min(j8, ((long) this.f11422c) - min));
        }

        public String toString() {
            return "ByteSource.wrap(" + Ascii.truncate(b.a().m(this.f11420a, this.f11421b, this.f11422c), 30, "...") + ")";
        }

        b(byte[] bArr, int i7, int i8) {
            this.f11420a = bArr;
            this.f11421b = i7;
            this.f11422c = i8;
        }
    }

    /* access modifiers changed from: private */
    public static final class c extends g {

        /* renamed from: a  reason: collision with root package name */
        final Iterable<? extends g> f11423a;

        c(Iterable<? extends g> iterable) {
            this.f11423a = (Iterable) Preconditions.checkNotNull(iterable);
        }

        @Override // com.google.common.io.g
        public boolean k() throws IOException {
            for (g gVar : this.f11423a) {
                if (!gVar.k()) {
                    return false;
                }
            }
            return true;
        }

        @Override // com.google.common.io.g
        public InputStream m() throws IOException {
            return new c0(this.f11423a.iterator());
        }

        @Override // com.google.common.io.g
        public long p() throws IOException {
            long j7 = 0;
            for (g gVar : this.f11423a) {
                j7 += gVar.p();
                if (j7 < 0) {
                    return Long.MAX_VALUE;
                }
            }
            return j7;
        }

        @Override // com.google.common.io.g
        public Optional<Long> q() {
            long valueOf;
            Iterable<? extends g> iterable = this.f11423a;
            if (!(iterable instanceof Collection)) {
                return Optional.absent();
            }
            Iterator<? extends g> it = iterable.iterator();
            long j7 = 0;
            while (true) {
                if (!it.hasNext()) {
                    valueOf = Long.valueOf(j7);
                    break;
                }
                Optional<Long> q7 = ((g) it.next()).q();
                if (q7.isPresent()) {
                    j7 += q7.get().longValue();
                    if (j7 < 0) {
                        valueOf = Long.MAX_VALUE;
                        break;
                    }
                } else {
                    return Optional.absent();
                }
            }
            return Optional.of(valueOf);
        }

        public String toString() {
            return "ByteSource.concat(" + this.f11423a + ")";
        }
    }

    private static final class d extends b {

        /* renamed from: d  reason: collision with root package name */
        static final d f11424d = new d();

        d() {
            super(new byte[0]);
        }

        @Override // com.google.common.io.g
        public l a(Charset charset) {
            Preconditions.checkNotNull(charset);
            return l.i();
        }

        @Override // com.google.common.io.g, com.google.common.io.g.b
        public byte[] o() {
            return this.f11420a;
        }

        @Override // com.google.common.io.g.b
        public String toString() {
            return "ByteSource.empty()";
        }
    }

    /* access modifiers changed from: private */
    public final class e extends g {

        /* renamed from: a  reason: collision with root package name */
        final long f11425a;

        /* renamed from: b  reason: collision with root package name */
        final long f11426b;

        e(long j7, long j8) {
            boolean z7 = true;
            Preconditions.checkArgument(j7 >= 0, "offset (%s) may not be negative", j7);
            Preconditions.checkArgument(j8 < 0 ? false : z7, "length (%s) may not be negative", j8);
            this.f11425a = j7;
            this.f11426b = j8;
        }

        private InputStream t(InputStream inputStream) throws IOException {
            o a8;
            long j7 = this.f11425a;
            if (j7 > 0) {
                try {
                    if (h.t(inputStream, j7) < this.f11425a) {
                        inputStream.close();
                        return new ByteArrayInputStream(new byte[0]);
                    }
                } catch (Throwable th) {
                    a8.close();
                    throw th;
                }
            }
            return h.f(inputStream, this.f11426b);
        }

        @Override // com.google.common.io.g
        public boolean k() throws IOException {
            return this.f11426b == 0 || g.super.k();
        }

        @Override // com.google.common.io.g
        public InputStream l() throws IOException {
            return t(g.this.l());
        }

        @Override // com.google.common.io.g
        public InputStream m() throws IOException {
            return t(g.this.m());
        }

        @Override // com.google.common.io.g
        public Optional<Long> q() {
            Optional<Long> q7 = g.this.q();
            if (!q7.isPresent()) {
                return Optional.absent();
            }
            long longValue = q7.get().longValue();
            return Optional.of(Long.valueOf(Math.min(this.f11426b, longValue - Math.min(this.f11425a, longValue))));
        }

        @Override // com.google.common.io.g
        public g r(long j7, long j8) {
            boolean z7 = true;
            Preconditions.checkArgument(j7 >= 0, "offset (%s) may not be negative", j7);
            if (j8 < 0) {
                z7 = false;
            }
            Preconditions.checkArgument(z7, "length (%s) may not be negative", j8);
            return g.this.r(this.f11425a + j7, Math.min(j8, this.f11426b - j7));
        }

        public String toString() {
            return g.this.toString() + ".slice(" + this.f11425a + ", " + this.f11426b + ")";
        }
    }

    protected g() {
    }

    public static g b(Iterable<? extends g> iterable) {
        return new c(iterable);
    }

    public static g c(Iterator<? extends g> it) {
        return b(t5.J(it));
    }

    public static g d(g... gVarArr) {
        return b(t5.L(gVarArr));
    }

    private long h(InputStream inputStream) throws IOException {
        long j7 = 0;
        while (true) {
            long t7 = h.t(inputStream, 2147483647L);
            if (t7 <= 0) {
                return j7;
            }
            j7 += t7;
        }
    }

    public static g i() {
        return d.f11424d;
    }

    public static g s(byte[] bArr) {
        return new b(bArr);
    }

    public l a(Charset charset) {
        return new a(charset);
    }

    public boolean e(g gVar) throws IOException {
        int n7;
        Preconditions.checkNotNull(gVar);
        byte[] d7 = h.d();
        byte[] d8 = h.d();
        o a8 = o.a();
        try {
            InputStream inputStream = (InputStream) a8.b(m());
            InputStream inputStream2 = (InputStream) a8.b(gVar.m());
            do {
                n7 = h.n(inputStream, d7, 0, d7.length);
                if (n7 == h.n(inputStream2, d8, 0, d8.length)) {
                    if (!Arrays.equals(d7, d8)) {
                    }
                }
                a8.close();
                return false;
            } while (n7 == d7.length);
            a8.close();
            return true;
        } catch (Throwable th) {
            a8.close();
            throw th;
        }
    }

    @p0.a
    public long f(f fVar) throws IOException {
        Preconditions.checkNotNull(fVar);
        o a8 = o.a();
        try {
            long b7 = h.b((InputStream) a8.b(m()), (OutputStream) a8.b(fVar.c()));
            a8.close();
            return b7;
        } catch (Throwable th) {
            a8.close();
            throw th;
        }
    }

    @p0.a
    public long g(OutputStream outputStream) throws IOException {
        Preconditions.checkNotNull(outputStream);
        o a8 = o.a();
        try {
            long b7 = h.b((InputStream) a8.b(m()), outputStream);
            a8.close();
            return b7;
        } catch (Throwable th) {
            a8.close();
            throw th;
        }
    }

    public q j(r rVar) throws IOException {
        s b7 = rVar.b();
        g(p.a(b7));
        return b7.i();
    }

    public boolean k() throws IOException {
        Optional<Long> q7 = q();
        boolean z7 = true;
        if (q7.isPresent()) {
            return q7.get().longValue() == 0;
        }
        o a8 = o.a();
        try {
            if (((InputStream) a8.b(m())).read() != -1) {
                z7 = false;
            }
            a8.close();
            return z7;
        } catch (Throwable th) {
            a8.close();
            throw th;
        }
    }

    public InputStream l() throws IOException {
        InputStream m7 = m();
        return m7 instanceof BufferedInputStream ? (BufferedInputStream) m7 : new BufferedInputStream(m7);
    }

    public abstract InputStream m() throws IOException;

    @m0.a
    @p0.a
    public <T> T n(e<T> eVar) throws IOException {
        Preconditions.checkNotNull(eVar);
        o a8 = o.a();
        try {
            T t7 = (T) h.o((InputStream) a8.b(m()), eVar);
            a8.close();
            return t7;
        } catch (Throwable th) {
            a8.close();
            throw th;
        }
    }

    public byte[] o() throws IOException {
        o a8 = o.a();
        try {
            InputStream inputStream = (InputStream) a8.b(m());
            Optional<Long> q7 = q();
            byte[] v7 = q7.isPresent() ? h.v(inputStream, q7.get().longValue()) : h.u(inputStream);
            a8.close();
            return v7;
        } catch (Throwable th) {
            a8.close();
            throw th;
        }
    }

    public long p() throws IOException {
        o a8;
        Optional<Long> q7 = q();
        if (q7.isPresent()) {
            return q7.get().longValue();
        }
        o a9 = o.a();
        try {
            long h7 = h((InputStream) a9.b(m()));
            a9.close();
            return h7;
        } catch (IOException unused) {
            a9.close();
            a8 = o.a();
            long e7 = h.e((InputStream) a8.b(m()));
            a8.close();
            return e7;
        } catch (Throwable th) {
            try {
                throw a8.c(th);
            } catch (Throwable th2) {
                a8.close();
                throw th2;
            }
        }
    }

    @m0.a
    public Optional<Long> q() {
        return Optional.absent();
    }

    public g r(long j7, long j8) {
        return new e(j7, j8);
    }
}
