package com.google.common.io;

import com.google.common.base.Joiner;
import com.google.common.base.Optional;
import com.google.common.base.Preconditions;
import com.google.common.base.Predicate;
import com.google.common.base.Splitter;
import com.google.common.collect.e7;
import com.google.common.collect.i9;
import com.google.common.collect.ke;
import com.google.common.graph.p0;
import com.google.common.graph.q0;
import com.google.common.hash.q;
import com.google.common.hash.r;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.RandomAccessFile;
import java.nio.MappedByteBuffer;
import java.nio.channels.FileChannel;
import java.nio.charset.Charset;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;

@m0.c
public final class t {

    /* renamed from: a  reason: collision with root package name */
    private static final int f11476a = 10000;

    /* renamed from: b  reason: collision with root package name */
    private static final ke<File> f11477b = new b();

    /* renamed from: c  reason: collision with root package name */
    private static final p0<File> f11478c = new c();

    /* access modifiers changed from: package-private */
    public static class a implements x<List<String>> {

        /* renamed from: a  reason: collision with root package name */
        final List<String> f11479a = i9.q();

        a() {
        }

        @Override // com.google.common.io.x
        public boolean a(String str) {
            this.f11479a.add(str);
            return true;
        }

        /* renamed from: b */
        public List<String> getResult() {
            return this.f11479a;
        }
    }

    static class b extends ke<File> {
        b() {
        }

        /* renamed from: h */
        public Iterable<File> b(File file) {
            return t.n(file);
        }

        public String toString() {
            return "Files.fileTreeTraverser()";
        }
    }

    static class c implements p0<File> {
        c() {
        }

        /* renamed from: Q */
        public Iterable<File> b(File file) {
            return t.n(file);
        }
    }

    /* access modifiers changed from: private */
    public static final class d extends f {

        /* renamed from: a  reason: collision with root package name */
        private final File f11480a;

        /* renamed from: b  reason: collision with root package name */
        private final e7<s> f11481b;

        private d(File file, s... sVarArr) {
            this.f11480a = (File) Preconditions.checkNotNull(file);
            this.f11481b = e7.P(sVarArr);
        }

        /* renamed from: f */
        public FileOutputStream c() throws IOException {
            return new FileOutputStream(this.f11480a, this.f11481b.contains(s.APPEND));
        }

        public String toString() {
            return "Files.asByteSink(" + this.f11480a + ", " + this.f11481b + ")";
        }

        /* synthetic */ d(File file, s[] sVarArr, a aVar) {
            this(file, sVarArr);
        }
    }

    /* access modifiers changed from: private */
    public static final class e extends g {

        /* renamed from: a  reason: collision with root package name */
        private final File f11482a;

        private e(File file) {
            this.f11482a = (File) Preconditions.checkNotNull(file);
        }

        @Override // com.google.common.io.g
        public byte[] o() throws IOException {
            o a8 = o.a();
            try {
                FileInputStream fileInputStream = (FileInputStream) a8.b(m());
                byte[] v7 = h.v(fileInputStream, fileInputStream.getChannel().size());
                a8.close();
                return v7;
            } catch (Throwable th) {
                a8.close();
                throw th;
            }
        }

        @Override // com.google.common.io.g
        public long p() throws IOException {
            if (this.f11482a.isFile()) {
                return this.f11482a.length();
            }
            throw new FileNotFoundException(this.f11482a.toString());
        }

        @Override // com.google.common.io.g
        public Optional<Long> q() {
            return this.f11482a.isFile() ? Optional.of(Long.valueOf(this.f11482a.length())) : Optional.absent();
        }

        /* renamed from: t */
        public FileInputStream m() throws IOException {
            return new FileInputStream(this.f11482a);
        }

        public String toString() {
            return "Files.asByteSource(" + this.f11482a + ")";
        }

        /* synthetic */ e(File file, a aVar) {
            this(file);
        }
    }

    private enum f implements Predicate<File> {
        IS_DIRECTORY {
            /* renamed from: a */
            public boolean apply(File file) {
                return file.isDirectory();
            }

            public String toString() {
                return "Files.isDirectory()";
            }
        },
        IS_FILE {
            /* renamed from: a */
            public boolean apply(File file) {
                return file.isFile();
            }

            public String toString() {
                return "Files.isFile()";
            }
        };

        /* synthetic */ f(a aVar) {
            this();
        }
    }

    private t() {
    }

    @m0.a
    public static BufferedWriter A(File file, Charset charset) throws FileNotFoundException {
        Preconditions.checkNotNull(file);
        Preconditions.checkNotNull(charset);
        return new BufferedWriter(new OutputStreamWriter(new FileOutputStream(file), charset));
    }

    @Deprecated
    @m0.a
    @p0.a
    public static <T> T B(File file, e<T> eVar) throws IOException {
        return (T) d(file).n(eVar);
    }

    @m0.a
    @Deprecated
    public static String C(File file, Charset charset) throws IOException {
        return f(file, charset).s();
    }

    @Deprecated
    @m0.a
    @p0.a
    public static <T> T D(File file, Charset charset, x<T> xVar) throws IOException {
        return (T) f(file, charset).u(xVar);
    }

    @m0.a
    public static List<String> E(File file, Charset charset) throws IOException {
        return (List) f(file, charset).u(new a());
    }

    @m0.a
    public static String F(String str) {
        Preconditions.checkNotNull(str);
        if (str.length() == 0) {
            return ".";
        }
        Iterable<String> split = Splitter.on('/').omitEmptyStrings().split(str);
        ArrayList arrayList = new ArrayList();
        for (String str2 : split) {
            str2.hashCode();
            if (!str2.equals(".")) {
                if (!str2.equals("..")) {
                    arrayList.add(str2);
                } else if (arrayList.size() <= 0 || ((String) arrayList.get(arrayList.size() - 1)).equals("..")) {
                    arrayList.add("..");
                } else {
                    arrayList.remove(arrayList.size() - 1);
                }
            }
        }
        String join = Joiner.on('/').join(arrayList);
        if (str.charAt(0) == '/') {
            join = "/" + join;
        }
        while (join.startsWith("/../")) {
            join = join.substring(3);
        }
        return join.equals("/..") ? "/" : "".equals(join) ? "." : join;
    }

    @m0.a
    public static byte[] G(File file) throws IOException {
        return d(file).o();
    }

    @m0.a
    @Deprecated
    public static String H(File file, Charset charset) throws IOException {
        return f(file, charset).r();
    }

    @m0.a
    public static void I(File file) throws IOException {
        Preconditions.checkNotNull(file);
        if (!file.createNewFile() && !file.setLastModified(System.currentTimeMillis())) {
            throw new IOException("Unable to update modification time of " + file);
        }
    }

    @m0.a
    @Deprecated
    public static void J(CharSequence charSequence, File file, Charset charset) throws IOException {
        e(file, charset, new s[0]).c(charSequence);
    }

    @m0.a
    public static void K(byte[] bArr, File file) throws IOException {
        c(file, new s[0]).d(bArr);
    }

    @m0.a
    @Deprecated
    public static void b(CharSequence charSequence, File file, Charset charset) throws IOException {
        e(file, charset, s.APPEND).c(charSequence);
    }

    public static f c(File file, s... sVarArr) {
        return new d(file, sVarArr, null);
    }

    public static g d(File file) {
        return new e(file, null);
    }

    public static j e(File file, Charset charset, s... sVarArr) {
        return c(file, sVarArr).a(charset);
    }

    public static l f(File file, Charset charset) {
        return d(file).a(charset);
    }

    @m0.a
    public static void g(File file, File file2) throws IOException {
        Preconditions.checkArgument(!file.equals(file2), "Source %s and destination %s must be different", file, file2);
        d(file).f(c(file2, new s[0]));
    }

    @m0.a
    public static void h(File file, OutputStream outputStream) throws IOException {
        d(file).g(outputStream);
    }

    @m0.a
    @Deprecated
    public static void i(File file, Charset charset, Appendable appendable) throws IOException {
        f(file, charset).g(appendable);
    }

    @m0.a
    public static void j(File file) throws IOException {
        Preconditions.checkNotNull(file);
        File parentFile = file.getCanonicalFile().getParentFile();
        if (parentFile != null) {
            parentFile.mkdirs();
            if (!parentFile.isDirectory()) {
                throw new IOException("Unable to create parent directories of " + file);
            }
        }
    }

    @m0.a
    public static File k() {
        File file = new File(System.getProperty("java.io.tmpdir"));
        String str = System.currentTimeMillis() + "-";
        for (int i7 = 0; i7 < f11476a; i7++) {
            File file2 = new File(file, str + i7);
            if (file2.mkdir()) {
                return file2;
            }
        }
        throw new IllegalStateException("Failed to create directory within 10000 attempts (tried " + str + "0 to " + str + 9999 + ')');
    }

    @m0.a
    public static boolean l(File file, File file2) throws IOException {
        Preconditions.checkNotNull(file);
        Preconditions.checkNotNull(file2);
        if (file == file2 || file.equals(file2)) {
            return true;
        }
        long length = file.length();
        long length2 = file2.length();
        if (length == 0 || length2 == 0 || length == length2) {
            return d(file).e(d(file2));
        }
        return false;
    }

    @m0.a
    public static q0<File> m() {
        return q0.h(f11478c);
    }

    /* access modifiers changed from: private */
    public static Iterable<File> n(File file) {
        File[] listFiles;
        return (!file.isDirectory() || (listFiles = file.listFiles()) == null) ? Collections.emptyList() : Collections.unmodifiableList(Arrays.asList(listFiles));
    }

    @Deprecated
    static ke<File> o() {
        return f11477b;
    }

    @m0.a
    public static String p(String str) {
        Preconditions.checkNotNull(str);
        String name = new File(str).getName();
        int lastIndexOf = name.lastIndexOf(46);
        return lastIndexOf == -1 ? "" : name.substring(lastIndexOf + 1);
    }

    @m0.a
    public static String q(String str) {
        Preconditions.checkNotNull(str);
        String name = new File(str).getName();
        int lastIndexOf = name.lastIndexOf(46);
        return lastIndexOf == -1 ? name : name.substring(0, lastIndexOf);
    }

    @m0.a
    @Deprecated
    public static q r(File file, r rVar) throws IOException {
        return d(file).j(rVar);
    }

    @m0.a
    public static Predicate<File> s() {
        return f.IS_DIRECTORY;
    }

    @m0.a
    public static Predicate<File> t() {
        return f.IS_FILE;
    }

    @m0.a
    public static MappedByteBuffer u(File file) throws IOException {
        Preconditions.checkNotNull(file);
        return v(file, FileChannel.MapMode.READ_ONLY);
    }

    @m0.a
    public static MappedByteBuffer v(File file, FileChannel.MapMode mapMode) throws IOException {
        return x(file, mapMode, -1);
    }

    @m0.a
    public static MappedByteBuffer w(File file, FileChannel.MapMode mapMode, long j7) throws IOException {
        Preconditions.checkArgument(j7 >= 0, "size (%s) may not be negative", j7);
        return x(file, mapMode, j7);
    }

    private static MappedByteBuffer x(File file, FileChannel.MapMode mapMode, long j7) throws IOException {
        Preconditions.checkNotNull(file);
        Preconditions.checkNotNull(mapMode);
        o a8 = o.a();
        try {
            FileChannel fileChannel = (FileChannel) a8.b(((RandomAccessFile) a8.b(new RandomAccessFile(file, mapMode == FileChannel.MapMode.READ_ONLY ? "r" : "rw"))).getChannel());
            if (j7 == -1) {
                j7 = fileChannel.size();
            }
            MappedByteBuffer map = fileChannel.map(mapMode, 0, j7);
            a8.close();
            return map;
        } catch (Throwable th) {
            a8.close();
            throw th;
        }
    }

    @m0.a
    public static void y(File file, File file2) throws IOException {
        Preconditions.checkNotNull(file);
        Preconditions.checkNotNull(file2);
        Preconditions.checkArgument(!file.equals(file2), "Source %s and destination %s must be different", file, file2);
        if (!file.renameTo(file2)) {
            g(file, file2);
            if (file.delete()) {
                return;
            }
            if (!file2.delete()) {
                throw new IOException("Unable to delete " + file2);
            }
            throw new IOException("Unable to delete " + file);
        }
    }

    @m0.a
    public static BufferedReader z(File file, Charset charset) throws FileNotFoundException {
        Preconditions.checkNotNull(file);
        Preconditions.checkNotNull(charset);
        return new BufferedReader(new InputStreamReader(new FileInputStream(file), charset));
    }
}
