package com.google.common.reflect;

import com.google.common.base.CharMatcher;
import com.google.common.base.Preconditions;
import com.google.common.base.Predicate;
import com.google.common.base.Splitter;
import com.google.common.base.StandardSystemProperty;
import com.google.common.collect.e7;
import com.google.common.collect.h6;
import com.google.common.collect.hc;
import com.google.common.collect.jc;
import com.google.common.collect.le;
import com.google.common.collect.oa;
import com.google.common.collect.t5;
import com.google.common.collect.v9;
import com.google.common.collect.y3;
import com.google.common.io.g;
import com.google.common.io.h0;
import com.google.common.io.l;
import java.io.File;
import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URISyntaxException;
import java.net.URL;
import java.net.URLClassLoader;
import java.nio.charset.Charset;
import java.util.Enumeration;
import java.util.HashSet;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.Map;
import java.util.NoSuchElementException;
import java.util.Set;
import java.util.jar.Attributes;
import java.util.jar.JarEntry;
import java.util.jar.JarFile;
import java.util.jar.Manifest;
import java.util.logging.Logger;

@m0.a
public final class b {

    /* renamed from: b  reason: collision with root package name */
    private static final Logger f11892b = Logger.getLogger(b.class.getName());

    /* renamed from: c  reason: collision with root package name */
    private static final Predicate<C0165b> f11893c = new a();

    /* renamed from: d  reason: collision with root package name */
    private static final Splitter f11894d = Splitter.on(" ").omitEmptyStrings();

    /* renamed from: e  reason: collision with root package name */
    private static final String f11895e = ".class";

    /* renamed from: a  reason: collision with root package name */
    private final e7<d> f11896a;

    static class a implements Predicate<C0165b> {
        a() {
        }

        /* renamed from: a */
        public boolean apply(C0165b bVar) {
            return bVar.f11897c.indexOf(36) == -1;
        }
    }

    @m0.a
    /* renamed from: com.google.common.reflect.b$b  reason: collision with other inner class name */
    public static final class C0165b extends d {

        /* renamed from: c  reason: collision with root package name */
        private final String f11897c;

        C0165b(String str, ClassLoader classLoader) {
            super(str, classLoader);
            this.f11897c = b.e(str);
        }

        public String g() {
            return this.f11897c;
        }

        public String h() {
            return h.b(this.f11897c);
        }

        public String i() {
            int lastIndexOf = this.f11897c.lastIndexOf(36);
            if (lastIndexOf != -1) {
                return CharMatcher.digit().trimLeadingFrom(this.f11897c.substring(lastIndexOf + 1));
            }
            String h7 = h();
            boolean isEmpty = h7.isEmpty();
            String str = this.f11897c;
            return isEmpty ? str : str.substring(h7.length() + 1);
        }

        public Class<?> j() {
            try {
                return this.f11900b.loadClass(this.f11897c);
            } catch (ClassNotFoundException e7) {
                throw new IllegalStateException(e7);
            }
        }

        @Override // com.google.common.reflect.b.d
        public String toString() {
            return this.f11897c;
        }
    }

    @m0.d
    static final class c extends e {

        /* renamed from: b  reason: collision with root package name */
        private final hc<ClassLoader, String> f11898b = oa.d().g().a();

        c() {
        }

        private void m(File file, ClassLoader classLoader, String str, Set<File> set) throws IOException {
            File[] listFiles = file.listFiles();
            if (listFiles == null) {
                b.f11892b.warning("Cannot read directory " + file);
                return;
            }
            for (File file2 : listFiles) {
                String name = file2.getName();
                if (file2.isDirectory()) {
                    File canonicalFile = file2.getCanonicalFile();
                    if (set.add(canonicalFile)) {
                        m(canonicalFile, classLoader, str + name + "/", set);
                        set.remove(canonicalFile);
                    }
                } else {
                    String str2 = str + name;
                    if (!str2.equals("META-INF/MANIFEST.MF")) {
                        this.f11898b.get(classLoader).add(str2);
                    }
                }
            }
        }

        /* access modifiers changed from: protected */
        @Override // com.google.common.reflect.b.e
        public void h(ClassLoader classLoader, File file) throws IOException {
            HashSet hashSet = new HashSet();
            hashSet.add(file.getCanonicalFile());
            m(file, classLoader, "", hashSet);
        }

        /* access modifiers changed from: protected */
        @Override // com.google.common.reflect.b.e
        public void k(ClassLoader classLoader, JarFile jarFile) {
            Enumeration<JarEntry> entries = jarFile.entries();
            while (entries.hasMoreElements()) {
                JarEntry nextElement = entries.nextElement();
                if (!nextElement.isDirectory() && !nextElement.getName().equals("META-INF/MANIFEST.MF")) {
                    this.f11898b.get(classLoader).add(nextElement.getName());
                }
            }
        }

        /* access modifiers changed from: package-private */
        public e7<d> l() {
            e7.a s7 = e7.s();
            for (Map.Entry<ClassLoader, String> entry : this.f11898b.h()) {
                s7.a(d.d(entry.getValue(), entry.getKey()));
            }
            return s7.e();
        }
    }

    @m0.a
    public static class d {

        /* renamed from: a  reason: collision with root package name */
        private final String f11899a;

        /* renamed from: b  reason: collision with root package name */
        final ClassLoader f11900b;

        d(String str, ClassLoader classLoader) {
            this.f11899a = (String) Preconditions.checkNotNull(str);
            this.f11900b = (ClassLoader) Preconditions.checkNotNull(classLoader);
        }

        static d d(String str, ClassLoader classLoader) {
            return str.endsWith(b.f11895e) ? new C0165b(str, classLoader) : new d(str, classLoader);
        }

        public final g a() {
            return h0.a(e());
        }

        public final l b(Charset charset) {
            return h0.b(e(), charset);
        }

        public final String c() {
            return this.f11899a;
        }

        public final URL e() {
            URL resource = this.f11900b.getResource(this.f11899a);
            if (resource != null) {
                return resource;
            }
            throw new NoSuchElementException(this.f11899a);
        }

        public boolean equals(Object obj) {
            if (!(obj instanceof d)) {
                return false;
            }
            d dVar = (d) obj;
            return this.f11899a.equals(dVar.f11899a) && this.f11900b == dVar.f11900b;
        }

        public int hashCode() {
            return this.f11899a.hashCode();
        }

        public String toString() {
            return this.f11899a;
        }
    }

    static abstract class e {

        /* renamed from: a  reason: collision with root package name */
        private final Set<File> f11901a = jc.u();

        e() {
        }

        private static t5<URL> a(ClassLoader classLoader) {
            return classLoader instanceof URLClassLoader ? t5.L(((URLClassLoader) classLoader).getURLs()) : classLoader.equals(ClassLoader.getSystemClassLoader()) ? e() : t5.R();
        }

        @m0.d
        static h6<File, ClassLoader> b(ClassLoader classLoader) {
            LinkedHashMap m02 = v9.m0();
            ClassLoader parent = classLoader.getParent();
            if (parent != null) {
                m02.putAll(b(parent));
            }
            le<URL> n7 = a(classLoader).iterator();
            while (n7.hasNext()) {
                URL next = n7.next();
                if (next.getProtocol().equals("file")) {
                    File j7 = b.j(next);
                    if (!m02.containsKey(j7)) {
                        m02.put(j7, classLoader);
                    }
                }
            }
            return h6.g(m02);
        }

        @m0.d
        static URL c(File file, String str) throws MalformedURLException {
            return new URL(file.toURI().toURL(), str);
        }

        @m0.d
        static e7<File> d(File file, Manifest manifest) {
            if (manifest == null) {
                return e7.Y();
            }
            e7.a s7 = e7.s();
            String value = manifest.getMainAttributes().getValue(Attributes.Name.CLASS_PATH.toString());
            if (value != null) {
                for (String str : b.f11894d.split(value)) {
                    try {
                        URL c7 = c(file, str);
                        if (c7.getProtocol().equals("file")) {
                            s7.a(b.j(c7));
                        }
                    } catch (MalformedURLException unused) {
                        Logger logger = b.f11892b;
                        logger.warning("Invalid Class-Path entry: " + str);
                    }
                }
            }
            return s7.e();
        }

        /* JADX WARNING: Can't wrap try/catch for region: R(8:3|4|5|7|8|15|12|1) */
        /* JADX WARNING: Code restructure failed: missing block: B:6:0x0039, code lost:
            r3 = move-exception;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:9:0x0050, code lost:
            r4 = com.google.common.reflect.b.f11892b;
            r5 = java.util.logging.Level.WARNING;
            r4.log(r5, "malformed classpath entry: " + r2, (java.lang.Throwable) r3);
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:7:0x003b */
        @m0.d
        static t5<URL> e() {
            t5.b t7 = t5.t();
            Iterator<String> it = Splitter.on(StandardSystemProperty.PATH_SEPARATOR.value()).split(StandardSystemProperty.JAVA_CLASS_PATH.value()).iterator();
            while (it.hasNext()) {
                String next = it.next();
                t7.a(new File(next).toURI().toURL());
                t7.a(new URL("file", (String) null, new File(next).getAbsolutePath()));
            }
            return t7.e();
        }

        private void i(File file, ClassLoader classLoader) throws IOException {
            try {
                if (file.exists()) {
                    if (file.isDirectory()) {
                        h(classLoader, file);
                    } else {
                        j(file, classLoader);
                    }
                }
            } catch (SecurityException e7) {
                Logger logger = b.f11892b;
                logger.warning("Cannot access " + file + ": " + e7);
            }
        }

        private void j(File file, ClassLoader classLoader) throws IOException {
            try {
                JarFile jarFile = new JarFile(file);
                try {
                    le<File> n7 = d(file, jarFile.getManifest()).iterator();
                    while (n7.hasNext()) {
                        f(n7.next(), classLoader);
                    }
                    k(classLoader, jarFile);
                } finally {
                    try {
                        jarFile.close();
                    } catch (IOException unused) {
                    }
                }
            } catch (IOException unused2) {
            }
        }

        /* access modifiers changed from: package-private */
        @m0.d
        public final void f(File file, ClassLoader classLoader) throws IOException {
            if (this.f11901a.add(file.getCanonicalFile())) {
                i(file, classLoader);
            }
        }

        public final void g(ClassLoader classLoader) throws IOException {
            le<Map.Entry<File, ClassLoader>> n7 = b(classLoader).entrySet().iterator();
            while (n7.hasNext()) {
                Map.Entry<File, ClassLoader> next = n7.next();
                f(next.getKey(), next.getValue());
            }
        }

        /* access modifiers changed from: protected */
        public abstract void h(ClassLoader classLoader, File file) throws IOException;

        /* access modifiers changed from: protected */
        public abstract void k(ClassLoader classLoader, JarFile jarFile) throws IOException;
    }

    private b(e7<d> e7Var) {
        this.f11896a = e7Var;
    }

    public static b c(ClassLoader classLoader) throws IOException {
        c cVar = new c();
        cVar.g(classLoader);
        return new b(cVar.l());
    }

    @m0.d
    static String e(String str) {
        return str.substring(0, str.length() - 6).replace('/', '.');
    }

    @m0.d
    static File j(URL url) {
        Preconditions.checkArgument(url.getProtocol().equals("file"));
        try {
            return new File(url.toURI());
        } catch (URISyntaxException unused) {
            return new File(url.getPath());
        }
    }

    public e7<C0165b> d() {
        return y3.J(this.f11896a).u(C0165b.class).e0();
    }

    public e7<d> f() {
        return this.f11896a;
    }

    public e7<C0165b> g() {
        return y3.J(this.f11896a).u(C0165b.class).t(f11893c).e0();
    }

    public e7<C0165b> h(String str) {
        Preconditions.checkNotNull(str);
        e7.a s7 = e7.s();
        le<C0165b> n7 = g().iterator();
        while (n7.hasNext()) {
            C0165b next = n7.next();
            if (next.h().equals(str)) {
                s7.a(next);
            }
        }
        return s7.e();
    }

    public e7<C0165b> i(String str) {
        Preconditions.checkNotNull(str);
        String str2 = str + '.';
        e7.a s7 = e7.s();
        le<C0165b> n7 = g().iterator();
        while (n7.hasNext()) {
            C0165b next = n7.next();
            if (next.g().startsWith(str2)) {
                s7.a(next);
            }
        }
        return s7.e();
    }
}
