package com.google.common.reflect;

import com.google.common.base.Preconditions;
import com.google.common.collect.t5;
import java.lang.annotation.Annotation;
import java.lang.reflect.AccessibleObject;
import java.lang.reflect.AnnotatedType;
import java.lang.reflect.Constructor;
import java.lang.reflect.GenericDeclaration;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Member;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.lang.reflect.Type;
import java.lang.reflect.TypeVariable;
import java.util.Arrays;

@m0.a
public abstract class e<T, R> extends c implements GenericDeclaration {

    /* access modifiers changed from: package-private */
    public static class a<T> extends e<T, T> {

        /* renamed from: c  reason: collision with root package name */
        final Constructor<?> f11906c;

        a(Constructor<?> constructor) {
            super(constructor);
            this.f11906c = constructor;
        }

        private boolean D() {
            Class<?> declaringClass = this.f11906c.getDeclaringClass();
            if (declaringClass.getEnclosingConstructor() != null) {
                return true;
            }
            Method enclosingMethod = declaringClass.getEnclosingMethod();
            return enclosingMethod != null ? !Modifier.isStatic(enclosingMethod.getModifiers()) : declaringClass.getEnclosingClass() != null && !Modifier.isStatic(declaringClass.getModifiers());
        }

        @Override // com.google.common.reflect.e
        public final boolean A() {
            return this.f11906c.isVarArgs();
        }

        @Override // java.lang.reflect.GenericDeclaration
        public final TypeVariable<?>[] getTypeParameters() {
            TypeVariable<Class<? super T>>[] typeParameters = getDeclaringClass().getTypeParameters();
            TypeVariable<Constructor<?>>[] typeParameters2 = this.f11906c.getTypeParameters();
            TypeVariable<?>[] typeVariableArr = new TypeVariable[(typeParameters.length + typeParameters2.length)];
            System.arraycopy(typeParameters, 0, typeVariableArr, 0, typeParameters.length);
            System.arraycopy(typeParameters2, 0, typeVariableArr, typeParameters.length, typeParameters2.length);
            return typeVariableArr;
        }

        /* access modifiers changed from: package-private */
        @Override // com.google.common.reflect.e
        public AnnotatedType[] o() {
            return this.f11906c.getAnnotatedParameterTypes();
        }

        @Override // com.google.common.reflect.e
        public AnnotatedType p() {
            return this.f11906c.getAnnotatedReturnType();
        }

        /* access modifiers changed from: package-private */
        @Override // com.google.common.reflect.e
        public Type[] r() {
            return this.f11906c.getGenericExceptionTypes();
        }

        /* access modifiers changed from: package-private */
        @Override // com.google.common.reflect.e
        public Type[] s() {
            Type[] genericParameterTypes = this.f11906c.getGenericParameterTypes();
            if (genericParameterTypes.length > 0 && D()) {
                Class<?>[] parameterTypes = this.f11906c.getParameterTypes();
                if (genericParameterTypes.length == parameterTypes.length && parameterTypes[0] == getDeclaringClass().getEnclosingClass()) {
                    return (Type[]) Arrays.copyOfRange(genericParameterTypes, 1, genericParameterTypes.length);
                }
            }
            return genericParameterTypes;
        }

        /* access modifiers changed from: package-private */
        @Override // com.google.common.reflect.e
        public Type t() {
            Class<? super T> declaringClass = getDeclaringClass();
            TypeVariable<Class<? super T>>[] typeParameters = declaringClass.getTypeParameters();
            return typeParameters.length > 0 ? o.m(declaringClass, typeParameters) : declaringClass;
        }

        /* access modifiers changed from: package-private */
        @Override // com.google.common.reflect.e
        public final Annotation[][] u() {
            return this.f11906c.getParameterAnnotations();
        }

        /* access modifiers changed from: package-private */
        @Override // com.google.common.reflect.e
        public final Object y(Object obj, Object[] objArr) throws InvocationTargetException, IllegalAccessException {
            try {
                return this.f11906c.newInstance(objArr);
            } catch (InstantiationException e7) {
                throw new RuntimeException(this.f11906c + " failed.", e7);
            }
        }

        @Override // com.google.common.reflect.e
        public final boolean z() {
            return false;
        }
    }

    /* access modifiers changed from: package-private */
    public static class b<T> extends e<T, Object> {

        /* renamed from: c  reason: collision with root package name */
        final Method f11907c;

        b(Method method) {
            super(method);
            this.f11907c = method;
        }

        @Override // com.google.common.reflect.e
        public final boolean A() {
            return this.f11907c.isVarArgs();
        }

        @Override // java.lang.reflect.GenericDeclaration
        public final TypeVariable<?>[] getTypeParameters() {
            return this.f11907c.getTypeParameters();
        }

        /* access modifiers changed from: package-private */
        @Override // com.google.common.reflect.e
        public AnnotatedType[] o() {
            return this.f11907c.getAnnotatedParameterTypes();
        }

        @Override // com.google.common.reflect.e
        public AnnotatedType p() {
            return this.f11907c.getAnnotatedReturnType();
        }

        /* access modifiers changed from: package-private */
        @Override // com.google.common.reflect.e
        public Type[] r() {
            return this.f11907c.getGenericExceptionTypes();
        }

        /* access modifiers changed from: package-private */
        @Override // com.google.common.reflect.e
        public Type[] s() {
            return this.f11907c.getGenericParameterTypes();
        }

        /* access modifiers changed from: package-private */
        @Override // com.google.common.reflect.e
        public Type t() {
            return this.f11907c.getGenericReturnType();
        }

        /* access modifiers changed from: package-private */
        @Override // com.google.common.reflect.e
        public final Annotation[][] u() {
            return this.f11907c.getParameterAnnotations();
        }

        /* access modifiers changed from: package-private */
        @Override // com.google.common.reflect.e
        public final Object y(Object obj, Object[] objArr) throws InvocationTargetException, IllegalAccessException {
            return this.f11907c.invoke(obj, objArr);
        }

        @Override // com.google.common.reflect.e
        public final boolean z() {
            return !c() && !f() && !i() && !Modifier.isFinal(getDeclaringClass().getModifiers());
        }
    }

    <M extends AccessibleObject & Member> e(M m7) {
        super(m7);
    }

    public static <T> e<T, T> m(Constructor<T> constructor) {
        return new a(constructor);
    }

    public static e<?, Object> n(Method method) {
        return new b(method);
    }

    public abstract boolean A();

    /* JADX DEBUG: Multi-variable search result rejected for r3v0, resolved type: com.google.common.reflect.e<T, R> */
    /* JADX WARN: Multi-variable type inference failed */
    public final <R1 extends R> e<T, R1> B(m<R1> mVar) {
        if (mVar.O(w())) {
            return this;
        }
        throw new IllegalArgumentException("Invokable is known to return " + w() + ", not " + mVar);
    }

    public final <R1 extends R> e<T, R1> C(Class<R1> cls) {
        return B(m.U(cls));
    }

    @Override // com.google.common.reflect.c
    public m<T> a() {
        return m.U(getDeclaringClass());
    }

    @Override // com.google.common.reflect.c
    public /* bridge */ /* synthetic */ boolean equals(Object obj) {
        return super.equals(obj);
    }

    @Override // java.lang.reflect.Member, com.google.common.reflect.c
    public final Class<? super T> getDeclaringClass() {
        return (Class<? super T>) super.getDeclaringClass();
    }

    @Override // com.google.common.reflect.c
    public /* bridge */ /* synthetic */ int hashCode() {
        return super.hashCode();
    }

    /* access modifiers changed from: package-private */
    public abstract AnnotatedType[] o();

    public abstract AnnotatedType p();

    public final t5<m<? extends Throwable>> q() {
        t5.b t7 = t5.t();
        for (Type type : r()) {
            t7.a(m.V(type));
        }
        return t7.e();
    }

    /* access modifiers changed from: package-private */
    public abstract Type[] r();

    /* access modifiers changed from: package-private */
    public abstract Type[] s();

    /* access modifiers changed from: package-private */
    public abstract Type t();

    @Override // com.google.common.reflect.c
    public /* bridge */ /* synthetic */ String toString() {
        return super.toString();
    }

    /* access modifiers changed from: package-private */
    public abstract Annotation[][] u();

    public final t5<g> v() {
        Type[] s7 = s();
        Annotation[][] u7 = u();
        AnnotatedType[] o7 = o();
        t5.b t7 = t5.t();
        for (int i7 = 0; i7 < s7.length; i7++) {
            t7.a(new g(this, i7, m.V(s7[i7]), u7[i7], o7[i7]));
        }
        return t7.e();
    }

    public final m<? extends R> w() {
        return (m<? extends R>) m.V(t());
    }

    @p0.a
    public final R x(T t7, Object... objArr) throws InvocationTargetException, IllegalAccessException {
        return (R) y(t7, (Object[]) Preconditions.checkNotNull(objArr));
    }

    /* access modifiers changed from: package-private */
    public abstract Object y(Object obj, Object[] objArr) throws InvocationTargetException, IllegalAccessException;

    public abstract boolean z();
}
