package com.google.common.reflect;

import com.google.common.base.Function;
import com.google.common.base.Joiner;
import com.google.common.base.Objects;
import com.google.common.base.Preconditions;
import com.google.common.base.Predicates;
import com.google.common.collect.h6;
import com.google.common.collect.le;
import com.google.common.collect.t5;
import com.google.common.collect.t8;
import java.io.Serializable;
import java.lang.reflect.AnnotatedElement;
import java.lang.reflect.Array;
import java.lang.reflect.GenericArrayType;
import java.lang.reflect.GenericDeclaration;
import java.lang.reflect.InvocationHandler;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Proxy;
import java.lang.reflect.Type;
import java.lang.reflect.TypeVariable;
import java.lang.reflect.WildcardType;
import java.security.AccessControlException;
import java.util.Arrays;
import java.util.Collection;
import java.util.Map;
import java.util.concurrent.atomic.AtomicReference;
import kotlin.text.h0;

/* access modifiers changed from: package-private */
public final class o {

    /* renamed from: a  reason: collision with root package name */
    private static final Function<Type, String> f11960a = new a();

    /* renamed from: b  reason: collision with root package name */
    private static final Joiner f11961b = Joiner.on(", ").useForNull("null");

    static class a implements Function<Type, String> {
        a() {
        }

        /* renamed from: a */
        public String apply(Type type) {
            return e.f11973y.c(type);
        }
    }

    /* access modifiers changed from: package-private */
    public static class b extends n {

        /* renamed from: b  reason: collision with root package name */
        final /* synthetic */ AtomicReference f11962b;

        b(AtomicReference atomicReference) {
            this.f11962b = atomicReference;
        }

        /* access modifiers changed from: package-private */
        @Override // com.google.common.reflect.n
        public void b(Class<?> cls) {
            this.f11962b.set(cls.getComponentType());
        }

        /* access modifiers changed from: package-private */
        @Override // com.google.common.reflect.n
        public void c(GenericArrayType genericArrayType) {
            this.f11962b.set(genericArrayType.getGenericComponentType());
        }

        /* access modifiers changed from: package-private */
        @Override // com.google.common.reflect.n
        public void e(TypeVariable<?> typeVariable) {
            this.f11962b.set(o.q(typeVariable.getBounds()));
        }

        /* access modifiers changed from: package-private */
        @Override // com.google.common.reflect.n
        public void f(WildcardType wildcardType) {
            this.f11962b.set(o.q(wildcardType.getUpperBounds()));
        }
    }

    /* access modifiers changed from: private */
    public enum c {
        OWNED_BY_ENCLOSING_CLASS {
            /* access modifiers changed from: package-private */
            @Override // com.google.common.reflect.o.c
            public Class<?> b(Class<?> cls) {
                return cls.getEnclosingClass();
            }
        },
        LOCAL_CLASS_HAS_NO_OWNER {
            /* access modifiers changed from: package-private */
            @Override // com.google.common.reflect.o.c
            public Class<?> b(Class<?> cls) {
                if (cls.isLocalClass()) {
                    return null;
                }
                return cls.getEnclosingClass();
            }
        };
        

        /* renamed from: p  reason: collision with root package name */
        static final c f11965p = a();

        /* access modifiers changed from: package-private */
        public class b<T> {
            b() {
            }
        }

        /* access modifiers changed from: package-private */
        public static class d extends b<String> {
            d() {
            }
        }

        private static c a() {
            new d();
            ParameterizedType parameterizedType = (ParameterizedType) d.class.getGenericSuperclass();
            c[] values = values();
            for (c cVar : values) {
                if (cVar.b(b.class) == parameterizedType.getOwnerType()) {
                    return cVar;
                }
            }
            throw new AssertionError();
        }

        /* access modifiers changed from: package-private */
        public abstract Class<?> b(Class<?> cls);

        /* synthetic */ c(a aVar) {
            this();
        }
    }

    /* access modifiers changed from: private */
    public static final class d implements GenericArrayType, Serializable {

        /* renamed from: g  reason: collision with root package name */
        private static final long f11967g = 0;

        /* renamed from: f  reason: collision with root package name */
        private final Type f11968f;

        d(Type type) {
            this.f11968f = e.f11973y.e(type);
        }

        public boolean equals(Object obj) {
            if (obj instanceof GenericArrayType) {
                return Objects.equal(getGenericComponentType(), ((GenericArrayType) obj).getGenericComponentType());
            }
            return false;
        }

        public Type getGenericComponentType() {
            return this.f11968f;
        }

        public int hashCode() {
            return this.f11968f.hashCode();
        }

        public String toString() {
            return o.t(this.f11968f) + "[]";
        }
    }

    /* access modifiers changed from: package-private */
    public enum e {
        JAVA6 {
            /* access modifiers changed from: package-private */
            @Override // com.google.common.reflect.o.e
            public Type e(Type type) {
                Preconditions.checkNotNull(type);
                if (!(type instanceof Class)) {
                    return type;
                }
                Class cls = (Class) type;
                return cls.isArray() ? new d(cls.getComponentType()) : type;
            }

            /* access modifiers changed from: package-private */
            /* renamed from: f */
            public GenericArrayType b(Type type) {
                return new d(type);
            }
        },
        JAVA7 {
            /* access modifiers changed from: package-private */
            @Override // com.google.common.reflect.o.e
            public Type b(Type type) {
                return type instanceof Class ? o.i((Class) type) : new d(type);
            }

            /* access modifiers changed from: package-private */
            @Override // com.google.common.reflect.o.e
            public Type e(Type type) {
                return (Type) Preconditions.checkNotNull(type);
            }
        },
        JAVA8 {
            /* access modifiers changed from: package-private */
            @Override // com.google.common.reflect.o.e
            public Type b(Type type) {
                return e.JAVA7.b(type);
            }

            /* access modifiers changed from: package-private */
            @Override // com.google.common.reflect.o.e
            public String c(Type type) {
                try {
                    return (String) Type.class.getMethod("getTypeName", new Class[0]).invoke(type, new Object[0]);
                } catch (NoSuchMethodException unused) {
                    throw new AssertionError("Type.getTypeName should be available in Java 8");
                } catch (IllegalAccessException | InvocationTargetException e7) {
                    throw new RuntimeException(e7);
                }
            }

            /* access modifiers changed from: package-private */
            @Override // com.google.common.reflect.o.e
            public Type e(Type type) {
                return e.JAVA7.e(type);
            }
        },
        JAVA9 {
            /* access modifiers changed from: package-private */
            @Override // com.google.common.reflect.o.e
            public boolean a() {
                return false;
            }

            /* access modifiers changed from: package-private */
            @Override // com.google.common.reflect.o.e
            public Type b(Type type) {
                return e.JAVA8.b(type);
            }

            /* access modifiers changed from: package-private */
            @Override // com.google.common.reflect.o.e
            public String c(Type type) {
                return e.JAVA8.c(type);
            }

            /* access modifiers changed from: package-private */
            @Override // com.google.common.reflect.o.e
            public Type e(Type type) {
                return e.JAVA8.e(type);
            }
        };
        

        /* renamed from: y  reason: collision with root package name */
        static final e f11973y;

        /* renamed from: com.google.common.reflect.o$e$e  reason: collision with other inner class name */
        static class C0168e extends i<Map.Entry<String, int[][]>> {
            C0168e() {
            }
        }

        static class f extends i<int[]> {
            f() {
            }
        }

        static {
            a aVar;
            b bVar;
            c cVar;
            d dVar;
            if (AnnotatedElement.class.isAssignableFrom(TypeVariable.class)) {
                if (new C0168e().a().toString().contains("java.util.Map.java.util.Map")) {
                    f11973y = cVar;
                } else {
                    f11973y = dVar;
                }
            } else if (new f().a() instanceof Class) {
                f11973y = bVar;
            } else {
                f11973y = aVar;
            }
        }

        /* access modifiers changed from: package-private */
        public boolean a() {
            return true;
        }

        /* access modifiers changed from: package-private */
        public abstract Type b(Type type);

        /* access modifiers changed from: package-private */
        public String c(Type type) {
            return o.t(type);
        }

        /* access modifiers changed from: package-private */
        public final t5<Type> d(Type[] typeArr) {
            t5.b t7 = t5.t();
            for (Type type : typeArr) {
                t7.a(e(type));
            }
            return t7.e();
        }

        /* access modifiers changed from: package-private */
        public abstract Type e(Type type);

        /* synthetic */ e(a aVar) {
            this();
        }
    }

    /* access modifiers changed from: package-private */
    public static final class f<X> {

        /* renamed from: a  reason: collision with root package name */
        static final boolean f11974a = (!f.class.getTypeParameters()[0].equals(o.l(f.class, "X", new Type[0])));

        f() {
        }
    }

    /* access modifiers changed from: private */
    public static final class g implements ParameterizedType, Serializable {

        /* renamed from: x  reason: collision with root package name */
        private static final long f11975x = 0;

        /* renamed from: f  reason: collision with root package name */
        private final Type f11976f;

        /* renamed from: g  reason: collision with root package name */
        private final t5<Type> f11977g;

        /* renamed from: p  reason: collision with root package name */
        private final Class<?> f11978p;

        g(Type type, Class<?> cls, Type[] typeArr) {
            Preconditions.checkNotNull(cls);
            Preconditions.checkArgument(typeArr.length == cls.getTypeParameters().length);
            o.g(typeArr, "type parameter");
            this.f11976f = type;
            this.f11978p = cls;
            this.f11977g = e.f11973y.d(typeArr);
        }

        public boolean equals(Object obj) {
            if (!(obj instanceof ParameterizedType)) {
                return false;
            }
            ParameterizedType parameterizedType = (ParameterizedType) obj;
            return getRawType().equals(parameterizedType.getRawType()) && Objects.equal(getOwnerType(), parameterizedType.getOwnerType()) && Arrays.equals(getActualTypeArguments(), parameterizedType.getActualTypeArguments());
        }

        public Type[] getActualTypeArguments() {
            return o.s(this.f11977g);
        }

        public Type getOwnerType() {
            return this.f11976f;
        }

        public Type getRawType() {
            return this.f11978p;
        }

        public int hashCode() {
            Type type = this.f11976f;
            return this.f11978p.hashCode() ^ ((type == null ? 0 : type.hashCode()) ^ this.f11977g.hashCode());
        }

        public String toString() {
            StringBuilder sb = new StringBuilder();
            if (this.f11976f != null) {
                e eVar = e.f11973y;
                if (eVar.a()) {
                    sb.append(eVar.c(this.f11976f));
                    sb.append('.');
                }
            }
            sb.append(this.f11978p.getName());
            sb.append(h0.f20272e);
            sb.append(o.f11961b.join(t8.S(this.f11977g, o.f11960a)));
            sb.append(h0.f20273f);
            return sb.toString();
        }
    }

    /* access modifiers changed from: private */
    public static final class h<D extends GenericDeclaration> {

        /* renamed from: a  reason: collision with root package name */
        private final D f11979a;

        /* renamed from: b  reason: collision with root package name */
        private final String f11980b;

        /* renamed from: c  reason: collision with root package name */
        private final t5<Type> f11981c;

        h(D d7, String str, Type[] typeArr) {
            o.g(typeArr, "bound for type variable");
            this.f11979a = (D) ((GenericDeclaration) Preconditions.checkNotNull(d7));
            this.f11980b = (String) Preconditions.checkNotNull(str);
            this.f11981c = t5.L(typeArr);
        }

        public Type[] a() {
            return o.s(this.f11981c);
        }

        public D b() {
            return this.f11979a;
        }

        public String c() {
            return this.f11980b;
        }

        public String d() {
            return this.f11980b;
        }

        public boolean equals(Object obj) {
            if (f.f11974a) {
                if (obj == null || !Proxy.isProxyClass(obj.getClass()) || !(Proxy.getInvocationHandler(obj) instanceof i)) {
                    return false;
                }
                h hVar = ((i) Proxy.getInvocationHandler(obj)).f11983a;
                return this.f11980b.equals(hVar.c()) && this.f11979a.equals(hVar.b()) && this.f11981c.equals(hVar.f11981c);
            } else if (!(obj instanceof TypeVariable)) {
                return false;
            } else {
                TypeVariable typeVariable = (TypeVariable) obj;
                return this.f11980b.equals(typeVariable.getName()) && this.f11979a.equals(typeVariable.getGenericDeclaration());
            }
        }

        public int hashCode() {
            return this.f11980b.hashCode() ^ this.f11979a.hashCode();
        }

        public String toString() {
            return this.f11980b;
        }
    }

    /* access modifiers changed from: private */
    public static final class i implements InvocationHandler {

        /* renamed from: b  reason: collision with root package name */
        private static final h6<String, Method> f11982b;

        /* renamed from: a  reason: collision with root package name */
        private final h<?> f11983a;

        static {
            h6.b b7 = h6.b();
            Method[] methods = h.class.getMethods();
            for (Method method : methods) {
                if (method.getDeclaringClass().equals(h.class)) {
                    try {
                        method.setAccessible(true);
                    } catch (AccessControlException unused) {
                    }
                    b7.f(method.getName(), method);
                }
            }
            f11982b = b7.a();
        }

        i(h<?> hVar) {
            this.f11983a = hVar;
        }

        @Override // java.lang.reflect.InvocationHandler
        public Object invoke(Object obj, Method method, Object[] objArr) throws Throwable {
            String name = method.getName();
            Method method2 = f11982b.get(name);
            if (method2 != null) {
                try {
                    return method2.invoke(this.f11983a, objArr);
                } catch (InvocationTargetException e7) {
                    throw e7.getCause();
                }
            } else {
                throw new UnsupportedOperationException(name);
            }
        }
    }

    /* access modifiers changed from: package-private */
    public static final class j implements WildcardType, Serializable {

        /* renamed from: p  reason: collision with root package name */
        private static final long f11984p = 0;

        /* renamed from: f  reason: collision with root package name */
        private final t5<Type> f11985f;

        /* renamed from: g  reason: collision with root package name */
        private final t5<Type> f11986g;

        j(Type[] typeArr, Type[] typeArr2) {
            o.g(typeArr, "lower bound for wildcard");
            o.g(typeArr2, "upper bound for wildcard");
            e eVar = e.f11973y;
            this.f11985f = eVar.d(typeArr);
            this.f11986g = eVar.d(typeArr2);
        }

        public boolean equals(Object obj) {
            if (!(obj instanceof WildcardType)) {
                return false;
            }
            WildcardType wildcardType = (WildcardType) obj;
            return this.f11985f.equals(Arrays.asList(wildcardType.getLowerBounds())) && this.f11986g.equals(Arrays.asList(wildcardType.getUpperBounds()));
        }

        public Type[] getLowerBounds() {
            return o.s(this.f11985f);
        }

        public Type[] getUpperBounds() {
            return o.s(this.f11986g);
        }

        public int hashCode() {
            return this.f11986g.hashCode() ^ this.f11985f.hashCode();
        }

        public String toString() {
            StringBuilder sb = new StringBuilder("?");
            le<Type> n7 = this.f11985f.iterator();
            while (n7.hasNext()) {
                sb.append(" super ");
                sb.append(e.f11973y.c(n7.next()));
            }
            for (Type type : o.h(this.f11986g)) {
                sb.append(" extends ");
                sb.append(e.f11973y.c(type));
            }
            return sb.toString();
        }
    }

    private o() {
    }

    /* access modifiers changed from: private */
    public static void g(Type[] typeArr, String str) {
        for (Type type : typeArr) {
            if (type instanceof Class) {
                Class cls = (Class) type;
                Preconditions.checkArgument(!cls.isPrimitive(), "Primitive type '%s' used as %s", cls, str);
            }
        }
    }

    /* access modifiers changed from: private */
    public static Iterable<Type> h(Iterable<Type> iterable) {
        return t8.o(iterable, Predicates.not(Predicates.equalTo(Object.class)));
    }

    static Class<?> i(Class<?> cls) {
        return Array.newInstance(cls, 0).getClass();
    }

    static Type j(Type type) {
        Preconditions.checkNotNull(type);
        AtomicReference atomicReference = new AtomicReference();
        new b(atomicReference).a(type);
        return (Type) atomicReference.get();
    }

    static Type k(Type type) {
        if (!(type instanceof WildcardType)) {
            return e.f11973y.b(type);
        }
        WildcardType wildcardType = (WildcardType) type;
        Type[] lowerBounds = wildcardType.getLowerBounds();
        boolean z7 = true;
        Preconditions.checkArgument(lowerBounds.length <= 1, "Wildcard cannot have more than one lower bounds.");
        if (lowerBounds.length == 1) {
            return r(k(lowerBounds[0]));
        }
        Type[] upperBounds = wildcardType.getUpperBounds();
        if (upperBounds.length != 1) {
            z7 = false;
        }
        Preconditions.checkArgument(z7, "Wildcard should have only one upper bound.");
        return p(k(upperBounds[0]));
    }

    static <D extends GenericDeclaration> TypeVariable<D> l(D d7, String str, Type... typeArr) {
        if (typeArr.length == 0) {
            typeArr = new Type[]{Object.class};
        }
        return o(d7, str, typeArr);
    }

    static ParameterizedType m(Class<?> cls, Type... typeArr) {
        return new g(c.f11965p.b(cls), cls, typeArr);
    }

    static ParameterizedType n(Type type, Class<?> cls, Type... typeArr) {
        if (type == null) {
            return m(cls, typeArr);
        }
        Preconditions.checkNotNull(typeArr);
        Preconditions.checkArgument(cls.getEnclosingClass() != null, "Owner type for unenclosed %s", cls);
        return new g(type, cls, typeArr);
    }

    private static <D extends GenericDeclaration> TypeVariable<D> o(D d7, String str, Type[] typeArr) {
        return (TypeVariable) h.d(TypeVariable.class, new i(new h(d7, str, typeArr)));
    }

    @m0.d
    static WildcardType p(Type type) {
        return new j(new Type[0], new Type[]{type});
    }

    /* access modifiers changed from: private */
    public static Type q(Type[] typeArr) {
        for (Type type : typeArr) {
            Type j7 = j(type);
            if (j7 != null) {
                if (j7 instanceof Class) {
                    Class cls = (Class) j7;
                    if (cls.isPrimitive()) {
                        return cls;
                    }
                }
                return p(j7);
            }
        }
        return null;
    }

    @m0.d
    static WildcardType r(Type type) {
        return new j(new Type[]{type}, new Type[]{Object.class});
    }

    /* access modifiers changed from: private */
    public static Type[] s(Collection<Type> collection) {
        return (Type[]) collection.toArray(new Type[collection.size()]);
    }

    static String t(Type type) {
        return type instanceof Class ? ((Class) type).getName() : type.toString();
    }
}
