package org.bouncycastle2.jce.provider;

import java.math.BigInteger;
import java.security.InvalidAlgorithmParameterException;
import java.security.InvalidKeyException;
import java.security.Key;
import java.security.SecureRandom;
import java.security.spec.AlgorithmParameterSpec;
import java.util.Hashtable;
import javax.crypto.KeyAgreementSpi;
import javax.crypto.SecretKey;
import javax.crypto.ShortBufferException;
import javax.crypto.interfaces.DHPrivateKey;
import javax.crypto.interfaces.DHPublicKey;
import javax.crypto.spec.DHParameterSpec;
import javax.crypto.spec.SecretKeySpec;
import org.bouncycastle2.crypto.params.c;
import v5.h;

public class q extends KeyAgreementSpi {

    /* renamed from: f  reason: collision with root package name */
    private static final Hashtable f24442f;

    /* renamed from: a  reason: collision with root package name */
    private BigInteger f24443a;

    /* renamed from: b  reason: collision with root package name */
    private BigInteger f24444b;

    /* renamed from: c  reason: collision with root package name */
    private BigInteger f24445c;

    /* renamed from: d  reason: collision with root package name */
    private BigInteger f24446d;

    /* renamed from: e  reason: collision with root package name */
    private SecureRandom f24447e;

    static {
        Hashtable hashtable = new Hashtable();
        f24442f = hashtable;
        Integer num = new Integer(64);
        Integer num2 = new Integer(192);
        Integer num3 = new Integer(128);
        hashtable.put("DES", num);
        hashtable.put("DESEDE", num2);
        hashtable.put("BLOWFISH", num3);
    }

    private byte[] a(BigInteger bigInteger) {
        byte[] byteArray = bigInteger.toByteArray();
        if (byteArray[0] != 0) {
            return byteArray;
        }
        int length = byteArray.length - 1;
        byte[] bArr = new byte[length];
        System.arraycopy(byteArray, 1, bArr, 0, length);
        return bArr;
    }

    /* access modifiers changed from: protected */
    @Override // javax.crypto.KeyAgreementSpi
    public Key engineDoPhase(Key key, boolean z7) throws InvalidKeyException, IllegalStateException {
        if (this.f24443a == null) {
            throw new IllegalStateException("Diffie-Hellman not initialised.");
        } else if (key instanceof DHPublicKey) {
            DHPublicKey dHPublicKey = (DHPublicKey) key;
            if (!dHPublicKey.getParams().getG().equals(this.f24445c) || !dHPublicKey.getParams().getP().equals(this.f24444b)) {
                throw new InvalidKeyException("DHPublicKey not for this KeyAgreement!");
            } else if (z7) {
                this.f24446d = dHPublicKey.getY().modPow(this.f24443a, this.f24444b);
                return null;
            } else {
                BigInteger modPow = dHPublicKey.getY().modPow(this.f24443a, this.f24444b);
                this.f24446d = modPow;
                return new s(modPow, dHPublicKey.getParams());
            }
        } else {
            throw new InvalidKeyException("DHKeyAgreement doPhase requires DHPublicKey");
        }
    }

    /* access modifiers changed from: protected */
    @Override // javax.crypto.KeyAgreementSpi
    public int engineGenerateSecret(byte[] bArr, int i7) throws IllegalStateException, ShortBufferException {
        if (this.f24443a != null) {
            byte[] a8 = a(this.f24446d);
            if (bArr.length - i7 >= a8.length) {
                System.arraycopy(a8, 0, bArr, i7, a8.length);
                return a8.length;
            }
            throw new ShortBufferException("DHKeyAgreement - buffer too short");
        }
        throw new IllegalStateException("Diffie-Hellman not initialised.");
    }

    /* access modifiers changed from: protected */
    @Override // javax.crypto.KeyAgreementSpi
    public void engineInit(Key key, SecureRandom secureRandom) throws InvalidKeyException {
        if (key instanceof DHPrivateKey) {
            DHPrivateKey dHPrivateKey = (DHPrivateKey) key;
            this.f24447e = secureRandom;
            this.f24444b = dHPrivateKey.getParams().getP();
            this.f24445c = dHPrivateKey.getParams().getG();
            BigInteger x7 = dHPrivateKey.getX();
            this.f24446d = x7;
            this.f24443a = x7;
            return;
        }
        throw new InvalidKeyException("DHKeyAgreement requires DHPrivateKey");
    }

    /* access modifiers changed from: protected */
    @Override // javax.crypto.KeyAgreementSpi
    public SecretKey engineGenerateSecret(String str) {
        if (this.f24443a != null) {
            String g7 = h.g(str);
            byte[] a8 = a(this.f24446d);
            Hashtable hashtable = f24442f;
            if (!hashtable.containsKey(g7)) {
                return new SecretKeySpec(a8, str);
            }
            int intValue = ((Integer) hashtable.get(g7)).intValue() / 8;
            byte[] bArr = new byte[intValue];
            System.arraycopy(a8, 0, bArr, 0, intValue);
            if (g7.startsWith("DES")) {
                c.c(bArr);
            }
            return new SecretKeySpec(bArr, str);
        }
        throw new IllegalStateException("Diffie-Hellman not initialised.");
    }

    /* access modifiers changed from: protected */
    @Override // javax.crypto.KeyAgreementSpi
    public void engineInit(Key key, AlgorithmParameterSpec algorithmParameterSpec, SecureRandom secureRandom) throws InvalidKeyException, InvalidAlgorithmParameterException {
        DHParameterSpec dHParameterSpec;
        if (key instanceof DHPrivateKey) {
            DHPrivateKey dHPrivateKey = (DHPrivateKey) key;
            this.f24447e = secureRandom;
            if (algorithmParameterSpec == null) {
                this.f24444b = dHPrivateKey.getParams().getP();
                dHParameterSpec = dHPrivateKey.getParams();
            } else if (algorithmParameterSpec instanceof DHParameterSpec) {
                dHParameterSpec = (DHParameterSpec) algorithmParameterSpec;
                this.f24444b = dHParameterSpec.getP();
            } else {
                throw new InvalidAlgorithmParameterException("DHKeyAgreement only accepts DHParameterSpec");
            }
            this.f24445c = dHParameterSpec.getG();
            BigInteger x7 = dHPrivateKey.getX();
            this.f24446d = x7;
            this.f24443a = x7;
            return;
        }
        throw new InvalidKeyException("DHKeyAgreement requires DHPrivateKey for initialisation");
    }

    /* access modifiers changed from: protected */
    @Override // javax.crypto.KeyAgreementSpi
    public byte[] engineGenerateSecret() throws IllegalStateException {
        if (this.f24443a != null) {
            return a(this.f24446d);
        }
        throw new IllegalStateException("Diffie-Hellman not initialised.");
    }
}
