package org.bouncycastle2.jce.provider;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.math.BigInteger;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;
import java.security.NoSuchProviderException;
import java.security.Principal;
import java.security.PublicKey;
import java.security.Signature;
import java.security.SignatureException;
import java.security.cert.CRLException;
import java.security.cert.Certificate;
import java.security.cert.X509CRL;
import java.security.cert.X509CRLEntry;
import java.security.cert.X509Certificate;
import java.util.Collections;
import java.util.Date;
import java.util.Enumeration;
import java.util.HashSet;
import java.util.Set;
import javax.security.auth.x500.X500Principal;
import org.bouncycastle2.asn1.c;
import org.bouncycastle2.asn1.k;
import org.bouncycastle2.asn1.x509.a1;
import org.bouncycastle2.asn1.x509.b0;
import org.bouncycastle2.asn1.x509.o;
import org.bouncycastle2.asn1.x509.q0;
import org.bouncycastle2.asn1.x509.z0;
import org.bouncycastle2.jce.g;
import x5.a;

public class w1 extends X509CRL {

    /* renamed from: f  reason: collision with root package name */
    private o f24558f;

    /* renamed from: g  reason: collision with root package name */
    private String f24559g;

    /* renamed from: p  reason: collision with root package name */
    private byte[] f24560p;

    /* renamed from: x  reason: collision with root package name */
    private boolean f24561x;

    public w1(o oVar) throws CRLException {
        this.f24558f = oVar;
        try {
            this.f24559g = b2.b(oVar.q());
            if (oVar.q().m() != null) {
                this.f24560p = ((c) oVar.q().m()).f();
            } else {
                this.f24560p = null;
            }
            this.f24561x = c();
        } catch (Exception e7) {
            throw new CRLException("CRL contents invalid: " + e7);
        }
    }

    private Set a(boolean z7) {
        a1 j7;
        if (getVersion() != 2 || (j7 = this.f24558f.r().j()) == null) {
            return null;
        }
        HashSet hashSet = new HashSet();
        Enumeration n7 = j7.n();
        while (n7.hasMoreElements()) {
            org.bouncycastle2.asn1.a1 a1Var = (org.bouncycastle2.asn1.a1) n7.nextElement();
            if (z7 == j7.k(a1Var).c()) {
                hashSet.add(a1Var.m());
            }
        }
        return hashSet;
    }

    private boolean c() throws CRLException {
        byte[] extensionValue = getExtensionValue(a1.f22744d6.m());
        if (extensionValue == null) {
            return false;
        }
        try {
            return b0.m(a.a(extensionValue)).p();
        } catch (Exception e7) {
            throw new n("Exception reading IssuingDistributionPoint", e7);
        }
    }

    private Set d() {
        HashSet hashSet = new HashSet();
        Enumeration n7 = this.f24558f.n();
        X500Principal issuerX500Principal = getIssuerX500Principal();
        while (n7.hasMoreElements()) {
            v1 v1Var = new v1((q0.a) n7.nextElement(), this.f24561x, issuerX500Principal);
            hashSet.add(v1Var);
            issuerX500Principal = v1Var.getCertificateIssuer();
        }
        return hashSet;
    }

    @Override // java.security.cert.X509Extension
    public Set getCriticalExtensionOIDs() {
        return a(true);
    }

    @Override // java.security.cert.X509CRL
    public byte[] getEncoded() throws CRLException {
        try {
            return this.f24558f.h(c.f22322f);
        } catch (IOException e7) {
            throw new CRLException(e7.toString());
        }
    }

    public byte[] getExtensionValue(String str) {
        z0 k7;
        a1 j7 = this.f24558f.r().j();
        if (j7 == null || (k7 = j7.k(new org.bouncycastle2.asn1.a1(str))) == null) {
            return null;
        }
        try {
            return k7.b().g();
        } catch (Exception e7) {
            throw new IllegalStateException("error parsing " + e7.toString());
        }
    }

    public Principal getIssuerDN() {
        return new g(this.f24558f.l());
    }

    public X500Principal getIssuerX500Principal() {
        try {
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            new k(byteArrayOutputStream).e(this.f24558f.l());
            return new X500Principal(byteArrayOutputStream.toByteArray());
        } catch (IOException unused) {
            throw new IllegalStateException("can't encode issuer DN");
        }
    }

    public Date getNextUpdate() {
        if (this.f24558f.m() != null) {
            return this.f24558f.m().j();
        }
        return null;
    }

    @Override // java.security.cert.X509Extension
    public Set getNonCriticalExtensionOIDs() {
        return a(false);
    }

    @Override // java.security.cert.X509CRL
    public X509CRLEntry getRevokedCertificate(BigInteger bigInteger) {
        Enumeration n7 = this.f24558f.n();
        X500Principal issuerX500Principal = getIssuerX500Principal();
        while (n7.hasMoreElements()) {
            q0.a aVar = (q0.a) n7.nextElement();
            v1 v1Var = new v1(aVar, this.f24561x, issuerX500Principal);
            if (bigInteger.equals(aVar.l().p())) {
                return v1Var;
            }
            issuerX500Principal = v1Var.getCertificateIssuer();
        }
        return null;
    }

    @Override // java.security.cert.X509CRL
    public Set getRevokedCertificates() {
        Set d7 = d();
        if (!d7.isEmpty()) {
            return Collections.unmodifiableSet(d7);
        }
        return null;
    }

    public String getSigAlgName() {
        return this.f24559g;
    }

    public String getSigAlgOID() {
        return this.f24558f.q().l().m();
    }

    public byte[] getSigAlgParams() {
        byte[] bArr = this.f24560p;
        if (bArr == null) {
            return null;
        }
        int length = bArr.length;
        byte[] bArr2 = new byte[length];
        System.arraycopy(bArr, 0, bArr2, 0, length);
        return bArr2;
    }

    public byte[] getSignature() {
        return this.f24558f.p().m();
    }

    @Override // java.security.cert.X509CRL
    public byte[] getTBSCertList() throws CRLException {
        try {
            return this.f24558f.r().h(c.f22322f);
        } catch (IOException e7) {
            throw new CRLException(e7.toString());
        }
    }

    public Date getThisUpdate() {
        return this.f24558f.s().j();
    }

    public int getVersion() {
        return this.f24558f.t();
    }

    public boolean hasUnsupportedCriticalExtension() {
        Set criticalExtensionOIDs = getCriticalExtensionOIDs();
        if (criticalExtensionOIDs == null) {
            return false;
        }
        criticalExtensionOIDs.remove(p1.f24427d);
        criticalExtensionOIDs.remove(p1.f24429f);
        return !criticalExtensionOIDs.isEmpty();
    }

    public boolean isRevoked(Certificate certificate) {
        if (certificate.getType().equals("X.509")) {
            q0.a[] o7 = this.f24558f.o();
            if (o7 != null) {
                BigInteger serialNumber = ((X509Certificate) certificate).getSerialNumber();
                for (q0.a aVar : o7) {
                    if (aVar.l().p().equals(serialNumber)) {
                        return true;
                    }
                }
            }
            return false;
        }
        throw new RuntimeException("X.509 CRL used with non X.509 Cert");
    }

    /*  JADX ERROR: JadxOverflowException in pass: RegionMakerVisitor
        jadx.core.utils.exceptions.JadxOverflowException: Regions count limit reached
        	at jadx.core.utils.ErrorsCounter.addError(ErrorsCounter.java:57)
        	at jadx.core.utils.ErrorsCounter.error(ErrorsCounter.java:31)
        	at jadx.core.dex.attributes.nodes.NotificationAttrNode.addError(NotificationAttrNode.java:15)
        */
    /* JADX WARNING: Removed duplicated region for block: B:12:0x009d  */
    /* JADX WARNING: Removed duplicated region for block: B:53:0x0173 A[EDGE_INSN: B:53:0x0173->B:37:0x0173 ?: BREAK  , SYNTHETIC] */
    public java.lang.String toString() {
        /*
        // Method dump skipped, instructions count: 444
        */
        throw new UnsupportedOperationException("Method not decompiled: org.bouncycastle2.jce.provider.w1.toString():java.lang.String");
    }

    @Override // java.security.cert.X509CRL
    public void verify(PublicKey publicKey) throws CRLException, NoSuchAlgorithmException, InvalidKeyException, NoSuchProviderException, SignatureException {
        verify(publicKey, "BC2");
    }

    @Override // java.security.cert.X509CRL
    public void verify(PublicKey publicKey, String str) throws CRLException, NoSuchAlgorithmException, InvalidKeyException, NoSuchProviderException, SignatureException {
        if (this.f24558f.q().equals(this.f24558f.r().q())) {
            Signature instance = Signature.getInstance(getSigAlgName(), str);
            instance.initVerify(publicKey);
            instance.update(getTBSCertList());
            if (!instance.verify(getSignature())) {
                throw new SignatureException("CRL does not verify with supplied public key.");
            }
            return;
        }
        throw new CRLException("Signature algorithm on CertificateList does not match TBSCertList.");
    }
}
